#+Title: settings.org


* 1info
  :PROPERTIES:
  :ID:       8193566d-2dd5-4368-8238-fac2fc9aa7e9
  :END:
** save custom configs in a seperate file
   :PROPERTIES:
   :ID:       e9b9538e-7693-47d3-940b-e7ca2e269ad7
   :END:
to save the custom configs in a seperate file from init.el

#+BEGIN_SRC emacs-lisp :results none
(setq custom-file "~/.emacs.d/custom.el")
(load custom-file 'noerror)
#+END_SRC


$Note The first function just reloads the Emacs configuration. The second function opens the configuration up for editing.$

** Check which OS your on
   :PROPERTIES:
   :ID:       9ed2cc7f-bf22-4a64-9850-0b8ae0e6f437
   :END:
#+begin_src emacs-lisp results none
  ; Check if system is windows
  (defun system-type-is-win ()
  (interactive)
  "Return true if system is windows"
  (string-equal system-type "windows-nt")
  )

  ;; Check if system is GNU/Linux
  (defun system-type-is-gnu ()
  (interactive)
  "Return true if system is GNU/Linux-based"
  (string-equal system-type "gnu/linux")
  )
#+end_src
** set main theme
   :PROPERTIES:
   :ID:       e829984a-842e-4903-add9-bdad670783e2
   :END:

To edit the theme file:~/.emacs.d/themes/zprime-theme.el

#+BEGIN_SRC emacs-lisp :results none
 ;;;add custom themes to list
 (add-to-list 'custom-theme-load-path "/home/zeltak/.emacs.d/themes")
 ;to load a specifc theme 
 ;(load-file "~/.emacs.d/themes/zprime-theme.el")
 ;load the choosen theme at startup 
(load-theme 'zprime t)


#+END_SRC

** custom org export options (must be on top of settings to work for reason still discovered)
   :PROPERTIES:
   :ID:       8f5d13df-7c9d-45b5-8e6f-576e51dc3dba
   :END:
 #+BEGIN_SRC emacs-lisp :results none
(setq org-export-backends (quote (ascii html icalendar latex org)))
 #+END_SRC
** add org contrib 
   :PROPERTIES:
   :ID:       6c4ab268-bbf0-4e5b-bff7-ac32ad00f6b4
   :END:
#+BEGIN_SRC emacs-lisp :results none
(add-to-list 'load-path "/home/zeltak/.emacs.g/org-mode/contrib/lisp/")
#+END_SRC
** Fonts
   :PROPERTIES:
   :ID:       2094e9ab-4a0b-4d66-aec5-e08a2a0aa52f
   :END:
#+begin_src emacs-lisp results none
; fonts in linux
(if (string= system-name "zx1voics")
;(add-to-list 'default-frame-alist '(font . "Inconsolata-16"))
;(add-to-list 'default-frame-alist '(font . "Source Code Pro-18"))
;(add-to-list 'default-frame-alist '(font . "Pragmata Pro-19"))
;(add-to-list 'default-frame-alist '(font . "Fantasque Sans Mono 14"))
(add-to-list 'default-frame-alist '(font . "fira mono 19"))
)

;; fontso in Win
;(if (system-type-is-win)
;(add-to-list 'default-frame-alist '(font . "Consolas-14"))
;)

(if (string= system-name "zbeast")
(add-to-list 'default-frame-alist '(font . "fira mono 23"))
)


;; backwards compatibility as default-buffer-file-coding-system
;; is deprecated in 23.2.
(if (boundp 'buffer-file-coding-system)
    (setq-default buffer-file-coding-system 'utf-8)
  (setq default-buffer-file-coding-system 'utf-8))
 
;; Treat clipboard input as UTF-8 string first; compound text next, etc.
(setq x-select-request-type '(UTF8_STRING COMPOUND_TEXT TEXT STRING))

;; UTF-8 as default encoding
(set-language-environment "UTF-8")
(set-charset-priority 'unicode)
(set-default-coding-systems 'utf-8)
(set-terminal-coding-system 'utf-8)
(set-keyboard-coding-system 'utf-8)
(set-selection-coding-system 'utf-8)
(prefer-coding-system 'utf-8)
(setq default-process-coding-system '(utf-8-unix . utf-8-unix))
#+end_src

#+RESULTS:
: (utf-8-unix . utf-8-unix)

* Packages
  :PROPERTIES:
  :ID:       e7933dd8-7554-4682-92d4-ea63c509c176
  :END:
@DON'T CHANGE ORDER SINCE SOME PACKAGES NEED TO ONLY LOAD AFTER OTHERS@

** hippie expand
   :PROPERTIES:
   :ID:       e93cb6ab-5e06-457d-a78b-045add644ab3
   :END:

$note its built into emacs no intsall needed$

#+BEGIN_SRC emacs-lisp :results none
  ;;  (setq dcsh-command-list '("all_registers"
  ;;                                "check_design" "check_test" "compile" "current_design"
  ;;                                "link" "uniquify"
  ;;                                "report_timing" "report_clocks" "report_constraint"
  ;;                                "get_unix_variable" "set_unix_variable"
  ;;                                "set_max_fanout"
  ;;                                "report_area" "all_clocks" "all_inputs" "all_outputs"))
  
  ;;      (defun he-dcsh-command-beg ()
  ;;        (let ((p))
  ;;          (save-excursion
  ;;            (backward-word 1)
  ;;            (setq p (point)))
  ;;          p))
  
  ;;      (defun try-expand-dcsh-command (old)
  ;;        (unless old
  ;;          (he-init-string (he-dcsh-command-beg) (point))
  ;;          (setq he-expand-list (sort
  ;;                                (all-completions he-search-string (mapcar 'list dcsh-command-list))
  ;;                                'string-lessp)))
  ;;        (while (and he-expand-list
  ;;                (he-string-member (car he-expand-list) he-tried-table))
  ;;          (setq he-expand-list (cdr he-expand-list)))
  ;;        (if (null he-expand-list)
  ;;            (progn
  ;;              (when old (he-reset-string))
  ;;              ())
  ;;          (he-substitute-string (car he-expand-list))
  ;;          (setq he-tried-table (cons (car he-expand-list) (cdr he-tried-table)))
  ;;          (setq he-expand-list (cdr he-expand-list))
  ;;          t))

  ;;  (setq hippie-expand-try-functions-list (cons 'yas/hippie-try-expand hippie-expand-try-functions-list))

  ;;  (defun my-hippie-expand-completions (&optional hippie-expand-function)
  ;;        "Return the full list of possible completions generated by `hippie-expand'.
  ;;      The optional argument can be generated with `make-hippie-expand-function'."
  ;;        (let ((this-command 'my-hippie-expand-completions)
  ;;              (last-command last-command)
  ;;              (buffer-modified (buffer-modified-p))
  ;;              (hippie-expand-function (or hippie-expand-function 'hippie-expand)))
  ;;          (flet ((ding)) ; avoid the (ding) when hippie-expand exhausts its options.
  ;;            (while (progn
  ;;                     (funcall hippie-expand-function nil)
  ;;                     (setq last-command 'my-hippie-expand-completions)
  ;;                     (not (equal he-num -1)))))
  ;;          ;; Evaluating the completions modifies the buffer, however we will finish
  ;;          ;; up in the same state that we began, and (save-current-buffer) seems a
  ;;          ;; bit heavyweight in the circumstances.
  ;;          (set-buffer-modified-p buffer-modified)
  ;;          ;; Provide the options in the order in which they are normally generated.
  ;;          (delete he-search-string (reverse he-tried-table))))
   
  ;;      (defmacro my-ido-hippie-expand-with (hippie-expand-function)
  ;;        "Generate an interactively-callable function that offers ido-based completion
  ;;      using the specified hippie-expand function."
  ;;        `(call-interactively
  ;;          (lambda (&optional selection)
  ;;            (interactive
  ;;             (let ((options (my-hippie-expand-completions ,hippie-expand-function)))
  ;;               (if options
  ;;                   (list (ido-completing-read "Completions: " options)))))
  ;;            (if selection
  ;;                (he-substitute-string selection t)
  ;;              (message "No expansion found")))))
   
  ;;      (defun my-ido-hippie-expand ()
  ;;        "Offer ido-based completion for the word at point."
  ;;        (interactive)
  ;;        (my-ido-hippie-expand-with 'hippie-expand))
   
  ;; ;; (global-set-key (kbd "<f12>") 'my-ido-hippie-expand)
  ;; ;; (global-set-key [(meta f5)] (make-hippie-expand-function
  ;; ;;                                '(try-expand-dcsh-command
  ;; ;;                                  try-expand-dabbrev-visible
  ;; ;;                                  try-expand-dabbrev
  ;; ;;                                  try-expand-dabbrev-all-buffers) t))
  ;; (global-set-key (kbd "M-/") 'hippie-expand)
  ;; ;; (global-set-key (kbd "TAB") 'hippie-expand)

#+END_SRC
  
** Ace window
   :PROPERTIES:
   :ID:       1429ffca-3d2e-4abc-8c26-851b62c3bd37
   :END:
https://github.com/abo-abo/ace-window
sets to only use homekeys 
#+BEGIN_SRC emacs-lisp :results none
(use-package ace-window
    :config
;set keys to only these 
;;    (setq aw-keys '(?a ?s ?d ?f ?g ?h ?j ?k ?l))
;;    (setq aw-keys '(?1 ?2 ?3 ?4 ?5 ))
;; set to work in frames not global! so that if only 2 windows in frames frame it would switch between them 
(setq aw-scope 'frame)
;; set to true if you want to darken the background during switch
(setq aw-background nil)
;; When non-nil, ace-window will issue a read-char even for one window- you want it nil!
(setq aw-dispatch-always nil)


)
#+END_SRC
arch
https://github.com/tam17aki/ace-isearch
*** start ace-isearch
    :PROPERTIES:
    :ID:       875ad78a-0726-4b58-9e75-d59b8717615c
    :END:
#+BEGIN_SRC emacs-lisp :results none
;  (use-package ace-isearch
;  :ensure t
;  :config
;  (ace-isearch-mode +1)
;  (global-ace-isearch-mode +1)
; (setq ace-isearch-function 'avy-goto-word-1)
;  )
#+END_SRC
*** customize 
    :PROPERTIES:
    :ID:       2dd38353-5caf-4d8c-b0b1-9cd1b5600ec1
    :END:
#+BEGIN_SRC emacs-lisp :results none
  ;;   (custom-set-variables
  ;;   '(ace-isearch-input-length 9)
  ;;   '(ace-isearch-input-idle-delay 0.4)
  ;;   '(ace-isearch-submode 'ace-jump-char-mode)
  ;;   '(ace-isearch-use-ace-jump 'printing-char)
  ;; )
#+END_SRC
** all-the-icons 

#+BEGIN_SRC emacs-lisp :results none
(use-package all-the-icons
 :ensure t
 :config
 
 )
#+END_SRC 


** ace link
   :PROPERTIES:
   :ID:       466946b4-4b3b-4266-9297-f26f5912e863
   :END:
https://github.com/abo-abo/ace-link

#+BEGIN_SRC emacs-lisp :results none
(use-package ace-link
 :ensure t
 :config
(ace-link-setup-default)
 )
#+END_SRC
** TODO alert
   :PROPERTIES:
   :ID:       f97b29b2-3921-40d6-8d38-87de0cdf5fe7
   :END:
https://github.com/jwiegley/alert

to send a alert I a function you write you can use

#+BEGIN_EXAMPLE
(alert "Upload to FB" :title "FB" )
#+END_EXAMPLE

#+BEGIN_SRC emacs-lisp :results none
(use-package alert
 :ensure t
 :config
(require 'alert)
;; This is the most basic form usage
(setq alert-default-style 'libnotify)

(defun alert-my-style (info)
  "Use libnotify + sound alert INFO."
  (progn
    (alert-libnotify-notify info)
    (play-sound-file (concat (getenv "HOME") "/MLT/sounds/IM/Kopete_notify.wav"))))

(alert-define-style 'my-alert-style :title "my alert style"
		    :notifier #'alert-my-style)

(setq alert-default-style 'my-alert-style)
 )
#+END_SRC 

** anzu
   :PROPERTIES:
   :ID:       a4615ab9-67d7-4611-9c25-2d0ff3fe158c
   :END:
https://github.com/syohex/emacs-anzu

#+BEGIN_SRC emacs-lisp :results none
(use-package anzu
 :ensure t
 :config
(require 'anzu)
(global-anzu-mode +1)

(set-face-attribute 'anzu-mode-line nil
                    :foreground "yellow" :weight 'bold)

(custom-set-variables
 '(anzu-mode-lighter "")
 '(anzu-deactivate-region t)
 '(anzu-search-threshold 1000)
 '(anzu-replace-to-string-separator " => "))
 
(global-set-key (kbd "M-%") 'anzu-query-replace)
(global-set-key (kbd "C-M-%") 'anzu-query-replace-regexp)

 )
#+END_SRC 

** async
   :PROPERTIES:
   :ID:       c7bbc1df-cc04-41be-8ae7-46003f7f6c20
   :END:
https://github.com/jwiegley/emacs-async
his is needed for org-download and dired async 

#+BEGIN_SRC emacs-lisp :results none
(use-package async
 :ensure t
 :config
(autoload 'dired-async-mode "dired-async.el" nil t)
(dired-async-mode 1)

)
#+END_SRC 




** auctex
   :PROPERTIES:
   :ID:       e1f4c8f1-a4eb-4eb8-9931-d35ac9d568ff
   :END:
#+BEGIN_SRC emacs-lisp :results none
;(require 'tex)
;(setq preview-scale-function 1.1)
#+END_SRC
** auto-complete
   :PROPERTIES:
   :ID:       1a7fccbe-7401-44a2-8bfe-3d90dad716d7
   :END:

#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package auto-complete
  ;;  :ensure t
  ;;  :config
  ;; (ac-config-default)

  ;; ;start after 4 characters
  ;; (setq ac-auto-start 4)
  ;; ;fix linium issues
  ;; (ac-linum-workaround)

  ;; ;; Examples
  ;; (set-face-background 'ac-candidate-face "lightgray")
  ;; (set-face-underline 'ac-candidate-face "darkgray")
  ;; (set-face-background 'ac-selection-face "steelblue")

  ;; )
#+END_SRC
** atomic-chrome
https://github.com/alpha22jp/atomic-chrome

#+BEGIN_SRC emacs-lisp :results none
(use-package atomic-chrome 
    :ensure t
    :config
(require 'atomic-chrome)

(atomic-chrome-start-server)

(setq atomic-chrome-buffer-open-style 'frame) 

(add-hook 'atomic-chrome-edit-mode-hook 'flyspell-mode)

;You can change the major mode manually. If you want to use a different major mode as the default, set atomic-chrome-default-major-mode like below.
;(setq atomic-chrome-default-major-mode 'markdown-mode)

    )
#+END_SRC 

Additionally, you can use atomic-chrome-url-major-mode-alist to choose the major mode for a specific website based on the page URL like below.

#+BEGIN_EXAMPLE
(setq atomic-chrome-url-major-mode-alist
      '(("github\\.com" . gfm-mode)
        ("redmine" . textile-mode)))

#+END_EXAMPLE


** Avy Jump
   :PROPERTIES:
   :ID:       b129aaf3-703f-4812-91bf-fec9e23d30f6
   :END:
https://github.com/abo-abo/avy

#+BEGIN_SRC emacs-lisp :results none
(use-package avy
 :ensure t
 :config
 (defcustom avy-keys '(?a ?s ?d ?f ?g ?h ?j ?k ?l ?q ?w ?e ?r ?t ?y ?u ?i ?o ?p ?z ?x ?c ?v ?b ?n ?m )
 "Keys for jumping.") 
(setq avy-timeout-seconds 0.6)
 )
#+END_SRC 


** avy zap
   :PROPERTIES:
   :LAST-EDITED: [03-08-2015(19:57)]
   :ID:       4e31179b-9d22-49f3-9379-a240162f0195
   :END:
https://github.com/cute-jumper/avy-zap
#+BEGIN_SRC emacs-lisp :results none
(use-package avy-zap
 :ensure t
 :config
  )
#+END_SRC
** avandu
   :PROPERTIES:
   :ID:       7ac1a6c2-a55c-40fb-8477-8e3a560351a3
   :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package avandu
 :ensure t
 :config
(setq avandu-tt-rss-api-url "https://ttrss.server-speed.net/api/") 
 )
#+END_SRC 


** arview
   :PROPERTIES:
   :ID:       f6ee50e0-248f-4c24-8d74-63388bd87a1a
   :END:

 #+BEGIN_SRC emacs-lisp :results none
   (use-package arview
   :ensure t
   :config
   (require 'arview)
   )
 #+END_SRC

** bm
   :PROPERTIES:
   :ID:       82feccd7-f641-4c41-8477-dc203beb9f5f
   :END:
https://github.com/joodland/bm
#+BEGIN_SRC emacs-lisp :results none
(use-package bm
             :ensure t
             :demand t

             :init
             ;; restore on load (even before you require bm)
             (setq bm-restore-repository-on-load t)

             :config
             ;; Allow cross-buffer 'next'
             (setq bm-cycle-all-buffers t)  
             ;; where to store persistant files
             (setq bm-repository-file "~/.emacs.d/bm-repository")
             ;; save bookmarks
             (setq-default bm-buffer-persistence t)

             ;; Loading the repository from file when on start up.
             (add-hook' after-init-hook 'bm-repository-load)

             ;; Restoring bookmarks when on file find.
             (add-hook 'find-file-hooks 'bm-buffer-restore)


             ;; Saving bookmarks
             (add-hook 'kill-buffer-hook #'bm-buffer-save)
             ;; Saving the repository to file when on exit.
             ;; kill-buffer-hook is not called when Emacs is killed, so we
             ;; must save all bookmarks first.
             (defun modi/bm-save-all-bm-to-repository ()
               (bm-buffer-save-all)
               (bm-repository-save))
             (add-hook 'kill-emacs-hook #'modi/bm-save-all-bm-to-repository)
             (add-hook 'after-save-hook #'bm-buffer-save)
             ;; The `after-save-hook' is not necessary to use to achieve persistence,
             ;; but it makes the bookmark data in repository more in sync with the file
             ;; state.


             ;; Restoring bookmarks
             (add-hook 'find-file-hooks   #'bm-buffer-restore)
             (add-hook 'after-revert-hook #'bm-buffer-restore)
             ;; The `after-revert-hook' is not necessary to use to achieve persistence,
             ;; but it makes the bookmark data in repository more in sync with the file
             ;; state. This hook might cause trouble when using packages
             ;; that automatically reverts the buffer (like vc after a check-in).
             ;; This can easily be avoided if the package provides a hook that is
             ;; called before the buffer is reverted (like `vc-before-checkin-hook').
             ;; Then new bookmarks can be saved before the buffer is reverted.
             ;; Make sure bookmarks is saved before check-in (and revert-buffer)
             (add-hook 'vc-before-checkin-hook #'bm-buffer-save)

             
             )

#+END_SRC
** helm-bm
   :PROPERTIES:
   :ID:       b16793bc-1467-4996-93d8-8b589f52201a
   :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package helm-bm
 :ensure t
 :config
  )
#+END_SRC 
** better shell 
https://github.com/killdash9/better-shell

#+BEGIN_SRC emacs-lisp  :results none
(use-package better-shell
    :ensure t

)
#+END_SRC

** bbdb 
   :PROPERTIES:
   :ID:       750e7876-e930-46f1-aa7d-14c15f650380
   :END:
 #+BEGIN_SRC emacs-lisp :results none
   ;; (use-package bbdb
   ;;  :ensure t
   ;;  :config
    (setq bbdb-file "~/.emacs.d/bbdb")           ;; keep ~/ clean; set before loading
   ; (require 'bbdb) 
   ;; (bbdb-initialize)

   ;;  )
 #+END_SRC 


** counsel-bbdb
https://github.com/redguardtoo/counsel-bbdb/issues/1
#+BEGIN_SRC emacs-lisp :results none
(use-package counsel-bbdb
:ensure t
 :config

 )
#+END_SRC 



** beacon mode 
   :PROPERTIES:
   :ID:       7ea5c483-e166-4506-9853-d4a4101d9d77
   :END:

 https://github.com/Malabarba/beacon

 #+BEGIN_SRC emacs-lisp :results none
 (use-package beacon
  :ensure t
  :config
 (beacon-mode 1)
 (setq beacon-push-mark 35)
 (setq beacon-color "#21D6F4")
  )
 #+END_SRC 


** Bookmark+

   :PROPERTIES:
   :ID:       a8e3e044-62db-4376-bd7b-37f82a0e926a
   :END:
*** use-package
#+BEGIN_SRC emacs-lisp :results none
(use-package bookmark+
:ensure t
:config
(setq bookmark-version-control t
      bookmark-save-flag t)
;ask for tags when saving a bookmark move nil to t to ask each time
(setq bmkp-prompt-for-tags-flag nil)
)

#+END_SRC
*** DOCU
**** bookmark to a specifc position in a file
stand in the line/position in the file you want to bookmark and then issue 
?C-x p m? and enter the name desired 
**** important keys
mark file  ?m?
rename  ?r? (will prompt for name followd by location, press ENTER to ignore changed location)
sort by name ?s-n?
**** create a sequence bookmark (multiple bookmarks launched from 1)
mark current bookmarks in bk+ with 'm' then use the menu item 'new sequence bookmark from marked' to create a special bookmark that launches all marked bookmakred in succsion. give it a name and your finished
**** higlighting
to higlight a bookmark first bookmark the position you want (C-x pm)
then issue ( C-x p h ) to bring the higlight menu
 
**** bookmark a Region
You can bookmark a region of text, not just a position.When you jump to a bookmark that records a region, the region is
activated. to do this select a region and them add the bookmark as ususal.
**** bookmark multiple files at once (using dired)
start a dired+ session
mark the files you want with 'm'
add then as bookmarks with M-b
**** tags
***** ask for tag each time you save a bookmark
add this to your config
#+BEGIN_EXAMPLE
;ask for tags when saving a bookmark
(setq bmkp-prompt-for-tags-flag t)
#+END_EXAMPLE
***** tagging in list view
see the hotkeys in config for personal tagging keys
$Note-when tagging one needs to enter tag> ENTER then ENTER again with an empty prompt to save the tag$ 
***** use tags to execute a lisp code (for example narrow region when launched)
Tags that have the prefix "bmkp-" are reserved – do not name your own tags using this prefix. Currently, "bmkp-jump" is the only predefined bookmark tag. You can give this tag a value that is a function – it is called whenever the tagged bookmark is visited. Any Lisp-readable function value is allowed: a symbol or a lambda expression.

For example, to display Hello! when a bookmark is visited you can use this:

issue ~T v~
enter bmkp-jump
press  RET
enter code
₆In example₆  (lambda () (message "Hello!"))

this is an example code for narrow region

#+BEGIN_EXAMPLE
(lambda () (org-narrow-to-subtree))
#+END_EXAMPLE

The function that is the value of a "bmkp-jump" tag is called just after the the standard hook ‘bookmark-after-jump-hook’ is invoked. You can use this tag to invoke functions that are specific to individual bookmarks; bookmarks can thus have their own, extra jump functions.

this is the whole procedure:
#+BEGIN_EXAMPLE
T v bmkp-jump RET (lambda () (org-narrow-to-subtree))
#+END_EXAMPLE

** Browse kill ring
   :PROPERTIES:
   :ID:       b19db516-8515-483f-b1f3-95cc26b7d44c
   :END:
#+BEGIN_SRC emacs-lisp :results none
(use-package browse-kill-ring
:ensure t
:config
)
#+END_SRC 

** bug hunter
   :PROPERTIES:
   :ID:       f91622a3-a901-45f2-ad17-dffafeb6937a
   :END:
https://github.com/Malabarba/elisp-bug-hunter

#+BEGIN_SRC emacs-lisp :results none
(use-package bug-hunter
 :ensure t
 :config
  )
#+END_SRC
** calfw
   :PROPERTIES:
   :ID:       753a86ce-dd2e-4f80-8e49-2aba23518121
   :END:
https://github.com/kiwanami/emacs-calfw
#+BEGIN_SRC emacs-lisp :results none
(use-package calfw
 :ensure t
 :config
 (require 'calfw)
(require 'calfw-org)

(defun my-open-calendar ()
  (interactive)
  (cfw:open-calendar-buffer
   :contents-sources
   (list
    (cfw:org-create-source "blue")  ; orgmode source
    (cfw:howm-create-source "magenta")  ; howm source
    (cfw:cal-create-source "Orange") ; diary source
   ))) 
 )
#+END_SRC 
** char-menu
   :PROPERTIES:
   :ID:       9d6bf5f5-49cb-40e5-b19d-2417da7fe0b7
   :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package char-menu
 :ensure t
 :config
 
(setq char-menu '("—" "‘’" "“”" "…" "«»" "–" "【】" "◀▶" "☚ ☛"
                            ("Typography" "•" "©" "†" "‡" "°" "·" "§" "№" "★")
                            ("Math"       "≈" "≡" "≠" "∞" "×" "±" "∓" "÷" "√")
                            ("Arrows"     "←" "→" "↑" "↓" "⇐" "⇒" "⇑" "⇓")
                            ("Greek"      "α" "β" "Y" "δ" "ε" "ζ" "η" "θ" "ι" "κ" "λ" "μ" "ν" "ξ" "ο" "π" "ρ" "σ" "τ" "υ" "φ" "χ" "ψ" "ω") 
))
 )
#+END_SRC 

** color-theme-approximate
   :PROPERTIES:
   :ID:       6285d091-4df8-47ca-8341-dd0f060f129b
   :END:
 If it doesn't work try to put the line lower in the .emacs file (it happened to me). If everything still look like shit check that you have the correct XTERM environment variable set 
$Note- is different inside screen or tmux$

#+BEGIN_SRC emacs-lisp :results none
(use-package color-theme-approximate
 :ensure t
 :config
(color-theme-approximate-on)
 )
#+END_SRC 

** company-statistics
   :PROPERTIES:
   :ID:       194e4abb-fc58-48ae-98d0-7da32f975682
   :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package company-statistics
 :ensure t
 :config
 )
#+END_SRC 


** company
   :PROPERTIES:
   :ID:       3cdd5b71-3539-4b8c-b0f8-fbe5c7c86edd
   :END:
#+BEGIN_SRC emacs-lisp :results none
  ;;   (use-package company
  ;;    :ensure t
  ;;    :config
  ;; ;; companymode
  ;;   (require 'company)

  ;; ; Company-mode backends
  ;; (eval-after-load "company"
  ;;   '(progn
  ;;      (add-to-list 'company-backends 'company-dabbrev)
  ;;      (add-to-list 'company-backends 'company-ispell)
  ;;      (add-to-list 'company-backends 'company-abbrev)
  ;;      (add-to-list 'company-backends 'company-files)

  ;; ;; @see https://github.com/company-mode/company-mode/issues/348
  ;;      (require 'company-statistics)
  ;;      (company-statistics-mode)

  ;; ;; yasnippet backend shadows other completions, see https://github.com/company-mode/company-mode/blob/master/company-yasnippet.el for solutions
  ;; ;;better to leave disabled and use the ido mode for yasnippets
  ;; ;;     (add-to-list 'company-backends 'company-yasnippet)
  ;; ;; using the delete command disables specific modes 
  ;;     (setq company-backends (delete 'company-capf company-backends))
  ;;     (setq company-backends (delete 'company-ropemacs company-backends))
  ;;     (setq company-backends (delete 'company-clang company-backends))
  ;;     (setq company-backends (delete 'company-cmake company-backends))
  ;;     (setq company-backends (delete 'company-css company-backends))
  ;;     (setq company-backends (delete 'company-eclim company-backends))
  ;;     (setq company-backends (delete 'company-elisp company-backends))
  ;;     (setq company-backends (delete 'company-etags company-backends))
  ;;     (setq company-backends (delete 'company-gtags company-backends))
  ;;     (setq company-backends (delete 'company-keywords company-backends))
  ;;     (setq company-backends (delete 'company-nxml company-backends))
  ;;     (setq company-backends (delete 'company-oddmuse company-backends))
  ;;     (setq company-backends (delete 'company-semantic company-backends))
  ;;     (setq company-backends (delete 'company-template company-backends))
  ;;     (setq company-backends (delete 'company-tempo company-backends))
  ;;     (setq company-backends (delete 'company-tests company-backends))
  ;;     (setq company-backends (delete 'company-xcode company-backends))
  ;;     (setq company-backends (delete 'company-tempo company-backends))
  ;;     (setq company-backends (delete 'company-yasnippet company-backends))
  ;; ;; capf is for all modes and all languges so its better to turn it off to not pollute completions.
  ;; ;;     (add-to-list 'company-backends 'company-capf)
  ;;      ))

  ;; ;;make it global
  ;; (add-hook 'after-init-hook 'global-company-mode)


  ;; ;; company delay until suggestions are shown
  ;; (setq company-idle-delay 0.2)
  ;; ;; whats the minimum to start completion 
  ;; (setq company-minimum-prefix-length 2)
  ;; (setq company-dabbrev-minimum-length 2)
  ;; ;; weight by frequency
  ;; (setq company-transformers '(company-sort-by-occurrence))
  ;; ;;dabbrev options 
  ;; (setq company-dabbrev-downcase nil)
  ;; (setq company-dabbrev-ignore-case nil)
  ;; (setq company-dabbrev-other-buffers t)
  ;;   ;; show numbers in popup?
  ;; (setq company-show-numbers t)
  ;; (setq company-require-match nil)
  ;; ;; company dabbrev config
  ;; ;; search all buffers 
  ;; (setq company-dabbrev-other-buffers t)


  ;; ;; Don't enable company-mode in below major modes, OPTIONAL
  ;; (setq company-global-modes '(not eshell-mode comint-mode erc-mode rcirc-mode))



  ;; (defun org-mode-hook-setup ()
  ;;   ;; make `company-backends' local is critcal
  ;;   ;; or else, you will have completion in every major mode, that's very annoying!
  ;;   (make-local-variable 'company-backends)

  ;;   ;; OPTIONAL, if `company-ispell-dictionary' is nil, `ispell-complete-word-dict' is used
  ;;   ;;  but I prefer hard code the dictionary path. That's more portable.
  ;;   (setq company-ispell-dictionary (file-truename "~/.emacs.d/abbrv/english-words.txt")))

  ;; (add-hook 'org-mode-hook 'org-mode-hook-setup)


  ;; ;;;keybinds
  ;; (global-set-key (kbd "M-.") 'company-complete)
  ;; (global-set-key (kbd "M-/") 'company-dabbrev)

  ;;    )
#+END_SRC 

** company-emoji
   :PROPERTIES:
   :ID:       248fb905-2d81-4c05-927b-0a78cbd0632a
   :END:
https://github.com/dunn/company-emoji

make sure to install ttf-ancient-fonts to get the fonts to show up


#+BEGIN_SRC emacs-lisp :results none
(use-package company-emoji
 :ensure t
 :config
(require 'company-emoji)
(add-to-list 'company-backends 'company-emoji)

(defun --set-emoji-font (frame)
  "Adjust the font settings of FRAME so Emacs can display emoji properly."
  (if (eq system-type 'darwin)
      ;; For NS/Cocoa
      (set-fontset-font t 'symbol (font-spec :family "Apple Color Emoji") frame 'prepend)
    ;; For Linux
    (set-fontset-font t 'symbol (font-spec :family "Symbola") frame 'prepend)))

;; For when Emacs is started in GUI mode:
(--set-emoji-font nil)

;; Hook for when a frame is created with emacsclient
;; see https://www.gnu.org/software/emacs/manual/html_node/elisp/Creating-Frames.html
(add-hook 'after-make-frame-functions '--set-emoji-font)
 )
#+END_SRC 
You can add shortcode aliases by modifying company-emoji-aliases. Run M-x customize-variable [RET] company-emoji-aliases to bring up company-emoji’s customization pane, then add or remove aliases to your taste.
** company-org-headings
   :PROPERTIES:
   :ID:       72848b2f-956e-4df8-8244-32ad45dabd5b
   :END:
#+BEGIN_SRC emacs-lisp :results none
  ;; (add-to-list 'load-path "/home/zeltak/.emacs.g/company-org-headings")
  ;; (setq
  ;;  ;; align all annotations to the right tooltip border
  ;;  company-tooltip-align-annotations t
  ;;  company-org-headings/search-directory "~/notes"
  ;;  company-org-headings/case-sensitive nil)

  ;; ;; (add-hook 'org-mode-hook
  ;; ;;           (lambda ()
  ;; ;;             (set (make-local-variable 'company-backends)
  ;; ;;                  '((company-org-headings
  ;; ;;                     company-abbrev
  ;; ;;                     company-files
  ;; ;;                     )))))
#+END_SRC

** crux
   :PROPERTIES:
   :ID:       e59bc606-b824-497b-8852-eb28ca8cf0c0
   :END:
https://github.com/bbatsov/crux

#+BEGIN_SRC emacs-lisp :results none
(use-package crux
 :ensure t
 :config
 
 )
#+END_SRC 


** `dired plugins`
   :PROPERTIES:
   :ID:       507f342b-e38d-4bf9-8c89-1d7035332631
   :END:
*** TODO dired-explorer
https://github.com/jidaikobo-shibata/dired-explorer/blob/master/dired-explorer.el
#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package dired-explorer
  ;; :ensure t
  ;;  :config
  ;; (require 'dired-explorer)
  ;; (add-hook 'dired-mode-hook
  ;;           (lambda ()
  ;;             (define-key dired-mode-map ":" (lambda () (interactive) (dired-explorer-mode t)))
  ;;             (dired-explorer-mode t))) 
  ;;  )
#+END_SRC 

 
*** dired hacks 
    :PROPERTIES:
    :ID:       b38085e7-0ce7-45c7-bb78-1bad0a4c0d4a
    :END:
**** dired-avfs
     :PROPERTIES:
     :ID:       04c0f439-a2c9-4bec-8e9a-724f7acfc8ad
     :END:
    https://github.com/Fuco1/dired-hacks#dired-avfs

 This extension therefore depends on the presence of avfsd on your system
 on arch to get it working issue this (at startup in xinitrc or other startup scripts)

 grep -q "^avfsd $HOME/.avfs " /proc/mounts || avfsd ~/.avfs -o auto_cache     

 #+BEGIN_SRC emacs-lisp :results none
 (use-package dired-avfs
  :ensure t
  :config
  )
 #+END_SRC 
**** dired-filter
     :PROPERTIES:
     :ID:       ccc735c0-e2d6-43bc-9635-7227fcfa193c
     :END:
 https://github.com/Fuco1/dired-hacks

 Saved filters

 call ~dired-filter-save-filters~ You will be prompted for a name under which this stack will be saved.
 it will save the new value into your customize file.

 You can delete saved filters with ~dired-filter-delete-saved-filters~

 To use a saved filter, you can use either ~dired-filter-add-saved-filters~ or ~dired-filter-load-saved-filters  ~

 The first pushes the saved filter on top of the currently active stack, the second clears current filter stack before loading the saved filter configuration.

 #+BEGIN_SRC emacs-lisp :results none
 (use-package dired-filter
  :ensure t
  :config
  )
 #+END_SRC 
**** dired-rainbow (define colors by extensions)
     :PROPERTIES:
     :ID:       72450b5f-e611-46f7-a094-38443bd6f9bd
     :END:
https://github.com/Fuco1/dired-hacks#dired-rainbow

 #+BEGIN_SRC emacs-lisp :results none
 (use-package dired-rainbow
  :ensure t
  :config
  (require 'dired-rainbow)

 (defconst dired-audio-files-extensions
   '("mp3" "MP3" "ogg" "OGG" "flac" "FLAC" "wav" "WAV")
   "Dired Audio files extensions")
 (dired-rainbow-define audio "#329EE8" dired-audio-files-extensions)


 (defconst dired-docs-files-extensions
   '("docx" "doc" "odf" "odt" "xls" "xlsx" "ppt" "pptx" "ods" "odt")
   "Dired Docs files extensions")
 (dired-rainbow-define docs "#42D14A" dired-docs-files-extensions)

 (defconst dired-video-files-extensions
     '("vob" "VOB" "mkv" "MKV" "mpe" "mpg" "MPG" "mp4" "MP4" "ts" "TS" "m2ts"
       "M2TS" "avi" "AVI" "mov" "MOV" "wmv" "asf" "m2v" "m4v" "mpeg" "MPEG" "tp")
     "Dired Video files extensions")
 (dired-rainbow-define video "#006EFF" dired-video-files-extensions)

 (defconst dired-image-files-extensions
     '("jpeg" "jpg" "JPG" "JPEG" "png" "PNG" "bmp" "tif" "tiff" "xbm" "svg" )
     "Dired image files extensions")
 (dired-rainbow-define image "#E009CF" dired-image-files-extensions)


 (defconst dired-pdf-files-extensions
   '("pdf" "PDF")
   "Dired pdf files extensions")
 (dired-rainbow-define pdf "#FF0000" dired-pdf-files-extensions)


 (defconst dired-org-files-extensions
   '("org" "ORG")
   "Dired org files extensions")
 (dired-rainbow-define org "#FF00A2" dired-org-files-extensions)


 (defconst dired-compressed-files-extensions
   '("zip" "ZIP"  "tar.bz" "tar.gz" "7zip" "7ZIP" "tar" "TAR" "rar" "RAR")
   "Dired compressed files extensions")
 (dired-rainbow-define compressed "#B56A00" dired-compressed-files-extensions)


  )
 #+END_SRC 

**** dired-narrow
     :PROPERTIES:
     :ID:       f93562d0-3804-452d-a51e-f0e98130bb93
     :END:
 https://github.com/Fuco1/dired-hacks
 #+BEGIN_SRC emacs-lisp :results none
 (use-package dired-narrow
  :ensure t
  :config
;;(setq dired-narrow-exit-action 'find-file)
(setq dired-narrow-exit-action 'dired-narrow-find-file)
  )
 #+END_SRC
**** dired-open
     :PROPERTIES:
     :ID:       117b070d-ee1d-4658-b027-c565e6606a46
     :END:
#+BEGIN_SRC emacs-lisp :results none


  ;; (use-package dired-open
  ;;  :ensure t
  ;;  :config
  ;;  (setq dired-open-extensions
  ;;       '(("pdf" . "okular")
  ;;         ("mkv" . "vlc")
  ;;         ("mp4" . "vlc")
  ;;         ("avi" . "vlc")
  ;;         ("html" . "firefox")
  ;;         ("mp3" . "vlc")
  ;;         ("doc" . "libreoffice")
  ;;         ("docx" . "libreoffice")
  ;;         ("odt" . "libreoffice")
  ;;         ("odf" . "libreoffice")
  ;;         ("xls" . "libreoffice")
  ;;         ("xlsx" . "libreoffice")
  ;;         ("ppt" . "libreoffice")
  ;;         ("pptx" . "libreoffice")
  ;; ))
  ;;  )
#+END_SRC
**** dired-subtree
     :PROPERTIES:
     :ID:       bc96979b-1f48-4230-95b9-f7b92400852f
     :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package dired-subtree
 :ensure t
 :config
 
 )
#+END_SRC
**** dired-ranger
     :PROPERTIES:
     :ID:       1299512c-1de7-4369-854a-0d5c459b75a6
     :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package dired-ranger
 :ensure t
 :config
 
 )
#+END_SRC 


*** dired-x
    :PROPERTIES:
    :ID:       9bd170a8-2d5c-4e62-a3d4-05e1a5af75b2
    :END:

http://www.gnu.org/software/emacs/manual/html_node/dired-x/Shell-Command-Guessing.html

$Note-no need to install its a internal dired package$ 
#+BEGIN_SRC emacs-lisp :results none
(require 'dired-x)

(add-hook 'dired-load-hook
              (function (lambda () (load "dired-x"))))

(setq dired-guess-shell-alist-user
      '(("\\.chm$" "xchm")
        ("\\.rar$" "unrar x")
        ("\\.pdf$" "zathura")
        ("\\.mkv$" "mpv")
        ("\\.mp4$" "mpv")
        ("\\.ogm$" "mpv")
        ("\\.avi$" "mpv")
        ("\\.png$" "feh")
        ("\\.jpg$" "feh")
        ("\\.JPG$" "feh")
        ("\\.doc$" "libreoffice")
        ("\\.docx$" "libreoffice")
        ("\\.xls$" "libreoffice")
        ("\\.xlsx$" "libreoffice")
        ("\\.ppt$" "libreoffice")
        ("\\.pptx$" "libreoffice")

))
#+END_SRC 

*** sorting 
    :PROPERTIES:
    :ID:       753f30b3-241b-41f6-a892-c45c659f9309
    :END:
**** dired-quick-sort
     :PROPERTIES:
     :ID:       820a63a9-c82a-4b6b-9e18-5b4e59285b3a
     :END:
 https://gitlab.com/xuhdev/dired-quick-sort#dired-quick-sort


 #+BEGIN_SRC emacs-lisp :results none
 (use-package dired-quick-sort 
  :ensure t
  :config
 (require 'dired-quick-sort)
 (dired-quick-sort-setup)
  )
 #+END_SRC 


**** dired sort
     :PROPERTIES:
     :ID:       c8075171-e8cf-4646-bc6f-204379e87608
     :END:
 https://www.emacswiki.org/emacs/dired-sort.el
 #+BEGIN_SRC emacs-lisp :results none
   ;; (use-package dired-sort
   ;;  :ensure t
   ;;  :config
   ;;   )
 #+END_SRC
**** dired-sort-menu
     :PROPERTIES:
     :ID:       74782867-dedd-46f9-9a2a-112f059add11
     :END:
 https://www.emacswiki.org/emacs/DiredSortMenu
 #+BEGIN_SRC emacs-lisp :results none
   ;; (use-package dired-sort-menu
   ;;  :ensure t
   ;;  :config
 
   ;;  )
 #+END_SRC 
 and the plus addon:
 https://www.emacswiki.org/emacs/dired-sort-menu+.el
 #+BEGIN_SRC emacs-lisp :results none
   ;; (use-package dired-sort-menu+
   ;;  :ensure t
   ;;  :config
 
   ;;  )
 #+END_SRC 
*** dired+
    :PROPERTIES:
    :ID:       1dc3bb29-f968-49b7-a50a-f28278428340
    :END:
https://www.emacswiki.org/emacs/DiredPlus
#+BEGIN_SRC emacs-lisp :results none
  (use-package dired+
   :ensure t
   :config
  ;;; don't create a buffer for every dir I visit (use 1 to not create and -1 to creare)
  (toggle-diredp-find-file-reuse-dir -1)
    )
#+END_SRC 
*** dired-efap (rename file at point)
    :PROPERTIES:
    :ID:       73793961-7f3f-4de9-8cb0-7569407950d4
    :END:
https://github.com/juan-leon/dired-efap

See also variable dired-efap-initial-filename-selection, if you want to control what part of the filename will be initially selected.

Type M-x customize-group RET dired-efap if you want make changes to the default behavior.

#+BEGIN_SRC emacs-lisp :results none
(use-package dired-efap
 :ensure t
 :config
;;; set this to nil so it doesn't delete backward/forward from point
(setq dired-efap-initial-filename-selection nil) 

 )
#+END_SRC 

*** dired tmtxt-async-tasks 
    :PROPERTIES:
    :ID:       850faebe-b0de-4328-8f07-21042038e4b8
    :END:
https://truongtx.me/tmtxt-async-tasks.html
https://truongtx.me/tmtxt-dired-async.html

#+BEGIN_SRC emacs-lisp :results none
(add-to-list 'load-path "/home/zeltak/.emacs.g/tmtxt-async-tasks")
(add-to-list 'load-path "/home/zeltak/.emacs.g/tmtxt-dired-async")
(require 'tmtxt-async-tasks)
(require 'tmtxt-dired-async)

(setq-default tat/window-close-delay "2")
(setq-default tat/window-height 15)
#+END_SRC
*** dired-fdclone
    :PROPERTIES:
    :ID:       d60b68e0-98f8-4da7-b06a-3eaf9f904edd
    :END:
https://github.com/knu/dired-fdclone.el
#+BEGIN_SRC emacs-lisp :results none
(use-package dired-fdclone
 :ensure t
 :config
 
 )
#+END_SRC 

good package for zip and unzip functions
*** helm-dired-recent-dirs
    :PROPERTIES:
    :ID:       3a7d55a5-bdb1-4175-80ea-e3e94896d3f1
    :END:
https://github.com/akisute3/helm-dired-recent-dirs
@makes dired super slow@
#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package helm-dired-recent-dirs
  ;;  :ensure t
  ;;  :config
 
  ;;  )
#+END_SRC 
*** image-dired+
    :PROPERTIES:
    :ID:       384546d8-b465-4a62-95f2-99c322e176de
    :END:
https://github.com/mhayashi1120/Emacs-image-diredx
#+BEGIN_SRC emacs-lisp :results none
(use-package image-dired+
 :ensure t
 :config
(eval-after-load 'image-dired+ '(image-diredx-async-mode 1))
(eval-after-load 'image-dired+ '(image-diredx-adjust-mode 1))
 )
#+END_SRC
*** TODO dired-atool
    :PROPERTIES:
    :ID:       6b88d04a-30df-4c68-8fd5-8f9451927b8b
    :END:
https://github.com/HKey/dired-atool

#+BEGIN_SRC emacs-lisp :results none
(use-package dired-atool
 :ensure t
 :config
 (dired-atool-setup)
 )
#+END_SRC
*** TODO make-it-so
    :PROPERTIES:
    :ID:       ed63d3d4-01d9-4f10-bc54-bacc927afb2a
    :END:
https://github.com/abo-abo/make-it-so
#+BEGIN_SRC emacs-lisp :results none
(use-package  make-it-so 
 :ensure t
 :config
(require 'make-it-so)
(setq mis-recipes-directory "/home/zeltak/.emacs.d/mis")
(mis-config-default)
 )
#+END_SRC
*** peep dired
    :PROPERTIES:
    :ID:       b19a0112-daa8-4adc-a933-ca45bb6eaa6e
    :END:
 https://github.com/asok/peep-dired
 #+BEGIN_SRC emacs-lisp  :results none
 ;;preview files in dired
 (use-package peep-dired
   :ensure t
   :defer t ; don't access `dired-mode-map' until `peep-dired' is loaded
   :bind (:map dired-mode-map
	       ("P" . peep-dired))
   :config 
(setq peep-dired-ignored-extensions '("mkv" "iso" "mp4"))
)
 #+END_SRC
*** TODO Runner
    :PROPERTIES:
    :ID:       40cc3eb5-eaad-4cd9-bbf3-a072c5532016
    :END:
https://github.com/thamer/runner

resolve popping of buffer when launching 

#+BEGIN_SRC emacs-lisp :results none
(use-package runner 
 :ensure t
 :config
(require 'runner)
(setq  runner-show-label        nil)
(setq  runner-shell-function   'runner-shell-function-eshell)
(setq runner-run-in-background t)
 )
#+END_SRC
*** TODO all-the-icons-dired

https://github.com/jtbm37/all-the-icons-dired

#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package all-the-icons-dired
  ;;  :ensure t
  ;;  :config
  ;; (add-hook 'dired-mode-hook 'all-the-icons-dired-mode)
 
  ;;  )
#+END_SRC 



** Deft
   :PROPERTIES:
   :ID:       c902fcce-831f-49c6-be75-a0443275ba9e
   :END:
http://jblevins.org/projects/deft/

#+BEGIN_SRC emacs-lisp :results none
(use-package deft
 :ensure t
 :config
(require 'deft)
(setq deft-extension "org")
(setq deft-text-mode 'org-mode)
(setq deft-directory "~/org/files/")
(setq deft-use-filename-as-title t)
(setq deft-recursive t)
;;strip org mode stuff
(setq deft-strip-title-regexp "#\\+TITLE: ")
;;ignore these dirs
(setq deft-recursive-ignore-dir-regexp
          (concat "\\(?:"
                  "\\."
                  "\\|\\.\\."
                  "#\\mypapers"
                  "\\|code"
                  "\\|auto"
                  "\\|_minted.*"
                  "\\)$"))

 )
#+END_SRC 


** drag stuff
   :PROPERTIES:
   :ID:       443a70cf-67e3-4c27-a546-ace69581d0fd
   :END:
https://github.com/rejeep/drag-stuff.el

allows to drag text around via keyboard 

#+BEGIN_SRC emacs-lisp :results none
(use-package drag-stuff
 :ensure t
 :config
  )
#+END_SRC
** duplicate-thing
   :PROPERTIES:
   :ID:       2f41a0ad-d16f-4dfc-bc2f-ab9014148023
   :END:
https://github.com/ongaeshi/duplicate-thing
#+BEGIN_SRC emacs-lisp :results none
(use-package  duplicate-thing 
 :ensure t
 :config
 )
#+END_SRC 

** ebib
   :PROPERTIES:
   :ID:       700b9532-80ce-4d38-986f-aa9aa118b73e
   :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package ebib
 :ensure t
 :config
(setq ebib-preload-bib-files '("/home/zeltak/org/files/Uni/papers/zeltak.2015.bib")) 

(setq ebib-common-optional-fields
      '(translator keywords origlanguage url file location
        partinfo subtitle edition abstract note annotator
        crossref urldate address subtitle language))

(setq ebib-file-associations '(("pdf" . "okular") ("djvu" . "okular")))
(setq ebib-uniquify-keys t)
(setq ebib-autogenerate-keys t)
(setq ebib-index-window-size 20)
(setq ebib-print-multiline t)

;index view
(setq ebib-index-display-fields (quote (year author)))
(setq ebib-sort-order (quote ((year) (author) )))

 )
#+END_SRC
** elmacro
   :PROPERTIES:
   :ID:       2a20dcc4-661e-4625-932a-065bb616937c
   :END:
https://github.com/Silex/elmacro

#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package elmacro
  ;;  :ensure t
  ;;  :config
  ;;  (elmacro-mode)
  ;;  )
#+END_SRC 

** easy-kill
   :PROPERTIES:
   :ID:       99ee2474-e803-4924-ba2a-def9b2381b23
   :END:
https://github.com/leoliu/easy-kill

#+BEGIN_SRC emacs-lisp :results none
(use-package easy-kill
   :ensure t
   :config
;; to replace Emacs native M-w
(global-set-key [remap kill-ring-save] 'easy-kill)
(global-set-key (kbd "M-3") 'easy-mark)
   )
#+END_SRC 
** edit-server (for chrome interaction)
   :PROPERTIES:
   :ID:       b89ea73a-2266-4ab0-89d4-c3e3ca9da770
   :END:
https://www.emacswiki.org/emacs/Edit_with_Emacs

 #+BEGIN_SRC emacs-lisp :results none
(require 'edit-server)
(edit-server-start)

;Gmail has switched to a new compose window which unfortunately breaks interaction with edit-server. However fortunately someone has hacked together a solution for this: https://github.com/frobtech/edit-server-htmlize
(autoload 'edit-server-maybe-dehtmlize-buffer "edit-server-htmlize" "edit-server-htmlize" t)
(autoload 'edit-server-maybe-htmlize-buffer   "edit-server-htmlize" "edit-server-htmlize" t)
(add-hook 'edit-server-start-hook 'edit-server-maybe-dehtmlize-buffer)
(add-hook 'edit-server-done-hook  'edit-server-maybe-htmlize-buffer)
 #+END_SRC
** elfeed
   :PROPERTIES:
   :ID:       f839ce5f-1d87-42f5-92e9-e4661327e324
   :END:
*** base 
    :PROPERTIES:
    :ID:       120e115c-3a31-4d1f-a35c-1e8d8729afe4
    :END:
#+BEGIN_SRC emacs-lisp :results none
(use-package elfeed
 :ensure t
 :config

;;;default search 
(setq-default elfeed-search-filter "@2-week-ago +unread ")

;;change date formay 
(setq elfeed-search-date-format '("%d %b %H:%M" 12 :left))

;;set sort order
(setq elfeed-sort-order 'ascending)

;;; add a star tag http://matt.hackinghistory.ca/2015/11/22/elfeed/

 (eval-after-load 'elfeed-search 
;;  '(define-key elfeed-search-mode-map (kbd "<tab>") 'mwp/elfeed-star))
  '(define-key elfeed-search-mode-map (kbd "t") 'mwp/elfeed-star))


(defun mwp/elfeed-star ()
  "add a star tag to marked"

  (interactive)
  (elfeed-search-tag-all (list starred))
  )

(defun mwp/elfeed-star ()
  "Apply TAG to all selected entries."
  (interactive )
  (let* ((entries (elfeed-search-selected))
         (tag (intern "starred")))

    (cl-loop for entry in entries do (elfeed-tag entry tag))
    (mapc #'elfeed-search-update-entry entries)
    (unless (use-region-p) (forward-line))))

;;; add visual cue
(defface elfeed-search-starred-title-face
 '((t :foreground "#f77"))
 "Marks a starred Elfeed entry.")

(push '(starred elfeed-search-starred-title-face) 
       elfeed-search-face-alist)


;;Avoiding tagging old entries as unread:

;; Entries older than 2 weeks are marked as read
(add-hook 'elfeed-new-entry-hook
          (elfeed-make-tagger :before "2 weeks ago"
                              :remove 'unread))

;;for "Queue timeout exceeded" errors
(setf url-queue-timeout 30)

(define-key elfeed-search-mode-map (kbd "j") 'next-line)
(define-key elfeed-show-mode-map    (kbd "j") 'elfeed-show-next)
(define-key elfeed-search-mode-map (kbd "k") 'previous-line)
(define-key elfeed-show-mode-map    (kbd "k") 'elfeed-show-prev)

 )
#+END_SRC 

next-line

Faces and Colors
All of the faces used in the display are declared for customization, so these can be changed to whatever you like.

elfeed-search-date-face
elfeed-search-title-face
elfeed-search-feed-face
elfeed-search-tag-face



*** feeds 
    :PROPERTIES:
    :ID:       0ccd8b8c-c8ee-4a93-8dce-6c9f81e83f64
    :END:
 #+BEGIN_SRC emacs-lisp :results none
(setq elfeed-feeds
   '(
;;comics
("http://phdcomics.com/gradfeed.php" comics)
("http://theoatmeal.com/feed/rss" comics)
("http://xkcd.com/rss.xml" comics)
("http://researchinprogress.tumblr.com/rss" comics)
;;food 
"http://feeds.feedburner.com/seriouseatsfeaturesvideos"
"http://feeds.feedburner.com/bazekalim" 
"http://feeds2.feedburner.com/thai-food-blog/main" 
"http://feeds2.feedburner.com/humus101rss" 
"http://feeds.feedburner.com/ptitim" 
"http://what-efrat.blogspot.com/feeds/posts/default" 
"http://feeds.feedburner.com/matkonation/BRUQ" 

;;Tech
"http://lifehacker.com/index.xml" 
"http://feeds.feedburner.com/Makeuseof" 
"http://xbmc.org/feed/" 
"http://googlecode.blogspot.com/atom.xml" 
"http://fulltextrssfeed.com/www.engadget.com/rss.xml"

;;geek stuff 
"http://www.geekologie.com/index.xml" 
;;personal blogs
"http://feeds.feedburner.com/AdventuresInOpenSource?format=xml"
"http://feeds.feedburner.com/yuval"

;;emacs
"http://oremacs.com/atom.xml" 
"http://emacshorrors.com/feed.atom" 
"http://emacsninja.com/feed.atom" 
"http://ericjmritz.name/feed/" 
"http://matt.hackinghistory.ca/feed/" 
"http://karl-voit.at/feeds/lazyblorg-all.atom_1.0.links-only.xml" 
"http://emacsmovies.org/atom.xml" 
"http://endlessparentheses.com/atom.xml" 
"http://planet.emacsen.org/atom.xml" 
"http://sachachua.com/blog/feed/" 
"http://kitchingroup.cheme.cmu.edu/blog/feed" 
"http://whattheemacsd.com/atom.xml" 
"http://www.masteringemacs.org/feed/" 
"http://emacsredux.com/atom.xml" 
"http://www.lunaryorn.com/feed.atom" 
"http://www.clarkdonley.com/atom.xml"

;;linux
"http://thelinuxrain.com/feed" 
"http://www.archlinux.org/feeds/news/" 
"http://www.freesoftwaremagazine.com/rss.xml" 
"http://www.kde.org/dotkdeorg.rdf" 
"http://www.linuxjournal.com/node/feed" 
"http://www.lunduke.com/?feed=rss2" 
"http://kmandla.wordpress.com/feed/" 
"http://www.phoronix.com/rss.php" 
"http://planet.linux.org.il/atom.xml" 
"http://planetkde.org/rss20.xml" 
"http://blog.sarine.nl/feed/" 
"http://rss.slashdot.org/Slashdot/slashdotLinux" 
"http://whatsup.org.il/backend.php" 
"http://igurublog.wordpress.com/feed/" 

;;mobile
"http://feeds.feedburner.com/xda-developers/ShsH" 
;;sports
"http://debuzzer.com/feed/" 
;;uni 
"http://rforpublichealth.blogspot.com/feeds/posts/default" 
;;music
"https://muspy.com/feed?id=f9qypqwxc658e6dbzwk8n9mqthsgv4" 

))
 #+END_SRC
*** star/unstar items 
http://pragmaticemacs.com/emacs/star-and-unstar-articles-in-elfeed/

#+BEGIN_SRC emacs-lisp  :results none
;; code to add and remove a starred tag to elfeed article
;; based on http://matt.hackinghistory.ca/2015/11/22/elfeed/

;; add a star
(defun bjm/elfeed-star ()
  "Apply starred to all selected entries."
  (interactive )
  (let* ((entries (elfeed-search-selected))
         (tag (intern "starred")))

    (cl-loop for entry in entries do (elfeed-tag entry tag))
    (mapc #'elfeed-search-update-entry entries)
    (unless (use-region-p) (forward-line))))

;; remove a start
(defun bjm/elfeed-unstar ()
  "Remove starred tag from all selected entries."
  (interactive )
  (let* ((entries (elfeed-search-selected))
         (tag (intern "starred")))

    (cl-loop for entry in entries do (elfeed-untag entry tag))
    (mapc #'elfeed-search-update-entry entries)
    (unless (use-region-p) (forward-line))))

;; face for starred articles
(defface elfeed-search-starred-title-face
  '((t :foreground "#f77"))
  "Marks a starred Elfeed entry.")

(push '(starred elfeed-search-starred-title-face) elfeed-search-face-alist)


;; add keybindings
(eval-after-load 'elfeed-search
  '(define-key elfeed-search-mode-map (kbd "*") 'bjm/elfeed-star))
(eval-after-load 'elfeed-search
  '(define-key elfeed-search-mode-map (kbd "8") 'bjm/elfeed-unstar))

;;shortcut to jump to starred bookmark
(defun bjm/elfeed-show-starred ()
  (interactive)
  (bookmark-jump "elfeed-starred"))
(define-key elfeed-search-mode-map (kbd "S") 'bjm/elfeed-show-starred)
#+END_SRC
*** orgmode integration
    :PROPERTIES:
    :ID:       a15d3101-0eed-46ae-8187-77a7b026efa4
    :END:
when I org-capture in elfeed-show-mode using a template that includes a link, I get a nicely formatted link to the online linked entry. I use this to capture stuff I want to read later

#+BEGIN_SRC emacs-lisp
(defun elfeed-entry-as-html-link ()
  "Store an http link to an elfeed entry"
  (when (equal major-mode 'elfeed-show-mode)
    (let ((description (elfeed-entry-title elfeed-show-entry))
      (link (elfeed-entry-link elfeed-show-entry)))
     (org-store-link-props
      :type "http"
      :link link
      :description description))))

(add-hook 'org-store-link-functions 'elfeed-entry-as-html-link)
#+END_SRC

** elfeed-goodies
   :PROPERTIES:
   :ID:       cce462d0-7cf2-4963-ac5f-41f117b10f19
   :END:
https://github.com/algernon/elfeed-goodies

customise some aspects of the package with M-x customize-group elfeed-goodies
this is saved in file:/home/zeltak/.emacs.d/custom.el
#+BEGIN_SRC emacs-lisp :results none
(use-package elfeed-goodies
 :ensure t
 :config
(require 'elfeed-goodies)
(elfeed-goodies/setup) 
 )
#+END_SRC 
** eyebrowse
   :PROPERTIES:
   :ID:       4d8626fe-a8cf-4145-93aa-3a95c7a4b3df
   :END:

#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package eyebrowse
  ;;  :ensure t
  ;;  :config
  ;; (eyebrowse-mode t) 
  ;;  )
#+END_SRC 



** engine-mode
   :PROPERTIES:
   :ID:       a30cc878-accd-4d72-bb10-de28a83c69f7
   :END:
   
#+BEGIN_SRC emacs-lisp :results none
(use-package engine-mode
 :ensure t
 :config 
 )
#+END_SRC
** ess 
   :PROPERTIES:
   :ID:       30ddc44f-9af8-4f5f-b3f0-fc0f8aeeb25d
   :END:
#+BEGIN_SRC emacs-lisp :results none
(use-package ess 
 :ensure t
 :config
 )
#+END_SRC 

** EVIL
   :PROPERTIES:
   :ID:       5f03cc2a-51ee-44fe-bee4-38f7ca3ce239
   :END:
*** config 
#+BEGIN_SRC emacs-lisp :results none
	(use-package evil
	:ensure t
	:config
	(require 'evil)
	(evil-mode t)

      ;;;;keys
    (define-key evil-normal-state-map "\\" 'hydra-leader/body)
    (define-key evil-motion-state-map  "\\" ''hydra-leader/body)

    ;(define-key evil-normal-state-map (kbd "SPC") 'hydra-leader-space/body)
    (define-key evil-normal-state-map (kbd "SPC") ' avy-goto-char-timer)
  
    ;;undo
    (setq evil-want-fine-undo t) 

    ;I want Y to yank to the end of line.
    (setq evil-want-Y-yank-to-eol t)


      ;;;exclude following mode from evil mode 
      (add-to-list 'evil-emacs-state-modes 'dired-mode)
      (add-to-list 'evil-emacs-state-modes 'image-mode)

    ;;for orgmode capture widnows
    (add-hook 'org-capture-mode-hook 'evil-insert-state)
    (add-hook 'pass-mode-hook 'evil-insert-state)

 
	)
#+END_SRC

go back to normal mode after 50 seconds idle
#+BEGIN_SRC emacs-lisp  :results none
  (defun evil-normalize-all-buffers ()
    "Force a drop to normal state."
    (unless (eq evil-state 'normal)
      (dolist (buffer (buffer-list))
	(set-buffer buffer)
	(unless (or (minibufferp)
                    (eq evil-state 'emacs))
          (evil-force-normal-state)))
      (message "Dropped back to normal state in all buffers")))

  (defvar evil-normal-timer
    (run-with-idle-timer 150 t #'evil-normalize-all-buffers)
    "Drop back to normal state after idle for 150 seconds.")
#+END_SRC
*** DOCU
**** yank within characters
     :PROPERTIES:
     :ID:       050c6aa2-e82c-4796-90b1-6eb082cc230e
     :END:
Use whatever navigation key you want to get inside the parentheses, then you can use either yi( or yi) to copy everything within the matching parens. 

This also works with square brackets (e.g. yi]) and curly braces. 

In addition to y, you can also delete or change text (e.g. ci), di])

example for quotes:

#+BEGIN_EXAMPLE
ci"
#+END_EXAMPLE

** evil-org
https://github.com/edwtjo/evil-org-mode
#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package evil-org
  ;;  :ensure t
  ;;  :config
  ;;  (require 'evil-org)
  ;;  )
#+END_SRC 


** EVIL NERD Commenter
   :PROPERTIES:
   :ID:       a33933b7-00c5-404d-bb45-79fb5415b3f5
   :END:
https://github.com/redguardtoo/evil-nerd-commenter

 #+BEGIN_SRC emacs-lisp :results none
(use-package evil-nerd-commenter
:ensure t
:config
)
;(evilnc-default-hotkeys)
;(setq evilnc-hotkey-comment-operator ",,")
 #+END_SRC


** expand region
   :PROPERTIES:
   :ID:       f6ab2197-b490-4f44-8b2f-38a1e828711c
   :END:
https://github.com/magnars/expand-region.el


#+BEGIN_SRC emacs-lisp :results none
(use-package expand-region
 :ensure t
 :config
 )
#+END_SRC 
** find-file-in-project
   :PROPERTIES:
   :ID:       7e4fa0be-5a24-4f71-9228-4023ac3df5da
   :END:
https://github.com/technomancy/find-file-in-project

#+BEGIN_SRC emacs-lisp :results none
(use-package find-file-in-project
 :ensure t
 :config

 )
#+END_SRC 
** flx
   :PROPERTIES:
   :ID:       0bb8cd58-de7e-488a-b1f0-c6dc71789270
   :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package flx
 :ensure t
 :config
 
 )
#+END_SRC 
** fontawesome
https://github.com/syohex/emacs-fontawesome
#+BEGIN_SRC emacs-lisp :results none
(use-package fontawesome
 :ensure t
 :config
 
 )
#+END_SRC 


** Fill colum mode
   :PROPERTIES:
   :ID:       6dedd934-70bc-4779-914e-53d79a6dde2a
   :END:
#+BEGIN_SRC emacs-lisp :results none
(use-package fill-column-indicator
:ensure t
:config
)
#+END_SRC
qq
** git-auto-commit-mode
   :PROPERTIES:
   :ID:       0c297f90-fc69-448f-94d1-8fcfe7439f1d
   :END:
*** use package 
https://github.com/ryuslash/git-auto-commit-mode
#+BEGIN_SRC emacs-lisp :results none
(use-package git-auto-commit-mode
 :ensure t
 :config
(setq-default gac-automatically-push-p t)
 )
#+END_SRC
*** DOCU
**** As file-local variable

This is the way I use it and I wanted to use it. Any file that you would like to have automatically committed upon saving gets this prop-line:

#+BEGIN_EXAMPLE
;; -*- eval: (git-auto-commit-mode 1) -*-

#+END_EXAMPLE
**** As a directory-local variable

Put the following in a .dir-locals.el file in any directory where you want to enable git-auto-commit-mode for all files:
#+BEGIN_EXAMPLE
((nil . ((git-auto-commit-mode . t))))
#+END_EXAMPLE
**** As a hook

I doubt this will ever really be useful, but it is possible:
#+BEGIN_EXAMPLE
(add-hook 'some-hook 'git-auto-commit-mode)

#+END_EXAMPLE
**** Automatically push

If you wish to push your changes each time the file is saved you should set gac-automatically-push-p to t. This is a buffer local variable, so you will have to put it in your dir-local or file-local variables. Alternatively, if you're sure you can also set the default value to t, like so:

#+BEGIN_EXAMPLE
(setq-default gac-automatically-push-p t)

#+END_EXAMPLE

** Gnus related
   :PROPERTIES:
   :ID:       f29fb11a-38bb-4b1a-b0d8-8fae55b09761
   :END:
*** gnus-desktop-notify
    :PROPERTIES:
    :ID:       fcc8aa65-ff64-49b8-bc19-60499df16cb5
    :END:
http://www.thregr.org/~wavexx/software/gnus-desktop-notify.el/

#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package gnus-desktop-notify
  ;;  :ensure t
  ;;  :config
  ;;  (require 'gnus-desktop-notify)
  ;; (gnus-desktop-notify-mode)
  ;; (gnus-demon-add-scanmail)

  ;;  )
#+END_SRC
** git-timemachine
   :PROPERTIES:
   :ID:       14b54962-f61f-4030-8e31-74a522380c1c
   :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package git-timemachine
 :ensure t
 :config

(defun z/git-timemachine-show-selected-revision ()
  "Show last (current) revision of file."
  (interactive)
  (let (collection)
    (setq collection
          (mapcar (lambda (rev)
                    ;; re-shape list for the ivy-read
                    (cons (concat (substring (nth 0 rev) 0 7) "|" (nth 5 rev) "|" (nth 6 rev)) rev))
                  (git-timemachine--revisions)))
    (ivy-read "commits:"
              collection
              :action (lambda (rev)
                        (git-timemachine-show-revision rev)))))

(defun z/git-timemachine ()
  "Open git snapshot with the selected version.  Based on ivy-mode."
  (interactive)
  (unless (featurep 'git-timemachine)
    (require 'git-timemachine))
  (git-timemachine--start #'my-git-timemachine-show-selected-revision))
 
 )
#+END_SRC 



** gscholar-bibtex
   :PROPERTIES:
   :ID:       b8f8feb4-acda-4434-87e9-010e0b5b9177
   :END:
https://github.com/cute-jumper/gscholar-bibtex

#+BEGIN_SRC emacs-lisp :results none
(use-package gscholar-bibtex
 :ensure t
 :config
(setq gscholar-bibtex-default-source "Google Scholar")
(setq gscholar-bibtex-database-file "/home/zeltak/org/files/Uni/papers/library.2015.bib")

 )
#+END_SRC 


** google contacts
   :PROPERTIES:
   :ID:       c32032b3-66a6-4679-b6c5-66d91cad4e73
   :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package google-contacts
:ensure t
:config
)
#+END_SRC
** TODO goobook
   :PROPERTIES:
   :ID:       235f32ec-2e4f-4f76-8cd2-7c2170548abb
   :END:
this requires that goobook 
https://gitlab.com/groups/goobook
is installed and that you have a executable script in PATH named goosearch:
file:/home/zeltak/bin/goosearch

 #+BEGIN_SRC emacs-lisp  :results none
 ;;; helm-goobook.el
 ;; Copyright 2016 Shivam Kalra
 ;;
 ;; Author: Shivam Kalra <skalra@gmx.ca>

 ;;; Code:
 (defun goobook-search (search-term)
   (message search-term)
   (process-lines "goosearch" search-term))


 (defun helm-goobook-search ()
   (mapcar (lambda (entry)
             (let* ((vals (split-string entry "\t"))
                    (email (car vals))
                    (name (car (cdr vals)))
                    (key (format "%s <%s>" name email)))
               `(,key
                 (name . ,name)
                 (email . ,email)
                 (val . ,key)))) (goobook-search helm-pattern)))


 (defun helm-goobook-insert-key (entry)
   (with-helm-current-buffer
     (insert (cdr (assoc 'val entry)))))


 (defun helm-goobook-insert-name (entry)
   (with-helm-current-buffer
     (insert (cdr (assoc 'name entry)))))


 (defun helm-goobook-insert-email (entry)
   (with-helm-current-buffer
     (insert (cdr (assoc 'email entry)))))


 (defvar helm-source-goobook
   '((name . "Goobook Search")
     (volatile)
     (delayed)
     (requires-pattern . 3)
     (candidates .  helm-goobook-search)
     (action . (("Insert key" . helm-goobook-insert-key)
		("Insert email" . helm-goobook-insert-email)
		("Insert name" . helm-goobook-insert-name)))))


 (defun helm-goobook ()
   (interactive)
   (helm :sources '(helm-source-goobook)
	 :buffer "*helm-goobook*"))
 #+END_SRC



** goto-chg
   :PROPERTIES:
   :ID:       d17a87ed-227d-490b-b903-c830efe38932
   :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package goto-chg
 :ensure t
 :config
 (require 'goto-chg)
 :bind (("C-." . goto-last-change)
         ("C-," . goto-last-change-reverse))
 )
#+END_SRC 


** gmail2bbdb
   :PROPERTIES:
   :ID:       9e909d46-31d0-464a-88cb-47d02514e53a
   :END:
https://github.com/redguardtoo/gmail2bbdb

#+BEGIN_SRC emacs-lisp :results none
(use-package gmail2bbdb
 :ensure t
 :config

 )
#+END_SRC 

** gnorb
   :PROPERTIES:
   :ID:       f01851f2-97c3-4b0a-8a44-c7c026d02d1a
   :END:

https://github.com/girzel/gnorb

examples:

- Whang attachments from Gnus messages onto Org headings, using org-attach.
- Automate the above as part of the org capture process
- Email contents of org subtree under point (prompt for export routine)
- Single-keystroke Org links or email citations of BBDB contacts
- Initiate search of emails from contacts in open BBDB buffer
- Initiate Org agenda tag search from BBDB buffer
- Inverse of the above: pop up a BBDB buffer alongside an Org tags search
- Treat headings as email-related TODOs, and handle them DWIM-style

  #+BEGIN_SRC emacs-lisp :results none
  (use-package gnorb
   :ensure t
   :config
      )
  #+END_SRC 
** gnus-desktop-notify
https://github.com/wavexx/gnus-desktop-notify.el
#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package gnus-desktop-notify
  ;;  :ensure t
  ;;  :config

  ;; (require 'gnus-desktop-notify)
  ;; (gnus-desktop-notify-mode)
  ;; (gnus-demon-add-scanmail)
 
  ;;  )
#+END_SRC 


** grizzl
   :PROPERTIES:
   :ID:       c36866b0-bcb0-47bb-a2be-1ead4ed7fe74
   :END:
for projectile fuzzy match
#+BEGIN_SRC emacs-lisp :results none
(use-package grizzl
 :ensure t
 :config
  )
#+END_SRC 
** hungry-delete
https://github.com/nflath/hungry-delete

#+BEGIN_SRC emacs-lisp :results none
(use-package hungry-delete
 :ensure t
 :config
(require 'hungry-delete)
(global-hungry-delete-mode)
 )
#+END_SRC 
** hamburger-menu

#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package hamburger-menu
  ;;  :ensure t
  ;;  :config
  ;; (require 'hamburger-menu)
  ;; (setq mode-line-front-space 'hamburger-menu-mode-line)
  ;;  )
#+END_SRC 


** Helm
   :PROPERTIES:
   :ID:       50f595ed-ff48-45dd-b57f-a4f244881bd8
   :END:
*** use-package
**** load Helm
     :PROPERTIES:
     :ID:       1031a0b4-555c-4b4a-afb4-d6bb602c686a
     :END:
 #+BEGIN_SRC emacs-lisp :results none
 (use-package helm
 :ensure t
 :config
 (require 'helm-config)
 ;;to have helm be global use '1'-currently disabled 
 ;;(helm-mode 1)
 ;(global-set-key (kbd "M-x") 'helm-M-x)
 (setq helm-M-x-fuzzy-match t) ;; optional fuzzy matching for helm-M-x
 (global-set-key (kbd "C-c h") 'helm-command-prefix)
 (global-unset-key (kbd "C-x c"))
 ;;Autoresize
 (helm-autoresize-mode t)
 ;; sets min and max helm height
 (setq helm-autoresize-max-height 60)
 (setq helm-autoresize-min-height 40)
 )
 #+END_SRC
**** helm mini 
***** set helm mini sources to also include bookmarks 
 #+BEGIN_SRC emacs-lisp  :results none
 (setq helm-mini-default-sources
       '(helm-source-buffers-list
         helm-source-bookmarks
         helm-source-recentf
         helm-source-buffer-not-found)) 
 #+END_SRC
***** enable fuzzy matching
      :PROPERTIES:
      :ID:       ccf485a0-bbb5-4189-afd5-15f5309f4d4f
      :END:
    #+BEGIN_SRC emacs-lisp :results none
    (setq helm-buffers-fuzzy-matching t
	  helm-recentf-fuzzy-match    t)

   (global-set-key (kbd "C-x b") 'helm-mini)
    #+END_SRC

**** Helm configuration 
     :PROPERTIES:
     :ID:       f4c4cc17-28d5-43e9-a859-11682dff2fc0
     :END:
***** Helm viewing options config 
      :PROPERTIES:
      :ID:       817f080c-4579-40ba-b3e4-3d6edb97ade6
      :END:

  #+BEGIN_SRC emacs-lisp :results none
 (setq  helm-split-window-in-side-p           t ; open helm buffer inside current window, not occupy whole other window
	helm-move-to-line-cycle-in-source     t ; move to end or beginning of source when reaching top or bottom of source.
	helm-scroll-amount                    8 ; scroll 8 lines other window using M-<next>/M-<prior>
	helm-ff-file-name-history-use-recentf t
 )
  #+END_SRC

***** search org folders
      :PROPERTIES:
      :ID:       95d02d06-79b6-4656-b19f-99ee19f430b1
      :END:
  #+BEGIN_SRC emacs-lisp :results none
  (use-package helm-cmd-t
  :ensure t
  :config
  (defvar my-org-folders (list  "~/org/files/")
    "my permanent folders for helm-mini")

  (defun helm-my-org (&optional arg)
    "Use C-u arg to work with repos."
    (interactive "P")
    (if (consp arg)
	(call-interactively 'helm-cmd-t-repos)
      (let ((helm-ff-transformer-show-only-basename nil))
	(helm :sources (mapcar (lambda (dir)
				 (helm-cmd-t-get-create-source-dir dir))
                               my-org-folders)
              :candidate-number-limit 20
              :buffer "*helm-my-org:*"
              :input "org$ "))))
  )
  #+END_SRC

***** google suggest 
      :PROPERTIES:
      :ID:       d48d21f5-480c-45df-99c5-227babe28dc5
      :END:
  #+BEGIN_SRC emacs-lisp :results none
  (when (executable-find "curl")
    (setq helm-google-suggest-use-curl-p t))
  #+END_SRC

***** helm man-woman (man doc reader)
      :PROPERTIES:
      :ID:       c825b8ea-8970-4b03-8939-6204a04a571c
      :END:
  enable at point
  #+BEGIN_SRC emacs-lisp :results none
  (add-to-list 'helm-sources-using-default-as-input 'helm-source-man-pages)
  #+END_SRC
***** helm locate
      :PROPERTIES:
      :ID:       372f7037-cc02-4935-b2df-d46bec698bfb
      :END:
  enable fuzzy 
  #+BEGIN_SRC emacs-lisp :results none
  (setq helm-locate-fuzzy-match t)	    
  #+END_SRC
***** helm occur
      :PROPERTIES:
      :ID:       57fb7312-5c4e-471b-a27e-66bf95cd052f
      :END:
 no config needed$
**** helm-ag
     :PROPERTIES:
     :ID:       badc7d3b-f837-4f0f-90a4-c9ffcf0422f5
     :END:
  https://github.com/syohex/emacs-helm-ag
  #+BEGIN_SRC emacs-lisp :results none
  (use-package helm-ag
   :ensure t
   :config
 
   )
  #+END_SRC 


**** helm-fuzzier
     :PROPERTIES:
     :ID:       1ca73d48-fbfa-4897-8589-768122eb65bb
     :END:
  https://github.com/EphramPerdition/helm-fuzzier

  better fuzzy matching for helm

  #+BEGIN_SRC emacs-lisp :results none
  (use-package helm-fuzzier
   :ensure t
   :config
   (require 'helm-fuzzier)
    (helm-fuzzier-mode 1)
   )
  #+END_SRC 

  helm-fuzzier will only enhance matching for sources that have fuzzy-matching enabled, so be sure to enable fuzzy-matching for the sources you're interested in by setting the appropriate variable (helm-M-x-fuzzy-match, helm-mode-fuzzy-match, helm-apropos-fuzzy-match, etc').

**** helm-swoop
     :PROPERTIES:
     :ID:       fd278b56-8091-4e02-a321-ae24a461f7ef
     :END:
  https://github.com/ShingoFukuyama/helm-swoop

  #+BEGIN_SRC emacs-lisp :results none
  (use-package helm-swoop
   :ensure t
   :config
  ;; Move up and down like isearch
  (define-key helm-swoop-map (kbd "C-r") 'helm-previous-line)
  (define-key helm-swoop-map (kbd "C-s") 'helm-next-line)
  (define-key helm-multi-swoop-map (kbd "C-r") 'helm-previous-line)
  (define-key helm-multi-swoop-map (kbd "C-s") 'helm-next-line)

  ;; From helm-swoop to helm-multi-swoop-all
  (define-key helm-swoop-map (kbd "M-i") 'helm-multi-swoop-all-from-helm-swoop)

  ;; Save buffer when helm-multi-swoop-edit complete
  (setq helm-multi-swoop-edit-save t)

  ;; If nil, you can slightly boost invoke speed in exchange for text color
  (setq helm-swoop-speed-or-color nil)


   )
  #+END_SRC 
  helm-multi-swoop

  Select any buffers by [C-SPC] or [M-SPC]
  Press [RET] to start helm-multi-swoop

  Edit mode

  While doing helm-swoop type C-c C-e to enter the edit mode. Before enter the edit mode, you can choose some lines marked by C-SPC or M-SPC to edit. Apply changes to original buffer type C-x C-s.

**** helm mu
     :PROPERTIES:
     :ID:       09cc0f75-2032-4dcf-8a04-b7c80a833a8d
     :END:
  https://github.com/emacs-helm/helm-mu

  When you would like to read an email without finishing the helm session, you can select the email and press ~Ctrl-z~
  To search for contacts use `helm-mu-contacts`

  #+BEGIN_SRC emacs-lisp :results none
  (use-package helm-mu
   :ensure t
   :config
    )
  #+END_SRC
**** helm-projectile
     :PROPERTIES:
     :ID:       6cf169a5-bd69-4594-aaec-971c2ea26ec1
     :END:

  #+BEGIN_SRC emacs-lisp :results none
  (use-package helm-projectile
   :ensure t
   :config
 
   )
  #+END_SRC
**** helm-flyspell
     :PROPERTIES:
     :ID:       ed06a327-a3b8-4857-b42c-e3a08330d191
     :END:

 #+BEGIN_SRC emacs-lisp :results none
 (use-package helm-flyspell
  :ensure t
  :config
 
  )
 #+END_SRC
**** helm-buffers-list
     :PROPERTIES:
     :ID:       2c1575f8-0ea2-45e7-be54-6e97464e286e
     :END:
 fix terminal function
 #+BEGIN_SRC emacs-lisp  :results none
  (defun z/helm-buffers-dired ()
    "show dired buffers"
    (interactive)
    (helm :sources '(helm-source-buffers-list)
          :full-frame t
          :input "*dired "
         ))

  (defun z/helm-buffers-org ()
    "show org buffers"
    (interactive)
    (helm :sources '(helm-source-buffers-list)
          :full-frame t
          :input "*org "
         ))

  (defun z/helm-buffers-terminal ()
    "show term buffers"
    (interactive)
    (helm :sources '(helm-source-buffers-list)
          :full-frame t
          :input "*terminal "
         ))
 #+END_SRC
*** DOCU
**** intro 
***** $start here$ 
!IMPORTANT! Please remember that, when you use Helm, @you never TAB to complete prefixes@
like vanilla or other packages like Ido and its related packages. In Helm, when you type something, candidates get updated automatically. In vanilla Emacs, you have to TAB to get a list of candidate. This is a great feature from Helm, not a miss of feature. You have to forget the mentally of TABBING to get candidates. If you want quick completion of search patterns in Helm prompt, you always have hippie-expand to replace the TAB behaviour,

When you execute a Helm command, you enter a Helm session. A Helm session is a dedicated state to working with Helm features; while in a Helm session, a dedicated Helm buffer is always opened. When you quit a Helm session, a Helm buffer is closed. In Helm, you basically need to remember the 3 commands:

Access to action menu with TAB. An action is a command to run on marked candidates (one or more) and quit current Helm session; an action menu is a text-based menu that lists actions you can take. For example, Find File (open file), Find File in Dired, Grep File…
C-z executes helm-execute-persistent-action; a persistent action is an action that you use in a Helm session without quitting the session.
In some Helm session, such as helm-find-files or helm-mini, you can select more than one candidates and execute actions on them, such as grep or open.

***** base completion
Completion with Helm is very different with the usual Emacs completion:
You type something:

Instead of TAB to expand the common part until you find your candidates, in Helm, you type a parts of the candidate you want to search, separated by spaces. In Helm, these strings are called patterns. Patterns can also be regexps.
Helm will try to search and sort according to highest match, from top to bottom. The best match is at the top, so you can press RET and select it.
You can navigate the buffer with C-n and C-p or <up> and <down> to move up/down, C-v and M-v to move to next/previous pages, and M-< and M-> to move to top and bottom of the Helm buffer.
You can mark candidates with C-SPC; this is useful when you need to perform an action on many candidates of your choice. M-a to select all.
You can insert marked candidates into current buffer with C-c C-i. This is useful when you narrow to a list of candidates, i.e. files, then you want to save such candidates.
If you find the current horizontal Helm window is small, you can always switch it to vertical window with C-t. Running C-t again returns the Helm window back to horizontal and so on.
	   
***** base keys 	   
~TAB~ shows menu of launch options
select up/donn etc with common ~up/down/enter~ 
~C-z~ same as tab for select action (but this is persistant, that is helm wont close)
~C-SPACE~ mark canidadtes 
~Alt-a~ mark all
You can insert marked candidates into current buffer with ~C-c C-I~
~C-t~ cycle through helm view modes
~C-C ?~ get help on helm  	    
~left/righ~ move between helm groups in helm view 
**** find in files (C-x f)
use:
`helm-for-files`
**** helm org integration
***** searh only org headers (top level) with helm
use:

'Helm-org-headline'
**** helm colors
used to see colors and faces currently in system, use:

#+BEGIN_EXAMPLE
helm-colors
#+END_EXAMPLE

Key binding: n <prefix> c (prefix is C-x c by default, or C-c h if set).

If you want to quickly view and copy hexadecimal values of colors, helm-color provides such features. But, helm-color is beyond a mere color picker. The real usage for helm-color is for face customization: the command list ALL available faces, with a preview of each face in the same row. This makes theme customization really quick because you can quickly view a face with its color. Because the way Helm work, you can look at a group of faces together to have a global view if the colors work well with each other.

helm-color contains two groups, with actions in each:

Colors:
Key	Action
[f1] or C-c N	Copy Name
 	Copy color name into kill-ring
[f2] or C-c R	Copy RGB
 	Copy hex value into kill-ring
[f3] or C-c n	Insert Name
 	Insert color name into current buffer
[f4] or C-c r	Insert RGB
 	Insert hex value into current buffer

Customize Face:
Key	Action
[f1]	Customize
 	Open Customization window
[f2]	Copy Name
 	Copy face name

**** searching/mathcing
***** search with 2 search terms    
helm has out of order matching, with regular expression. That's right, you can enter every search pattern as regexp!
First, I enter main.c, and I got lots of candidates. Then, I only want the main.c inside x86 directory, so I type x86. The whole pattern is:
#+BEGIN_EXAMPLE
main.c x86 
#+END_EXAMPLE
and Helm returns the correct candidate: arch/x86/boot/main.c.
**** helm mini
***** helm-mini comprises of multiple sources:

`Current opened` buffers, under the header Buffers.
`Recently opened` files, under the header Recentf.
`create a new buffer` by pressing RET, under the header Create Buffer.

You can move back and forth between the groups by using ~<left> // <right>~ arrow keys. Or you can just scroll down/up with C-v and M-v.

***** filter out buffers by major mode using the pattern *<major-mode>.
For example,

#+BEGIN_EXAMPLE
*dired
#+END_EXAMPLE

***** narrows to only Dired buffers.

You can also `filter out` buffers that belong to a major mode by adding `!` to the pattern. For example,
#+BEGIN_EXAMPLE
*!dired
#+END_EXAMPLE
select all buffers that are not in Dired mode.

***** You can also select buffers in a specific directory by using the pattern `/directory`.
For example,
#+BEGIN_EXAMPLE
/.emacs.d/
#+END_EXAMPLE

narrows to buffers that are only inside .emacs.d. Add ! before the pattern for reverse version. For example, !/.emacs.d/ narrows to buffers not in .emacs.d.

***** narrow to buffers that contains a regexp in their contents
by appending `@` before the search pattern. For example, you can select buffers that only contain the string "test":

#+BEGIN_EXAMPLE
@test
#+END_EXAMPLE

***** meaning of colors and prefixes for buffers:
Remote buffers are prefixed with '@'.
Red => Buffer have its file modified on disk by an external process.
Indianred2 => Buffer exists but its file have been deleted.
Orange => Buffer is modified and its file not saved to disk.
Italic => A non-file buffer.
$Note$-Some Emacs themes change the colors. You should check the corresponding colour in your color themes.

***** Example mini helm narrow searches

If I enter in pattern prompt: *lisp ^helm @moc, Helm will narrow down the list by selecting only buffers that are in lisp mode, start by helm and match "moc" in their contents.
If I want to specify more than one major-mode, separate them with ,, e.g *!lisp,!sh,!fun will list all buffers but the ones in lisp-mode, sh-mode and fundamental-mode.
If I enter in pattern prompt: *lisp ^helm moc. Notice there is no @ this time helm will look for lisp mode buffers starting by "helm" and have "moc" in their name.
If I enter in pattern prompt: *!lisp !helm Helm will narrow down to buffers that are not in "lisp" mode and that do not match "helm".
If I enter in pattern prompt: /helm/ w3 Helm will narrow down buffers that are in any "helm" sub-directory and matching w3.
	    
**** helm find files 
***** base 
helm-find-files is file navigation on steroid:

helm-find-files can fuzzy match candidates in current directory. e.g "fob" or "fbr" will complete "foobar".

You can also execute persistent action, which is bound to C-z (by default) or TAB if you changed the default configuration (to have TAB be persistant) to narrow the current highlighting candidate

pressing  C-z or TAB again allows to  view content of the buffer (preview)

You can scroll the other buffer up/down by M-<next> and M-<prior>.

you can ~C-j~  to narrow to the highlighting candidate
and ~C-j~ again to view the content of other buffer. C-l to go back.

***** quick nav 
left take you back
right enters a folder 
Enter-opens the file or the folder in dired

Enter ~/ at end of pattern to quickly reach home directory.
Enter / at end of pattern to quickly reach root of your file system.
Enter ./ at end of pattern to quickly reach `default-directory' (initial start of session). If you are in `default-directory' move cursor on top.
***** go up one directory level with ~C-l~
You can also go up one directory level with ~C-l~

$Note$ if you use C-l, Helm goes up one level and the cursor is on the directory you've just got out. If you want to go up and have the cursors on the parent directory, in Helm prompt, enter ../.

***** File and directory histories
With prefix argument before running helm-find-files, Helm displays a list of visited directories. Select one at point transfer helm-find-files to that directory and you can start navigating there.

During a helm-find-files session, you can get a list of visited files and directories with

~C-c h~

From there, the default action is RET to open the file/directory at point, or continue with helm-find-files starting at that file/directory.

You can use M-p and M-n to move back and forth between previously visited directory.	    
***** create a directory/file
enter a new name that does not exist in the current directory and append / at the end. After you created a directory, Helm continues in that directory.

To create a new file, enter a name and select the top row that has the symbol [?] next to it. By default, Helm always selects the first match in the directory.

***** invoke grep on the current highlighting entry 
You can invoke grep on the current highlighting entry by C-s. C-u C-s to perform recursive grep.
***** find file on point
helm-find-files can be used to find file paths on point : all you need to do is moving your point on a proper filepath, and Helm will reach the correct path for you, similar to the screenshot. Now, you have no longer to use a separate command for open file at point, but using the same C-x C-f. It's really convenient.

**** helm-man-woman (read manuals with org)
Key binding:

<prefix> m (prefix is C-x c by default, or C-c h if set).

Description:

With helm-man-woman, you can quickly jump to any man entry using Helm interface, either by typing in Helm prompt or if point is on a symbol, get a man page at point. To enable man page at point, add the following code:

(add-to-list 'helm-sources-using-default-as-input 'helm-source-man-pages)
**** helm locate    
Key binding:

<prefix> l (prefix is C-x c by default, or C-c h if set).

Description:

Similar to helm-find, but use locate command and accepts search patterns according to locate input. Use helm-man-woman to read locate man page.

To use local database, execute helm-locate with prefix argument C-u. You can also customize Helm to use locate with arguments of your choice:

#+BEGIN_SRC emacs-lisp :results none
(setq helm-locate-command "locate %s -e -A --regex %s")
#+END_SRC

If you use helm-locate on a large directory and feel the update is too sluggish, you can always suspend the live updating with C-! and resume the live updating with C-! later.

To enable fuzzy matching in helm-locate, add this setting:

#+BEGIN_EXAMPLE
(setq helm-locate-fuzzy-match t)	    

#+END_EXAMPLE

**** helm-occur
Command: helm-occur

Key binding:

<prefix> M-s o (prefix is C-x c by default, or C-c h if set). Since this is a rather long binding, we should bind a more convenient key sequence:

(global-set-key (kbd "C-c h o") 'helm-occur)

Similar to occur, but using Helm interface. As you type, matching lines are updated immediately. This is convenient when you want to have a list of matches in the current buffer to jump back and forth. TAB to temporary move point to the location of current highlighting match. C-g cancels current Helm session and returns to the original location where helm-occur is invoked. RET on a match jumps to that match.

**** helm-apropos
<prefix> a (prefix is C-x c by default, or C-c h if set).

Pre-configured helm to describe commands, functions, variables and faces - all in one command!. It is similar to C-h a which runs apropos-command, but interactive includes more than just commands. helm-apropos comprises of 5 sources:

Commands: Lists all available commands.
Fucntion: Lists all available functions.
Classes: Lists all classes created by defclass. See Building Classes.
Generic Functions: Lists all functions created by defmethod. See Writing Methods
Variables: Lists all available variables.
Faces: Lists all available faces.
Helm attributes: Lists all attributes that you can use to build a Helm source. Useful if you want to write extension with Helm.
To enable fuzzy matching, add this setting:

(setq helm-apropos-function-list t)
**** helm-info-*

Key binding:

<prefix> h <key> (prefix is C-x c by default, or C-c h if set); <key>, by defaults, is one of g, i or r:

So, the prefix for info commands is <prefix> h. You can think of h as stands for help and <key> is one of the info topic to make it easier to remember and recall.

helm offers a wide ranges of info commands for various topics. M-x helm info to see these commands, i.e. helm-info-as, helm-info-gdb… You can search for info nodes easily with Helm interface and TAB on an entry to view. M-<next> moves to the next page, M-<prior> moves to the previous page in the other buffer.

You can have more helm-info- commands, such as:

helm-info-gdb.
helm-info-find.
helm-info-elisp.

Use M-x helm-info to see the list of helm-info- commands using the default info prefix: <prefix> h or key bindings of your choice.

**** helm-resume

Key binding:

<prefix> b (prefix is C-x c by default, or C-c h if set).

Description:

This command allows you to resume the previous Helm session, along with your previous patterns in the prompt. For example, if your last helm session was helm-ff-run-grep and you entered patterns in Helm prompt, helm-resume resumes that session along with your previous input.

With prefix argument, helm-resume allows you to choose among all existing Helm buffers. helm-mini or helm-buffer-list does not show existing Helm buffers; they ignore it by default; but if you run ibuffer, you will see a list of Helm buffers visible there. Don't kill them or you won't be able to resume.

This is really convenient when you have complex input ,and preparation steps. For example, if you have multiple regexp patterns in your previous Helm session, then you don't have to type it again. Or in your previous Helm session, you have to travel to a deep directory, and helm-resume helps you to reuse your previous session without going through all the troubles again.
**** TODO helm-all-mark-rings
Key binding:

<prefix> C-c SPC (prefix is C-x c by default, or C-c h if set). This is a rather long key sequence, this command deserves a better binding, for example:

(global-set-key (kbd "C-h SPC") 'helm-all-mark-rings)
Description:

One handy command. It allows you to view the content of the both the local and global mark rings in a friendly interface, so you can always jump back to where you were. Without this command, if you want to view the mark rings, you have to run M-: and enter mark-ring or global-mark-ring to view their contents. And even so, Emacs only displays the bare content of the mark-ring and global-mark-ring lists, which is the line number and its buffer like this:

**** helm-top

Key binding:

<prefix> t (prefix is C-x c by default, or C-c h if set).

Description:

This command provides Helm interface for top program. You can interact with each process with the following actions:

Key	Binding
[f1]	kill (SIGTERM)
[f2]	kill (SIGKILL)
[f3]	kill (SIGINT)
[f4]	kill (Choose signal)
helm-top specific commands:

Key	Binding
C-c C-u	Refresh helm-top
M-C	Sort by shell commands
M-P	Sort by CPU usage
M-U	Sort by user
M-M	Sort by memory
user and shell commands are sorted alphabetically.

**** helm-calcul-expression

Key binding:

<prefix> C-, (prefix is C-x c by default, or C-c h if set).

Description:

This commands provides a Helm interface for calc command

**** helm m-x
***** prefix key
n the original M-x, you pass prefix arguments before M-x.I
'In Helm', you pass prefix arugments after running helm-M-x.
In a helm-M-x session, if you type any prefix argument, it will be visible, i.e. if you type C-u 100, a message prefix argument: 100 appears. Then run your command as usual, the interactive command will receive the argument you passed in.

** help-fns+
   :PROPERTIES:
   :ID:       d6bf1be3-a92b-4ec2-8588-4943a1ee4a6f
   :END:
http://www.emacswiki.org/emacs/help-fns+.el

used also in dired
#+BEGIN_SRC emacs-lisp :results none
(use-package help-fns+
 :ensure t
 :config
 
 )
#+END_SRC 


** helm-bibtex
   :PROPERTIES:
   :ID:       d25ec766-c44d-4e75-ae83-17cbd57b0205
   :END:
https://github.com/tmalsburg/helm-bibtex
*** use packages
**** main conf 
 #+BEGIN_SRC emacs-lisp :results none
 (use-package helm-bibtex
  :ensure t
  :config

 ;;;if not installing through MELPA
 ;;;(autoload 'helm-bibtex "helm-bibtex" "" t)

 ;;; telling helm-bibtex where your bibliographies can be found:
 (setq helm-bibtex-bibliography '("/home/zeltak/org/files/Uni/papers/zeltak.papers.bib" "/home/zeltak/org/files/Uni/papers/library.bib" "/home/zeltak/org/files/Uni/papers/zeltak.misc.bib" ))

 ;;Specify where PDFs can be found:
 (setq helm-bibtex-library-path (list "/home/zeltak/Sync/Uni/pdf_lib/" "/home/zeltak/Sync/Uni/pdf_lib_gen/") ) 

 ;;;If the BibTeX entries have a field that specifies the full path to the PDFs, that field can also be used
 (setq helm-bibtex-pdf-field "File")

 ;;;; Note files
 (setq helm-bibtex-notes-path "/home/zeltak/org/files/Uni/papers/notes")
 (setq helm-bibtex-notes-extension ".org")

 (setq helm-bibtex-format-citation-functions
   '((org-mode      . helm-bibtex-format-citation-org-link-to-PDF)
     (latex-mode    . helm-bibtex-format-citation-cite)
     (markdown-mode . helm-bibtex-format-citation-pandoc-citeproc)
     (default       . helm-bibtex-format-citation-default)))

 ;;Fields used for searching
 (setq helm-bibtex-additional-search-fields '(tags))

 ;;;Symbols used for indicating the availability of notes and PDF files
 (setq helm-bibtex-pdf-symbol "𝍌")
 (setq helm-bibtex-notes-symbol "✎")

 ;;set default browser
 (setq helm-bibtex-browser-function
;   (lambda (url _) (start-process "qutebrowser" "*qutebrowser*" "qutebrowser" url)))
;   (lambda (url _) (start-process "firefox" "*firefox*" "firefox" url)))
   (lambda (url _) (start-process "chromium" "*chromium*" "chromium" url)))

(setq bibtex-completion-display-formats
    '(
    (t  ."${=key=:14} ${author:36} ${title:*} ${year:4} ${=has-pdf=:1}${=has-note=:1} ${=type=:7}")
    ))




  )
 #+END_SRC 

(setq bibtex-completion-display-formats
    '(
    (article .  "${=key=:14} ${author:36} ${title:*} ${year:4} ${=has-pdf=:1}${=has-note=:1} ${=type=:7}")
    (t  ."${=key=:14} ${author:36} ${title:*} ${year:4} ${=has-pdf=:1}${=has-note=:1} ${=type=:7}")
    ))


**** my papers 
     :PROPERTIES:
     :ID:       944b7fd3-3354-43fa-925d-d46c67307250
     :END:
 this example below also restricts to a specific bib file

 #+BEGIN_SRC emacs-lisp :results none
  (defun helm-bibtex-izeltak-publications ()
    "Search BibTeX entries authored by me"
    (interactive)
 (let ((helm-bibtex-bibliography "/home/zeltak/org/files/Uni/papers/zeltak.papers.bib"))
    (helm :sources '(helm-source-bibtex)
    :full-frame t
          :input "zeltak !kprep !ktalk !kconf !unpublished "
          :candidate-number-limit 500)))
	 
 #+END_SRC
**** papers RTODO (to read)
     :PROPERTIES:
     :ID:       85f35a00-7e0a-4229-98f5-b32952219f36
     :END:
 this example below also restricts to a specific bib file

 #+BEGIN_SRC emacs-lisp :results none
  (defun helm-bibtex-papers-rtodo ()
    "Search BibTeX entries authored by me"
    (interactive)
 (let ((helm-bibtex-bibliography "/home/zeltak/org/files/Uni/papers/library.bib"))
    (helm :sources '(helm-source-bibtex)
          :full-frame t
          :input "rtodo "
          :candidate-number-limit 500)))

 #+END_SRC


**** my papers (all)
     :PROPERTIES:
     :ID:       632f2d71-8da7-423d-a20a-a286513afaa3
     :END:
 #+BEGIN_SRC emacs-lisp :results none

  ;; Define helm-search with predefined search expression:
  (defun helm-bibtex-izeltak-publications-all ()
    "Search BibTeX entries authored by me (ALL including prep)"
    (interactive)
    (helm :sources '(helm-source-bibtex)
          :full-frame t
          :input "zeltak !unpublished "
          :candidate-number-limit 500))
 #+END_SRC

**** my prepared maunscripts
     :PROPERTIES:
     :ID:       4a4b85ad-8a2c-4600-bc93-5e08d287224b
     :END:
 #+BEGIN_SRC emacs-lisp :results none

  ;; Define helm-search with predefined search expression:
  (defun helm-bibtex-izeltak-prep         ()
    "Search BibTeX entries in preperation with me"
    (interactive)
    (helm :sources '(helm-source-bibtex)
          :full-frame t
          :input "zeltak kprep !unpublished "
          :candidate-number-limit 500))

  #+END_SRC
*** DOCU
**** naming pdf 
Helm-bibtex assumes that the name of a PDF consists of the BibTeX key followed by the suffix .pdf. For example, if a BibTeX entry has the key Darwin1859, helm-bibtex searches for Darwin1859.pdf.

you can use =key= in the format string: e.g., ${=key=:14}

**** change color of modline matches
change this variable wither in theme or with M-x > customize faces 
#+BEGIN_EXAMPLE
;;modline color for helm inof there
`(helm-candidate-number ((,class (:foreground "green" :background "#073642")))) 
#+END_EXAMPLE
**** custom helm-bibtex search 
example :
#+BEGIN_EXAMPLE

;; Define helm-search with predefined search expression:
(defun helm-bibtex-my-publications ()
  "Search BibTeX entries authored by Xebar Sara."
  (interactive)
  (helm :sources '(helm-source-bibtex)
        :full-frame t
        :input "xebar saram"
        :candidate-number-limit 500))

;; Bind this search function to Ctrl-x p:
;(global-set-key (kbd "C-x p") 'helm-bibtex-my-publications)
#+END_EXAMPLE

**** search on custom keywords
from dev email

I use two BibTeX fields to tag entries: “keywords” for keywords
describing the content of the paper (as usual) and “tags” for meta
data.  Values that I use in tags are “own”, “manuscript”, “poster”,
“talk”, … So if I want a list of all articles in progress, I search for
“own manuscript”.  Since the tags field is non-standard, it has to be
added to `helm-bibtex-additional-search-fields`.

Another solution would be to use the pubstate field and to search for
your name and “forthcoming” (add pubstate to
helm-bibtex-additional-search-fields for this to work).

in my example I add to my *.bib file a `tags` filed. then I add this to my helm-bibtex config

#+BEGIN_EXAMPLE
(setq helm-bibtex-additional-search-fields '(tags))
#+END_EXAMPLE

**** serach tips
the key to NOT select is
`!`

-Publications from 2010 and 2011:
#+BEGIN_EXAMPLE
\(2010\|2011\)
#+END_EXAMPLE

**** Search the word under the cursor
A common use case is where a search term is written in a document (say in your LaTeX manuscript) and you want to search for it in your bibliography. In this situation, just start helm-bibtex and enter M-n. This inserts the word under the cursor as the search term. (This is a helm feature and can be used in all helm sources not just helm-bibtex.) Note that it is also possible to use BibTeX keys for searching. So if your cursor is on a BibTeX key (e.g., in a LaTeX cite command) you can start helm-bibtex, hit M+n and see the entry associated with that BibTeX key. Special case: you want to open the PDF associated with the BibTeX key under the cursor: M-x helm-bibtex M-n Enter. This is of course shorter if you bind helm-bibtex to a convenient key (see Key-bindings).
**** Change order of entries
Yes.  Helm uses the first action as the default action.  To move an
action to the top of the list you can use the following code:

#+BEGIN_EXAMPLE
(helm-delete-action-from-source "Insert BibTeX key" helm-source-bibtex)
(helm-add-action-to-source "Insert BibTeX key" 'helm-bibtex-insert-key helm-source-bibtex 0)

#+END_EXAMPLE

The second argument in the second line is the function that executes the
action.  Here is a list of all actions and their functions:
#+BEGIN_EXAMPLE
  Open PDF file (if present): helm-bibtex-open-pdf
  Open URL or DOI in browser: helm-bibtex-open-url-or-doi
  Insert citation: helm-bibtex-insert-citation
  Insert reference: helm-bibtex-insert-reference
  Insert BibTeX key: helm-bibtex-insert-key
  Insert BibTeX entry: helm-bibtex-insert-bibtex
  Attach PDF to email: helm-bibtex-add-PDF-attachment
  Edit notes: helm-bibtex-edit-notes
  Show entry: helm-bibtex-show-entry
#+END_EXAMPLE

**** Send emails (mu4e) with references/pdfs 
Start an email to your colleague and M-x helm-bibtex. Select your new publications and select “Attach PDF to email.” Then M-x helm-resume (the publications are still marked) and select “Insert BibTeX entry.” Optionally insert more human readable references by M-x helm-resume and “Insert reference.” Send email. Done. This takes less than 10 seconds. Of course, this assumes that you’re sending email from Emacs, e.g. via Mu4e.
**** select all 
~M-a~ selects all candidates
**** use regular expressions to search for a range of
years: 201[2-5]

** helm-bbdb
https://github.com/emacs-helm/helm-bbdb/blob/master/helm-bbdb.el


#+BEGIN_SRC emacs-lisp :results none
(use-package helm-bbdb
:ensure t
 :config
)
#+END_SRC 


** isearch
   :PROPERTIES:
   :ID:       e343aaf6-ec9c-44cb-b726-2e3fc1e53288
   :END:
*** main 
And you can use M-e (isearch-edit-string) to interrupt Isearch to edit the current search string, using the minibuffer

#+BEGIN_SRC emacs-lisp :results none
  (progn
    ;; set arrow keys in isearch. left/right is backward/forward, up/down is history. press Return to exit
    (define-key isearch-mode-map (kbd "<up>") 'isearch-ring-retreat )
    (define-key isearch-mode-map (kbd "<down>") 'isearch-ring-advance )
    (define-key isearch-mode-map (kbd "<left>") 'isearch-repeat-backward) ; single key, useful
    (define-key isearch-mode-map (kbd "<right>") 'isearch-repeat-forward) ; single key, useful
    (define-key isearch-mode-map (kbd "C-y") 'isearch-repeat-forward) ; single key, useful
    (define-key isearch-mode-map (kbd "S-<insert>") 'isearch-repeat-forward) ; single key, useful
   )

;; color isearch


  ;; (add-hook 'isearch-mode-hook
  ;;           (lambda ()
  ;;             (set (make-local-variable 'isearch-mode-line-face-remap-cookie)
  ;;                  (face-remap-add-relative
  ;;                   'mode-line '((:foreground "ivory" :background "red") mode-line)))))

  ;; (add-hook 'isearch-mode-end-hook
  ;;           (lambda ()
  ;;             (face-remap-remove-relative isearch-mode-line-face-remap-cookie)))

#+END_SRC
*** Connected packages
**** isearch-dabbrev
https://github.com/Dewdrops/isearch-dabbrev
#+BEGIN_SRC emacs-lisp :results none
(use-package isearch-dabbrev
 :ensure t
 :config
(define-key isearch-mode-map (kbd "<tab>") 'isearch-dabbrev-expand) 
 )
#+END_SRC
**** TODO ace-isearch
https://github.com/tam17aki/ace-isearch
#+BEGIN_SRC emacs-lisp :results none
(use-package ace-isearch
 :ensure t
 :config
;(ace-isearch-mode +1) 
;(global-ace-isearch-mode +1)

(setq ace-isearch-funciton 'avy-goto-word-1) 
(define-key isearch-mode-map (kbd "C-'") 'ace-isearch-jump-during-isearch)

 )
#+END_SRC
**** isearch+
https://www.emacswiki.org/emacs/IsearchPlus

#+BEGIN_SRC emacs-lisp :results none
(use-package isearch+
 :ensure t
 :config
 
 )
#+END_SRC 

** ivy-bibtex 
https://github.com/tmalsburg/helm-bibtex
#+BEGIN_SRC emacs-lisp :results none
(use-package ivy-bibtex
 :ensure t
 :config
 
 )
#+END_SRC 
** helm-unicode 

#+BEGIN_SRC emacs-lisp :results none
(use-package helm-unicode
 :ensure t
 :config
 
 )
#+END_SRC 


** helm-org-rifle
   :PROPERTIES:
   :ID:       aad40df6-cec2-48b8-ae6b-fd6e4c49c1f7
   :END:
https://github.com/alphapapa/helm-org-rifle

#+BEGIN_SRC emacs-lisp :results none
(use-package helm-org-rifle
 :ensure t
 :config
 )
#+END_SRC 
** helm pass 
https://github.com/jabranham/helm-pass
#+BEGIN_SRC emacs-lisp  :results none
(use-package helm-pass
  :ensure t
  )
#+END_SRC
** TODO helm-recoll
https://github.com/emacs-helm/helm-recoll
#+BEGIN_SRC emacs-lisp :results none
(use-package helm-recoll
 :ensure t
 :config
;; you can also create data sources 
(helm-recoll-create-source "org" "~/.recoll-org/")
)
#+END_SRC 

installing:

First you have to create an index for each directory you want such as ~/.recoll-<your-directory-name. see:

file:~/.recoll-org/

then create "recoll.conf" config files in each directory containing
topdirs = <full/path/to/your/directory>
#+BEGIN_EXAMPLE
topdirs = /home/zeltak/org /home/zeltak/Sync
#+END_EXAMPLE

then run recollindex -c ~/.recoll-<your-directory-name>

#+BEGIN_EXAMPLE
recollindex -c ~/.recoll-org         
#+END_EXAMPLE

also you can use counsel-recoll. this uses the ~/.recoll database 
** mu4e-alert							
   :PROPERTIES:
   :ID:       3d5b22fc-bce6-4615-b634-7e19647d753f
   :END:
https://github.com/iqbalansari/mu4e-alert
#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package mu4e-alert
  ;;  :ensure t
  ;;  :config
  ;; ;; Choose the style you prefer for desktop notifications
  ;; (mu4e-alert-set-default-style 'libnotify)
  ;; (add-hook 'after-init-hook #'mu4e-alert-enable-notifications) 
  ;; (add-hook 'after-init-hook #'mu4e-alert-enable-mode-line-display)
  ;; ;;below will color the fringe (left side of an Emacs window)..worked but couldn't see how to disable it
  ;; ;;;(alert-add-rule :category "mu4e-alert" :style 'fringe :predicate (lambda (_) (string-match-p "^mu4e-" (symbol-name major-mode))) :continue t)
  ;; (mu4e-alert-enable-notifications)

  ;;  )
#+END_SRC 

*** to restore the fringe to to a bug
    :PROPERTIES:
    :ID:       8dc668df-5348-45b7-a830-03264e91b29f
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun alert-fringe-restore (info)
  (copy-face 'alert-saved-fringe-face 'fringe))
#+END_SRC

** Highlight symbol
   :PROPERTIES:
   :ID:       894f4b11-c136-4385-9fc6-a4632590ffb4
   :END:
https://github.com/nschum/highlight-symbol.el
highlight word at point and move forward next to other words
#+BEGIN_SRC emacs-lisp :results none
(use-package highlight-symbol
 :ensure t
 :config
 )
#+END_SRC 
** iedit
   :PROPERTIES:
   :ID:       c1b4d29d-20ee-4898-be1a-e5a0649060ca
   :END:
https://github.com/victorhge/iedit

#+BEGIN_SRC emacs-lisp :results none
(use-package iedit
 :ensure t
 :config
 )
#+END_SRC 
** `ivy` family
   :PROPERTIES:
   :ID:       9c17e9d9-c28d-4c48-a897-504da4face7a
   :END:
*** ivy 
**** base 
http://oremacs.com/swiper/#getting-started

#+BEGIN_SRC emacs-lisp :results none
 (use-package ivy
  :ensure t
  :config
 ;;ivy everywhere 
 (ivy-mode 1)
 (setq ivy-use-virtual-buffers t)
 ;;go back to first entry when reaching end of completion list (wrap)
 (setq ivy-wrap nil)
 ;;height of ivy buffer
 (setq ivy-height 16)


 ;;;keys 
; (global-set-key "\C-s" 'counsel-grep-or-swiper)
 ;(global-set-key "\C-s" 'swiper)
; (global-set-key "\C-r" 'swiper-at-point)
 (global-set-key (kbd "C-c C-r") 'ivy-resume)


 ;;(define-key ivy-minibuffer-map (kbd "<left>") 'ivy-backward-delete-char)
 (define-key ivy-minibuffer-map (kbd "<left>") 'counsel-up-directory)
 (define-key ivy-minibuffer-map (kbd "<right>") 'ivy-alt-done)
 
(define-key ivy-minibuffer-map (kbd "<M-down>") 'ivy-end-of-buffer)
(define-key ivy-minibuffer-map (kbd "<M-up>") 'ivy-beginning-of-buffer)
 


;;allow【M-o I】 use to insert M-x commands into current buffer  
 (defun ivy-insert-action (x)
   (with-ivy-window
     (insert x)))



 (ivy-set-actions
 t
  '(("j" find-file-other-window "other window")
    ("i" ivy-insert-action "insert current command into buffer")
    ("s" ivy-sudo-edit-action "open as root")
    ("c" (lambda (_) (interactive) (counsel-bookmark)) "open bookmark buffer")
    ("f" counsel-find-file-cd-bookmark-action "cd in swiper to bookmark")
  ))


 )
 #+END_SRC 

**** enable fuzzy matching by default
     :PROPERTIES:
     :ID:       58a7a0a2-9e59-4de2-aee4-cc930142aa3b
     :END:
 #+BEGIN_SRC emacs-lisp :results none
 (setq ivy-re-builders-alist
       '((t . ivy--regex-fuzzy)))
 #+END_SRC
**** Enable fancy mode
     :PROPERTIES:
     :ID:       d4661c00-44fd-4a6e-b09a-118da7159012
     :END:
 #+BEGIN_SRC emacs-lisp :results none
 (setq ivy-display-style 'fancy)

 (custom-set-faces
  '(swiper-minibuffer-match-face-1
    ((t :background "#dddddd")))
  '(swiper-minibuffer-match-face-2
    ((t :background "#bbbbbb" :weight bold)))
  '(swiper-minibuffer-match-face-3
    ((t :background "#bbbbff" :weight bold)))
  '(swiper-minibuffer-match-face-4
    ((t :background "#ffbbff" :weight bold))))
 #+END_SRC
**** show more verbose matching 
     :PROPERTIES:
     :ID:       39ddbaae-13ec-4368-9c6e-36fd7748270d
     :END:
 #+BEGIN_SRC emacs-lisp :results none
 (setq ivy-count-format "(%d/%d) ")
 #+END_SRC
**** notes
ivy-immediate-done 【C-M-j 】 to finialize file names

*** Counsel
    :PROPERTIES:
    :ID:       740c355d-36fd-486e-bba8-c996a9792a3e
    :END:
 #+BEGIN_SRC emacs-lisp :results none
 (use-package counsel
  :ensure t
  :config
;; Do not show "./" and "../" in the `counsel-find-file' completion list
(setq ivy-extra-directories nil) ; default value: ("../" "./")

   )
 #+END_SRC 
**** notes 
     :PROPERTIES:
     :ID:       ef2266b5-d067-4164-a986-6140f31c4b77
     :END:
to make sure counsel-grep-or-swiper isn't case sensitive use the customize-variable menu and make the 〖counsel-grep-base-command〗  value be 〖grep -nEi \"%s\" %s〗 

** ivy-pages
https://github.com/igorepst/ivy-pages
#+BEGIN_SRC emacs-lisp :results none
(use-package ivy-pages
 :ensure t
 :config
 
 )
#+END_SRC 


** ibuffer
   :PROPERTIES:
   :ID:       7e63dd5d-b026-4b31-a2bb-4775645633fb
   :END:

#+BEGIN_SRC emacs-lisp  :results none
;; Use human readable Size column instead of original one
(define-ibuffer-column size-h
  (:name "Size" :inline t)
  (cond
   ((> (buffer-size) 1000000) (format "%7.1fM" (/ (buffer-size) 1000000.0)))
   ((> (buffer-size) 100000) (format "%7.0fk" (/ (buffer-size) 1000.0)))
   ((> (buffer-size) 1000) (format "%7.1fk" (/ (buffer-size) 1000.0)))
   (t (format "%8d" (buffer-size)))))

;; Modify the default ibuffer-formats
  (setq ibuffer-formats
	'((mark modified read-only " "
		(name 18 18 :left :elide)
		" "
		(size-h 9 -1 :right)
		" "
		(mode 16 16 :left :elide)
		" "
		filename-and-process)))
#+END_SRC
** ox-clip
https://github.com/jkitchin/scimax

#+BEGIN_SRC emacs-lisp :results none
(use-package ox-clip
 :ensure t
 :config
 
 )
#+END_SRC 


** org-grep
   :PROPERTIES:
   :ID:       3b7e220f-c7bd-4a3a-b1eb-616a5f0dc500
   :END:
https://github.com/pinard/org-grep

#+BEGIN_SRC emacs-lisp :results none
(use-package org-grep
 :ensure t
 :config

 )
#+END_SRC 


** org highlight
   :PROPERTIES:
   :ID:       d12c21a9-d7ae-44a8-a642-49ee5c82fe44
   :END:
#+BEGIN_SRC emacs-lisp :results none
;(require 'highlights)
;; make sure you have dash, helm, helm-bibtex, ebib, s, f, hydra and key-chord
;; in your load-path
;require 'highlights)
#+END_SRC
** TODO org-tree-slide

https://github.com/takaxp/org-tree-slide
#+BEGIN_SRC emacs-lisp :results none
(use-package org-tree-slide
 :ensure t
 :config
 
 )
#+END_SRC 


** hydra
   :PROPERTIES:
   :ID:       94326940-a661-4dc5-a3e9-8ee31f51bad7
   :END:
*** use package 
 #+BEGIN_SRC emacs-lisp :results none
(use-package hydra
:ensure t 
:config
(require 'hydra-examples) ;;for window splits etc
)
 #+END_SRC
*** DOCU
**** The full defhydra syntax
***** base 
http://oremacs.com/2015/02/02/colorful-hydrae/

https://github.com/abo-abo/hydra

Note that `defhydra` looks intentionally like a defun, ₆In example₆ :

#+BEGIN_EXAMPLE
(defhydra hydra-toggle (global-map "C-c" :color red)
   "toggle"
   ("a" abbrev-mode "abbrev" :color blue)
   ("d" toggle-debug-on-error "debug" :color blue)
   ("f" auto-fill-mode "fill" :color blue)
   ("t" toggle-truncate-lines "truncate" :color blue)
   ("w" whitespace-mode "whitespace" :color blue)
   ("v" recenter-top-bottom "recenter" :color red)
   ("q" nil "cancel" :color blue))
(global-set-key (kbd "C-c C-v") 'hydra-toggle/body)
#+END_EXAMPLE

The code above:

binds C-c a, C-c d etc with the usual global-set-key approach.
binds C-c C-v a, C-c C-v d with the new approach, which shows you the hint right after C-c C-v and allows you to cancel easier.
binds C-c v to be repeatable, i.e. you can press C-c v v v. Same with C-c C-v v v v.

***** First argument: Hydra name

This argument decides the prefix to all the functions that will be generated. In this case the following functions will be generated:

#+BEGIN_EXAMPLE
hydra-toggle/abbrev-mode
hydra-toggle/toggle-debug-on-error
hydra-toggle/toggle-debug-on-error
hydra-toggle/auto-fill-mode
hydra-toggle/toggle-truncate-lines
hydra-toggle/whitespace-mode
hydra-toggle/recenter-top-bottom
hydra-toggle/nil
hydra-toggle/body
#+END_EXAMPLE

The final function calls the Hydras body, displaying the hint in the echo area and setting the transient map. It's the return result of defhydra, thats why it was possible to pass it to global-set-key in the first example.

***** Second argument: Hydra body

The Hydra body consists of:

a map used for binding, like global-map or c++-mode-map or projectile-mode-map

the body prefix: its a string passable to kbd that will be used in conjunction with heads' prefixes to bind the functions
an optional plist, which currently recognizes only the :color key, which in turn can be either red (the old behavior) or blue.

Its possible to omit the map and the body prefix simultaneously (it doesn't make sense to omit one but not the other), or just pass () if you want to get a red Hydra body that you can bind yourself.

***** Third argument: Hydra hint

This string will be used in the echo area to distinguish the current Hydra. This is optional, it case you don't provide it, it will default to "hydra".

***** Fourth argument: Hydra heads

Each Hydra head is a list of:
the key extension
the function
optional hint
optional plist.
Again, the plist recognizes only :color currently. The color is inherited from the body, if you don't specify it. In turn, the body color is red if you dont specify it.

***** launch a different hydra from a hydra
to do so you would want to issue the name/body command of the new hydra, ₆In example₆
#+BEGIN_EXAMPLE
(global-set-key
 (kbd "C-M-o")
 (defhydra hydra-org-edit ()
   "yas command "
   ("t" org-insert-todo-heading-respect-content "insert TODO" :color blue)
   ("d" org-cut-subtree  "org cut" :color blue)
   ("x" hydra-org2/body   "ins date" :color blue)

#+END_EXAMPLE

here we call on a different hydra `hydra-org/body` via keybind x
***** colors 
Since version 0.5.0, Hydra's heads all have a color associated with them:

`red` (default) means the calling this head will *not* vanquish the Hydra
`blue` means that the Hydra will be vanquished after calling this head
`amaranth` Hydras with amaranth body are impossible to quit with any binding except a blue head. A check for at least one blue head exists in defhydra, so that you don't get stuck by accident.

remembert that heads can inherit the color from the body, the following is equivalent:

#+BEGIN_EXAMPLE
(global-set-key
 (kbd "C-c C-v")
 (defhydra toggle (:color blue)
   "toggle"
   ("a" abbrev-mode "abbrev")
   ("d" toggle-debug-on-error "debug")
   ("f" auto-fill-mode "fill")
   ("t" toggle-truncate-lines "truncate")
   ("w" whitespace-mode "whitespace")
   ("q" nil "cancel")))

#+END_EXAMPLE
***** Can Hydras can be helpful?
They can, if


#+BEGIN_EXAMPLE
(setq hydra-is-helpful t)

#+END_EXAMPLE
This is the default setting. In this case, you'll get a hint in the echo area consisting of current Hydra's base comment and heads. You can even add comments to the heads like this:

#+BEGIN_EXAMPLE
(defhydra hydra-zoom (global-map "<f2>")
  "zoom"
  ("g" text-scale-increase "in")
  ("l" text-scale-decrease "out"))

#+END_EXAMPLE
With this, you'll see zoom: [g]: in, [l]: out. in your echo area, once the zoom Hydra becomes active.
***** awesome-docstring (help menus)

This can be a simple string used to build the final hydra hint. However, if you start it with a newline, the key-highlighting and Ruby-style string interpolation becomes enabled, as you can see in hydra-buffer-menu above.

To highlight a key, just wrap it in underscores.

$Note$ that the key must belong to one of the heads.

 The key will be highlighted with the color that is appropriate to the behavior of the key, i.e. if the key will make the hydra exit, the color will be blue.

To insert an empty character, use ^. The only use of this is to have your code aligned as nicely as the result.

To insert a dynamic Elisp variable, use %` followed by the variable. Each time the variable changes due to a head, the docstring will be updated. format-style width specifiers can be used.

To insert a dynamic Elisp expression, use e.g. %(length (dired-get-marked-files)). If a head will change the amount of marked files, for example, it will be appropriately updated.

If the result of the Elisp expression is a string and you don't want to quote it, use this form: %s(shell-command-to-string "du -hs").

**** Hydra example and recipes
***** helm-related functions
#+BEGIN_EXAMPLE
(global-set-key
 "κ"
 (defhydra hydra-helm (:color blue)
   "helm"
   ("f" projectile-find-file "file")
   ("w" helm-org-wiki "wiki")
   ("r" helm-recentf "recent")
   ("s" helm-swoop "swoop")
   ("q" nil "quit")))
#+END_EXAMPLE
***** use numric prefixes
Now it's possible to write this:

#+BEGIN_EXAMPLE
(global-set-key
 (kbd "C-z")
 (defhydra hydra-vi ()
   "vi"
   ("l" forward-char)
   ("h" backward-char)
   ("j" next-line)
   ("k" previous-line)))
#+END_EXAMPLE

And now ~C-z 5j7l~ will move 5 lines down and 7 characters left, still with the option to press h, j, k, l some more.

Additionally ~C-z C-u C-u C-u k~ will move 64 lines up, since C-u multiplies its argument by 4 each time.

other example 

#+BEGIN_EXAMPLE
(defhydra hydra-zoom (global-map "<f2>")
  "zoom"
  ("g" text-scale-increase "in")
  ("l" text-scale-decrease "out"))
#+END_EXAMPLE

Now, <f2> g 4g 2l will zoom in 5 times, and zoom out 2 times for a total of +3 zoom.
***** move-splitter

#+BEGIN_EXAMPLE
(defhydra hydra-splitter (global-map "C-M-s")
  "splitter"
  ("h" hydra-move-splitter-left)
  ("j" hydra-move-splitter-down)
  ("k" hydra-move-splitter-up)
  ("l" hydra-move-splitter-right))
#+END_EXAMPLE

This Hydra can benefit from numeric arguments as well: C-M-s l 40l will quickly make the right window a lot smaller.

If I wanted to type C-M-s 40 l, I would have to use this definition instead:

#+BEGIN_EXAMPLE
(global-set-key
 (kbd "C-M-s")
 (defhydra hydra-splitter ()
   "splitter"
   ("h" hydra-move-splitter-left)
   ("j" hydra-move-splitter-down)
   ("k" hydra-move-splitter-up)
   ("l" hydra-move-splitter-right)))
#+END_EXAMPLE

For that case, I would get the hint immediately after C-M-s and would be able to give the numeric argument immediately, but I wouldn't be able to bind anything else on C-M-s as a prefix, e.g.:

#+BEGIN_EXAMPLE
(global-set-key (kbd "C-M-s z") 'recenter-top-bottom)
#+END_EXAMPLE


The code above would give the error "Key sequence C-M-s z starts with non-prefix key C-M-s". So you can pick the method that you prefer, the choice is there.

***** rectangle selector 
#+BEGIN_EXAMPLE
(defun ora-ex-point-mark ()
  (interactive)
  (if rectangle-mark-mode
      (exchange-point-and-mark)
    (let ((mk (mark)))
      (rectangle-mark-mode 1)
      (goto-char mk))))

(defhydra hydra-rectangle (:body-pre (rectangle-mark-mode 1)
                           :color pink
                           :post (deactivate-mark))
  "
  ^_k_^     _d_elete    _s_tring     |\\     _,,,--,,_
_h_   _l_   _o_k        _y_ank       /,`.-'`'   ._  \-;;,_
  ^_j_^     _n_ew-copy  _r_eset     |,4-  ) )_   .;.(  `'-'
^^^^        _e_xchange  _u_ndo     '---''(_/._)-'(_\_)
^^^^        ^ ^         _p_aste
"
  ("h" backward-char nil)
  ("l" forward-char nil)
  ("k" previous-line nil)
  ("j" next-line nil)
  ("e" ora-ex-point-mark nil)
  ("n" copy-rectangle-as-kill nil)
  ("d" delete-rectangle nil)
  ("r" (if (region-active-p)
           (deactivate-mark)
         (rectangle-mark-mode 1)) nil)
  ("y" yank-rectangle nil)
  ("u" undo nil)
  ("s" string-rectangle nil)
  ("p" kill-rectangle nil)
  ("o" nil nil))
(global-set-key (kbd "C-x SPC") 'hydra-rectangle/body)

#+END_EXAMPLE
***** gnus hydra

#+BEGIN_EXAMPLE
(defhydra hydra-gnus-reply (:color blue)
  "reply"
  ("o" gnus-summary-reply-with-original "one")
  ("O" gnus-summary-reply)
  ("a" gnus-summary-wide-reply-with-original "all")
  ("A" gnus-summary-wide-reply)
  ("u" gnus-summary-very-wide-reply-with-original "universe")
  ("U" gnus-summary-very-wide-reply)
  ("q" nil "quit"))
(define-key gnus-summary-mode-map "r" 'hydra-gnus-reply/body)
#+END_EXAMPLE

** indent guide
   :PROPERTIES:
   :ID:       f33e1dcc-35f9-4386-91e8-a06b1d7f5d0e
   :END:
#+BEGIN_SRC emacs-lisp :results none
(use-package indent-guide
:ensure t
:config
)
#+END_SRC
** interleave
   :PROPERTIES:
   :ID:       54a9905f-67d5-408c-94c3-26d716a7c8b3
   :END:
https://github.com/rudolfochrist/interleave

#+BEGIN_SRC emacs-lisp :results none
(use-package interleave
 :ensure t
 :config
 
 )
#+END_SRC 

** ispell
   :PROPERTIES:
   :ID:       41ec3152-b33e-4437-be97-71eca98cc47d
   :END:
#+BEGIN_SRC emacs-lisp :results none
(setq ispell-personal-dictionary "~/.emacs.d/ispell-dico-personal")
;;below command skipps checking inside org mode code blocks 
(add-to-list 'ispell-skip-region-alist '("#\\+begin_src". "#\\+end_src"))
#+END_SRC
** keyfreq
   :PROPERTIES:
   :ID:       de6b19f0-807c-41c5-8cfd-ab765261f0b5
   :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package keyfreq
 :ensure t
 :config
 (require 'keyfreq)
(setq keyfreq-excluded-commands
      '(self-insert-command
        abort-recursive-edit
        previous-line
        next-line))
(keyfreq-mode 1)
(keyfreq-autosave-mode 1)
 )
#+END_SRC 


** link hint
   :PROPERTIES:
   :ID:       e6e8611b-8b0b-4efa-995c-52c41d172c96
   :END:
https://github.com/noctuid/link-hint.el
#+BEGIN_SRC emacs-lisp :results none
(use-package link-hint
 :ensure t
 :config
 ;; Use chromium to open urls
(setq browse-url-browser-function 'browse-url-chromium)
;; You can alternatively change this setting in the config

;;; mu4e
(defun my/mu4e-open-all-attachments ()
  "Open all visible mu4e attachments."
  (interactive)
  (let ((link-hint-ignore-types
         (remove 'mu4e-attachment link-hint-all-types-list))
        link-hint-act-on-all-ignore-types)
    (link-hint-open-all-links)))
 )
#+END_SRC
** latex-preview-pane
   :PROPERTIES:
   :ID:       4f7b6fd3-8d46-4f41-9d68-6aae0243261c
   :END:
https://www.emacswiki.org/emacs/LaTeXPreviewPane

#+BEGIN_SRC emacs-lisp :results none
(use-package latex-preview-pane
 :ensure t
 :config
 
 )
#+END_SRC 
** TODO lyrics
@works for emacs 25@    
https://github.com/emacs-pe/lyrics.el
#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package lyrics 
  ;;  :ensure t
  ;;  :config
 
  ;;  )
#+END_SRC 



** magit
   :PROPERTIES:
   :ID:       ceb8fc01-5439-4c54-9e23-50e01022523d
   :END:
https://github.com/magit/magit
#+BEGIN_SRC emacs-lisp :results none
(use-package magit
:ensure t
:config
)
#+END_SRC 

** manage-minor-mode  
   :PROPERTIES:
   :ID:       cb6406b4-254c-4e5d-87c7-19a4b6e836d7
   :END:

https://github.com/ShingoFukuyama/manage-minor-mode

Set minor-modes status for each major-mode in advance

#+BEGIN_SRC emacs-lisp :results none
(setq manage-minor-mode-default
      '((global
         (on   rainbow-mode)
         (off  line-number-mode))
         (emacs-lisp-mode
         (on   rainbow-delimiters-mode eldoc-mode show-paren-mode))
         (js2-mode
         (on   color-identifiers-mode)
         (off  flycheck-mode))))
#+END_SRC

** mic-parens
   :PROPERTIES:
   :ID:       d40b042c-e368-48f5-87fc-31c174b182d8
   :END:
https://www.emacswiki.org/emacs/mic-paren.el
better parens match than bulit in Emacs one 
#+BEGIN_SRC emacs-lisp :results none
(use-package mic-paren
 :ensure t
 :config
  )
#+END_SRC
** mu4e-maildirs-extension
   :PROPERTIES:
   :ID:       5396d89c-9194-42e0-8740-4a21ef1077bb
   :END:
https://github.com/agpchil/mu4e-maildirs-extension
#+BEGIN_SRC emacs-lisp :results none
;(use-package mu4e-maildirs-extension
; :ensure t
; :config
;(setq mu4e-maildirs-extension-title "Mail")
;(setq mu4e-maildirs-extension-custom-list (quote ("INBOX" "Starred"  )))
; )
#+END_SRC

** multiple-cursors
   :PROPERTIES:
   :ID:       6ab8cc60-6c9c-4ba2-a78b-fc25ee4df929
   :END:
https://github.com/magnars/multiple-cursors.el

#+BEGIN_SRC emacs-lisp :results none
(use-package multiple-cursors
 :ensure t
 :config
 (require 'multiple-cursors)
(global-set-key (kbd "C-S-c C-S-c") 'mc/edit-lines)

 )
#+END_SRC 
When you want to add multiple cursors not based on continuous lines, but based on keywords in the buffer, use:

(global-set-key (kbd "C->") 'mc/mark-next-like-this)
(global-set-key (kbd "C-<") 'mc/mark-previous-like-this)
(global-set-key (kbd "C-c C-<") 'mc/mark-all-like-this)

First mark the word, then add more cursors.
** multi-term
   :PROPERTIES:
   :ID:       f7f4d6ab-7f26-418f-bfb5-b1e6e2687a9c
   :END:
https://www.emacswiki.org/emacs-test/MultiTerm
also: https://iloveemacs.wordpress.com/2014/09/10/emacs-as-an-advanced-terminal-multiplexer/

#+BEGIN_SRC emacs-lisp :results none
(use-package multi-term
 :ensure t
 :config
(setq multi-term-program "/bin/zsh")
 )
#+END_SRC
** nlinum
   :PROPERTIES:
   :ID:       095490b6-f2a3-4a6e-a7c8-e4f8e805b506
   :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package nlinum
 :ensure t
 :config

 )
#+END_SRC
** not-much 

#+BEGIN_SRC emacs-lisp :results none
(use-package notmuch
 :ensure t
 :config
 
 )
#+END_SRC
** nofelt 

#+BEGIN_SRC emacs-lisp  :results none
(use-package noflet
  :ensure t )
(defun make-capture-frame ()
  "Create a new frame and run org-capture."
  (interactive)
  (make-frame '((name . "capture")))
  (select-frame-by-name "capture")
  (delete-other-windows)
  (noflet ((switch-to-buffer-other-window (buf) (switch-to-buffer buf)))
    (org-capture)))

(defadvice org-capture-finalize 
    (after delete-capture-frame activate)  
  "Advise capture-finalize to close the frame"  
  (if (equal "capture" (frame-parameter nil 'name))  
    (delete-frame)))

(defadvice org-capture-destroy 
    (after delete-capture-frame activate)  
  "Advise capture-destroy to close the frame"  
  (if (equal "capture" (frame-parameter nil 'name))  
    (delete-frame)))  

#+END_SRC

** helm-notmuch
https://github.com/xuchunyang/helm-notmuch
#+BEGIN_SRC emacs-lisp :results none
(use-package helm-notmuch
 :ensure t
 :config
 
 )
#+END_SRC 



** org-ref
   :PROPERTIES:
   :ID:       a6b8c4f8-9692-4f15-bbee-ca0303a86bd6
   :END:
*** config 
    :PROPERTIES:
    :ID:       8f7e794a-f240-441e-ac0b-a7de79cf5731
    :END:
#+BEGIN_SRC emacs-lisp  :results none
 (use-package org-ref 
   :ensure t
   :config
(require 'org-ref)
;; for pdf support  
(require 'org-ref-pdf)
(require 'org-ref-url-utils)
(require 'org-ref-wos)
(require 'org-ref-pubmed)
;;(setq reftex-default-bibliography '("/home/zeltak/org/files/Uni/papers/zeltak.papers.bib"))

(setq reftex-default-bibliography
      (quote
       ("/home/zeltak/org/files/Uni/papers/library.bib" "/home/zeltak/org/files/Uni/papers/zeltak.papers.bib")))

  ;; see org-ref for use of these variables
(setq org-ref-bibliography-notes "/home/zeltak/org/files/Uni/papers/notes/"
        org-ref-default-bibliography '("/home/zeltak/org/files/Uni/papers/zeltak.papers.bib" "/home/zeltak/org/files/Uni/papers/library.bib" )
        org-ref-pdf-directory "/home/zeltak/Sync/Uni/pdf_lib/")

(setq org-ref-completion-library 'org-ref-ivy-bibtex)

  (setq bibtex-autokey-year-length 4
        bibtex-autokey-name-year-separator "-"
        bibtex-autokey-year-title-separator "-"
        bibtex-autokey-titleword-separator "-"
        bibtex-autokey-titlewords 2
        bibtex-autokey-titlewords-stretch 1
        bibtex-autokey-titleword-length 5)

;;; open pdfs internally 
(defun my/org-ref-open-pdf-at-point ()
  "Open the pdf for bibtex key under point if it exists."
  (interactive)
  (let* ((results (org-ref-get-bibtex-key-and-file))
         (key (car results))
         (pdf-file (funcall org-ref-get-pdf-filename-function key)))
    (if (file-exists-p pdf-file)
        (find-file pdf-file)
      (message "No PDF found for %s" key))))

(setq org-ref-open-pdf-function 'my/org-ref-open-pdf-at-point)


;; fix nil issue
(defun org-ref-remove-nil ()
  (save-restriction
    (bibtex-narrow-to-entry)
    (bibtex-beginning-of-entry)
    (while (re-search-forward "\{nil\}" nil t)
      (replace-match "{}"))))

(add-to-list 'org-ref-clean-bibtex-entry-hook 'org-ref-remove-nil t)
   )
#+END_SRC
** org link edit
   :PROPERTIES:
   :ID:       c6ddebca-6243-47d7-a868-6152e2839449
   :END:
https://github.com/kyleam/org-link-edit
#+BEGIN_SRC emacs-lisp :results none
(add-to-list 'load-path "/home/zeltak/.emacs.g/org-link-edit/")
(require 'org-link-edit)
#+END_SRC

** org-bullets
   :PROPERTIES:
   :ID:       637f8bd3-2370-440f-ba66-05d42bbed4d3
   :END:
https://github.com/sabof/org-bullets

#+BEGIN_SRC emacs-lisp :results none
  (use-package org-bullets 
   :ensure t
   :config
(require 'org-bullets)
(add-hook 'org-mode-hook (lambda () (org-bullets-mode 1)))
(setq  org-bullets-bullet-list '(
    "①"
    "②"
    "③ "
    "④"
    "⑤"
    "⑥"
    "⑦"
    "⑧"
    "⑨"
    "⑩"
    "⑪"
    "⑫"
    "⑬"
    "⑭"
    "⑮"
    ))
 )
#+END_SRC
** org-bookmark-heading
   :PROPERTIES:
   :ID:       594d0149-29cf-457f-ae0f-e98bdb2ef056
   :END:
https://github.com/alphapapa/org-bookmark-heading
#+BEGIN_SRC emacs-lisp :results none
(use-package org-bookmark-heading
 :ensure t
 :config
(require 'org-bookmark-heading) 
 )
#+END_SRC 


** org-cliplink
   :PROPERTIES:
   :ID:       7d235b46-9d45-4c65-b8f0-7e772d07a3fa
   :END:
https://github.com/rexim/org-cliplink

#+BEGIN_SRC emacs-lisp :results none
(use-package org-cliplink
 :ensure t
 :config
 
 )
#+END_SRC 
** org-Download
   :PROPERTIES:
   :ID:       54e01618-35eb-45c5-b0b7-6f830faef316
   :Attachments: screenshot_2015-04-05_08:15:22.png
   :END:
https://github.com/abo-abo/org-download

provides function to drag images from browser and link address
$Note$ this requires package async to be installed, @async must be loaded before this package@

#+BEGIN_SRC emacs-lisp :results none
    (use-package org-download 
     :ensure t
     :config
     (setq-default org-download-heading-lvl nil)
     (setq  org-download-image-width 700 )
     (setq-default org-download-image-dir "/home/zeltak/Sync/attach/images_2015")
     ;;; to get rid of the #+DOWNLOADED part
  ;;(setq org-download-annotate-function (lambda (_) ""))
    )
 #+END_SRC

*** old configs 
    :PROPERTIES:
    :ID:       1bb218a7-fd27-43a0-ae12-3cc146dcb353
    :END:
#+BEGIN_SRC emacs-lisp :results none
  ;; (setq org-download-method 'attach
  ;;        org-download-screenshot-method "scrot -s %s"
  ;;        org-download-backend (if (executable-find "curl") "curl \"%s\" -o \"%s\"" t)))
#+END_SRC

 #+BEGIN_SRC emacs-lisp :results none
;(if (string= system-name "voices") (setq-default org-download-image-dir "/home/zeltak/org/attach/images_2014/") (setq-default org-download-image-dir "/media/NAS/Uni/org/attach/images_2013/"))                                                           
 #+END_SRC\N
** org-dp (wrap code blocks functions) 
   :PROPERTIES:
   :ID:       5c51b906-d5cc-4cfe-ad40-e9bb54e72c16
   :END:
https://github.com/tj64/org-dp


#+BEGIN_SRC emacs-lisp :results none
(use-package org-dp
 :ensure t
 :config
 (require 'org-dp-lib)
 )
#+END_SRC 
*** my wrap functions
    :PROPERTIES:
    :ID:       6735eac2-4018-41f1-8f9a-d6415b32386c
    :END:

#+BEGIN_SRC emacs-lisp :results none
(when (require 'org-dp-lib nil t)

;;;;;;;;;; wrap in elisp
  (defun z/wrap-elisp ()
        (org-dp-wrap-in-block
         nil '(src-block nil nil nil (:language "emacs-lisp" :preserve-indent 1  :parameters ":results none" ))))

;for hydra create interactive new functions
(defun z/hydra-wrap-elisp () (interactive) (beginning-of-line) (z/wrap-elisp))

;;;;;;;;;; wrap in bash
  (defun z/wrap-bash ()
        (org-dp-wrap-in-block
         nil '(src-block nil nil nil (:language "sh" :preserve-indent 1  :parameters ":results none" ))))

;for hydra create interactive new functions
(defun z/hydra-wrap-bash () (interactive) (beginning-of-line) (z/wrap-bash))


;;;;;;;;;; wrap in bash
  (defun z/wrap-example ()
        (org-dp-wrap-in-block
         nil '(src-block nil nil nil (:language "example" :preserve-indent 1  :parameters ":results none" ))))

;for hydra create interactive new functions
(defun z/hydra-wrap-example () (interactive) (beginning-of-line) (z/wrap-example))



;;;;;;;;;; wrap in R
  (defun z/wrap-R ()
        (org-dp-wrap-in-block
         nil '(src-block nil nil nil (:language "R" :preserve-indent 1  :parameters ":results none" ))))

;for hydra create interactive new functions
(defun z/hydra-wrap-R () (interactive) (beginning-of-line) (z/wrap-R))

;;;;;;;;;; wrap in latex
  (defun z/wrap-latex ()
        (org-dp-wrap-in-block
         nil '(src-block nil nil nil (:language "latex" :preserve-indent 1  :parameters ":results none" ))))

;for hydra create interactive new functions
(defun z/hydra-wrap-latex () (interactive) (beginning-of-line) (z/wrap-latex))


;end paren
     )
#+END_SRC
** org-fstree 

#+BEGIN_SRC emacs-lisp :results none
(use-package org-fstree 
 :ensure t
 :config
 
 )
#+END_SRC 

usage:
#+BEGIN_EXAMPLE
;; Usage:
;;   - enter a line containing "#+BEGIN_FSTREE: <dir>" into an org buffer, 
;;     where <dir> is the directory, that is to be inserted.
;;   - while the cursor is in the line mentioned, press "C-c C-c"
;;
;; Options:
;;   Specify options in the form:
;;   "#+BEGIN_FSTREE: <dir> :<optionname1> <optionvalue1> :<optionname2> <optionvalue2>  ...
;;   Options are:
;;     - :non-recursive t , to suppress recursion into directories
;;     - :exclude-regexp-name <list of regexp strings> , exclude file/directory names matching either 
;;                                                  of the given regexp expressions
;;       Examples: 
;;         :exclude-regexp-name (".*\\.pdf$" ".*\\.zip$"), excludes files/directories ending with either ".pdf" or ".zip"
;;         :exclude-regexp-name ("^\\.git$") , excludes files/directories named ".git"
;;
;;     - :exclude-regexp-fullpath <list of regexp strings>, same as :exclude-regexp-name but matches absolute path to file/directory
;;     - :relative-links t , generates relative instead of absolute links
;;     - :show-only-matches t , only files that are being linked to show up
;;     - :dynamic-update t , [EXPERIMENTAL] dynamically update a subtree on visibility cycling.
;;     - :links-as-properties t, sets the links as properties Link1, Link2,... for use in column view [Does not work with dynamic-update!]
#+END_EXAMPLE

** org-contacts
   :PROPERTIES:
   :ID:       82bee7e0-7718-4a5c-874f-e4b3643d770d
   :END:
#+BEGIN_SRC emacs-lisp :results none
(require 'org-contacts)
#+END_SRC
** org-vcard
   :PROPERTIES:
   :ID:       b1a5ab29-bcc4-44be-a051-322a6dcd91e1
   :END:
https://github.com/flexibeast/org-vcard

also explore how this relates to org-contacs
#+BEGIN_SRC emacs-lisp :results none
(use-package org-vcard
 :ensure t
 :config
 
 )
#+END_SRC 
** ox-pandoc
   :PROPERTIES:
   :ID:       77c5de54-b41e-4bb8-916e-93dd151ed161
   :END:
https://github.com/kawabata/ox-pandoc

#+BEGIN_SRC emacs-lisp :results none
(use-package ox-pandoc
 :ensure t
 :config
 )
#+END_SRC

** org-pdfview
   :PROPERTIES:
   :ID:       285e8a45-9534-455e-bef3-26d71cbc5ee9
   :END:
only enable if pdf-tools is installed 
#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package org-pdfview
  ;;  :ensure t
  ;;  :config
  ;;  )
#+END_SRC
** TODO ov-highlighter.el

#+BEGIN_SRC emacs-lisp  :results none
(use-package lunaryorn-simple
  :load-path "/home/zeltak/.emacs.g/ov-highlighter.el/"
  :config

;(ov-make-highlight "Warning" '(:foreground "#B40000" :background "#FFDDDD"  :weight bold))
;(ov-make-highlight "!notice!" '(:foreground "#B40000" :weight bold))
;(ov-make-highlight "%tip%" '(:foreground "#DDFFDD" :weight bold))
;(ov-make-highlight "z/green" '(:foreground "#35FF00" :weight bold))

)
#+END_SRC

;tip
(font-lock-add-keywords
 'org-mode
'(("\\(%[^%\n]+%\\)" (0 '(:weight ultra-bold :background "#DDFFDD" :foreground "#000000") t))))

;notice
(font-lock-add-keywords
 'org-mode
'(("\\(![^!\n]+!\\)" (0 '(:weight ultra-bold :foreground "#B40000") t))))

;high-green
(font-lock-add-keywords
 'org-mode
'(("\\('[^'\n]+'\\)" (0 '(:background "#35FF00" :weight ultra-bold) t))))

;high-yellow
(font-lock-add-keywords
 'org-mode
'(("\\(`[^`\n]+`\\)" (0 '(:foreground "#000000" :weight ultra-bold :background "#FBFF00") t))))

;
(font-lock-add-keywords
 'org-mode
'(("\\(₆[^₆\n]+₆\\)" (0 '(:foreground "#000000" :underline t :background "#FF9AEA" :weight ultra-bold) t))))

;
(font-lock-add-keywords
 'org-mode
'(("\\(₅[^₅\n]+₅\\)" (0 '(:weight ultra-bold :foreground "#1E00DE") t))))


;
(font-lock-add-keywords
 'org-mode
'(("\\(₄[^₄\n]+₄\\)" (0 '(:weight ultra-bold :foreground "#FF9800") t))))

;blusish
(font-lock-add-keywords
 'org-mode
'(("\\(•[^•\n]•+\\)" (0 '(:weight ultra-bold :foreground "#393D900") t))))


 
;;;;SPECIFIC WORDS 

;server
(font-lock-add-keywords
'org-mode
'(("\\b[Ss]erver\\b" (0 '(:weight ultra-bold :foreground "#FF9800") t))))

;client
(font-lock-add-keywords
'org-mode
'(("\\b[Cc]lient\\b" (0 '(:weight ultra-bold :foreground "#0044FF") t))))

;private
(font-lock-add-keywords
'org-mode
'(("\\b[Pp]rivate\\b" (0 '(:weight ultra-bold :foreground "#FF6767") t))))

;public
(font-lock-add-keywords
'org-mode
'(("\\b[Pp]ublic\\b" (0 '(:weight ultra-bold :foreground "#59BD7E") t))))


;In Example
(font-lock-add-keywords
'org-mode
'(("\\b[Ii]n example\\b" (0 '(:foreground "#000000" :underline t :background "#FF9AEA" :weight ultra-bold) t))))


;header
(font-lock-add-keywords
 'org-mode
'(("\\(‡[^‡\n]+‡\\)" (0 '(:foreground "#ffffff" :weight ultra-bold :slant italic :background "#59BD7F" :height 1.3) t))))

;;;FOR SPECIAL CHARACTERS

;for key shortucts
(font-lock-add-keywords
 'org-mode
'(("\\(\\?[^?\n]+\\?\\)" (0 '(:foreground "#000000" :weight ultra-bold :background "#FF9C2C") t))))

;for $Note$ 
(font-lock-add-keywords
 'org-mode
'(("\\(\\$[^$\n]+\\$\\)" (0 '(:background "#DDDDFF" :foreground "#000000" :weight ultra-bold) t))))

;for ^
(font-lock-add-keywords
 'org-mode
'(("\\(\\^[^^\n]+\\^\\)" (0 '(:weight bold  :box (:line-width 1 :color "#A5A0FF")  :foreground "#00006F" :background "#FFFFFF") t))))

;for † 
(font-lock-add-keywords
 'org-mode
'(("\\(\\†[^†\n]+\\†\\)" (0 '(:weight bold  :box (:line-width 1 :color "#A5A0FF")  :foreground "#00006F" :background "#FFFFFF") t))))




** pass mode
   :PROPERTIES:
   :ID:       07144779-6c62-40f6-a8aa-e1eaab8b318c
   :END:
for password store files : 
https://github.com/NicolasPetton/pass

#+BEGIN_SRC emacs-lisp :results none
(use-package pass
 :ensure t
 :config
  )
#+END_SRC 


** password-store
   :PROPERTIES:
   :ID:       35f8c705-ddc8-430d-a08c-abc73ff10f28
   :END:
#+BEGIN_SRC emacs-lisp :results none
(use-package password-store
 :ensure t
 :config
(require 'password-store)
 )
#+END_SRC 

** pandoc-mode
   :PROPERTIES:
   :ID:       ee757519-8421-4271-9e97-920781a4bc7c
   :END:
http://joostkremers.github.io/pandoc-mode/
#+BEGIN_SRC emacs-lisp :results none
(use-package pandoc-mode
 :ensure t
 :config
  )
#+END_SRC 
** pabbrev
   :PROPERTIES:
   :ID:       a8932442-103c-491f-8f9e-685c206cf71e
   :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package  pabbrev
 :ensure t
 :config
(require 'pabbrev)
;; to autoload
(global-pabbrev-mode)
;;disable annoying message every few seconds 
(setq pabbrev-idle-timer-verbose nil)
 )
#+END_SRC 

** pdf-tools
   :PROPERTIES:
   :ID:       e99804f6-ca8b-4ed4-8aef-4d469276e719
   :END:
https://github.com/politza/pdf-tools

if you have issues remove, reintsall and rebuild server
#+BEGIN_EXAMPLE
(pdf-tools-install)
#+END_EXAMPLE


#+BEGIN_SRC emacs-lisp :results none
(if (string= system-name "zx1voics")
  (use-package pdf-tools
     :ensure t
     :config
(pdf-tools-install)
;;;enable PDF tools everythime instead of doc view
;;from http://emacs.stackexchange.com/questions/4089/can-i-configure-eww-to-use-pdf-view-mode-from-pdf-tools-for-pdfs-instead-of-do
(defvar tv/prefer-pdf-tools (fboundp 'pdf-view-mode))
(defun tv/start-pdf-tools-if-pdf ()
  (when (and tv/prefer-pdf-tools
             (eq doc-view-doc-type 'pdf))
    (pdf-view-mode)))
(add-hook 'doc-view-mode-hook 'tv/start-pdf-tools-if-pdf)
      )
)


(if (string= system-name "zbeast")
  (use-package pdf-tools
     :ensure t
     :config
(pdf-tools-install)
;;;enable PDF tools everythime instead of doc view
;;from http://emacs.stackexchange.com/questions/4089/can-i-configure-eww-to-use-pdf-view-mode-from-pdf-tools-for-pdfs-instead-of-do
(defvar tv/prefer-pdf-tools (fboundp 'pdf-view-mode))
(defun tv/start-pdf-tools-if-pdf ()
  (when (and tv/prefer-pdf-tools
             (eq doc-view-doc-type 'pdf))
    (pdf-view-mode)))
(add-hook 'doc-view-mode-hook 'tv/start-pdf-tools-if-pdf)
      )


;;keys
(define-key pdf-view-mode-map (kbd "\C-s") 'isearch-forward)

)
#+END_SRC 

** projectile
   :PROPERTIES:
   :ID:       028b32c7-3684-40e9-834b-f197f0737b8b
   :END:

@Warning@: projectile global mode will kill ssh/sudo in tramp with hanging in:
#+BEGIN_EXAMPLE
Decrypting /home/chz/.authinfo.gpg...done
#+END_EXAMPLE
follow this : https://github2.com/bbatsov/projectile/issues/835 for more details 

#+BEGIN_SRC emacs-lisp :results none
  ;;   (use-package projectile
  ;;    :ensure t
  ;;    :config
  ;; ;;;disable global mode otherwise it kills tramp shh
  ;; ;;(projectile-global-mode)
  ;; ;; caching can significantly speedup file and directory listings, making it display instantly.
  ;; (setq projectile-enable-caching t)

  ;; ;;below is needed if you get the projectile-current-project-files: Wrong type argument: hash-table-p, nil error 
  ;; (setq projectile-global-mode t)

  ;; ;;(setq projectile-completion-system 'grizzl)
  ;; (setq projectile-completion-system 'helm)
  ;; (helm-projectile-on)
  ;; ;;(setq projectile-switch-project-action 'helm-projectile-find-file)
  ;; (setq projectile-switch-project-action 'helm-projectile)

  ;; (setq projectile-globally-ignored-directories
  ;;       (append '(
  ;;         ".git"
  ;;         ".svn"
  ;;         "out"
  ;;         "repl"
  ;;         "target"
  ;;         "venv"
  ;;         )
  ;;           projectile-globally-ignored-directories))
  ;; (setq projectile-globally-ignored-files
  ;;       (append '(
  ;;         ".DS_Store"
  ;;         "*.gz"
  ;;         "*.pyc"
  ;;         "*.jar"
  ;;         "*.tar.gz"
  ;;         "*.tgz"
  ;;         "*.zip"
  ;;         )
  ;;           projectile-globally-ignored-files))

  ;;    )
#+END_SRC
** persp-mode
   :PROPERTIES:
   :ID:       fb7ff438-93c4-4c83-be29-c62973341404
   :END:

#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package persp-mode
  ;;  :ensure t
  ;;  :config
  ;; (with-eval-after-load "persp-mode-autoloads"
  ;;   (setq wg-morph-on nil) ;; switch off animation
  ;;   (add-hook 'after-init-hook #'(lambda () (persp-mode 1))))

  ;;   )
#+END_SRC 
** persistent-scratch
https://github.com/Fanael/persistent-scratch

#+BEGIN_SRC emacs-lisp  :results none
;; persistent-scratch
(use-package persistent-scratch
  :config
  (persistent-scratch-setup-default))
#+END_SRC
** TODO purpose
wait until it hits melpa 
https://github.com/bmag/emacs-purpose
#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package purpose-mode
  ;;  :ensure t
  ;;  :config
  ;; (require 'window-purpose)
  ;; (purpose-mode)
 
  ;;  )
#+END_SRC 


** perspective
   :PROPERTIES:
   :ID:       a64d3831-3b35-4e1b-8aea-3a3997f9da16
   :END:
#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package perspective
  ;;  :ensure t
  ;;  :config
  ;;  )
#+END_SRC 
** TODO plur
https://github.com/xuchunyang/plur

#+BEGIN_SRC emacs-lisp :results none
  (use-package plur
  :ensure t
  :config

  )
#+END_SRC 


** polymode
   :PROPERTIES:
   :ID:       e547e0c5-1d99-4b1f-adca-bcbe7281db71
   :END:
https://github.com/vspinu/polymode

#+BEGIN_SRC emacs-lisp :results none
(use-package polymode
 :ensure t
 :config
(require 'poly-R) 
(require 'poly-org)
(add-to-list 'auto-mode-alist '("\\.org" . poly-org-mode))
 )
#+END_SRC 

When point is inside a src-block the local mode prevails.
So:
C-c C-n inside an R src block sends the line point is on to the R process.
C-c C-c sends the region (or function or paragraph) to the process when point is in the body. 
To execute `org-ctrl-c-ctrl-c' on the src block with the C-c C-c keying, it is necessary to move point to before or after the body.
** Rainbow mode
   :PROPERTIES:
   :ID:       dc1c37ec-dfd2-456f-9374-49da3bbda302
   :END:
http://julien.danjou.info/projects/emacs-packages#rainbow-mode

fix or update since it seems broken and colors are white

#+BEGIN_SRC emacs-lisp :results none
  (use-package rainbow-mode
  :ensure t
  :config
  )

  (dolist (hook '(css-mode-hook
                  html-mode-hook
                  js-mode-hook
                  emacs-lisp-mode-hook
                  org-mode-hook
                  text-mode-hook
                  ))
    (add-hook hook 'rainbow-mode))
#+END_SRC
** rainbow-delimiters
   :PROPERTIES:
   :ID:       7d609efb-a350-407e-9d66-feef57a5826c
   :END:
https://github.com/Fanael/rainbow-delimiters
#+BEGIN_SRC emacs-lisp :results none
(use-package rainbow-delimiters
 :ensure t
 :config
 (add-hook 'prog-mode-hook 'rainbow-delimiters-mode)
(require 'rainbow-delimiters)
(set-face-attribute 'rainbow-delimiters-unmatched-face nil
                    :foreground 'unspecified
                    :inherit 'error)
 )
#+END_SRC 
** Ranger
   :PROPERTIES:
   :ID:       326350a8-94ad-4a3c-bf9f-e9cbe6a68528
   :END:
https://github.com/ralesi/ranger/

#+BEGIN_SRC emacs-lisp :results none
(use-package ranger
 :ensure t
 :config
(setq ranger-cleanup-eagerly t)
(setq ranger-show-dotfiles t)
(setq ranger-parent-depth 1)
(setq ranger-ignored-extensions '("mkv" "iso" "mp4"))
(setq ranger-cleanup-on-disable t)
(setq ranger-show-literal t)
(setq ranger-width-preview 0.55)

 )
#+END_SRC 
【we】 to open in external app 
** restart-emacs 

#+BEGIN_SRC emacs-lisp :results none
(use-package restart-emacs 
 :ensure t
 :config
 
 )
#+END_SRC 


** region-bindings-mode
   :PROPERTIES:
   :ID:       ff39456b-d8f8-4137-999f-af5bc4637fd3
   :END:

old replaced by selected.el

#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package region-bindings-mode
  ;;  :ensure t
  ;;  :config
  ;; (require 'region-bindings-mode)
  ;; (region-bindings-mode-enable)
  ;; (define-key region-bindings-mode-map "d" 'kill-region)
  ;; (define-key region-bindings-mode-map "y" 'kill-ring-save)
  ;; (define-key region-bindings-mode-map "e" 'duplicate-current-line-or-region)
  ;; (define-key region-bindings-mode-map "g" 'google-search)
 
  ;;  )
#+END_SRC 

** scratch
   :PROPERTIES:
   :ID:       ad103f8b-b32c-435b-a103-53f6b6de5037
   :END:
Instant scratch buffer for current mode
http://pragmaticemacs.com/emacs/instant-scratch-buffer-for-current-mode/

#+BEGIN_SRC emacs-lisp :results none
(use-package scratch
 :ensure t
 :config
 (autoload 'scratch "scratch" nil t)
 )
#+END_SRC
** shrink-whitespace
   :PROPERTIES:
   :ID:       f0ce934a-2c24-4f26-a700-35a56f50be14
   :END:
https://github.com/jcpetkovich/shrink-whitespace.el

#+BEGIN_SRC emacs-lisp :results none
(use-package shrink-whitespace
 :ensure t
 :config
 )
#+END_SRC 
** selected 
   :PROPERTIES:
   :ID:       599f12a9-bf79-4bf4-a769-47f750ce4e0a
   :END:
https://github.com/Kungsgeten/selected.el
#+BEGIN_SRC emacs-lisp :results none
  (use-package selected
   :ensure t
:config
  (require 'selected)
  (selected-global-mode) 

  (define-key selected-keymap (kbd "q") #'selected-off)
  (define-key selected-keymap (kbd "U") #'upcase-region)
  (define-key selected-keymap (kbd "D") #'downcase-region)
  (define-key selected-keymap (kbd "w") #'count-words-region)
  (define-key selected-keymap (kbd "m") #'apply-macro-to-region-lines)
  (define-key selected-keymap (kbd "d") #'kill-region)
  (define-key selected-keymap (kbd "y") #'kill-ring-save)
  (define-key selected-keymap (kbd "e") #'duplicate-current-line-or-region)
  (define-key selected-keymap (kbd "g") #'google-search)
   )
#+END_SRC 


** Shell-pop
   :PROPERTIES:
   :ID:       908c9531-1b2a-4762-9acf-2c11e07ae757
   :END:

https://github.com/kyagi/shell-pop-el

#+BEGIN_SRC emacs-lisp :results none
(use-package shell-pop
 :ensure t
 :config
 (custom-set-variables
 '(shell-pop-default-directory "/home/zeltak/")
 '(shell-pop-shell-type (quote ("ansi-term" "*ansi-term*" (lambda nil (ansi-term shell-pop-term-shell)))))
 '(shell-pop-term-shell "/bin/zsh")
 '(shell-pop-universal-key "C-t")
 '(shell-pop-window-size 30)
 '(shell-pop-full-span t)
 '(shell-pop-window-position "bottom"))
 )
#+END_SRC 
** smart tab
   :PROPERTIES:
   :ID:       187fe44c-c0be-4496-943c-46bfa9142d01
   :END:
https://github.com/genehack/smart-tab

#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package  smart-tab 
  ;;  :ensure t
  ;;  :config
  ;; (require 'smart-tab)
  ;; (global-smart-tab-mode 1)

  ;; (setq smart-tab-disabled-major-modes
  ;;       (list 'term-mode
  ;;             'inferior-python-mode 'rcirc-mode  'mu4e-view-mode
  ;;             'mu4e-main-mode 'mu4e-headers-mode 
  ;;             'mu4e-about-mode))

  ;; (setq hippie-expand-try-functions-list
  ;;       '(try-expand-dabbrev
  ;;         try-expand-dabbrev-all-buffers
  ;;         try-expand-dabbrev-from-kill
  ;;         try-complete-file-name
  ;;         try-complete-lisp-symbol))

  ;; (setq smart-tab-using-hippie-expand t)

  ;;  )
#+END_SRC 


** smart comment
   :PROPERTIES:
   :ID:       6f4d89cc-21ed-459b-a5a2-c6ef37df4a57
   :END:
https://github.com/paldepind/smart-comment

#+BEGIN_SRC emacs-lisp :results none
(use-package smart-comment
 :ensure t
 :config
 :bind ("M-;" . smart-comment) 
 )
#+END_SRC
** smart parens 
   :PROPERTIES:
   :ID:       fbf5dd35-cd48-4ec7-a9a7-d90fb0ad14ca
   :END:
https://github.com/Fuco1/smartparens

#+BEGIN_SRC emacs-lisp :results none
(use-package smartparens
 :ensure 
 :config
(require 'smartparens-config) 
 )
#+END_SRC 


** smooth-scrolling
   :PROPERTIES:
   :ID:       de1d1c03-fb6c-41af-bc00-357e8382a97a
   :END:
https://github.com/aspiers/smooth-scrolling

for "normal" scrolling

#+BEGIN_SRC emacs-lisp :results none
(use-package smooth-scrolling
 :ensure t
 :config
(require 'smooth-scrolling)
 )
#+END_SRC 


** smex
   :PROPERTIES:
   :ID:       4487f835-ae34-48ab-98ee-6164cb1e196b
   :END:
@needed for counsel ivy completions@
#+BEGIN_SRC emacs-lisp :results none
(use-package smex
:ensure t
:config
)
#+END_SRC
** Super-save
   :PROPERTIES:
   :ID:       fdec1c7a-2207-4586-8940-a01c4aa0fe99
   :END:
https://github.com/bbatsov/super-save

#+BEGIN_SRC emacs-lisp :results none
(use-package super-save
 :ensure t
 :config
(super-save-mode +1)
(setq super-save-auto-save-when-idle t)
(setq auto-save-default nil)
 )
#+END_SRC 


** sunrise-commander
   :PROPERTIES:
   :ID:       19a65fe9-b034-4fb0-b806-07f76d7cad4d
   :END:
*** main 
    :PROPERTIES:
    :ID:       cf05a7ae-52e5-482a-a374-f1c16ed3a891
    :END:
http://www.emacswiki.org/emacs/Sunrise_Commander_Tips
#+BEGIN_SRC emacs-lisp :results none
(use-package sunrise-commander
 :ensure t
 :config
;;what to shoe in list view
(setq sr-attributes-display-mask '(nil nil t t t t t))
;start with no attributes in view (if set to nil)
(setq sr-show-file-attributes nil)
;sorting
(setq sr-listing-switches "--time-style=locale --group-directories-first -AlDhgG")


;;disbale F keys
;(setq sr-use-commander-keys nil)


;Here’s how to disable “click to visit file” and “cursor follows mouse”.
(setq sr-cursor-follows-mouse nil)
(setq sr-toggle-attribute 1)
(define-key sr-mode-map [mouse-1]        nil)
(define-key sr-mode-map [mouse-movement] nil)

;;nicer icons in modline
(setq sr-modeline-use-utf8-marks t)
;;where is avfs root
(setq sr-avfs-root "~/.avfs")

 )
#+END_SRC 
*** plugins
    :PROPERTIES:
    :ID:       96045319-5c0e-4810-b302-8c2e96bbe26a
    :END:
**** sunrise-x-popviewer
     :PROPERTIES:
     :ID:       dff4733b-a800-4c05-a032-6f8b06a708ba
     :END:

 #+BEGIN_SRC emacs-lisp :results none
 (use-package sunrise-x-popviewer
  :ensure t
  :config
(require 'sunrise-x-popviewer)
(sr-popviewer-mode 1)
;; to open in next pane and not new window
(setq sr-popviewer-select-viewer-action
         (lambda nil (let ((sr-running nil)) (other-window 1))))
  )
 #+END_SRC 
**** sunrise-x-mirror
     :PROPERTIES:
     :ID:       ddddd9e0-225e-4c1f-a173-2b9456a58379
     :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package sunrise-x-mirror
 :ensure t
 :config
 (require 'sunrise-x-mirror)
(setq sr-mirror-unionfs-impl (quote unionfs-fuse))
 )
#+END_SRC 
**** sunrise-x-loop
     :PROPERTIES:
     :ID:       bb8c182b-1cef-46f5-97cb-05755d12b155
     :END:
when yo need to copy of move any big files, just prefix the appropriate command with C-u.

#+BEGIN_SRC emacs-lisp :results none
(use-package sunrise-x-loop
 :ensure t
 :config
(require 'sunrise-x-loop) 
 )
#+END_SRC 

**** sunrise-x-modeline
     :PROPERTIES:
     :ID:       8ab1cc7e-5f70-4524-8059-45df93dbc615
     :END:
#+BEGIN_SRC emacs-lisp :results none
  (use-package  sunrise-x-modeline
   :ensure t
   :config
   )
#+END_SRC 

**** sunrise-x-tabs
     :PROPERTIES:
     :ID:       81bbcba3-1e48-4bc4-a3c3-edfab00b02f5
     :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package sunrise-x-tabs
 :ensure t
 :config
;(require 'sunrise‐x‐tabs) 
 )
#+END_SRC 

**** sunrise-x-checkpoints
     :PROPERTIES:
     :ID:       ff9e94c2-d18c-4b3b-a17c-9aac7c061161
     :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package sunrise-x-checkpoints
 :ensure t
 :config
  )
#+END_SRC 
*** functions
    :PROPERTIES:
    :ID:       ff7eb04a-3be8-4735-b7df-271a3519fdca
    :END:
**** open with external programs
     :PROPERTIES:
     :ID:       4c18feb2-0637-4c4f-bec9-ee4f295d86c4
     :END:
#+BEGIN_SRC emacs-lisp :results none
;;; Adding files opened with external apps to the history of recent files.
(defadvice openwith-file-handler
  (around advice-openwith-file-handler (operation &rest args))
  (condition-case description
      ad-do-it
    (error (progn
             (recentf-add-file (car args))
             (error (cadr description))))))
(ad-activate 'openwith-file-handler)

(defun er/sunrise-flatten ()
 (interactive)
 (sr-find "-type f"))

; Kill all sunrise and dired buffers when closing Sunrise Commander
(defun er/kill-all-sunrise-buffers()
      "Kill all dired buffers."
      (interactive)
      (save-excursion
        (let((count 0))
          (dolist(buffer (buffer-list))
            (set-buffer buffer)
            (when (derived-mode-p 'dired-mode 'sr-virtual-mode 'sr-mode)
                (setq count (1+ count))
                (kill-buffer buffer)))
          (message "Killed %i sunrise buffer(s)." count ))))
(setq sr-quit-hook 'er/kill-all-sunrise-buffers)

#+END_SRC 
*** keys
    :PROPERTIES:
    :ID:       a5d10f77-75c0-49f3-83d5-177809f82811
    :END:
**** main 
     :PROPERTIES:
     :ID:       97b78752-5f85-46ca-b962-ae0c807ba0b5
     :END:
#+BEGIN_SRC emacs-lisp :results none
(define-key sr-mode-map (kbd "/") 'sr-fuzzy-narrow) 
(define-key sr-mode-map (kbd "") 'er/sunrise-flatten) 
(define-key sr-mode-map (kbd "\\") 'hydra-sr-chd/body ) 
(define-key sr-mode-map (kbd "`") 'hydra-sunrise-leader/body ) 
;lynx like
(define-key sr-mode-map (kbd "<left>") 'sr-dired-prev-subdir ) 
(define-key sr-mode-map (kbd "<right>") 'sr-advertised-find-file ) 
;move back/forward im history
(define-key sr-mode-map (kbd "M-<left>") 'sr-history-prev ) 
(define-key sr-mode-map (kbd "M-<right>") 'sr-history-next ) 
#+END_SRC
** sr-speedbar
   :PROPERTIES:
   :ID:       ccc60114-794c-422f-b14c-e86b3e2b8cc4
   :END:
SrSpeedbar is mode make SpeedBar show in Current Frame 
http://www.emacswiki.org/emacs/SrSpeedbar

#+BEGIN_SRC emacs-lisp :results none
(use-package sr-speedbar
 :ensure t
 :config
  )
#+END_SRC 
** Swiper
   :PROPERTIES:
   :ID:       01c1c225-76b8-447c-8967-b90eee738e3a
   :END:
#+BEGIN_SRC emacs-lisp :results none
(use-package swiper 
 :ensure t
 :config
;(ivy-mode 1)

 )
#+END_SRC

#+BEGIN_SRC emacs-lisp :results none
(defun swiper-at-point ()
  (interactive)
  (swiper (thing-at-point 'symbol)))
#+END_SRC

** swiper helm
   :PROPERTIES:
   :ID:       28115c9b-0758-4d42-9c13-c58e21ee9d18
   :END:
#+BEGIN_SRC emacs-lisp :results none
(use-package swiper-helm
 :ensure t
 :config
  )
#+END_SRC
** spaceline
   :PROPERTIES:
   :ID:       c0de1a33-4f99-4cb1-a464-eaa8555af303
   :END:
https://github.com/TheBB/spaceline

Each segment has a variable spaceline-NAME-p that can switch the segment off by setting it to nil. There are also three convenient interactive functions for toggling:
#+BEGIN_EXAMPLE
    spaceline-toggle-<name>
    spaceline-toggle-<name>-on
    spaceline-toggle-<name>-off
#+END_EXAMPLE


#+BEGIN_SRC emacs-lisp :results none
  (use-package spaceline 
  :ensure t
  :config
  (require 'spaceline-config)
  (spaceline-spacemacs-theme)
  :config
(defun window-numbering-install-mode-line (&optional position)
  "Do nothing.")
;; add evil-states 
(setq spaceline-highlight-face-func 'spaceline-highlight-face-evil-state)
;; type of seperator 
(setq powerline-default-separator 'utf-8)
;;needed to get the proper seperator 
(spaceline-compile)
(setq powerline-height 20)
(setq spaceline-window-numbers-Unicode t)
(setq spaceline-workspace-numbers-Unicode t)
(setq powerline-default-separator 'utf-8)

;;evil state
(spaceline-toggle-evil-state-on)
;;;get rid of all of the minor modes in modline 
(spaceline-toggle-minor-modes-off)
;;likewise uncommet if you want to get rid of major modes
;;(spaceline-toggle-major-mode-off)
(spaceline-toggle-buffer-modified-on)
;;; size of buffer indicator 
(spaceline-toggle-buffer-size-off)
;; get rid of git info 
(spaceline-toggle-version-control-off)
;;buffer modifed 
(spaceline-toggle-buffer-modified-on)
(spaceline-toggle-buffer-id-on)
(spaceline-toggle-remote-host-on)


)
#+END_SRC 


** spu (silent package upgrade)
   :PROPERTIES:
   :ID:       a8a5499c-1098-412b-9152-3425e71981c9
   :END:
https://github.com/mola-T/spu
#+BEGIN_SRC emacs-lisp  :results none
(use-package spu
  :defer 5 ;; defer package loading for 5 second
  :config (spu-package-upgrade-daily))
#+END_SRC
** twittering-mode
   :PROPERTIES:
   :ID:       8a97bf36-226d-40f6-996d-21d54e58439f
   :END:
https://github.com/hayamiz/twittering-mode/
#+BEGIN_SRC emacs-lisp :results none
(use-package twittering-mode
 :ensure t
 :config
;; save encrypted password 
(setq twittering-use-master-password t)
;;To display icons
(setq twittering-icon-mode t)
;;save local icons
(setq twittering-use-icon-storage t)
;;start with older first
(setq twittering-reverse-mode t)


 )

#+END_SRC 


** tiny
   :PROPERTIES:
   :ID:       b13125f0-b43a-48b2-a152-046d56ef50f5
   :END:
*** config
    :PROPERTIES:
    :ID:       1dab9375-2309-4e31-ad07-529a70ecf561
    :END:
https://github.com/abo-abo/tiny
#+BEGIN_SRC emacs-lisp :results none
(use-package tiny
  :config
;  (global-set-key (kbd "C-s-t") 'tiny-expand)
)
#+END_SRC
*** examples
    :PROPERTIES:
    :ID:       e5294386-f108-4b4a-a283-a30d8c00afeb
    :END:
General Format: m[range start][separator(s)][range end]
₆In example₆ 
;; mBSEO|F
;;  ||||||
;;  |||||+--> (optional) Format - %x | 0x%x | %c | %s | %(+ x x) | %014.2f | %03d | %(date "Jan 16" (* x 7))
;;  ||||+---> (optional) Pipe character to separate Format for reading clarity
;;  |||+----> (optional) Operator - *xx | (* x x) | (+ x ?A) | *2+3x | (* 2 (+ 3 x))
;;  ||+-----> End value
;;  |+------> (optional) Separator - Space | , | \n (default=Space)
;;  +-------> (optional) Begin value (default=0)
;; - No space allowed between 'm' and 'B'
;; - No space allowed between 'E' and 'O'
 
Fancier Formatting
Do you know how I generated that numbered list of four elements? I used m1\n\n4|%d., which Tiny expands into:

1.

2.

3.

4.
This demonstrates that you can have multiple separator characters; here I use two \n’s for the extra space. But there is that |%d. at the end. Tiny lets you use Emacs Lisp format strings, which you write at the end of your expression and delimit with a vertical bar. The formatting string %d. prints each number as a digit (%d) with a period after it. Used in conjunction with the newline separators it gives me exactly the output I want for a numbered list in Markdown.
** TODO tile
*** use-package
https://github.com/IvanMalison/tile

#+BEGIN_SRC emacs-lisp :results none
(use-package tile 
 :ensure t
 :config


(progn
    (defvar imalison:tall-tile-strategy (tile-split-n-tall 3))
    (defvar imalison:wide-tile-strategy tile-wide)
    (defvar imalison:master-tile-strategy (tile-argument-buffer-fetcher
                                           :layout tile-master-left))
    (defhydra imalison:hydra-tile
      nil
      "tile"
      ("t" (tile :strategy imalison:tall-tile-strategy))
      ("w" (tile :strategy imalison:wide-tile-strategy))
      ("m" (tile :strategy imalison:master-tile-strategy))
      ("s" tile-select)
      ("0" (tile :strategy tile-one))
      ("n" tile)
      ("l" winner-undo))
    (setq tile-cycler
          (tile-strategies :strategies
                           (list imalison:tall-tile-strategy
                                 imalison:master-tile-strategy
                                 imalison:wide-tile-strategy
                                 tile-one))))
)
#+END_SRC 


** TODO transfer.sh
add quick keybinds

https://github.com/Brillow/transfer-sh.el

An upload can be performed by selecting the region/buffer to upload and then executing one of the following commands:

;; This simply uploads the selected text to transfer-sh and returns the link
transfer-sh-upload

;; Use this to encrypt files before uploading. It will prompt you for a passcode to pass to gpg.
transfer-sh-upload-gpg

When called with the universal prefix argument (C-u), the upload will be done asynchronously. This prevents emacs from locking while uploading large files. This functionality requires the async.el package to be installed.

#+BEGIN_SRC emacs-lisp :results none
(use-package transfer-sh
 :ensure t
 :config

 )
#+END_SRC


** tabbar
   :PROPERTIES:
   :ID:       4020a235-23e9-4617-a9ae-fdbd69396f74
   :END:
https://www.emacswiki.org/emacs/TabBarMode

http://emacs.stackexchange.com/questions/10081/browser-style-tabs-for-Emacs

#+BEGIN_SRC emacs-lisp :results none
  ;; (use-package tabbar
  ;;  :ensure t
  ;;  :config
  ;; (require 'tabbar)
  ;; ; turn on the tabbar
  ;; (tabbar-mode t)
  ;; ; define all tabs to be one of 3 possible groups: “Emacs Buffer”, “Dired”,
  ;; ;“User Buffer”.

  ;; (defun tabbar-buffer-groups ()
  ;;   "Return the list of group names the current buffer belongs to.
  ;; This function is a custom function for tabbar-mode's tabbar-buffer-groups.
  ;; This function group all buffers into 3 groups:
  ;; Those Dired, those user buffer, and those emacs buffer.
  ;; Emacs buffer are those starting with “*”."
  ;;   (list
  ;;    (cond
  ;;     ((string-equal "*" (substring (buffer-name) 0 1))
  ;;      "Emacs Buffer"
  ;;      )
  ;;     ((eq major-mode 'dired-mode)
  ;;      "Dired"
  ;;      )
  ;; ((memq major-mode
  ;;        '(org-mode text-mode rst-mode))
  ;;  "org"
  ;;  )

  ;;    (t
  ;;      "General"
  ;;      )
  ;;     ))) 

  ;; (setq tabbar-buffer-groups-function 'tabbar-buffer-groups)

  ;; ;;Sort tabbar buffers by name

  ;; (defun tabbar-add-tab (tabset object &optional append_ignored)
  ;;   "Add to TABSET a tab with value OBJECT if there isn't one there yet.
  ;; If the tab is added, it is added at the beginning of the tab list,
  ;; unless the optional argument APPEND is non-nil, in which case it is
  ;; added at the end."
  ;;   (et ((tabs (tabbar-tabs tabset)))
  ;;     (if (tabbar-get-tab object tabset)
  ;;         tabs
  ;;       (let ((tab (tabbar-make-tab object tabset)))
  ;;         (tabbar-set-template tabset nil)
  ;;         (set tabset (sort (cons tab tabs)
  ;;                           (lambda (a b) (string< (buffer-name (car a)) (buffer-name (car b))))))))))

  ;;  )
#+END_SRC
** transmission
   :PROPERTIES:
   :ID:       b132d6b0-0efe-4347-b812-4a9bf0d5b746
   :END:
*** use-package
need to install let-alist and seq packages from melpa
https://github.com/holomorph/transmission/issues/1

#+BEGIN_SRC emacs-lisp :results none
(use-package transmission
 :ensure t
 :config
(require 'transmission)
(setq transmission-host "10.0.0.2")
(setq transmission-rpc-auth '(:username "zeltak" :password "XXXX" ) )
 )
#+END_SRC 
*** DOCU 
**** you can try and add the user pass to you config file
#+BEGIN_EXAMPLE
(setq transmission-rpc-auth '(:username "USER" :password "PASS" ) )
#+END_EXAMPLE

** Undo tree
   :PROPERTIES:
   :ID:       89d8b48e-b551-48e1-8ad7-68ce49184ac9
   :END:
#+BEGIN_SRC emacs-lisp :results none
(use-package undo-tree 
:ensure t
:config
(global-undo-tree-mode 1)
;; undo-tree-auto-save-history when set to 't' will often crash emacs... be careful when using this  
(setq undo-tree-auto-save-history nil)
(setq undo-tree-history-directory-alist '((".*" . "~/.emacs.t/undo-files")))
(setq undo-tree-mode-lighter "")	 
)
#+END_SRC
** TODO viking-mode
   :PROPERTIES:
   :ID:       c11b89df-997d-45f2-b0b6-2bbb64b5a93d
   :END:
https://github.com/tlinden/viking-mode
the default key bind is 【C-d】

#+BEGIN_SRC emacs-lisp :results none
(use-package viking-mode
 :ensure t
 :config
(viking-global-mode)
 )
#+END_SRC 


** vimish-fold 
   :PROPERTIES:
   :ID:       be1aad9a-6dd1-4526-b064-21bd010a562e
   :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package vimish-fold
 :ensure t
 :config
 (require 'vimish-fold)
;(global-set-key (kbd "<menu> v f") #'vimish-fold)
;(global-set-key (kbd "<menu> v v") #'vimish-fold-delete)
 )
#+END_SRC 


** unfill
   :PROPERTIES:
   :ID:       ff28bfc5-758e-4f39-956c-21b2307a8cfb
   :END:
https://github.com/purcell/unfill

makes or unmakes a marked section wider/shorter (look fill command)

#+BEGIN_SRC emacs-lisp :results none
(use-package unfill
:ensure t
:config
)
#+END_SRC
** unison-mode
   :PROPERTIES:
   :ID:       d37cb0e4-f8a0-4532-b068-05379d8cec27
   :END:
https://github.com/impaktor/unison-mode

syntax highlight for unison files 
#+BEGIN_SRC emacs-lisp :results none
(use-package unison-mode
 :ensure t
 :config
(autoload 'unison-mode "unison-mode" "my unison mode" t)
(setq auto-mode-alist (append '(("\\.prf$" . unison-mode)) auto-mode-alist))
 )
#+END_SRC 
** visual-regexp
https://github.com/benma/visual-regexp.el
#+BEGIN_SRC emacs-lisp :results none
(use-package visual-regexp
 :ensure t
 :config
 
 )
#+END_SRC 


** volatile-highlights
   :PROPERTIES:
   :ID:       d9f31fdf-cfff-4961-82fe-33e262667605
   :END:
https://github.com/k-talo/volatile-highlights.el
#+BEGIN_SRC emacs-lisp :results none
(use-package volatile-highlights
 :ensure t
 :config
(require 'volatile-highlights)
(volatile-highlights-mode t) 
 )
#+END_SRC 

** wanderlust
   :PROPERTIES:
   :ID:       a9e1a664-b736-4428-8676-2b0d4ffa2718
   :END:
#+BEGIN_SRC emacs-lisp 1p:results none
(use-package wanderlust
 :ensure t
 :config
 
 )
#+END_SRC
** with editor 
#+BEGIN_SRC emacs-lisp  :results none
(use-package with-editor
  :ensure t
  :init
  (progn
    (add-hook 'shell-mode-hook  'with-editor-export-editor)
    (add-hook 'eshell-mode-hook 'with-editor-export-editor)))
#+END_SRC
** worf
   :PROPERTIES:
   :ID:       638452e7-b9be-4e07-9454-df760bb2ffd4
   :END:
look here for more details on keybinds
https://github.com/abo-abo/worf/blob/master/worf.el
this package us

#+BEGIN_SRC emacs-lisp :results none
  (use-package worf
   :ensure t
   :config
   )
#+END_SRC
** wgrep 
https://github.com/mhayashi1120/Emacs-wgrep
#+BEGIN_SRC emacs-lisp :results none
(use-package wgrep
 :ensure t
 :config
 
 )
#+END_SRC 


** weechat.el
   :PROPERTIES:
   :ID:       214adcf5-d7aa-4080-839a-7cb44afa66d9
   :END:

#+BEGIN_SRC emacs-lisp :results none
  (use-package weechat
   :ensure t
   :config
  (require 'weechat)
(setq weechat-modules '(weechat-button
                        weechat-complete
                        weechat-spelling
                        weechat-corrector
                        weechat-tracking
                        weechat-notifications))
   )
#+END_SRC 

#+BEGIN_SRC emacs-lisp :results none
(eval-after-load 'weechat
  '(progn
     (setq weechat-host-default "karif.server-speed.net"
           weechat-port-default 9001
           weechat-color-list
           '(unspecified "black" "dark gray" "dark red" "red"
                         "dark green" "light green" "brown"
                         "yellow" "RoyalBlue3"
                         "light blue"
                         "dark magenta" "magenta" "dark cyan"
                         "light cyan" "gray" "white")
           weechat-prompt "> "
           weechat-notification-mode t
           weechat-auto-monitor-buffers t 
           weechat-complete-nick-ignore-self nil
           weechat-button-buttonize-nicks nil
           weechat-tracking-types '(:highlight (".+#weechat.el" . :message))
           weechat-sync-active-buffer t)
     (setq weechat-auto-monitor-buffers
      '("freenode.#rofi" ))
     (set-face-background 'weechat-highlight-face "dark red")
     (set-face-foreground 'weechat-highlight-face "light grey")
     (add-hook 'weechat-mode-hook 'visual-line-mode)
     (tracking-mode)))
#+END_SRC
** wc-mode
https://github.com/bnbeckwith/wc-mode 
 #+BEGIN_SRC emacs-lisp :results none
 (use-package wc-mode
  :ensure t
  :config
(add-hook 'org-mode-hook 'wc-mode)
)
 #+END_SRC 
 
 
** winner-mode
   :PROPERTIES:
   :ID:       27ab02be-b567-48c8-a70c-30b39038b1d5
   :END:
#+BEGIN_SRC emacs-lisp :results none
(winner-mode 1)
#+END_SRC
** which key
   :PROPERTIES:
   :ID:       4bdca253-fa8c-42da-b429-8224ac8b93da
   :END:
https://github.com/justbur/emacs-which-key
#+BEGIN_SRC emacs-lisp :results none
(use-package which-key
 :ensure t
 :config
(which-key-mode)
(which-key-setup-minibuffer)
;;Popup side window on right. For defaults use
;;(which-key-setup-side-window-right)

 )
#+END_SRC 


** Wrap region
   :PROPERTIES:
   :ID:       ad3ac1b3-7192-4af7-9fdc-b05593f9e8f4
   :END:

https://github.com/rejeep/wrap-region.el

#+BEGIN_SRC emacs-lisp :results none
(use-package wrap-region
  :ensure t
  :config
  (wrap-region-add-wrappers
   '(("*" "*" nil org-mode)
     ("~" "~" nil org-mode)
     ("/" "/" nil org-mode)
     ("=" "=" nil org-mode)
     ("_" "_" nil org-mode)
     ("%" "%" nil org-mode)
     ("!" "!" nil org-mode)
     ("`" "`" nil org-mode)
     ("'" "'" nil org-mode)
     ("@" "@" nil org-mode)
     ("$" "$" nil (org-mode latex-mode))
))
  (add-hook 'org-mode-hook 'wrap-region-mode)
  (add-hook 'latex-mode-hook 'wrap-region-mode)
)
#+END_SRC 


** workgroup2
   :PROPERTIES:
   :ID:       d4c070c9-017a-4d40-a90c-9a6fda6b39a7
   :END:
http://workgroups2.readthedocs.org/en/latest/guide/installation.html
#+BEGIN_SRC emacs-lisp :results none
;;  (use-package workgroups2
;;  :ensure t
;;  :config
;;  (workgroups-mode 1)        ; put this one at the bottom of .emacs (init.el)
;;  (require 'workgroups2)
 ;; Change workgroups session file
;;  (setq wg-session-file "~/.emacs.d/.emacs_workgroups") 
;;  )
#+END_SRC 

** xah-find
   :PROPERTIES:
   :ID:       957bdb38-8258-49dd-9d00-d0b5aad091f7
   :END:
http://ergoemacs.org/emacs/elisp-xah-find-text.html
This is the home page for “xah-find.el”.

This package provides emacs commands for find/replace in a directory, like {grep, rgrep, lgrep, unix sed}, but written entirely in emacs lisp.

This package provides these commands:

xah-find-text
xah-find-text-regex
xah-find-count
xah-find-replace-text
xah-find-replace-text-regex

Press Enter ↵ on a link to jump to the file location. (or mouse clic)k
Press 【Tab ↹】 to jump to next occurence. (【⇧ Shift+Tab ↹】 for previous)
Press 【Alt+p】 or 【Alt+n】 to move cursor to previous/next file name.

#+BEGIN_SRC emacs-lisp :results none
(use-package xah-find
 :ensure t
 :config
  )
#+END_SRC 

** org-reveal (ox-reveal)
   :PROPERTIES:
   :ID:       d863a80a-8bb5-47c3-be3b-987c33977f2d
   :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package ox-reveal
 :ensure t
 :config
;;where the root reveal folder is
(setq org-reveal-root  "file:///home/zeltak/apps/reveal.js") 
 )
#+END_SRC 

** org-velocity
   :PROPERTIES:
   :ID:       0ad580f4-60b9-48b3-8508-438a53e240f9
   :END:
#+BEGIN_SRC emacs-lisp
(require 'org-velocity)
#+END_SRC
** Yasnippet
   :PROPERTIES:
   :ID:       4d7110ab-1722-4dbe-bddd-30ea62406a0c
   :END:
*** load yasnippet
    :PROPERTIES:
    :ID:       729a978f-729c-4711-899f-1a690c87cd87
    :END:

#+BEGIN_SRC emacs-lisp :results none
(use-package yasnippet
:ensure t
 :config 
(require 'yasnippet)
(yas-global-mode 1)
;; Use custom snippets.
(yas-reload-all)
(setq yas-snippet-dirs '("~/.emacs.d/snippets/"))
;for orgmode properties fix 
(setq yas-indent-line 'fixed)
;set insert at point prompt type- here ido
(setq yas/prompt-functions '(yas/ido-prompt
                            yas/completing-prompt))
)
#+END_SRC
*** function helm 
    :PROPERTIES:
    :ID:       83d27e31-9f8e-4851-a956-ad9c61c83075
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun shk-yas/helm-prompt (prompt choices &optional display-fn)
  "Use helm to select a snippet. Put this into `yas/prompt-functions.'"
  (interactive)
  (setq display-fn (or display-fn 'identity))
  (if (require 'helm-config)
      (let (tmpsource cands result rmap)
        (setq cands (mapcar (lambda (x) (funcall display-fn x)) choices))
        (setq rmap (mapcar (lambda (x) (cons (funcall display-fn x) x)) choices))
        (setq tmpsource
              (list
	       (cons 'name prompt)
	       (cons 'candidates cands)
	       '(action . (("Expand" . (lambda (selection) selection))))
	       ))
        (setq result (helm-other-buffer '(tmpsource) "*helm-select-yasnippet"))
        (if (null result)
            (signal 'quit "user quit!")
          (cdr (assoc result rmap))))
    nil))
#+END_SRC

*** DOC
**** install and configure Yasnippet
***** where do snippets appear and when (yas modes)
this is set by the name of the folder (in your custom snippet folder defined in the `yas-snippet-dirs`
₆In example₆ to get snippets to appear in ess-mode (r and sas snippets) you would create a folder named:

file:~/.emacs.d/snippets/ess-mode/

and put all you .snippets there

you can use folder names like org-mode, python-mode etc etc.

%Tip- you can get other modes snippets in you current mode by using the following tips:%

1. use a `text-mode` folder and this will make sure it will appear in many modes

2. issue the command `yas-activate-extra-mode` which can activate arbitrary "yas-only" modes corresponding to the names of snippet subdirectories, and not necessarily actual major-mode names
₆In example₆ if I am in org-mode and issue `yas-activate-extra-mode` >> ess-mode. I will get my ess snippets in org-mode 

3. use a folder named `fundamental-mode` and add this snippet to you config

https://github.com/capitaomorte/yasnippet/issues/557

#+BEGIN_EXAMPLE
(add-hook 'yas-minor-mode-hook
          (lambda ()
            (yas-activate-extra-mode 'fundamental-mode)))
#+END_EXAMPLE

this will load all `fundamental-mode` snippet 

4. The .yas-parents file

It's very useful to have certain modes share snippets between themselves. To do this, choose a mode subdirectory and place a `.yas-parents` file  containing a whitespace-separated list of other mode names.
When you reload those modes become parents of the original mode.

#+BEGIN_EXAMPLE

|-- c-mode
|   |-- .yas-parents    # contains "cc-mode text-mode"
|   `-- printf
|-- cc-mode
|   |-- for
|   `-- while
|-- java-mode
|   |-- .yas-parents    # contains "cc-mode text-mode"
|   `-- println
`-- text-mode
    |-- email
    `-- time
#+END_EXAMPLE


**** Quickly finding snippets

There are some ways you can quickly find a snippet file:

#+BEGIN_EXAMPLE
M-x yas-new-snippet
#+END_EXAMPLE

Prompts you for a snippet name, then tries to guess a suitable directory to store it, prompting you for creation if it does not exist. Finally, places you in a new buffer set to snippet-mode so you can write your snippet.

#+BEGIN_EXAMPLE
M-x yas-visit-snippet-file
#+END_EXAMPLE

Prompts you for possible snippet expansions like yas-insert-snippet, but instead of expanding it, takes you directly to the snippet definition's file, if it exists.

**** Define custom Templates

make sure the in you yas config ([[install%20and%20configure%20Yasnippet][config]])  the local location for the user snippets are correct (inlcuding top folder)
then create files like these there
#+BEGIN_EXAMPLE

# -- mode: snippet --
# name:cb_bsh
# key: cbb
# --

test$1
test$2
etc

#+END_EXAMPLE

The `name` of the snippet, function is more like a comment than anything else.
On the other hand, `key` is very important: it's what I have to insert in the buffer to get the expansion with M-x yas-expand.
Everything after # -- is the snippet body.
This particular snippet has two fields, in places of $1 and $2.
$0 is where the point will be when the snippet expansion is finished
As I expand, pressing TAB will move from field to field until the expansion is finished.

**** escape special characters
Arbitrary text can be included as the content of a template. They are usually interpreted as plain text, except

#+BEGIN_EXAMPLE
$ and ==. 

You need to use \` to escape them: \$ and \.  
#+END_EXAMPLE
The \` itself may also needed to be escaped as \\ sometimes.
**** Tab stop fields
for more info look here:
http://capitaomorte.github.io/yasnippet/snippet-development.html

Tab stops are fields that you can navigate back and forth by TAB and S-TAB. They are written by `$` followed with a number.
`$0` has the special meaning of the exit point of a snippet. That is the last place to go when youve traveled all the fields.
Here is a typical example:

#+BEGIN_EXAMPLE
<div$1>
    $0
</div>
#+END_EXAMPLE
**** using yasnippets with R

since R uses $ in syntax, You need to use backslash to escape the $:
₆In example₆ 

#+BEGIN_EXAMPLE
$1\$$2

#+END_EXAMPLE
or

#+BEGIN_EXAMPLE
${1:DATA}\$${2:VAR}

#+END_EXAMPLE

**** choose pre defined values on expansion
use the yas-choose-value command
₆In example₆ 
#+BEGIN_EXAMPLE
  :PROPERTIES:
    :ID: 
    :Time:  ${1:$$(yas-choose-value '("10" "15" "30" "60"))}
    :Rating:  ${2:$$(yas-choose-value '("1" "2" "3" "4" "5"))} 
    :Source: $3
    :Cuisine:  ${4:$$(yas-choose-value '("Indian" "Thai" "Asian" "Vietnamese" "Chinese" "Israeli" "Italian" "American" "EastEuro" "Mexican" "French" "Persian" "Austria" ))}
    :Type:   ${5:$$(yas-choose-value '("main" "side" "starter" "sweets" "drinks" "sauce" "breakfast"))}   
    :Serves:  ${6:$$(yas-choose-value '("1" "2" "4" "6" "8"))} 
    :Fav: $7
    :END:
#+END_EXAMPLE

** yankpad
   :PROPERTIES:
   :ID:       d5bc7fd8-3d26-4a60-ba7e-d88ae25a1264
   :END:
https://github.com/Kungsgeten/yankpad
*** use-package

#+BEGIN_SRC emacs-lisp :results none
(use-package yankpad
 :ensure t
 :config
  (require 'yankpad)
  (setq yankpad-file "/home/zeltak/org/files/help/yankpad.org")
;; to make lv3 snippets (and use lv2 as sub category)
(setq yankpad-snippet-heading-level 3) 
 )
#+END_SRC
*** DOCU
**** per file category
 Sometimes it may be useful to set the category automatically for a specific file. In this case you can add yankpad-category as a file variable, for instance by adding this line at the top of your file:

 #+BEGIN_EXAMPLE
 -*- yankpad-category: "Category name"; -*-
 #+END_EXAMPLE
 The above will not add keybindings to yankpad-map. In order to do that on a file-to-file basis, add the following to the top of the file instead:

 #+BEGIN_EXAMPLE
 -*- eval: (yankpad-set-local-category "Category name") -*-
 #+END_EXAMPLE

 if you need to put it at the end of the file the syntax is a bit different
#+BEGIN_EXAMPLE
; /* Local Variables:  */
; /*   yankpad-category: "settings";         */
; /* End:              */
#+END_EXAMPLE

**** to auto switch to a category for a  specific file add this to the top of a file 

#+BEGIN_EXAMPLE
-*- yankpad-category: "food"; -*-
#+END_EXAMPLE

** uniquify 
#+BEGIN_SRC emacs-lisp  :results none
(use-package uniquify
  :config
  (setq uniquify-buffer-name-style 'post-forward-angle-brackets)
)
#+END_SRC   









* Org
  :PROPERTIES:
  :ID:       5862c12f-5cba-4220-add5-e92307bceaac
  :END:
** org faces
   :PROPERTIES:
   :ID:       7fa7903e-ef65-4c53-96b8-7279ad7e1eb8
   :END:
*** add more levels
    :PROPERTIES:
    :ID:       cc760e0d-861f-41c5-a9d3-f9e7385a683c
    :END:
#+BEGIN_SRC emacs-lisp  :results none

;;; add more org levels

;;; level 9

(progn
  (defface org-level-9 
    (org-compatible-face nil ;; not inheriting from outline-9 because that does not exist
      '((((class color) (min-colors 16) (background light)) (:foreground "#Fa8072"))
        (((class color) (min-colors 16) (background dark)) (:foreground "#Fa8072"))
        (((class color) (min-colors 8)) (:foreground "green"))))
    "Face used for level 9 headlines."
    :group 'org-faces)
  (setq org-level-faces (append org-level-faces (list 'org-level-9)))
  (setq org-n-level-faces (length org-level-faces)))

;;level 10

(progn
  (defface org-level-10 
    (org-compatible-face nil ;; not inheriting from outline-9 because that does not exist
      '((((class color) (min-colors 16) (background light)) (:foreground "#Daa520"))
        (((class color) (min-colors 16) (background dark)) (:foreground "#Daa520"))
        (((class color) (min-colors 8)) (:foreground "green"))))
    "Face used for level 10 headlines."
    :group 'org-faces)
  (setq org-level-faces (append org-level-faces (list 'org-level-10)))
  (setq org-n-level-faces (length org-level-faces)))

;; level 11 
(progn
  (defface org-level-11 
    (org-compatible-face nil ;; not inheriting from outline-9 because that does not exist
      '((((class color) (min-colors 16) (background light)) (:foreground "#6b8e23"))
        (((class color) (min-colors 16) (background dark)) (:foreground "#6b8e23"))
        (((class color) (min-colors 8)) (:foreground "green"))))
    "Face used for level 11 headlines."
    :group 'org-faces)
  (setq org-level-faces (append org-level-faces (list 'org-level-11)))
  (setq org-n-level-faces (length org-level-faces)))

#+END_SRC
*** hide markups in org buffer
*don't* hide things like = and / for emphasis markers
to hide change nil to t 
#+BEGIN_SRC emacs-lisp  :results none
(setq org-hide-emphasis-markers nil)
#+END_SRC
*** general
    :PROPERTIES:
    :ID:       8dedf73e-c5a0-4f70-8338-33027b44a0e5
    :END:
#+BEGIN_SRC emacs-lisp :results none
(fset 'orgstyle-tnote
   [?! home ?!])
(define-key org-mode-map (kbd "C-1") 'orgstyle-tnote)


(fset 'orgstyle-warning
   "@\341@WARNING:")
(define-key org-mode-map (kbd "C-2") 'orgstyle-warning)

(fset 'orgstyle-warning2
   [?@ home ?@])
(define-key org-mode-map (kbd "C-S-2") 'orgstyle-warning2)



(fset 'orgstyle-com1
   [?~ home ?~])
(define-key org-mode-map (kbd "C-3") 'orgstyle-com1)

(fset 'orgstyle-note
   "$\341$NOTE:")
(define-key org-mode-map (kbd "C-4") 'orgstyle-note)

(fset 'orgstyle-note2
   [?$ home ?$])
(define-key org-mode-map (kbd "C-S-4") 'orgstyle-note2)

(fset 'orgstyle-tip
   "%\341%TIP:")
(define-key org-mode-map (kbd "C-5") 'orgstyle-tip)


(fset 'orgstyle-tip2
   [?% home ?%])
(define-key org-mode-map (kbd "C-S-5") 'orgstyle-tip2)


(fset 'orgstyle-code
   [?^ home ?^])
(define-key org-mode-map (kbd "C-6") 'orgstyle-code)

(fset 'orgstyle-header
   [?& home ?&])
(define-key org-mode-map (kbd "C-7") 'orgstyle-header)

(fset 'orgstyle-bold
   [?* home ?*])
(define-key org-mode-map (kbd "C-7") 'orgstyle-bold)

(fset 'orgstyle-highlight-green
   [?' home ?'])
(define-key org-mode-map (kbd "C-9") 'orgstyle-highlight-green)

(fset 'orgstyle-com2
   [?` home ?`])
(define-key org-mode-map (kbd "C-0") 'orgstyle-com2)

(fset 'underline_net_delete
   [?\M-% ?\  return return ?!])

#+END_SRC
*** org-fontify-whole-heading-line 
#+BEGIN_SRC emacs-lisp  :results none
org-fontify-whole-heading-line t
#+END_SRC
*** TODO color monday/Wed headers
http://emacs.stackexchange.com/questions/28905/color-specific-days-in-different-background-in-org-agenda/28923#28923

#+BEGIN_SRC emacs-lisp  :results none
(defun my-org-agenda-get-day-face-fn (date)
"Return the face DATE should be displayed with."
  (let ((day-of-week (calendar-day-of-week date)))
    (cond
      ((or (= day-of-week 1) (= day-of-week 3))
        '(:background "DarkSeaGreen"))
      ((org-agenda-todayp date)
        'org-agenda-date-today)
      ((member (calendar-day-of-week date) org-agenda-weekend-days)
        'org-agenda-date-weekend)
      (t 'org-agenda-date))))

(setq org-agenda-day-face-function 'my-org-agenda-get-day-face-fn)
#+END_SRC
** Base
   :PROPERTIES:
   :ID:       097c101e-4270-4700-8719-0d84ab7f9ebd
   :END:
*** swap C and M RETURN
    :PROPERTIES:
    :ID:       1616e677-3896-455a-ae5e-19b508160e58
    :END:
#+BEGIN_SRC emacs-lisp :results none
(with-eval-after-load "org" 
(define-key org-mode-map (kbd "<C-return>") 'org-insert-heading)
(define-key org-mode-map (kbd "<M-return>")  'org-insert-heading-respect-content)
) 
#+END_SRC
*** org base configs
    :PROPERTIES:
    :ID:       ff225ea4-967a-4cd6-b806-063a4d725974
    :END:
**** define org mode locations for all operations
     :PROPERTIES:
     :ID:       d0ea8c97-c78a-4c57-9a74-59f8ac9c0844
     :END:
#+BEGIN_SRC emacs-lisp :results none
(setq org-directory "~/org/files/")
(setq org-default-notes-file "~/org/files/refile.org")
#+END_SRC 
**** main configs
     :PROPERTIES:
     :ID:       6f11b870-3701-4154-ac73-853aa5349d7e
     :END:
#+BEGIN_SRC emacs-lisp :results none
;associate these files with org

(add-to-list 'auto-mode-alist '("\\.\\(org\\|org_archive\\|txt\\)$" . org-mode))

;make new headings appear after the content for the current one
(setq org-insert-heading-respect-content t)

;going to the beginning and end of the heading instead of the current line
(setq org-special-ctrl-a/e t)
;rebind certain one-letter keybindings when the cursor is at the beginning of the row - most notably ‘t’ for org-todo instead of ‘C-c C-t’
(setq org-startup-align-all-tables t)
(setq org-archive-location (concat org-directory "archive/%s_archive::"))
(setq org-attach-store-link-p 1)
;to make ido mode work in org mode as wel
(setq org-completion-use-ido t)
;allow speedkeys
(setq org-use-speed-commands t)
(setq org-speed-commands-user nil)
 #+END_SRC
*** add time stamp on every org header
    :PROPERTIES:
    :LAST-EDITED: [03-08-2015(20:57)]
    :ID:       dd27839d-e493-430e-823e-fff9df387dcb
    :END:
this will update when the header text will change

#+BEGIN_SRC emacs-lisp
  ;;   (defun update-last-edited (beg end length)
  ;;     (when
  ;;         (and
  ;;          (not (org-before-first-heading-p))
  ;;          (org-get-heading))
  ;;       (org-entry-put nil "LAST-EDITED" (format-time-string "[%d-%m-%Y(%H:%M)]"))))

  ;; (add-hook 'org-mode-hook (lambda ()
  ;; (add-to-list 'after-change-functions 'update-last-edited))) 
#+END_SRC

#+RESULTS:
*** org-crypt
#+BEGIN_SRC emacs-lisp  :results none
(require 'org-crypt)
(org-crypt-use-before-save-magic)
(setq org-tags-exclude-from-inheritance (quote ("crypt")))
;; GPG key to use for encryption
;; Either the Key ID or set to nil to use symmetric encryption.
(setq org-crypt-key nil)
#+END_SRC

#+END_SRC
*** Save all org buffers every hour
    :PROPERTIES:
    :LAST-EDITED: [02-08-2015(21:32)]
    :ID:       53bc7b4a-f55f-48dd-ba51-16ca43e955cf
    :END:
redudndant to to auto save package??

#+BEGIN_SRC emacs-lisp :results none
(run-at-time "00:59" 3600 'org-save-all-org-buffers)
#+END_SRC 

*** flyspell
    :PROPERTIES:
    :ID:       801682a8-1bf4-4db3-bfd8-a6cef172d95c
    :END:
#+begin_src emacs-lisp
;enable flyspelll
(add-hook 'org-mode-hook  
          (lambda ()      
            (flyspell-mode)))

;; 2. ignore message flags which can slow org 
(setq flyspell-issue-message-flag nil)

;; ignore tex commands in org 
(add-hook 'org-mode-hook (lambda () (setq ispell-parser 'tex)))
(defun flyspell-ignore-tex ()
  (interactive)
  (set (make-variable-buffer-local 'ispell-parser) 'tex))
(add-hook 'org-mode-hook 'flyspell-ignore-tex)

#+end_src

#+RESULTS:
| org-mark-readonly | my-org-mode-hook | flyspell-ignore-tex | (lambda nil (setq ispell-parser (quote tex))) | (lambda nil (flyspell-mode)) | wrap-region-mode | rainbow-mode | (lambda nil (org-bullets-mode 1)) | org-ref-org-menu | (lambda nil (advice-add (quote org-activate-bracket-links) :after (function org-ref-make-org-link-cite-key-visible)) (font-lock-add-keywords nil (quote ((org-ref-match-next-cite-link (0 (quote org-ref-cite-face) t)) (org-ref-match-next-label-link (0 (quote org-ref-label-face) t)) (org-ref-match-next-ref-link (0 (quote org-ref-ref-face) t)) (org-ref-match-next-bibliography-link (0 (quote org-link) t)) (org-ref-match-next-bibliographystyle-link (0 (quote org-link) t)))) t)) | (closure (t) nil (font-lock-add-keywords nil (quote ((or-next-acronym-link (0 (quote org-ref-acronym-face) t)))) t)) | (closure (t) nil (font-lock-add-keywords nil (quote ((or-next-glossary-link (0 (quote org-ref-glossary-face) t)))) t)) | er/add-org-mode-expansions | #[nil \300\301\302\303\304$\207 [org-add-hook change-major-mode-hook org-show-block-all append local] 5] | #[nil \300\301\302\303\304$\207 [org-add-hook change-major-mode-hook org-babel-show-result-all append local] 5] | org-babel-result-hide-spec | org-babel-hide-all-hashes | org-eldoc-load |

*** LateX support
    :PROPERTIES:
    :ID:       eac818f0-109a-4d7b-bc83-9644f451d757
    :END:
CDLaTeX is “is a minor mode that is normally used in combination with a major LaTeX mode like AUCTeX in order to speed-up insertion of environments and math templates”.
the Org manual gives a very easy way to enable it:
#+BEGIN_SRC emacs-lisp :results none
;; enable cdlatex 
;;(add-hook 'org-mode-hook 'turn-on-org-cdlatex)
#+END_SRC
*** disable linium mode 
    :PROPERTIES:
    :ID:       7bc40469-02ce-4fc7-88ed-fd5a8ac52ef2
    :END:
#+BEGIN_SRC emacs-lisp :results none
;;disable linemode on org
(defun my-org-mode-hook () 
  (linum-mode 0)) 
(add-hook 'org-mode-hook 'my-org-mode-hook)
#+END_SRC
*** make default notes read-only
    :PROPERTIES:
    :ID:       3fea170d-27d7-4513-b473-333184ba81d4
    :END:
#+BEGIN_SRC emacs-lisp :results none
;(add-hook 'org-mode-hook (lambda () (view-mode 1)))
#+END_SRC
*** make org mode read-only after 5 minutes @may cause wierd issues@
    :PROPERTIES:
    :ID:       869765f4-0005-4212-b4c4-1800f87119a7
    :END:

@Warning- this may cause strange behviour@

#+begin_src emacs-lisp :results none
  ;; (defvar tj/last-buffer-tick nil)
  ;; (make-variable-buffer-local 'tj/last-buffer-tick)
  
  ;; (defun tj/new-buffer-ticks-p ()
  ;;   (let ((curr-tick (buffer-modified-tick))
  ;;         (last-tick tj/last-buffer-tick))
  ;;     (setq tj/last-buffer-tick curr-tick)
  ;;     (and last-tick (= last-tick curr-tick))))
  
  ;; (defun tj/reset-view-mode ()
  ;;   (run-with-timer 0 (* 5 60)
  ;;                   (lambda ()
  ;;                     (when (tj/new-buffer-ticks-p)
  ;;                       (view-mode t)))))
  
  ;; (add-hook 'org-mode-hook 'tj/reset-view-mode)
#+end_src

*** enable shift selection 
    :PROPERTIES:
    :ID:       f7418b95-88d3-46fa-a8ee-34c2c503bd90
    :END:

use setq org-support-shift-select:

'always- to always use it
'nil- to disable on org mode
't- for When outside special context

#+BEGIN_SRC emacs-lisp :results none
(setq org-support-shift-select 't)
#+END_SRC

*** Header behavior
    :PROPERTIES:
    :ID:       7fe8b5b3-c071-40ca-b764-15a044056711
    :END:
#+BEGIN_SRC emacs-lisp :results none
;; when creating new headers make sure there isn't a space
(setq org-blank-before-new-entry '((heading . nil) (plain-list-item . nil)))
;;;this will make sure there are no empty lines betwwn headers after collapsing headers 
(setq org-cycle-separator-lines 0) 
#+END_SRC
*** don't let edit invisible areas
    :PROPERTIES:
    :ID:       4d41ad16-b457-4c77-b93d-5b86aa026d10
    :END:
#+BEGIN_SRC emacs-lisp  :results none
 ;; don't let me accidentally delete text without realizing it in org.  ie: point is buried in a subtree, but you only
 ;; see the heading and you accidentally kill a line without knowing it.
 ;; this might not be supported for evil-mode
 org-catch-invisible-edits 'show-and-error
#+END_SRC
** links
:PROPERTIES:
   :ID:       ac3f739d-aa11-4d74-8fd7-3c49152a3206
   :END:
*** follow links on enter
#+BEGIN_SRC emacs-lisp  :results none
;allow RETURN to open links (nil or t)
(setq org-return-follows-link nil)
#+END_SRC

*** grep link
    :PROPERTIES:
    :ID:       7a4ac856-e2cf-41ed-86e0-6de8e5c04636
    :END:
#+BEGIN_SRC emacs-lisp :results none
(org-add-link-type
 "grep"
 (defun endless/follow-grep-link (regexp)
   "Run `rgrep' with REGEXP as argument."
   (grep-compute-defaults)
   (rgrep regexp "*" (expand-file-name "./"))))
#+END_SRC 
*** dired links
    :PROPERTIES:
    :ID:       666f785c-9fcf-4c7a-afa3-5a017f5433c6
    :END:
#+BEGIN_SRC emacs-lisp :results none
  (org-add-link-type "file+emacs+dired" 'org-open-file-with-emacs-dired)
  (add-hook 'org-store-link-functions 'org-dired-store-link)

  (defun org-open-file-with-emacs-dired (path)
    "Open in dired."
    (let ((d (file-name-directory path))
          (f (file-name-nondirectory path)))
      (dired d)
      (goto-char (point-min))
      (search-forward f nil t)))

  (defun org-dired-store-link ()
    "Store link to files/directories from dired."
    (require 'dired+)
    (when (eq major-mode 'dired-mode)
      (let ((f (dired-get-filename)))
        (setq link (concat "file+emacs+dired" ":" f)
              desc (concat f " (dired)"))
        (org-add-link-props :link link :description desc)
        link)))
#+end_src

*** org link open with
    :PROPERTIES:
    :ID:       07d0a21f-31d6-4601-a93f-82bc51c65c1a
    :END:
#+BEGIN_SRC emacs-lisp :results none
(eval-after-load "org"
  (lambda ()
    (if (assoc "\\.avi\\'" org-file-apps)
	(setcdr (assoc "\\.avi\\'" org-file-apps) "vlc %s")
      (add-to-list 'org-file-apps '("\\.avi\\'" . "vlc %s") t))
    (if (assoc "\\.mp4\\'" org-file-apps)
	(setcdr (assoc "\\.mp4\\'" org-file-apps) "vlc %s")
      (add-to-list 'org-file-apps '("\\.mp4\\'" . "vlc %s") t))))

#+END_SRC

*** insert id based links
    :PROPERTIES:
    :ID:       33cffe53-1b34-44fa-a949-6cad72e442e0
    :END:
this will make org-store-link use id when creating a link.
#+BEGIN_SRC emacs-lisp :results none
(require 'org-id)
(setq org-id-link-to-org-use-id t)
;; Use global IDs
;; Update ID file .org-id-locations on startup
(org-id-update-id-locations)
 #+END_SRC

*** org-colored-text
    :PROPERTIES:
    :ID:       65b612d7-7eed-4a9a-8256-e4046686a7f4
    :END:

#+BEGIN_SRC emacs-lisp  :results none
(require 's)
(defvar org-link-colors '(("color1" . '(:foreground "blue"))
              ("color2" . '(:foreground "red" :background "yellow"))))

(defun color-comp (&optional arg)
  (let ((color-data (progn
              (save-selected-window
            (list-colors-display))
              (append
               (mapcar (lambda (cell)
                 (cons (propertize (car cell)
                           'face (cdr cell))
                       (list (car cell))))
                   org-link-colors)
               (prog1
               (with-current-buffer (get-buffer "*Colors*")
                 (mapcar (lambda (line)
                       (append (list line)
                           (s-split " " line t)))
                     (s-split "\n" (buffer-string))))
             (kill-buffer "*Colors*"))))))
    (format "color:%s"
        (s-trim (cadr (assoc (completing-read "Color: " color-data) color-data))))))


(defun color-link-face (path)
  (or (cdr (assoc path org-link-colors))
      `(:foreground ,path)))

(defun color-link-export (path description backend)
  (cond
    ((eq backend 'html)
     (let ((rgb (assoc (downcase path) color-name-rgb-alist))
       r g b)
       (if rgb
       (progn
         (setq r (* 255 (/ (nth 1 rgb) 65535.0))
           g (* 255 (/ (nth 2 rgb) 65535.0))
           b (* 255 (/ (nth 3 rgb) 65535.0)))
         (format "<span style=\"color: rgb(%s,%s,%s)\">%s</span>"
             (truncate r) (truncate g) (truncate b)
             (or description path)))
     (format "No Color RGB for %s" path))))))


(org-link-set-parameters "color"         
             :face 'color-link-face
             :complete 'color-comp
             :export 'color-link-export)
#+END_SRC


** loading on startup
   :PROPERTIES:
   :ID:       72673867-13e1-47f9-9e0a-9f7c39785e76
   :END:
*** org models
    :PROPERTIES:
    :ID:       5e0007df-1a72-4dbf-a6c5-0423347d7237
    :END:

#+BEGIN_SRC emacs-lisp :results none
(add-to-list 'org-modules "org-habit")
#+END_SRC

** Agenda
   :PROPERTIES:
   :ID:       ef462cd2-f853-4bb1-9d9c-430e46561789
   :END:
*** set agenda location
    :PROPERTIES:
    :ID:       c60d39b4-affc-4800-86f4-45500bbfed92
    :END:
#+BEGIN_SRC emacs-lisp :results none
;(setq org-agenda-files '("~/org/files/agenda/"))
(setq org-agenda-files (list "~/org/files/agenda/" "/home/zeltak/org/files/web/wbookmarks.org"))
#+END_SRC
*** agenda popup behivour
    :PROPERTIES:
    :ID:       1411d45a-f018-4fe3-b4ca-d3c3717a9d2c
    :END:
#+BEGIN_SRC emacs-lisp :results none
(setq org-agenda-window-setup "current-window")
;;return the configuration of the screen before agenda display
(setq org-agenda-restore-windows-after-quit t)
#+END_SRC
*** keep refreshing org agenda
    :PROPERTIES:
    :ID:       2cc03c94-02f2-4d4d-9121-1379a0f8b8c4
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(run-with-idle-timer 600 t #'org-agenda-redo) ;; to rebuild it every 600 seconds
#+END_SRC
*** agenda view
    :PROPERTIES:
    :ID:       587aff06-4e47-4739-99fe-a91ef714ad99
    :END:
#+BEGIN_SRC emacs-lisp :results none
;change agenda colors
;(setq org-upcoming-deadline '(:foreground "blue" :weight bold))
;max days to show in agenda view
(setq org-agenda-ndays 14)
;start agenda from today-  don't show listings from earlier in the week
;(setq org-agenda-start-on-weekday nil)
;;;constant agenda start on sunday always (0)
(setq org-agenda-start-on-weekday 0)
;Items that have deadlines are displayed 10 days in advance
(setq org-deadline-warning-days 10)
;don’t display items that are done in my agenda.
(setq org-agenda-skip-deadline-if-done t)
(setq org-agenda-skip-scheduled-if-done t)
(setq org-agenda-span 14)

#+END_SRC
*** hydra org-agenda command
    :PROPERTIES:
    :ID:       2ee1fa91-e5bb-460b-820f-1ce73f9a676d
    :END:
http://oremacs.com/2016/04/04/hydra-doc-syntax/

http://orgmode.org/manual/Agenda-commands.html#Agenda-commands
#+BEGIN_SRC emacs-lisp  :results none
  ;;needed function
  (defun org-agenda-cts ()
    (let ((args (get-text-property
                 (min (1- (point-max)) (point))
                 'org-last-args)))
      (nth 2 args)))


  (defhydra hydra-org-agenda-view (:hint nil :columns 4)
  "

  "
  ;;;views
    ("d" org-agenda-day-view
         (if (eq 'day (org-agenda-cts))
             "[x]" "[ ]"))
    ("w" org-agenda-week-view
         (if (eq 'week (org-agenda-cts))
             "[x]" "[ ]"))
    ("m" org-agenda-month-view
         (if (eq 'month (org-agenda-cts)) "[x]" "[ ]"))
    ("c" cfw:open-org-calendar  "cfw month calendar"  )
;;;commands
("X"    org-agenda-reset-view   "reset view"  )
("j"    org-agenda-goto-date   "goto date" :face 'hydra-face-green )
("k"    org-agenda-kill   "delete"  )
("t"    org-agenda-todo      "change todo")
("m"    org-agenda-bulk-toggle  "bulk mark"  :color red ) 
("M"    org-agenda-bulk-action  "bulk exe")
("x"   org-agenda-archive      "archive ")
("w"   org-agenda-refile      "refile ")
(":"   org-agenda-set-tags      "set tags ")
(","   org-agenda-priority      "priority (S-UP/S-Dn to change as well ")
("s"   org-agenda-schedule      "schedule task ")
("d"   org-agenda-deadline      "deadline task ")
("p"   org-agenda-date-prompt      "prompt date ")
("f" org-agenda-follow-mode
         (format "% -3S" org-agenda-follow-mode))

("e" org-agenda-entry-text-mode (format "% -3S" org-agenda-entry-text-mode))
("g" org-agenda-toggle-time-grid (format "% -3S" org-agenda-use-time-grid))
("D" org-agenda-toggle-diary (format "% -3S" org-agenda-include-diary))
("!" org-agenda-toggle-deadlines "toggle deadlines")

("q" (message "Abort") :exit t))


  (define-key org-agenda-mode-map
      "v" 'hydra-org-agenda-view/body)
#+END_SRC
*** define Israeli weekends
    :PROPERTIES:
    :ID:       f7bb566d-56d4-405a-b15f-ad7fd7f4c80b
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(setq org-agenda-weekend-days '(5 6))
#+END_SRC

*** look and feel
    :PROPERTIES:
    :ID:       adcc5aa3-a52f-410f-923d-9c37a2a05df3
    :END:

#+BEGIN_SRC emacs-lisp :results none
;; Do not dim blocked tasks
(setq org-agenda-dim-blocked-tasks nil)
;; Compact the block agenda view
(setq org-agenda-compact-blocks t)
;; Always hilight the current agenda line
(add-hook 'org-agenda-mode-hook
          '(lambda () (hl-line-mode 1))
          'append)

;; Show all agenda dates - even if they are empty
(setq org-agenda-show-all-dates t)

;;  Enable display of the time grid so we can see the marker for the current time
(setq org-agenda-time-grid (quote ((daily today remove-match)
                                  #("----------------" 0 16 (org-heading t))
                                  (0900 1100 1300 1500 1700))))

;; Display tags farther right
(setq org-agenda-tags-column -102)
#+END_SRC

*** specific sparse trees 
    :PROPERTIES:
    :ID:       09722f19-b52a-41ab-8f95-816db81d6f76
    :END:
***** breakfeast
      :PROPERTIES:
      :ID:       d8c3c8ba-dd7b-458e-bafa-efe46111835e
      :END:
#+BEGIN_SRC emacs-lisp :results none
  (defun cooking-sparse-tree-breakfeast ()
    (interactive)
    (org-match-sparse-tree t "+TODO=\"COOK\"+Type=\"breakfest\""))

  (defun cooking-sparse-tree-main ()
    (interactive)
    (org-match-sparse-tree t "+TODO=\"COOK\"+Type=\"main\""))

  (defun cooking-sparse-tree-sweet ()
    (interactive)
    (org-match-sparse-tree t "+TODO=\"COOK\"+Type=\"sweet\""))

  (defun cooking-sparse-tree-meat ()
    (interactive)
    (org-match-sparse-tree t "+TODO=\"COOK\"+Type=\"meat\""))

  (defun cooking-sparse-tree-fav ()
    (interactive)
    (org-match-sparse-tree t "+Fav=\"y\""))

#+end_src

*** export agenda
    :PROPERTIES:
    :ID:       08b0da38-9239-4f49-bd0b-7e234de2c409
    :END:
#+BEGIN_SRC emacs-lisp :results none
          (setq org-agenda-exporter-settings
                '((ps-number-of-columns 2)
                  (ps-landscape-mode t)
                  (org-agenda-add-entry-text-maxlines 5)
                  (htmlize-output-type 'css)))
#+END_SRC
*** habits
    :PROPERTIES:
    :ID:       43cc4b66-971a-47b6-ae87-9a42f7af4c84
    :END:
#+BEGIN_SRC emacs-lisp :results none
(setq org-habit-graph-column 70)
(setq org-habit-show-habits-only-for-today nil)
#+END_SRC

*** get popups for meetings
    :PROPERTIES:
    :ID:       2a862be9-bcbf-4803-bd09-bc35abf4e7ad
    :END:
#+BEGIN_SRC emacs-lisp
 (appt-activate 1)
 (org-agenda-to-appt)
#+END_SRC

#+RESULTS:
: Added 2 events for today

thos  will be reminded of things in your org files, before the appointment time (I think 12 min is the default)
You could also add this, so that the appointments refresh and new get added every time that you call the agenda:

#+BEGIN_SRC emacs-lisp
(add-hook 'org-agenda-finalize-hook (lambda ()  (org-agenda-to-appt t)))
#+END_SRC

#+RESULTS:
| (lambda nil (org-agenda-to-appt t)) | gnorb-org-popup-bbdb |

*** Sorting by date and priority
    :PROPERTIES:
    :ID:       2d71dc73-f499-4e80-9bcf-bdbbd5e583c2
    :END:

#+BEGIN_SRC emacs-lisp :results none
(setq org-agenda-sorting-strategy
      '((agenda time-up priority-down tag-up effort-up category-keep)
        (todo user-defined-up todo-state-up priority-down effort-up)
        (tags user-defined-up)
        (search category-keep)))
(setq org-agenda-cmp-user-defined 'my/org-sort-agenda-items-user-defined)
(require 'cl)
(defun my/org-get-context (txt)
  "Find the context."
  (car (member-if
        (lambda (item) (string-match "@" item))
        (get-text-property 1 'tags txt))))

(defun my/org-compare-dates (a b)
  "Return 1 if A should go after B, -1 if B should go after A, or 0 if a = b."
  (cond
   ((and (= a 0) (= b 0)) nil)
   ((= a 0) 1)
   ((= b 0) -1)
   ((> a b) 1)
   ((< a b) -1)
   (t nil)))

(defun my/org-complete-cmp (a b)
  (let* ((state-a (or (get-text-property 1 'todo-state a) ""))
         (state-b (or (get-text-property 1 'todo-state b) "")))
    (or
     (if (member state-a org-done-keywords-for-agenda) 1)
     (if (member state-b org-done-keywords-for-agenda) -1))))

(defun my/org-date-cmp (a b)
  (let* ((sched-a (or (get-text-property 1 'org-scheduled a) 0))
         (sched-b (or (get-text-property 1 'org-scheduled b) 0))
         (deadline-a (or (get-text-property 1 'org-deadline a) 0))
         (deadline-b (or (get-text-property 1 'org-deadline b) 0)))
    (or
     (my/org-compare-dates
      (my/org-min-date sched-a deadline-a)
      (my/org-min-date sched-b deadline-b)))))

(defun my/org-min-date (a b)
  "Return the smaller of A or B, except for 0."
  (funcall (if (and (> a 0) (> b 0)) 'min 'max) a b))

(defun my/org-sort-agenda-items-user-defined (a b)
  ;; compare by deadline, then scheduled date; done tasks are listed at the very bottom
  (or
   (my/org-complete-cmp a b)
   (my/org-date-cmp a b)))

(defun my/org-context-cmp (a b)
  "Compare CONTEXT-A and CONTEXT-B."
  (let ((context-a (my/org-get-context a))
        (context-b (my/org-get-context b)))
    (cond
     ((null context-a) +1)
     ((null context-b) -1)
     ((string< context-a context-b) -1)
     ((string< context-b context-a) +1)
     (t nil))))

(defun my/org-sort-agenda-items-todo (a b)
  (or
   (org-cmp-time a b)
   (my/org-complete-cmp a b)
   (my/org-context-cmp a b)
   (my/org-date-cmp a b)
   (org-cmp-todo-state a b)
   (org-cmp-priority a b)
   (org-cmp-effort a b)))
#+END_SRC

*** agenda icons 
    :PROPERTIES:
    :ID:       bff6d154-b4d3-49b5-8bca-081ee0d569e9
    :END:
this will set icons based on the category
#+BEGIN_EXAMPLE
#+CATEGORY: work
#+END_EXAMPLE

#+BEGIN_SRC emacs-lisp  :results none
(setq org-agenda-category-icon-alist '(
                                  ("pc"      "/home/zeltak/MLT/programs/Krusader/Toolbar/refresh.png" nil nil nil nil)
                                  ("work"       "/home/zeltak/MLT/org/bgu.png" nil nil nil nil)
                                  ))
#+END_SRC


** `Custom Agenda commands`
   :PROPERTIES:
   :ID:       4b396dfc-0c1c-407c-9d2d-6cca29c8879c
   :END:
*** info
    :PROPERTIES:
    :ID:       fa20a52f-3a3b-4d8a-9766-fa363151c3d0
    :END:
look here for more info
http://orgmode.org/worg/org-tutorials/org-custom-agenda-commands.html

and here id:cf2c69b4-3d4c-4f81-a01d-bbbe1d120e62

$Note$ that to get the priorities to appear first you need to use priorities-down.

("w" tags-todo "CATEGORY=\"work\"")

(org-agenda-view-columns-initially t)

 will start the view in a column view

also the headers can be customized

(org-columns-default-format "%50ITEM %TODO %3PRIORITY %Effort{:} %TAGS")

-sorting:
(org-agenda-sorting-strategy '(priority-down  tag-up ))

@add@- deadline column , time column to agenda column view

mutiple todos are with the pipe sign 〖TODO|TASK〗
*** start with clean slate
    :PROPERTIES:
    :ID:       4a1a7fca-e9b8-47a6-b7b9-e90443789fc4
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(setq org-agenda-custom-commands nil)
#+END_SRC
*** Uni TODOS (b)
    :PROPERTIES:
    :ID:       fef10f46-bca7-436b-99a4-401532c39367
    :END:
#+BEGIN_SRC emacs-lisp  :results none
;; define "s" as the prefix key for uni
(add-to-list 'org-agenda-custom-commands
             '("b" . "BGU" ))


(add-to-list 'org-agenda-custom-commands
               '("ba" "all BGU TODOS" todo "TODO|TASK" 
((org-agenda-files (list "~/org/files/agenda/research.org" "~/org/files/agenda/bgu.org")))
(org-agenda-sorting-strategy '(priority-down effort-down deadline-up))
(org-agenda-cmp-user-defined 'my/org-sort-agenda-items-todo)
                 ))


(add-to-list 'org-agenda-custom-commands
               '("bb" "BGU TODOS" todo "TODO" 
((org-agenda-files (list  "~/org/files/agenda/bgu.org")))
                 ))


(add-to-list 'org-agenda-custom-commands
               '("br" "Research TODOS" todo "TODO" 
((org-agenda-files (list  "~/org/files/agenda/research.org")))
                 ))


(add-to-list 'org-agenda-custom-commands
               '("bu" "urgent TODOS"
tags-todo "DEADLINE>=\"<today>\"&DEADLINE<=\"<+7d>\""
((org-agenda-files (list  "~/org/files/agenda/research.org" "~/org/files/agenda/bgu.org")))
                 ))


#+END_SRC
*** student tasks (s)
    :PROPERTIES:
    :ID:       78c7d7ec-541b-43e6-8cee-13426ce08826
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-agenda-custom-commands
             '("s" . "students" ))


(add-to-list 'org-agenda-custom-commands
               '("sm" "meytar" 
                  tags-todo "meytar"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))


(add-to-list 'org-agenda-custom-commands
               '("sa" "adar" 
                  tags-todo "adar"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))

(add-to-list 'org-agenda-custom-commands
               '("sy" "maayan" 
                  tags-todo "maayan"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))


(add-to-list 'org-agenda-custom-commands
               '("sx" "alex" 
                  tags-todo "alex"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))


(add-to-list 'org-agenda-custom-commands
               '("so" "omer" 
                  tags-todo "omer"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))


(add-to-list 'org-agenda-custom-commands
               '("sl" "lara" 
                  tags-todo "lara"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))


(add-to-list 'org-agenda-custom-commands
               '("sd" "adi" 
                  tags-todo "adi"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))


(add-to-list 'org-agenda-custom-commands
               '("sh" "helena" 
                  tags-todo "helena"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))


#+END_SRC
*** collaborator tasks (c)
    :PROPERTIES:
    :ID:       60542612-c2c8-429f-b612-1a7f02d36582
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-agenda-custom-commands
             '("c" . "collaborator" ))



(add-to-list 'org-agenda-custom-commands
               '("ca" "allan" 
                  tags-todo "allan"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))


(add-to-list 'org-agenda-custom-commands
               '("cj" "joel" 
                  tags-todo "joel"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))



(add-to-list 'org-agenda-custom-commands
               '("cd" "david" 
                  tags-todo "david"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))



(add-to-list 'org-agenda-custom-commands
               '("cb" "boris" 
                  tags-todo "boris"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))


(add-to-list 'org-agenda-custom-commands
               '("cs" "massimo" 
                  tags-todo "massimo"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))


(add-to-list 'org-agenda-custom-commands
               '("cm" "michael" 
                  tags-todo "michael"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))



(add-to-list 'org-agenda-custom-commands
               '("cn" "johanna" 
                  tags-todo "johanna"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))


(add-to-list 'org-agenda-custom-commands
               '("ct" "tal" 
                  tags-todo "tal"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))


#+END_SRC
*** location based
    :PROPERTIES:
    :ID:       1e58726b-df44-4165-997c-9f51e0881864
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-agenda-custom-commands
             '("2" . "location" ))



(add-to-list 'org-agenda-custom-commands
               '("2h" "@home" 
                  tags-todo "@home"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))



(add-to-list 'org-agenda-custom-commands
               '("2w" "@work" 
                  tags-todo "@work"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))



(add-to-list 'org-agenda-custom-commands
               '("2p" "@pc" 
                  tags-todo "@pc"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))



(add-to-list 'org-agenda-custom-commands
               '("2f" "@family" 
                  tags-todo "@family"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))



(add-to-list 'org-agenda-custom-commands
               '("2s" "@shop" 
                  tags-todo "@shop"
((org-agenda-sorting-strategy '(priority-down effort-down)))
                 ))

#+END_SRC

*** media tasks (d)
    :PROPERTIES:
    :ID:       3aa9ea96-121f-4157-adc2-ecf126aa0cdf
    :END:

#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-agenda-custom-commands
             '("d" . "media" ))

(add-to-list 'org-agenda-custom-commands
               '("dd" "downloads" todo "DOWN"
((org-agenda-files (list "~/org/files/agenda/dl.org" )))
((org-agenda-sorting-strategy '(priority-down effort-down)))
))

(add-to-list 'org-agenda-custom-commands
               '("ds" "music pre release" tags-todo "Pre_Release"
((org-agenda-files (list "~/org/files/agenda/dl.org" )))
((org-agenda-sorting-strategy '(priority-down effort-down)))
))

#+END_SRC

*** Home tasks (h)
    :PROPERTIES:
    :ID:       564eb0fe-f107-44a6-861e-5201958a37de
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-agenda-custom-commands
             '("h" . "home" ))

(add-to-list 'org-agenda-custom-commands
               '("he" "tech" todo "TODO"
((org-agenda-files (list "~/org/files/agenda/TODO.org" )))
((org-agenda-sorting-strategy '(priority-down effort-down)))
))


(add-to-list 'org-agenda-custom-commands
               '("hh" "home" todo "TODO"
((org-agenda-files (list "~/org/files/agenda/home.org" )))
((org-agenda-sorting-strategy '(priority-down effort-down)))
))


#+END_SRC


*** calendar tasks (m)
    :PROPERTIES:
    :ID:       253390af-671d-4aab-9ce8-b89c03c8dc60
    :END:
*** Tech tasks (e)
    :PROPERTIES:
    :ID:       4374f24f-2621-428a-b593-54d1fbb03203
    :END:
*** papers (p)
    :PROPERTIES:
    :ID:       1fcbb22f-83d6-412a-b64a-33bedaa792a4
    :END:
*** food (f)
    :PROPERTIES:
    :ID:       baee8ad4-cf6e-4969-bf6d-8f04fd67058c
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-agenda-custom-commands
             '("f" . "food/travel" ))

(add-to-list 'org-agenda-custom-commands
               '("ff" "COOK" todo "COOK"
((org-agenda-files (list "~/org/files/agenda/food.org" )))
((org-agenda-sorting-strategy '(priority-down effort-down)))
))


(add-to-list 'org-agenda-custom-commands
               '("fd" "desserts" tags-todo "dessert"
((org-agenda-files (list "~/org/files/agenda/food.org" )))
((org-agenda-sorting-strategy '(priority-down effort-down)))
))

;;;property example

(add-to-list 'org-agenda-custom-commands
               '("fa" "american" tags "Cuisine=\"American\""
((org-agenda-files (list "~/org/files/agenda/food.org" )))
((org-agenda-sorting-strategy '(priority-down effort-down)))
))


#+END_SRC

*** Various operations (v)
    :PROPERTIES:
    :ID:       901527a8-90d1-4fcf-9e2e-ddcc4e519b96
    :END:
*** Uni TODOS (b)
    :PROPERTIES:
    :ID:       6ff18076-e0de-472f-b230-7779aa64d341
    :END:
#+BEGIN_SRC emacs-lisp  :results none

(add-to-list 'org-agenda-custom-commands
             '("v" . "Various" ))


(add-to-list 'org-agenda-custom-commands
                  '("vo" occur-tree "TODO") 
                 )

#+END_SRC



** Images
   :PROPERTIES:
   :ID:       aac1aa45-9576-4cda-b564-710c9c90fd09
   :END:
*** base
    :PROPERTIES:
    :ID:       d35b55f7-f3fc-4fb7-a6ab-95c7c2178298
    :END:
**** inline images by default at startup
     :PROPERTIES:
     :ID:       bfcf4372-b314-4272-be08-edebb0eba54c
     :END:
#+begin_src emacs-lisp :results none
;;iimage in org (display images in org files)
(setq org-startup-with-inline-images t)
#+end_src
**** size defaults @Warning- this may screw up image config@ 
     :PROPERTIES:
     :ID:       397371ce-31a6-44b3-8778-bf396cedbeb6
     :END:

#+BEGIN_SRC emacs-lisp :results none
;;set the org image default size
;(setq org-image-actual-width nil)
(setq org-image-actual-width '(400))

#+END_SRC
** Tags
   :PROPERTIES:
   :ID:       6622bf10-946c-4317-a521-f711d909279b
   :END:
*** tag inheritance
    :PROPERTIES:
    :ID:       d098b705-9275-4c43-83fc-afe43a173ddc
    :END:
make sure child headers don't get the header tags
http://orgmode.org/manual/Tag-inheritance.html

#+BEGIN_SRC emacs-lisp :results none
(setq org-use-tag-inheritance nil)
#+END_SRC

*** tag alist
    :PROPERTIES:
    :ID:       4da69088-0361-4cbd-a256-bf2cbc0196de
    :END:

〖:startgroup〗 is is used when you want exclusive tags (that is only 1 at a time is possible)
〖:startgrouptags〗 is is used when you want to use several tags at a time)


#+BEGIN_SRC emacs-lisp  :results none
  (setq org-tag-persistent-alist  '(

(:startgroup)
    ("Where?")
    (:grouptags)
     ("@home" . ?h)
     ("@work" . ?w)
     ("@pc" . ?p)
     ("@family" . ?f)
     ("@shop" . ?s)
     (:endgroup)

(:startgrouptag)
    ("people")
    (:grouptags)
    ("allan" . ?a)
    ("bob" . ?o)
    ("joel" . ?j)
    ("david" . ?d)
    ("boris" . ?b)
    ("massimo" . ?s)
    ("michael" . ?m)
    ("tal" . ?t)
    ("johanna" . ?n)
    (:endgrouptag)

(:startgrouptag)
   ("students")
   (:grouptags)
   ("adar" . ?a)
   ("meytar" . ?m)
   ("maayan" . ?y)
   ("alex" . ?x)
   ("omer" . ?o)
   ("hila" . ?z)
   ("adi" . ?v)
   ("lara" . ?l)
   ("helena" . ?h)
   ("aliza" . ?z)
   (:endgrouptag)


(:startgrouptag)
   ("publishing")
   (:grouptags)
   ("pres" . ?p)
   ("noexport" . ?n)
   (:endgrouptag)


  ))
#+END_SRC


*** org-tag-faces
    :PROPERTIES:
    :ID:       91af074d-ebee-4bb9-9737-43e57991f6ef
    :END:

does not work at all
#+begin_src emacs-lisp :results none
(setq org-tag-faces
      '(

;; places 
("@home" . "#3498db")
("@work" . "#3498db")
("@pc" . "#3498db")
("@family" . "#3498db")
("@shop" . "#3498db")

;;;collaborators 
("allan" . (:foreground "blue" :weight bold))
("joel" . (:foreground "blue" :weight bold))
("david" . (:foreground "blue" :weight bold))
("boris" . (:foreground "blue" :weight bold))
("massimo" (:foreground "blue" :weight bold))
("bob" (:foreground "blue" :weight bold))
("michael" (:foreground "blue" :weight bold))
("tal" (:foreground "blue" :weight bold))
;;students 
("adar" . (:foreground "Purple" :weight bold))
("meytar" . (:foreground "Purple" :weight bold))
("maayan" . (:foreground "Purple" :weight bold))
("alex" . (:foreground "Purple" :weight bold))
("omer" . (:foreground "Purple" :weight bold))
("hila" . (:foreground "Purple" :weight bold))
("adi" . (:foreground "Purple" :weight bold))
("lara" . (:foreground "Purple" :weight bold))
("helena" . (:foreground "Purple" :weight bold))
("aliza" .  (:foreground "Purple" :weight bold))

))


#+end_src



*** Allow setting single tags without the menu			      
    :PROPERTIES:
    :ID:       c5519c08-0372-42d3-94a8-664b3b43ae43
    :END:
#+BEGIN_SRC emacs-lisp  :results none
;; Allow setting single tags without the menu
(setq org-fast-tag-selection-single-key (quote expert))
#+END_SRC

*** tag searches function  
    :PROPERTIES:
    :ID:       c1e25ca7-8cbd-4bd8-b417-3ac09c61474b
    :END:
#+BEGIN_SRC emacs-lisp :results none
(org-add-link-type
 "tag"
 (defun endless/follow-tag-link (tag)
   "Display a list of TODO headlines with tag TAG.
With prefix argument, also display headlines without a TODO keyword."
   (org-tags-view (null current-prefix-arg) tag)))
#+END_SRC
** Todo
   :PROPERTIES:
   :ID:       fd828cb4-901a-4431-ba82-7de04eb87859
   :END:
*** org todo config
    :PROPERTIES:
    :ID:       7617300f-6851-4720-abbc-9e26d3881872
    :END:
#+BEGIN_SRC emacs-lisp :results none
;allow fast todo
(setq org-use-fast-todo-selection t)
;allow shift-left right to change todo state
(setq org-treat-S-cursor-todo-selection-as-state-change nil)
#+END_SRC
*** todo keywords
    :PROPERTIES:
    :ID:       6fb9e02d-6181-459e-a4b7-2bd469f7b8a9
    :END:
#+begin_src emacs-lisp :results none
(setq org-todo-keywords
      (quote ((sequence "TODO(t)"  "|" "DONE(d)")
              (sequence "TASK(f)" "|" "DONE(d)")
              (sequence "INPR(r)" "|" "DONE(d)")
              (sequence "ACTION(a)" "|" "DONE(d)")
)))
(setq org-todo-keyword-faces
      (quote (("TODO" :foreground "red" :weight bold)
              ("TASK" :foreground "magenta" :weight bold)
              ("ACTION" :foreground "#7b68ee" :weight bold)
              ("NEXT" :foreground "blue" :weight bold)
              ("INPR" :background "#9CFFBB" :foreground "#004D18" :weight bold)
              ("PAUS" :foreground "gray" :weight bold)
              ("SUBMITTED" :foreground "#FFC612" :weight bold)
              ("K_TRACK" :foreground "#45D0FF" :weight bold)
              ("DONE" :foreground "forest green" :weight bold)
              ("PUB" :foreground "#00FF37" :weight bold)
              ("PREP" :foreground "#FF7BD0" :weight bold)
              ("SUB" :foreground "#CE008B" :weight bold)
              ("TOVISIT" :background "#0CFB32" :foreground "#001F57" :weight bold)
              ("VISITED" :background "#FF7BD0" :foreground "#001F57" :weight bold)
              ("COOK" :background "#0CFB32" :foreground "#001F57" :weight bold)
              ("SHOP" :background "#9CFFBB" :foreground "#004D18" :weight bold)
              ("DOWN" :background "#9CFFBB" :foreground "#004D18" :weight bold)
              )))
#+end_src


*** auto add tags
    :PROPERTIES:
    :ID:       a1ac87ef-4fb8-4265-966a-c038f7ac5b26
    :END:
#+BEGIN_SRC emacs-lisp :results none
(setq org-todo-state-tags-triggers
      (quote (("CANCELLED" ("CANCELLED" . t))
              ("WAITING" ("WAITING" . t))
              ("HOLD" ("WAITING" . t) ("HOLD" . t))
              (done ("WAITING") ("HOLD"))
              ("TODO" ("WAITING") ("CANCELLED") ("HOLD"))
              ("NEXT" ("WAITING") ("CANCELLED") ("HOLD"))
              ("DONE" ("WAITING") ("CANCELLED") ("HOLD")))))
#+END_SRC
*** priorities
    :PROPERTIES:
    :ID:       992bd4b3-4f91-45d9-85e2-7c0bc6bd4e2c
    :END:
**** This can mess up the sort order in org-agenda-sorting-strategy and thus its commented out
     :PROPERTIES:
     :ID:       11c6f746-62b4-4736-85bf-7039aeba7a3f
     :END:
 #+BEGIN_SRC emacs-lisp :results none
   ;; ;;set priority range from A to C with default A
   ;; (setq org-highest-priority ?A)
   ;; (setq org-lowest-priority ?C)
   ;; (setq org-default-priority ?A)

 #+END_SRC
**** colours for priorities
     :PROPERTIES:
     :ID:       c590da8e-aa89-4f49-9510-362341577e4b
     :END:
#+BEGIN_SRC emacs-lisp
(setq org-priority-faces '((?A . (:foreground "#F0DFAF" :weight bold))
                           (?B . (:foreground "LightSteelBlue"))
                           (?C . (:foreground "OliveDrab"))))
#+END_SRC

#+RESULTS:
| 65 | :foreground | #F0DFAF        | :weight | bold |
| 66 | :foreground | LightSteelBlue |         |      |
| 67 | :foreground | OliveDrab      |         |      |

*** mark as done when archiving
    :PROPERTIES:
    :ID:       707388f5-6e2e-4694-9265-295698b0f292
    :END:
#+BEGIN_SRC emacs-lisp  :results none
;; Mark entries as done when archiving
(setq org-archive-mark-done t)
#+END_SRC
** Refile
   :PROPERTIES:
   :ID:       5c55a118-9cd2-4bea-a1e9-50cbe1498729
   :END:
*** set which refile method to us (currently helm)
    :PROPERTIES:
    :ID:       bdfd5d78-f820-4f57-95cc-435690699ab7
    :END:
this command below will use helm for completion since in the above helm config we sepcify these two commands: (require 'helm-config) and (helm-mode 1)
#+BEGIN_SRC emacs-lisp :results none
(setq org-outline-path-complete-in-steps nil)
#+END_SRC
*** settings for paths and headers shown
    :PROPERTIES:
    :ID:       a8335be2-949e-43b3-a6df-2d2821a09ced
    :END:
#+BEGIN_SRC emacs-lisp :results none
;;list everything instead of stepping through each level gradually
(setq org-outline-path-complete-in-steps nil)
;; Refile on top of file max
(setq org-refile-use-outline-path 'file )
#+END_SRC
*** set heading depth
    :PROPERTIES:
    :ID:       9d5a6651-5fb6-482b-b650-ad8583c53127
    :END:
set how many levels of headers to show while refiling 
#+begin_src emacs-lisp results none
; Targets include this file and any file contributing to the agenda - up to 9 levels deep
(setq org-refile-targets (quote ((nil :maxlevel . 9)
                                 (org-agenda-files :maxlevel . 9))))
#+end_src

#+RESULTS:
: ((nil :maxlevel . 9) (org-agenda-files :maxlevel . 9))

$Note$ that you can also refile per file with specific levels 

#+BEGIN_EXAMPLE

(setq org-refile-targets (quote (("tickler.org" :maxlevel . 1)
                                 ("organizer.org" :level . 1)
                                 ("someday.org" :level . 2))))

#+END_EXAMPLE

here you can  refile to any level 1 headings in the first two files, and any level 2 headings (but not level 1 headings) in the third file.

** mobile org
   :PROPERTIES:
   :ID:       26b682c8-967d-40f4-8c62-ad21a471cc7e
   :END:
*** setup
    :PROPERTIES:
    :ID:       63e95bdd-5886-44ff-8ef9-d65aaf602efc
    :END:
#+begin_src emacs-lisp :results none
;;For agenda files locations, each location you add within " "
(require 'org-mobile)
(setq org-mobile-directory "~/Dropbox/MobileOrg/")
;; Set to the name of the file where new captures will be stored after pulling from mobile
(setq org-mobile-inbox-for-pull "~/org/files/from-mobile.org")

#+end_src

*** auto sync
    :PROPERTIES:
    :ID:       1f2bea28-63e3-487e-89b8-fd75d180f61f
    :END:
**** (old, keep around since thid DOES work)
     :PROPERTIES:
     :ID:       2f3aab4a-b90f-40cb-84c5-df33f782f40e
     :END:
#+BEGIN_SRC emacs-lisp :results none
  ;; (defvar org-mobile-push-timer nil
  ;;   "Timer that `org-mobile-push-timer' used to reschedule itself, or nil.")

  ;; (defun org-mobile-push-with-delay (secs)
  ;;   (when org-mobile-push-timer
  ;;     (cancel-timer org-mobile-push-timer))
  ;;   (setq org-mobile-push-timer
  ;;         (run-with-idle-timer
  ;;          (* 1 secs) nil 'org-mobile-push)))

  ;; (add-hook 'after-save-hook 
  ;;  (lambda () 
  ;;    (when (eq major-mode 'org-mode)
  ;;      (dolist (file (org-mobile-files-alist))
  ;;       (if (string= (file-truename (expand-file-name (car file)))
  ;;                    (file-truename (buffer-file-name)))
  ;;            (org-mobile-push-with-delay 30)))
  ;;    )))

  ;; (run-at-time "00:05" 86400 '(lambda () (org-mobile-push-with-delay 1))) ;; refreshes agenda file each day

#+END_SRC

**** auto push
     :PROPERTIES:
     :ID:       9c738fd5-0239-4f25-a3cb-f7a8faf21655
     :END:
#+BEGIN_SRC emacs-lisp :results none
  ;; ;; Fork the work (async) of pushing to mobile
  ;; ;; https://gist.github.com/3111823 ASYNC org mobile push...
  ;; (require 'gnus-async) 
  ;; ;; Define a timer variable
  ;; (defvar org-mobile-push-timer nil
  ;;   "Timer that `org-mobile-push-timer' used to reschedule itself, or nil.")
  ;; ;; Push to mobile when the idle timer runs out
  ;; (defun org-mobile-push-with-delay (secs)
  ;;    (when org-mobile-push-timer
  ;;     (cancel-timer org-mobile-push-timer))
  ;;   (setq org-mobile-push-timer
  ;;         (run-with-idle-timer
  ;;          (* 1 secs) nil 'org-mobile-push)))
  ;; ;; After saving files, start an idle timer after which we are going to push 
  ;; (add-hook 'after-save-hook 
  ;;  (lambda () 
  ;;    (if (or (eq major-mode 'org-mode) (eq major-mode 'org-agenda-mode))
  ;;      (dolist (file (org-mobile-files-alist))
  ;;        (if (string= (expand-file-name (car file)) (buffer-file-name))
  ;;            (org-mobile-push-with-delay 10)))
  ;;      )))
  ;; ;; Run after midnight each day (or each morning upon wakeup?).
  ;; (run-at-time "00:01" 86400 '(lambda () (org-mobile-push-with-delay 1)))
  ;; ;; Run 1 minute after launch, and once a day after that.
  ;; (run-at-time "1 min" 86400 '(lambda () (org-mobile-push-with-delay 1)))
#+END_SRC
**** auto pull
     :PROPERTIES:
     :ID:       5c987dcc-da83-4723-985a-e24f13d12b22
     :END:
#+BEGIN_SRC emacs-lisp :results none
  ;; ;; watch mobileorg.org for changes, and then call org-mobile-pull
  ;; ;; http://stackoverflow.com/questions/3456782/emacs-lisp-how-to-monitor-changes-of-a-file-directory
  ;; (defun install-monitor (file secs)
  ;;   (run-with-timer
  ;;    0 secs
  ;;    (lambda (f p)
  ;;      (unless (< p (second (time-since (elt (file-attributes f) 5))))
  ;;        (org-mobile-pull)))
  ;;    file secs))
  ;; (defvar monitor-timer (install-monitor (concat org-mobile-directory "/mobileorg.org") 30)
  ;;   "Check if file changed every 30 s.")
#+END_SRC

** Capture
   :PROPERTIES:
   :ID:       c32b52c3-22c3-4f4e-b64d-67439e118517
   :END:
*** load org-protocl and org-capture
    :PROPERTIES:
    :ID:       49000e9f-e53c-4e16-8780-d66edaa0d87d
    :END:
#+BEGIN_SRC emacs-lisp :results none
(require 'org-protocol)
(require 'org-capture)
#+END_SRC
*** make org take up 1 frame
    :PROPERTIES:
    :ID:       14e63bf0-0966-4074-98af-bdce51a5f2d4
    :END:
#+BEGIN_SRC emacs-lisp :results none
  ;; (defadvice org-capture (around bp/org-capture--around)
  ;;   (flet ((switch-to-buffer-other-window (buf) (switch-to-buffer buf)))
  ;;     ad-do-it))
  ;; (ad-activate 'org-capture)

#+END_SRC

#+BEGIN_SRC emacs-lisp :results none

  ;; (defadvice org-capture
  ;;     (after make-full-window-frame activate)
  ;;   "Advise capture to be the only window when used as a popup"
  ;;   (if (equal "emacs-capture" (frame-parameter nil 'name))
  ;;       (delete-other-windows)))

  ;; (defadvice org-capture-finalize
  ;;     (after delete-capture-frame activate)
  ;;   "Advise capture-finalize to close the frame"
  ;;   (if (equal "emacs-capture" (frame-parameter nil 'name))
  ;;       (delete-frame)))
#+END_SRC

*** make C-c x close and save frame
    :PROPERTIES:
    :ID:       60a2f9fe-5e99-47a7-8546-1f3d40c70376
    :END:
#+BEGIN_SRC emacs-lisp :results none
  (defun my-capture-finalize ()
    (interactive)
    (org-capture-finalize)
    (delete-frame))

  (add-hook 'org-capture-mode-hook
            (lambda ()
              (define-key org-capture-mode-map "\C-c\C-x" (function my-capture-finalize))))
  ((lambda nil (define-key org-capture-mode-map "" (function my-capture-finalize))))
#+END_SRC
*** TODO add date after capture finishes in property drawer

need to find a way to add to current capture template 
#+BEGIN_SRC emacs-lisp  :results none
  (defun add-property-with-date-captured ()
    "Add DATE_CAPTURED property to the current item."
    (interactive)
    (org-set-property "DATE_CAPTURED" (format-time-string "%F")))

  (add-hook 'org-capture-before-finalize-hook 'add-property-with-date-captured)

#+END_SRC
** `Custom Capture templates`
    :PROPERTIES:
    :ID:       2bf19d27-a0af-4e4c-91f1-9723a2dedf18
    :END:
$Note$-the dispatcher line has to be always at the end of each dispatcher block 
also the order the captures appear is reverse since it add them sequentially 
*** start with clean slate
    :PROPERTIES:
    :ID:       5d6e9038-1cc6-47bd-8ff8-5ed1f91ba5b4
    :END:
#+BEGIN_SRC emacs-lisp  :results none
  (setq org-capture-templates nil)
  (setq org-capture-templates-contexts nil)
#+END_SRC
*** OLD
    :PROPERTIES:
    :ID:       c3f44f6b-4622-4289-a5ef-832d16282c24
    :END:

#+BEGIN_SRC emacs-lisp :results none

  ;;     ;;;; journaling

  ;;     ("j" "journal" entry (file+datetree+prompt "/home/zeltak/org/files/agenda/Research.org" "Lab-book")
  ;;        "* %(format-time-string \"%H:%M\") %^{Entry} %^G\n%i%?")
 
  ;;    -------------------------------

  ;;     ;; ("c" "Contacts" entry (file "/home/zeltak/org/files/PIM/contacts.org")
  ;;     ;;                "* %(org-contacts-template-name)
  ;;     ;; :PROPERTIES:
  ;;     ;; :EMAIL: %(org-contacts-template-email)
  ;;     ;; :END:")

  ;;     ;;;;---------------------------------------------------------------------------
  ;;     ;;;; elfeed 
  ;;   ;;  ("s" "Elfeed" entry (file+headline "TODO.org" "Web")
  ;;   ;;     "*  %:description
  ;;   ;;      %t
  ;;   ;;   \nLink: %a\n\n"  :immediate-finish t)




  ;;     ;;;;;---------------------------------------------------------------------------

  ;;     ("G" "Generic-ask which file" entry (file+headline (expand-file-name (read-string "Name of file: ")) "Generic")
  ;;                      "|%f| %U|%A|" :prepend t)

  ;;   ;; 
  ;;          )))
 #+END_SRC

*** Misc (z)
    :PROPERTIES:
    :ID:       a38ebf42-0b66-4e10-9552-97162f305047
    :END:
#+BEGIN_SRC emacs-lisp  :results none
    (add-to-list 'org-capture-templates
                       '("kk" "bookmark"
                         entry
                         (file+headline "/home/zeltak/org/files/web/wbookmarks.org" "bookmarks")
                  "* %(org-cliplink-capture)  %?\nEntered on %U\n"
                             ))



  ;;; for this https://github.com/igorepst/org-docs-public/blob/master/org-capture-settings.org
  ;;   (add-to-list 'org-capture-templates
  ;;                      '("kw" "Weblink" 
  ;;                  entry 
  ;;                 (file (expand-file-name "/home/zeltak/org/files/web/wbookmarks.org" "bookmarks"))
  ;;                  "* %c\n  :PROPERTIES:\n  :CREATED: %U\n  :END:\n  - Quote:\n    %i" :unnarrowed
  ;; ))



    ;; dispatcher for bgu
  (add-to-list 'org-capture-templates '("z" "Misc"))

#+END_SRC


*** email tasks (l)
    :PROPERTIES:
    :ID:       c4f4187f-5a92-46a5-84a0-d98a1121ab36
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-capture-templates
                   '("le" "Email Todo"
                    entry
                    (file+headline "~/org/files/agenda/bgu.org" "TD")
                    "* TODO Read Message%? (%:fromname about %:subject)\nAdded:%U\n%a\nDEADLINE: %^t"
                         ))

(add-to-list 'org-capture-templates
                   '("ll" "Etodo" 
                   entry 
                   (file+headline "~/org/files/agenda/bgu.org" "TDEN")
                    "* TODO [#A] %?\nSCHEDULED: %(org-insert-time-stamp (org-read-date nil t \"+0d\"))\n%a\n"
                     ))


;; dispatcher for bgu
(add-to-list 'org-capture-templates '("l" "email"))

#+END_SRC
*** calendar tasks (w)
    :PROPERTIES:
    :ID:       9d3425b8-bbbd-4a95-9e09-e47b05e0af30
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-capture-templates
                   '("m" "meetings"
                     entry
                     (file+headline "~/org/files/agenda/meetings.org" "2016")
                       "* %?\n%^T"
                         ))

(add-to-list 'org-capture-templates
                   '("wn" "Recurring Meetings"
                     entry
                     (file+headline "~/org/files/agenda/meetings.org" "Recurring")
                       "* %?\n%^T"
                         ))




;; dispatcher for bgu
(add-to-list 'org-capture-templates '("w" "Meetings"))

#+END_SRC




*** Tech tasks (e)
    :PROPERTIES:
    :ID:       727d7e4f-f1d7-465f-b7a4-22df781a1114
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-capture-templates
                   '("ex" "tech"
                     entry
                     (file+headline "~/org/files/agenda/TODO.org" "TODO")
                      "* TODO  %?\n%^T"   
                         ))



;; dispatcher for bgu
(add-to-list 'org-capture-templates '("e" "Tech"))

#+END_SRC
*** papers (p)
    :PROPERTIES:
    :ID:       450b69ce-bb18-488c-ba57-ad52735e2ce1
    :END:
#+BEGIN_SRC emacs-lisp  :results none
;; Inbox working paper

(add-to-list 'org-capture-templates
                   '("pp" "new working paper"
                     entry
                     (file+headline "/home/zeltak/org/files/Uni/papers/paper.meta.org" "Zeltak working papers")
                     "* working %^{title}     
        :PROPERTIES:
        :ID: %(org-id-uuid)
        :lead: %^{lead?}
        :END:
    "          
                       ))

(add-to-list 'org-capture-templates
                   '("pa" "new abstract"
                     entry
                     (file+headline "/home/zeltak/org/files/Uni/papers/paper.meta.org" "abstracts")
                     "* working %^{title}     
        :PROPERTIES:
        :ID: %(org-id-uuid)
        :lead: %^{lead?}
        :END:
    "          
                       ))

;; dispatcher for bgu
(add-to-list 'org-capture-templates '("p" "papers"))

#+END_SRC
*** food (f)
    :PROPERTIES:
    :ID:       d88d396a-2f85-4dd2-bfb6-f2904e6f7618
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-capture-templates
                   '("ff" "Food"
                     entry
                     (file+headline "/home/zeltak/org/files/agenda/food.org" "Inbox")
      "* COOK %^{Recipe Name} %^g     
      :PROPERTIES:
      :ID: %(org-id-uuid)
      :Time: %^{minutes|-|10|15|30|60}
      :Rating: %^{rating?|-|1|2|3|4|5}
      :Source: %^{Source?}
      :Cuisine: %^{Cuisine?|-|Indian|Thai|Vietnamese|Asian|Chinese|Israeli|Italian|American|EastEuro|Mexican|French|Persian|Austrian}
      :Type: %^{Type?|-|ain|side|starter|sweets|drinks|sauce|breakfast}
      :Serves: %^{Type?|-|1|2|4|6|8}
      :Fav: %^{}
      :END:
  %^{prompt|*** Ingredients}
  %?
  %^{prompt|*** Preparation}
  "
  "Capture Template for food recipe"
                         ))




  (add-to-list 'org-capture-templates
                     '("fl" "food link"
                       entry
                     (file+headline "/home/zeltak/org/files/agenda/food.org" "Inbox")
                "* COOK  %(org-cliplink-capture)  %?\nEntered on %U\n"
                           ))


(add-to-list 'org-capture-templates
                   '("fs" "shopping"
                     entry
                     (file+headline "/home/zeltak/org/files/agenda/food.org" "shopping")
                      "* SHOP %^{Description} "
                         ))



;; dispatcher for bgu
(add-to-list 'org-capture-templates '("f" "food"))
#+END_SRC
*** travel (u)
    :PROPERTIES:
    :ID:       76e5e82d-3999-4828-9516-20caa06e6640
    :END:
 #+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-capture-templates
'("uu" "Inbox resturant"
entry
(file+headline "/home/zeltak/org/files/agenda/travel.org" "Inbox")
"* %^{Description}   
:PROPERTIES:
:ID: %(org-id-uuid)
:Rating: %^{rating?|-|1|2|3|4|5}
:price: %^{price in local currancy?|-|0-10|10-20|20-30|30-50|50+}
:Source: %^{Source?}
:Type: %^{Type?|meal|breakfeast|dessert|street}
:Cuisine: %^{Cuisine?|-|Indian|Thai|Vietnamese|Asian|Chinese|Israeli|Italian|American|EastEuro|Mexican|French|Persian|Austrian|Jewish|Japan}
:Fav: %^{Fav|yes|no}
:END:
%?
"
))


(add-to-list 'org-capture-templates
'("un" "Add NYC resturant"
entry
(file+headline "/home/zeltak/org/files/agenda/travel.org" "NYC")
"* TOVISIT %^{Description}   
%u
:PROPERTIES:
:ID: %(org-id-uuid)
:Rating: %^{rating?|-|1|2|3|4|5}
:price: %^{price in local currancy?|-|0-10|10-20|20-30|30-50|50+}
:Source: %^{Source?}
:Type: %^{Type?|meal|breakfeast|dessert|street}
:Cuisine: %^{Cuisine?|-|Indian|Thai|Vietnamese|Asian|Chinese|Israeli|Italian|American|EastEuro|Mexican|French|Persian|Austrian|Jewish|Japan}
:Fav: %^{Fav|-|yes|no}
:END:
%?
"
))


(add-to-list 'org-capture-templates
'("uN" "review NYC resturant"
entry
(file+headline "/home/zeltak/org/files/agenda/travel.org" "NYC")
"* VISITED %^{Description}   
:PROPERTIES:
:ID: %(org-id-uuid)
:Rating: %^{rating?|-|1|2|3|4|5}
:price: %^{price in local currancy?|-|0-10|10-20|20-30|30-50|50+}
:Source: %^{Source?}
:Type: %^{Type?|meal|breakfeast|dessert|street}
:Cuisine: %^{Cuisine?|-|Indian|Thai|Vietnamese|Asian|Chinese|Israeli|Italian|American|EastEuro|Mexican|French|Persian|Austrian|Jewish|Japan}
:Fav: %^{Fav|-|yes|no}
:END:

%^{prompt|** My Review}
%?
"
))




;; dispatcher for bgu
(add-to-list 'org-capture-templates '("u" "travel"))
#+END_SRC
*** bookmarks (k)
    :PROPERTIES:
    :ID:       e7fe78ea-5899-42cb-a148-7ab17cf8da4e
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-capture-templates
                   '("kk" "bookmark"
                     entry
                     (file+headline "/home/zeltak/org/files/web/wbookmarks.org" "bookmarks")
              "* %(org-cliplink-capture)  %?\nEntered on %U\n"
                         ))

(add-to-list 'org-capture-templates
                   '("kl" "bookmark-url"
                     entry
                     (file+headline "/home/zeltak/org/files/web/wbookmarks.org" "bookmarks")
              "* %x  %?\nEntered on %U\n"
                         ))


(add-to-list 'org-capture-templates
                   '("kw" "website"
                     entry
                     (file+headline "/home/zeltak/org/files/agenda/TODO.org" "Web")
                     "* %c :website:\n%U %?%:initial"
                         ))
;; dispatcher for bgu
(add-to-list 'org-capture-templates '("k" "bookmarks"))

#+END_SRC


;; dispatcher for bgu
(add-to-list 'org-capture-templates '("e" "Tech"))

#+END_SRC


*** Home tasks (h)
    :PROPERTIES:
    :ID:       cb8fb4c0-76a3-4797-aba6-d914427fbe03
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-capture-templates
                   '("hh" "home"
                     entry
                     (file+headline "~/org/files/agenda/home.org" "HomeTD")
                      "* TODO   %?  :@home:  \n%^T"   
                         ))



;; dispatcher for bgu
(add-to-list 'org-capture-templates '("h" "Home"))

#+END_SRC
*** media tasks (d)
    :PROPERTIES:
    :ID:       2595f6f6-7cbb-4829-858b-478567c1b349
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-capture-templates
                   '("dm" "dl_movies"
                     entry
                     (file+headline "~/org/files/agenda/dl.org" "Movies")
                       "* DOWN  :@pc:  %^{Description}  "  
                         ))

(add-to-list 'org-capture-templates
                   '("dp" "dl_movies_prerelease"
                     entry
                     (file+headline "~/org/files/agenda/dl.org" "Movies-Pre release")
                       "* DOWN  :@pc: %^{Description} :Pre_Release:  "  
                         ))

(add-to-list 'org-capture-templates
                   '("dt" "dl_TV"
                     entry
                     (file+headline "~/org/files/agenda/dl.org" "TV")
                       "* DOWN  :@pc:  %^{Description}  "  
                         ))

(add-to-list 'org-capture-templates
                   '("ds" "dl_music"
                     entry
                     (file+headline "~/org/files/agenda/dl.org" "Music")
                       "* DOWN  :@pc: %^{Description}  "  
                         ))

(add-to-list 'org-capture-templates
                   '("da" "dl_music_prerlease"
                     entry
                     (file+headline "~/org/files/agenda/dl.org" "Music-Pre Release")
                       "* DOWN  :@pc:  %^{Description} :Pre_Release: "  
                         ))

(add-to-list 'org-capture-templates
                   '("dc" "dl_comics"
                     entry
                     (file+headline "~/org/files/agenda/dl.org" "Comics")
                       "* DOWN  :@pc:  %(org-cliplink-capture)  "  
                         ))


;; dispatcher for bgu
(add-to-list 'org-capture-templates '("d" "Media"))

#+END_SRC
*** collaborator tasks (assign to other collaborators) (c)
    :PROPERTIES:
    :ID:       b280e2e5-e15f-405d-bd50-963d92a6723d
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-capture-templates
                   '("ca" "allan"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "INBOX")
                      "* TASK  %?  :allan:@work:\n%^T"   
                         ))

(add-to-list 'org-capture-templates
                   '("cm" "massmio"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "INBOX")
                      "* TASK  %?  :massimo:@work:\n%^T"   
                         ))


(add-to-list 'org-capture-templates
                   '("cj" "joel"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "INBOX")
                      "* TASK  %?  :joel:@work:\n%^T"   
                         ))


(add-to-list 'org-capture-templates
                   '("cb" "boris"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "INBOX")
                      "* TASK  %?  :boris:@work:\n%^T"   
                         ))



(add-to-list 'org-capture-templates
      
             '("cm" "michael"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "INBOX")
                      "* TASK  %?  :michal:@work:\n%^T"   
                         ))



(add-to-list 'org-capture-templates
                   '("ct" "tal"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "INBOX")
                      "* TASK  %?  :tal:@work:\n%^T"   
                         ))



(add-to-list 'org-capture-templates
                   '("cd" "david"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "INBOX")
                      "* TASK  %?  :david:@work:\n%^T"   
                         ))



(add-to-list 'org-capture-templates
                   '("co" "bob"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "INBOX")
                      "* TASK  %?  :bob:@work:\n%^T"   
                         ))



(add-to-list 'org-capture-templates
                   '("cn" "johanna"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "INBOX")
                      "* TASK  %?  :johanna:@work:\n%^T"   
                         ))





;; dispatcher for bgu
(add-to-list 'org-capture-templates '("c" "Collaborator-tasks"))

#+END_SRC

*** student tasks (assign to other people) (s)
    :PROPERTIES:
    :ID:       045021da-1412-4e0e-9742-d00413836eae
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-capture-templates
                   '("sa" "adar"
                    entry
                    (file+headline "~/org/files/agenda/research.org" "INBOX")
                    "* TASK  %?  :adar:@work:\n%^T"   
                    ))

(add-to-list 'org-capture-templates
                   '("sm" "meytar"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "Misc")
                      "* TASK  %?  :meytar:@work:\n%^T"   
                         ))

(add-to-list 'org-capture-templates
                   '("sy" "maayan"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "Misc")
                      "* TASK  %?  :maayan:@work:\n%^T"   
                         ))

(add-to-list 'org-capture-templates
                   '("sx" "alex"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "Misc")
                      "* TASK  %?  :alex:@work:\n%^T"   
                         ))

(add-to-list 'org-capture-templates
                   '("so" "omer"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "Misc")
                      "* TASK  %?  :omer:@work:\n%^T"   
                         ))

(add-to-list 'org-capture-templates
                   '("sl" "lara"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "Misc")
                      "* TASK  %?  :lara:@work:\n%^T"   
                         ))

(add-to-list 'org-capture-templates
                   '("sd" "adi"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "Misc")
                      "* TASK  %?  :adi:@work:\n%^T"   
                         ))

(add-to-list 'org-capture-templates
                   '("sh" "helena"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "Misc")
                      "* TASK  %?  :helena:@work:\n%^T"   
                         ))



;; dispatcher for bgu
(add-to-list 'org-capture-templates '("s" "students-tasks"))
#+END_SRC

*** BGU (b)
    :PROPERTIES:
    :ID:       5086e296-66d5-4965-97dc-c698d95b7580
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-capture-templates
                   '("bx" "refile below"
                    entry
                   (function z/org-move-point-to-capture)
                   "* TODO %?"
                   ))

(add-to-list 'org-capture-templates
                   '("br" "Research_TD"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "scheduled mail/calls/meetings")
                      "* TODO  %?:@work: \n%^T"   
                     ))

(add-to-list 'org-capture-templates
                   '("bb" "BGU_TD"
                     entry
                     (file+headline "~/org/files/agenda/bgu.org" "TDEN")
                      "* TODO  %? :@work:\n%^T"   
                     ))
(add-to-list 'org-capture-templates
                   '("bm" "respond"
                     entry
                     (file+headline "~/org/files/agenda/research.org" "Mails")
                      "* TODO  %? :@work: \n%^T"   
                     ))



;; dispatcher for bgu
(add-to-list 'org-capture-templates '("b" "BGU-work"))

#+END_SRC

** Babel
   :PROPERTIES:
   :ID:       180c370b-efb2-427d-b5d0-e710f889a431
   :END:
*** languages
    :PROPERTIES:
    :ID:       a3909978-76fe-4008-90e3-140e04e22a56
    :END:
#+BEGIN_SRC emacs-lisp :results none
(org-babel-do-load-languages
 'org-babel-load-languages
 '((emacs-lisp . t)
   (python . t)
   (shell . t)
   (calc . t)
   (matlab . t)
   (sqlite . t)
   (ruby . t)
   (perl . t)
   (org . t)
   (ledger . t)        
   (dot . t)
   (gnuplot . t)
   (octave .t)
   (plantuml . t)
   (R . t)
   ))
#+END_SRC
    
*** enable prompt-free code running
    :PROPERTIES:
    :ID:       78956a2e-211e-4e4b-a397-37d8196a9c6d
    :END:
#+BEGIN_SRC emacs-lisp :results none
;; enable prompt-free code running
(setq org-confirm-babel-evaluate nil        ;; for running code blocks
      org-confirm-elisp-link-function nil   ;; for elisp links
      org-confirm-shell-link-function nil)  ;; for shell links 
#+END_SRC
*** done eval when exporting code
    :PROPERTIES:
    :ID:       63e05489-2bf9-4948-897c-0b16ff324b2c
    :END:
#+BEGIN_SRC emacs-lisp :results none
(setq org-export-babel-evaluate nil)
#+END_SRC
*** Fonts
    :PROPERTIES:
    :ID:       165406d7-9b8e-4571-b6bd-4fead5401eae
    :END:
#+BEGIN_SRC emacs-lisp :results none
;; fontify code in code blocks
(setq org-src-fontify-natively t)
#+END_SRC
*** don't indent source code
#+BEGIN_SRC emacs-lisp  :results none
;; don't indent source code
org-edit-src-content-indentation 0
;; don't adapt indentation
org-adapt-indentation nil
;; preserve the indentation inside of source blocks
org-src-preserve-indentation t
#+END_SRC
*** how org-src windows are set up when hitting C-c ' 
#+BEGIN_SRC emacs-lisp  :results none
;; how org-src windows are set up when hitting C-c '
org-src-window-setup 'current-window
#+END_SRC
** font locks
   :PROPERTIES:
   :ID:       b92e34e1-04fb-49e9-a4a4-65ea15dfff50
   :END:
 

#+BEGIN_SRC emacs-lisp :results none
;@Warning@ @
(font-lock-add-keywords
 'org-mode
'(("\\(@[^@\n]+@\\)" (0 '(:foreground "#B40000" :background "#FFDDDD" :weight bold) t))))

;tip
(font-lock-add-keywords
 'org-mode
'(("\\(%[^%\n]+%\\)" (0 '(:weight ultra-bold :background "#DDFFDD" :foreground "#000000") t))))

;notice
(font-lock-add-keywords
 'org-mode
'(("\\(![^!\n]+!\\)" (0 '(:weight ultra-bold :foreground "#B40000") t))))

;high-green
(font-lock-add-keywords
 'org-mode
'(("\\('[^'\n]+'\\)" (0 '(:background "#35FF00" :weight ultra-bold) t))))

;high-yellow
(font-lock-add-keywords
 'org-mode
'(("\\(`[^`\n]+`\\)" (0 '(:foreground "#000000" :weight ultra-bold :background "#FBFF00") t))))

;
(font-lock-add-keywords
 'org-mode
'(("\\(₆[^₆\n]+₆\\)" (0 '(:foreground "#000000" :underline t :background "#FF9AEA" :weight ultra-bold) t))))

;
(font-lock-add-keywords
 'org-mode
'(("\\(₅[^₅\n]+₅\\)" (0 '(:weight ultra-bold :foreground "#1E00DE") t))))


;
(font-lock-add-keywords
 'org-mode
'(("\\(₄[^₄\n]+₄\\)" (0 '(:weight ultra-bold :foreground "#FF9800") t))))

;blusish
(font-lock-add-keywords
 'org-mode
'(("\\(•[^•\n]•+\\)" (0 '(:weight ultra-bold :foreground "#393D900") t))))


 
;;;;SPECIFIC WORDS 

;server
(font-lock-add-keywords
'org-mode
'(("\\b[Ss]erver\\b" (0 '(:weight ultra-bold :foreground "#FF9800") t))))

;client
(font-lock-add-keywords
'org-mode
'(("\\b[Cc]lient\\b" (0 '(:weight ultra-bold :foreground "#0044FF") t))))

;private
(font-lock-add-keywords
'org-mode
'(("\\b[Pp]rivate\\b" (0 '(:weight ultra-bold :foreground "#FF6767") t))))

;public
(font-lock-add-keywords
'org-mode
'(("\\b[Pp]ublic\\b" (0 '(:weight ultra-bold :foreground "#59BD7E") t))))


;In Example
(font-lock-add-keywords
'org-mode
'(("\\b[Ii]n example\\b" (0 '(:foreground "#000000" :underline t :background "#FF9AEA" :weight ultra-bold) t))))


;header
(font-lock-add-keywords
 'org-mode
'(("\\(‡[^‡\n]+‡\\)" (0 '(:foreground "#ffffff" :weight ultra-bold :slant italic :background "#59BD7F" :height 1.3) t))))

;;;FOR SPECIAL CHARACTERS

;for key shortucts
(font-lock-add-keywords
 'org-mode
'(("\\(\\?[^?\n]+\\?\\)" (0 '(:foreground "#000000" :weight ultra-bold :background "#FF9C2C") t))))

;for $Note$ 
(font-lock-add-keywords
 'org-mode
'(("\\(\\$[^$\n]+\\$\\)" (0 '(:background "#DDDDFF" :foreground "#000000" :weight ultra-bold) t))))

;for ^
(font-lock-add-keywords
 'org-mode
'(("\\(\\^[^^\n]+\\^\\)" (0 '(:weight bold  :box (:line-width 1 :color "#A5A0FF")  :foreground "#00006F" :background "#FFFFFF") t))))

;for † 
(font-lock-add-keywords
 'org-mode
'(("\\(\\†[^†\n]+\\†\\)" (0 '(:weight bold  :box (:line-width 1 :color "#A5A0FF")  :foreground "#00006F" :background "#FFFFFF") t))))

#+END_SRC

The following characters are special : . * + ? ^ $ \ [

more characters :
http://en.wikipedia.org/wiki/List_of_Unicode_characters
#+BEGIN_EXAMPLE
†•‖‣․‥ 	… ⁅⁆	⁑⁒⁓⁔⁕⁖⁗⁘⁙⁚⁛⁜⁝₀ 	₁₂₃₄	₅₆₇₈₉ ₊ ₋ ₌
#+END_EXAMPLE

** look and feel
   :PROPERTIES:
   :ID:       7bde7c04-91b1-4c68-8de3-0516c914f02f
   :END:
*** allow font lock
    :PROPERTIES:
    :ID:       b7deec19-0c6b-4253-afec-543699a86f2a
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(setq org-src-fontify-natively t);; syntax highlighting the source code
#+END_SRC
you can no longer color the backgrounds and get fontification. You can choose one or the other. I decided I'd rather have the backgrounds:
(setq org-src-fontify-natively nil)
and then you can set the org-block, org-block-begin-line, org-block-end-line faces. I use a color scheme similar to the one you linked to, but I made mine a little less bold:
org-block: foreground #00007f background #f8f8eb height 0.9
org-block-begin-line, org-block-end-line: foreground #545454 background #e0dfd1

*** Changing the org-mode ellipsis
    :PROPERTIES:
    :ID:       f74a402c-7493-4586-a0bd-88d6caae29ba
    :END:
#+BEGIN_SRC emacs-lisp :results none
;(setq org-ellipsis "⤵")
(setq org-ellipsis "⚡")
#+END_SRC
Other interesting characters are ↴, ⬎, ⤷, and ⋱.

** Export/publishing
   :PROPERTIES:
   :ID:       59a1f475-63ea-4f72-852a-7986efb419d6
   :END:
*** export in background
    :PROPERTIES:
    :ID:       7d2fb8ff-43a1-4bce-98a9-686c95ebb460
    :END:
@this casues org-reveal to spit an error@
#+BEGIN_SRC emacs-lisp :results none
;(setq org-export-in-background t)
#+END_SRC
*** extra exporters; ODT, beamer etc  exporters
    :PROPERTIES:
    :ID:       f7fb5dd4-8ca0-4840-85c1-749cfc71c1cd
    :END:
**** add (require) specific models. 
     :PROPERTIES:
     :ID:       8512751e-96fc-441a-a10d-369e5d556ffb
     :END:
#+BEGIN_SRC emacs-lisp :results none
(require 'ox-odt)
(require 'ox-beamer)
(require 'ox-latex)

#+END_SRC
**** odt defaule export format 
     :PROPERTIES:
     :ID:       4b1aa3b9-b14e-4af3-a444-169f2fd3bae5
     :END:
#+BEGIN_SRC emacs-lisp  :results none
;; org v8 bundled with Emacs 24.4
(setq org-odt-preferred-output-format "docx")
;; BTW, you can assign "pdf" in above variables if you prefer PDF format

#+END_SRC
**** koma
     :PROPERTIES:
     :ID:       ed121447-07c9-459b-bf3b-4fd60b606392
     :END:
http://orgmode.org/worg/exporters/koma-letter-export.html
***** load koma
      :PROPERTIES:
      :ID:       2ae71066-2db8-4380-bf4f-457b9ccf3f7a
      :END:

#+BEGIN_SRC emacs-lisp :results none
(eval-after-load 'ox '(require 'ox-koma-letter))

(eval-after-load 'ox-latex
  '(add-to-list 'org-latex-packages-alist '("AUTO" "babel" t) t))

#+END_SRC
***** define letter-class-definition
      :PROPERTIES:
      :ID:       b8844bf5-ee60-43bd-a742-509444769dc0
      :END:
#+BEGIN_SRC emacs-lisp :results none
(add-to-list 'org-latex-classes
             '("my-letter"
               "\\documentclass\{scrlttr2\}
\\usepackage[english]{babel}
\[NO-DEFAULT-PACKAGES]
\[NO-PACKAGES]
\[EXTRA]"))
#+END_SRC
*** visual option 
    :PROPERTIES:
    :ID:       7d7b82cf-21cc-48c8-9c4f-c7f03fbb7e24
    :END:
**** remove the “Validate XHTML 1.0” message from HTML export
     :PROPERTIES:
     :ID:       a73a28bd-4cfb-43d0-b042-691d550bf5bc
     :END:
#+BEGIN_SRC emacs-lisp :results none
(setq org-export-html-validation-link nil)
#+END_SRC
**** disregard _ as subscript
     :PROPERTIES:
     :ID:       7367e858-5627-49ee-ae8b-814f98070319
     :END:
#+BEGIN_SRC emacs-lisp :results none
org-use-sub-superscripts nil        ;; don't use `_' for subscript
#+END_SRC
    
** `Custom Publishing` 
*** start with clean slate
#+BEGIN_SRC emacs-lisp  :results none
(setq org-publish-project-alist nil)
#+END_SRC
*** BGUC004.GIS.Planners 
    :PROPERTIES:
    :ID:       cd022ed5-57c1-445d-bf86-1c47444c92a2
    :END:
**** define BGUC004.GIS.Planners groups 
 #+BEGIN_SRC emacs-lisp  :results none
 (add-to-list 'org-publish-project-alist
                    '("BGUC004.GIS.Planners"
                     :components ("BGUC004.GIS.Planners.html" "BGUC004.GIS.Planners.single" "BGUC004.GIS.Planners.hw"))
 )
 #+END_SRC
**** BGUC004.GIS.Planners.html
			  
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-publish-project-alist
                   '("BGUC004.GIS.Planners.html"
              :base-directory "/home/zeltak/org/files/Uni/Courses/BGUC004.GIS.Planners/"
              :base-extension "org"
              :publishing-directory "/home/zeltak/org/files/Uni/Courses/BGUC004.GIS.Planners/src.html"
              :publishing-function z/org-reveal-publish-to-html
              :recursive t
	      :exclude-tags '("note" "noexport")
              )
)
#+END_SRC

**** BGUC004.GIS.Planners.single
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-publish-project-alist
                 '("BGUC004.GIS.Planners.single"
                :base-directory "/home/zeltak/org/files/Uni/Courses/BGUC004.GIS.Planners/"
                :base-extension "org"
                :publishing-directory "/home/zeltak/org/attach/bgu/courses/BGUC004.GIS.Planners/single/"
                :publishing-function z/org-reveal-publish-to-html
                :recursive t
		:exclude-tags '("note" "noexport")             
                :reveal-single-file t)
)
#+END_SRC

**** BGUC004.GIS.Planners.src.hw 
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'org-publish-project-alist
                 '    ("BGUC004.GIS.Planners.src.hw"
                :base-directory "/home/zeltak/org/files/Uni/Courses/BGUC004.GIS.Planners/"
                :base-extension "org"
                :publishing-directory "/home/zeltak/org/attach/bgu/courses/BGUC004.GIS.Planners/hw/"
                :publishing-function z/org-reveal-publish-to-html
                :recursive t
		:exclude-tags '("note" "noexport")
                :reveal-single-file t)
)
#+END_SRC

*** BGUC001.R.Base 
**** define BGUC001.R.Base groups 
  #+BEGIN_SRC emacs-lisp  :results none
  (add-to-list 'org-publish-project-alist
                     '("BGUC001.R.Base"
                      :components ("BGUC001.R.Base.html" "BGUC001.R.Base.single" "BGUC001.R.Base.hw"))
  )
  #+END_SRC
**** BGUC001.R.Base.html 
			  
  #+BEGIN_SRC emacs-lisp  :results none
  (add-to-list 'org-publish-project-alist
                     '("BGUC001.R.Base.html"
		:base-directory "/home/zeltak/org/files/Uni/Courses/BGUC001.R.Base/"
		:base-extension "org"
		:publishing-directory "/home/zeltak/org/files/Uni/Courses/BGUC001.R.Base/src.html"
		:publishing-function z/org-reveal-publish-to-html
		:recursive t
		:exclude-tags '("note" "noexport")
		)
  )
  #+END_SRC

**** BGUC001.R.Base.single
  #+BEGIN_SRC emacs-lisp  :results none
  (add-to-list 'org-publish-project-alist
                   '("BGUC001.R.Base.single"
                  :base-directory "/home/zeltak/org/files/Uni/Courses/BGUC001.R.Base/"
                  :base-extension "org"
                  :publishing-directory "/home/zeltak/org/attach/bgu/courses/BGUC001.R.Base/single/"
                  :publishing-function z/org-reveal-publish-to-html
                  :recursive t
		  :exclude-tags '("note" "noexport")             
                  :reveal-single-file t)
  )
  #+END_SRC

**** BGUC001.R.Base.hw 
  #+BEGIN_SRC emacs-lisp  :results none
  (add-to-list 'org-publish-project-alist
                   '    ("BGUC001.R.Base.hw"
                  :base-directory "/home/zeltak/org/files/Uni/Courses/BGUC001.R.Base/"
                  :base-extension "org"
                  :publishing-directory "/home/zeltak/org/attach/bgu/courses/BGUC001.R.Base/hw/"
                  :publishing-function z/org-reveal-publish-to-html
                  :recursive t
		  :exclude-tags '("note" "noexport" "pres")
                  :reveal-single-file t)
  )
  #+END_SRC


*** misc 
               ("Help_files"
               :base-directory "~/org/files/help/"
               :publishing-directory "~/org/files/export/"
               :section-numbers nil
               :table-of-contents nil
               :publishing-function org-ascii-publish-to-ascii)

               ("econf"
               :base-directory "~/org/files/agenda/"
               :publishing-directory "~/org/files/export/"
               :section-numbers nil
               :table-of-contents nil
               :publishing-function org-html-publish-to-html)


** org attach
   :PROPERTIES:
   :ID:       d7dd53da-bc7d-42c1-b3e6-d649728d09ac
   :END:
#+BEGIN_SRC emacs-lisp :results none
(setq org-attach-directory "/home/zeltak/org/attach/files_2015/")
#+END_SRC
** org functions 
   :PROPERTIES:
   :ID:       77be5dba-33ef-4f3d-9706-18b680022cd3
   :END:
*** org editing
**** bullets-to-spaces
#+BEGIN_SRC emacs-lisp  :results none
(defun z/bullets-to-spaces ()
  "Replace * with a space except in org headers."
  (interactive)
  (save-restriction
    (save-excursion
      (widen)
      (goto-char (point-min))
      (while (re-search-forward "\\*" nil t)
        (unless (org-at-heading-p)
          (replace-match " "))))))
#+END_SRC
**** paste as image link 
#+BEGIN_SRC emacs-lisp  :results none
(defun  z/org-paste-image-link ()
   "paste a image link"
  (interactive)
  (insert "[[")
  (yank)
  (insert "]]")
(org-toggle-inline-images)
(org-toggle-inline-images)
)
#+END_SRC

*** org insert drawer
    :PROPERTIES:
    :ID:       d6f292d7-ab50-4305-ab5e-384ed8548df8
    :END:

#+BEGIN_SRC emacs-lisp :results none
(defun z/org-insert-drawer  ()
                     (interactive)                                
                     (let ((current-prefix-arg '(4)))             
                       (call-interactively #'org-insert-drawer)))
#+END_SRC
*** convert to same level header
    :PROPERTIES:
    :ID:       bc1f2a7d-1d39-4b1a-ac28-676e9f371766
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/org-convert-header-samelevel  ()
                     (interactive)                                
                     (let ((current-prefix-arg '(4)))             
                       (call-interactively #'org-toggle-heading)))

#+END_SRC

*** TODO tangle only code block at point
    :PROPERTIES:
    :ID:       d1d81ab3-ce09-4a79-abde-02a9e2601969
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/org-tangle-atpoint  ()
                     (interactive)                                
                     (let ((current-prefix-arg '(4)))             
                       (call-interactively #'org-babel-tangle)))
#+END_SRC

*** TODO tangle only code at  block 
#+BEGIN_SRC emacs-lisp :results none
(defun z/org-tangle-at-block  ()
                     (interactive)                                
                     (let ((current-prefix-arg '(16)))             
                       (call-interactively #'org-babel-tangle)))
#+END_SRC


*** agenda views
    :PROPERTIES:
    :ID:       1956993f-3e20-4558-a2fa-d5430efa89a8
    :END:
**** org agenda work 
     :PROPERTIES:
     :ID:       52b8d1bb-6903-4938-ac91-08b5d4863008
     :END:

#+BEGIN_SRC emacs-lisp :results none
(defun z/org-agenda-work ()
"open work agenda"
(interactive)                                
(org-agenda nil "w")
)
#+END_SRC

**** org agenda Joel
     :PROPERTIES:
     :ID:       3737d15b-792b-4324-a161-c21ea67702af
     :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/org-agenda-joel ()
"open work agenda"
(interactive)                                
(org-agenda nil "j")
)
#+END_SRC
**** org TODO spares tree
     :PROPERTIES:
     :ID:       4a6be637-848c-4fef-9a17-6fddb277521b
     :END:
add all todo states to sparse tree
#+begin_src emacs-lisp
  (defun z/org-sparse-todo ()
    "all todo sparse"
    (interactive)
    (org-match-sparse-tree t )
)
#+end_src
*** Links
    :PROPERTIES:
    :ID:       e7d7bac4-f9c6-4bc2-99f8-34800d7ddf3c
    :END:
**** link to file
     :PROPERTIES:
     :ID:       eac01508-b05e-441f-9d4c-c31d552f264c
     :END:
 #+BEGIN_SRC emacs-lisp :results none
 (defun z/org-link-file  ()
                      (interactive)                                
                      (let ((current-prefix-arg '(4)))             
			(call-interactively #'org-insert-link)))

 #+END_SRC
**** link/refile to any header
     :PROPERTIES:
     :ID:       c5b4ae5c-e8ca-4988-a823-f3912a1ebbe3
     :END:

Gives helm buffer to select headlines from org-files in the directory I select and when I press f3 (for the third action), it inserts a link to the selected headline. It does the file finding recursively, so big folders can be slow.  to add the org id component to the above script eval this as well

 #+BEGIN_SRC emacs-lisp
 (defun helm-org-insert-id-link-to-heading-at-marker (marker)
   (with-current-buffer (marker-buffer marker)
     (let ((file-name (buffer-file-name))
           (id (save-excursion (goto-char (marker-position marker))
                               (org-id-get-create)
                               (org-id-store-link))))

       (with-helm-current-buffer
         (org-insert-link
          file-name id)))))


 (cl-defun helm-source-org-headings-for-files (filenames
                                               &optional (min-depth 1) (max-depth 8))
   (helm-build-sync-source "Org Headings"
     :candidates (helm-org-get-candidates filenames min-depth max-depth)
     :action '(("Go to line" . helm-org-goto-marker)
               ("Refile to this heading" . helm-org-heading-refile)
               ("Insert link to this heading"
		. helm-org-insert-link-to-heading-at-marker)
               ("Insert id link to this heading" .
		helm-org-insert-id-link-to-heading-at-marker))))

 #+END_SRC

**** paste file:/ link
     :PROPERTIES:
     :ID:       4d7b13eb-8d19-4f26-bc2c-171466455abb
     :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun  z/org-link-paste-file-path ()
   "paste file path in killring"
  (interactive)
  (insert "file:")
  (yank)
  )
#+END_SRC

*** terminal
    :PROPERTIES:
    :ID:       77a6bc6a-709b-4395-b73a-4102bd05536d
    :END:
**** org evaluate to term
     :PROPERTIES:
     :ID:       1306b783-76d7-4c69-b936-44f73f1046bb
     :END:

 #+begin_src emacs-lisp
 (defadvice org-babel-execute:sh (around sacha activate)
   (if (assoc-default :term (ad-get-arg 1) nil)
     (let ((buffer (make-term "babel" "/bin/zsh")))
       (with-current-buffer buffer
	 (insert (org-babel-expand-body:generic
	      body params (org-babel-variable-assignments:sh params)))
	 (term-send-input))
 (pop-to-buffer buffer))
     ad-do-it))
 #+end_src

 #+RESULTS:
 : org-babel-execute:sh

*** editing
    :PROPERTIES:
    :ID:       fb2eea33-632b-40f5-88c1-467a17ce4224
    :END:
**** Insert current time stamp
     :PROPERTIES:
     :ID:       7dbcc90f-6796-4130-93ee-255eeb7fa7b2
     :END:

#+BEGIN_SRC emacs-lisp :results none
(defun org-timestamp-now ()
  "Inserts org timestamp at end of heading"
  (interactive)
  (save-excursion
    (org-back-to-heading)
    (org-end-of-line nil)
    (insert " ")
    (org-insert-time-stamp nil nil t nil nil nil)))
#+END_SRC

**** Insert time stamp selector 
     :PROPERTIES:
     :ID:       16c5e28e-dc2f-437b-90ee-0a25d2fc49b8
     :END:

#+BEGIN_SRC emacs-lisp :results none
(defun org-timestamp-select ()
  "Inserts org timestamp at end of heading"
  (interactive)
  (save-excursion
    (org-back-to-heading)
    (org-end-of-line nil)
    (org-time-stamp-inactive nil)))

#+END_SRC
**** import ods file into org table
     :PROPERTIES:
     :ID:       039da431-55f0-449f-9aac-5356133229da
     :END:
#+BEGIN_SRC emacs-lisp :results none
(defun org-table-import-ods (&optional file-name)
(interactive "fFile: ")
(let ((csv-file (org-odt-convert file-name "csv"))
(pos (point)))
(save-excursion
(insert (with-temp-buffer
(insert-file-contents csv-file)
(org-table-convert-region (point-min) (point-max) '(4))
(buffer-string))))))
#+END_SRC
**** convert lines to checkboxes
     :PROPERTIES:
     :ID:       3d2233e7-6009-4c2b-b14d-bc9ba9f934ae
     :END:
 
#+BEGIN_SRC emacs-lisp :results none
(defun org-set-line-checkbox (arg)
  (interactive "P")
  (let ((n (or arg 1)))
    (when (region-active-p)
      (setq n (count-lines (region-beginning)
                           (region-end)))
      (goto-char (region-beginning)))
    (dotimes (i n)
      (beginning-of-line)
      (insert "- [ ] ")
      (forward-line))
    (beginning-of-line)))
#+END_SRC
    
**** convert lines to headline
     :PROPERTIES:
     :ID:       58d65bbf-6a87-40ec-a816-5aa46dcf86fe
     :END:
 
#+BEGIN_SRC emacs-lisp :results none
(defun org-set-line-headline (arg)
  (interactive "P")
  (let ((n (or arg 1)))
    (when (region-active-p)
      (setq n (count-lines (region-beginning)
                           (region-end)))
      (goto-char (region-beginning)))
    (dotimes (i n)
      (beginning-of-line)
      (insert "** TODO ")
      (forward-line))
    (beginning-of-line)))
#+END_SRC
    
**** read only function
     :PROPERTIES:
     :ID:       5cce186a-f61b-4e72-be71-ed97eead6e8f
     :END:
Make some org-sections read-only

$Note- you !MUST! tag the header :read_only: other wise it wont work$ 

#+BEGIN_SRC emacs-lisp :results none
(defun org-mark-readonly ()
(interactive)
(org-map-entries
(lambda ()
(let* ((element (org-element-at-point))
(begin (org-element-property :begin element))
(end (org-element-property :end element)))
(add-text-properties begin (- end 1) '(read-only t
font-lock-face '(:background "#FFE3E3")))))
"read_only")
(message "Made readonly!"))
(defun org-remove-readonly ()
(interactive)
(org-map-entries
(lambda ()
(let* ((element (org-element-at-point))
(begin (org-element-property :begin element))
(end (org-element-property :end element))
(inhibit-read-only t))
(remove-text-properties begin (- end 1) '(read-only t font-lock-face '(:background "yellow")))))
"read_only"))
(add-hook 'org-mode-hook 'org-mark-readonly)
#+END_SRC

*** code blocks
    :PROPERTIES:
    :ID:       3c3933cc-49aa-4ecb-8807-d5716461ff3e
    :END:
**** comment inside org code block 
     :PROPERTIES:
     :ID:       f7c7ea2d-2ec7-4e96-832e-db2fec5455cc
     :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/org-cblock-comment ()    
(interactive)
(org-edit-special)
(mark-whole-buffer)
(comment-dwim nil)
(org-edit-src-exit))

#+END_SRC
**** paste code block
     :PROPERTIES:
     :ID:       0457fca3-c102-410e-91f3-df9118d09c74
     :END:
***** z/org-cblock-paste-lisp
      :PROPERTIES:
      :ID:       c0e60258-cc52-4f4c-9f6c-90c984322fe8
      :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun  z/org-cblock-paste-lisp ()
   "paste in already quote block"
  (interactive)
  (insert "#+BEGIN_SRC emacs-lisp  :results none\n")
  (yank)
  (insert "\n#+END_SRC"))
#+END_SRC
***** z/org-cblock-paste-sh
      :PROPERTIES:
      :ID:       5458d7fd-fffa-4ec4-91df-3b75db308ae7
      :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun  z/org-cblock-paste-sh ()
   "paste in already quote block"
  (interactive)
  (insert "#+BEGIN_SRC sh  :results none\n")
  (yank)
  (insert "\n#+END_SRC"))
#+END_SRC
***** z/org-cblock-paste-conf
#+BEGIN_SRC emacs-lisp  :results none
(defun  z/org-cblock-paste-conf ()
   "paste in already quote block"
  (interactive)
  (insert "#+BEGIN_SRC conf :results none\n")
  (yank)
  (insert "\n#+END_SRC"))
#+END_SRC

***** z/org-cblock-paste-EXAMPLE
      :PROPERTIES:
      :ID:       8767f416-96f0-425d-a752-6ad4a4b0463e
      :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun  z/org-cblock-paste-example ()
   "paste in already quote block"
  (interactive)
  (insert "#+BEGIN_EXAMPLE\n")
  (yank)
  (insert "\n#+END_EXAMPLE"))
#+END_SRC
***** z/org-cblock-paste-R
#+BEGIN_SRC emacs-lisp  :results none
(defun  z/org-cblock-paste-R ()
   "paste in already quote block"
  (interactive)
  (insert "#+BEGIN_SRC R :session Rorg  :results none\n")
  (yank)
  (insert "\n#+END_SRC"))
#+END_SRC
***** z/org-cblock-paste-tangle-base
#+BEGIN_SRC emacs-lisp  :results none
(defun  z/org-cblock-paste-tangle-base ()
   "paste in already quote block"
  (interactive)
  (insert "#+BEGIN_SRC conf :mkdirp yes :tangle-mode (identity #o755) :tangle ~/  \n ")
  (yank)
  (insert "\n#+END_SRC"))
#+END_SRC

***** z/org-cblock-paste-R-full
#+BEGIN_SRC emacs-lisp  :results none
(defun  z/org-cblock-paste-R-full ()
   "paste in already quote block"
  (interactive)
  (insert "#+NAME: mygraph-code\n #+BEGIN_SRC R :session Rorg :results output graphics :file \n")
  (yank)
  (insert "\n#+END_SRC"))
#+END_SRC


***** z/org-cblock-paste-SAS
      :PROPERTIES:
      :ID:       d25e043c-dfec-4593-9f8b-a47e4afdad62
      :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun  z/org-cblock-paste-SAS ()
   "paste in already quote block"
  (interactive)
  (insert "#+BEGIN_SRC SAS\n")
  (yank)
  (insert "\n#+END_SRC"))
#+END_SRC
***** z/org-cblock-paste-QUOTE
      :PROPERTIES:
      :ID:       974b1999-2e50-406b-aef0-c8bd4e6d3325
      :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun  z/org-cblock-paste-QUOTE ()
   "paste in already quote block"
  (interactive)
  (insert "#+BEGIN_QUOTE\n")
  (yank)
  (insert "\n#+END_QUOTE"))
#+END_SRC
**** interactive wrap
     :PROPERTIES:
     :ID:       589a0b3c-6dc4-45a4-bc6e-087c4417e3be
     :END:
***** z/org-cblock-iwrap-emacs-lisp
      :PROPERTIES:
      :ID:       c7a97f24-6662-43e8-b4a7-68cb280449f1
      :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/org-cblock-iwrap-emacs-lisp (&optional lang lines)
  "Wrap sexp-at-point or region in src-block.
Use Org-Babel LANGuage for the src-block if given, Emacs-Lisp
otherwise. A region instead of the sexp-at-point is wrapped if
either
   - optional argument LINES is an (positive or negative) integer
   - or the region is active
In the first case the region is determined by moving +/- LINES
forward/backward from point using `forward-line', in the second
case the active region is used.
When called with prefix argument 'C-u', prompt the user for the
Org-Babel language to use. When called with two prefix arguments
'C-u C-u', prompt the user for both the Org-Babel language to use
and the number of lines to be wrapped."
  (interactive
   (cond
    ((equal current-prefix-arg nil) nil)
    ((equal current-prefix-arg '(4))
     (list
      (ido-completing-read "Org-Babel language: "
                           (mapcar
                            (lambda (--lang)
                              (symbol-name (car --lang)))
                            org-babel-load-languages)
                           nil nil nil nil "emacs-lisp")))
    ((equal current-prefix-arg '(16))
     (list
      (ido-completing-read "Org-Babel language: "
                           (mapcar
                            (lambda (--lang)
                              (symbol-name (car --lang)))
                            org-babel-load-languages)
                           nil nil nil nil "emacs-lisp")
      (read-number "Number of lines to wrap: " 1)))))
  (let* ((language (or lang "emacs-lisp"))
         (beg (or (and (not lines)
		       (region-active-p)
		       (region-beginning))
                  (point)))
         (marker (save-excursion (goto-char beg) (point-marker)))
         (bol (save-excursion (goto-char beg) (bolp)))
         (end (cond
	       (lines (save-excursion
                        (forward-line lines) (point)))
	       ((region-active-p)(region-end))
	       (t (save-excursion
                    (forward-sexp) (point)))))
         (cut-strg (buffer-substring beg end)))
    (delete-region beg end)
    (goto-char (marker-position marker))
    (insert
     (format
      "%s#+begin_src %s\n%s%s#+end_src\n"
      (if (or (and lines (< lines 0)) bol) "" "\n")
      language
      cut-strg
      (if lines "" "\n")))
    (set-marker marker nil)))
#+end_src
***** z/org-cblock-iwrap-ASK 
      :PROPERTIES:
      :ID:       446595a8-ad57-44ef-b83d-4a98bc667842
      :END:
 #+BEGIN_SRC emacs-lisp :results none
(defun z/org-cblock-iwrap-ASK ()
(interactive)
(let ((current-prefix-arg '(4)))
(call-interactively
'z/org-cblock-iwrap-emacs-lisp)))
 #+END_SRC
***** z/org-cblock-iwrap-ASK-LINE 
      :PROPERTIES:
      :ID:       ec70a629-f862-49aa-b467-6e872dd0c7d1
      :END:
 #+BEGIN_SRC emacs-lisp :results none
(defun z/org-cblock-iwrap-ASK-LINE ()
(interactive)
(let ((current-prefix-arg '(4)))
(call-interactively
'z/org-cblock-iwrap-emacs-lisp)))
 #+END_SRC
***** z/org-cblock-iwrap-R
      :PROPERTIES:
      :ID:       1c55842d-4fd8-4524-a61f-e855616e6338
      :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/org-cblock-iwrap-R ()
(interactive)
(z/org-cblock-iwrap-emacs-lisp  "R" ))
#+end_src
***** z/org-cblock-iwrap-sh
      :PROPERTIES:
      :ID:       c89741a3-02b9-477d-b894-0ceb20057bd6
      :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/org-cblock-iwrap-sh ()
(interactive)
(z/org-cblock-iwrap-emacs-lisp  "sh" ))
#+end_src

***** z/org-cblock-nowrap-EXAMPLE
      :PROPERTIES:
      :ID:       58ac13bc-63ea-4da9-8118-0b7de5a05c74
      :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun  z/org-cblock-nowrap-example ()
   "paste in already quote block"
  (interactive)
  (insert "#+BEGIN_EXAMPLE\n")
  (insert "\n#+END_EXAMPLE"))
#+END_SRC
**** menu for wrapping 
     :PROPERTIES:
     :ID:       e633a3da-3e4f-49c5-a1b2-242435687a63
     :END:
#+BEGIN_SRC emacs-lisp :results none
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; function to wrap blocks of text in org templates                       ;;
;; e.g. latex or src etc                                                  ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(defun z/org-cblock-iwrap-menu ()
  "Make a template at point."
  (interactive)
  (if (org-at-table-p)
      (call-interactively 'org-table-rotate-recalc-marks)
    (let* ((choices '(("s" . "SRC")
                      ("e" . "EXAMPLE")
                      ("q" . "QUOTE")
                      ("v" . "VERSE")
                      ("c" . "CENTER")
                      ("l" . "LaTeX")
                      ("h" . "HTML")
                      ("r" . "R")
                      ("a" . "ASCII")))
           (key
            (key-description
             (vector
              (read-key
               (concat (propertize "Template type: " 'face 'minibuffer-prompt)
                       (mapconcat (lambda (choice)
                                    (concat (propertize (car choice) 'face 'font-lock-type-face)
                                            ": "
                                            (cdr choice)))
                                  choices
                                  ", ")))))))
      (let ((result (assoc key choices)))
        (when result
          (let ((choice (cdr result)))
            (cond
             ((region-active-p)
              (let ((start (region-beginning))
                    (end (region-end)))
                (goto-char end)
                (insert "#+END_" choice "\n")
                (goto-char start)
                (insert "#+BEGIN_" choice "\n")))
             (t
              (insert "#+BEGIN_" choice "\n")
              (save-excursion (insert "#+END_" choice))))))))))

#+END_SRC
**** move to next/prev code block 
     :PROPERTIES:
     :ID:       ae4ce341-31f4-40d0-8ba8-07f5a88af473
     :END:
https://mail.google.com/mail/u/0/#starred/151493e15427d634
If a【C-u】 prefix is supplied, the edit is aborted rather than exited retaining edits.

#+BEGIN_SRC emacs-lisp  :results none
(defun my-babel-src-jump (arg jump-fn)
  (let* ((minor-modes (cl-remove-if-not (lambda (x)
                                          (and (boundp x) (symbol-value x)))
                                        minor-mode-list)))
    (when (member 'org-src-mode minor-modes)
      (if (equal arg '(4))
          (org-edit-src-abort)
        (org-edit-src-exit)))
    (when (eq major-mode 'org-mode)
      (funcall jump-fn)
      (org-edit-src-code))))

(defun z/org-babel-edit-next (arg)
  (interactive "P")
  (my-babel-src-jump arg #'org-babel-next-src-block))

(defun z/org-babel-edit-previous (arg)
  (interactive "P")
  (my-babel-src-jump arg #'org-babel-previous-src-block))

#+END_SRC
**** Refresh images when executing code block
     :PROPERTIES:
     :ID:       7f77e3aa-6743-4ee7-8d97-0df3a28ffb65
     :END:
https://mail.google.com/mail/u/0/#starred/1511bbdb0a30576d

#+BEGIN_SRC emacs-lisp  :results none
;; refresh images after running a block
(defun org-refresh-images ()
  "Refreshes images displayed inline."
  (interactive)
  (org-remove-inline-images)
  (org-display-inline-images))

(add-hook 'org-babel-after-execute-hook
          (lambda () (org-refresh-images)))
#+END_SRC
**** search and replace functions
***** z/replace-quote-2-R
  #+BEGIN_SRC emacs-lisp  :results none
  (defun z/replace-quote-2-R ()
    (interactive)
    (replace-string "#+BEGIN_QUOTE" "#+BEGIN_SRC R :session Rorg  :results none" nil (point-min) (point-max))
    (replace-string "#+END_QUOTE" "#+END_SRC" nil (point-min) (point-max))
  )
  #+END_SRC
***** z/replace-EXAMPLE-2-R
      :PROPERTIES:
      :ID:       49a196d6-4160-4fd1-8eb8-d2ea08ecbc8e
      :END:
  #+BEGIN_SRC emacs-lisp  :results none
  (defun z/replace-EXAMPLE-2-R ()
    (interactive)
    (replace-string "#+BEGIN_EXAMPLE" "#+BEGIN_SRC R :session Rorg  :results none" nil (point-min) (point-max))
    (replace-string "#+END_EXAMPLE" "#+END_SRC" nil (point-min) (point-max))
  )
  #+END_SRC
***** z/clean-html-2-org-pandoc
  #+BEGIN_SRC emacs-lisp  :results none
  (defun z/clean-html-2-org-pandoc ()
    (interactive)
    (replace-string "#+BEGIN_QUOTE" "#+BEGIN_SRC R :session Rorg  :results none" nil (point-min) (point-max))
    (replace-string "#+END_QUOTE" "#+END_SRC" nil (point-min) (point-max))
  ;clean extra \\
    (replace-string "\\\\" "" nil (point-min) (point-max))
  ;;clean \_
    (replace-string "\\\_" "_" nil (point-min) (point-max))
   ( z/bullets-to-spaces)
  )
  #+END_SRC

*** food 	
    :PROPERTIES:
    :ID:       a7614759-b474-4b5e-9286-465a3fc3be6c
    :END:
**** inbox Recipe Template
     :PROPERTIES:
     :ID:       23137dc6-c270-41b9-b2f0-2f974ace372e
     :END:
based on the following blog post:
http://lebensverrueckt.haktar.org/articles/org-mode-Food/#comment-1348609811

#+BEGIN_SRC emacs-lisp :results none
(defun recipe-template ()
        (interactive)
        (goto-line 0)
        (search-forward "* Inbox")
         (org-meta-return)
         (org-metaright)
         (setq recipe-name (read-string "Title: "))
         (insert recipe-name)
         (org-todo "COOK") 
         (org-set-tags)
         (org-meta-return)
         (org-metaright)
         (insert "Ingridients")
         (org-meta-return)
         (insert "Preperation")
         (search-backward recipe-name)
         (setq src1 (read-string "Time: "))
         (org-set-property "Time" src1)
         (setq src2 (read-string "Rating: "))
         (org-set-property "Rating" src2)
         (setq src3 (read-string "Sources: "))
         (org-set-property "Source" src3)
         (setq src4 (read-string "Ammount: "))
         (org-set-property "Ammount" src4)
         (setq src5 (read-string "Fav: "))
         (org-set-property "Fav" src5)
         (search-forward "Ingridients")
         (evil-open-below 1)
         (beginning-of-visual-line)
)
#+END_SRC
**** ADD Recipe Template
     :PROPERTIES:
     :ID:       5ba1cc59-ee96-41c6-a260-029a0a2cfd63
     :END:

#+BEGIN_SRC emacs-lisp :results none
(defun blank-recipe-template ()
        (interactive)
         (org-meta-return)
         (org-metaright)
         (setq recipe-name (read-string "Title: "))
         (insert recipe-name)
         (org-set-tags)
         (org-meta-return)
         (org-metaright)
         (insert "Ingridients")
         (org-meta-return)
         (insert "Preperation")
         (search-backward recipe-name)
         (setq src1 (read-string "Time: "))
         (org-set-property "Time" src1)
         (setq src2 (read-string "Rating: "))
         (org-set-property "Rating" src2)
         (setq src3 (read-string "Sources: "))
         (org-set-property "Source" src3)
         (setq src4 (read-string "Ammount: "))
         (org-set-property "Ammount" src4)
         (setq src5 (read-string "Fav: "))
         (org-set-property "Fav" src5)
         (search-forward "Ingridients")
         (evil-open-below 1)
         (beginning-of-visual-line)
)
#+END_SRC
**** add Travel Template
     :PROPERTIES:
     :ID:       7fa1618e-8ed6-41bc-902f-beb87d1c0fd0
     :END:

#+BEGIN_SRC emacs-lisp :results none
(defun travel-template ()
        (interactive)
        (goto-line 0)
        (search-forward "* Inbox")
         (org-meta-return)
         (org-metaright)
         (setq travel-name (read-string "Title: "))
         (insert travel-name)
         (org-set-tags)
         (org-meta-return)
         (org-metaright)
         (insert "Details")
         (org-meta-return)
         (search-backward travel-name)
         (setq src1 (read-string "Rating: "))
         (org-set-property "Rating" src1)
         (setq src2 (read-string "Sources: "))
         (org-set-property "Source" src2)
         (setq src3 (read-string "Fav: "))
         (org-set-property "Fav" src3)
         (search-forward "Details")
         (evil-open-below 1)
)
#+END_SRC

*** email org headers
    :PROPERTIES:
    :ID:       00ee947b-9c3a-4055-b755-1b7411c0f385
    :END:
**** send header via Email 		 
     :PROPERTIES:
     :ID:       4a2579ef-f423-4748-aa87-0e93095670ec
     :END:

 #+BEGIN_SRC emacs-lisp :results none
   (defun z/org-email-heading ()
     "Send the current org-mode heading as the body of an email, with headline as the subject.
   use these properties
   TO
   CC
   BCC
   OTHER-HEADERS is an alist specifying additional
   header fields.  Elements look like (HEADER . VALUE) where both
   HEADER and VALUE are strings.
   Save when it was sent as a SENT property. this is overwritten on
   subsequent sends."
     (interactive)
     ; store location.
     (setq *email-heading-point* (set-marker (make-marker) (point)))
     (save-excursion
       (org-mark-subtree)
       (let ((content (buffer-substring (point) (mark)))
             (TO (org-entry-get (point) "TO" t))
             (SUBJECT (nth 4 (org-heading-components)))
             (OTHER-HEADERS (eval (org-entry-get (point) "OTHER-HEADERS")))
             (continue nil)
             (switch-function nil)
             (yank-action nil)
             (send-actions '((email-send-action . nil)))
             (return-action '(email-heading-return)))
        
         (compose-mail TO SUBJECT OTHER-HEADERS continue switch-function yank-action send-actions return-action)
         (message-goto-body)
         (insert content)
         (when CC
           (message-goto-cc)
           (insert CC))
         (when BCC
           (message-goto-bcc)
           (insert BCC))
         (if TO
             (message-goto-body)
           (message-goto-to)))))

 #+END_SRC
**** Send email to myself
     :PROPERTIES:
     :ID:       b9a2cd17-7772-4629-8304-8573373cd633
     :END:
 #+BEGIN_SRC emacs-lisp
 (defun z/org-email-heading-me ()
   "Send the current org-mode heading as the body of an email, with headline as the subject."
   (interactive)
   (save-excursion
     (org-mark-subtree)
     (let ((content (buffer-substring (point) (mark)))
           (SUBJECT (nth 4 (org-heading-components))))

       (compose-mail "izeltak@gmail.com" SUBJECT)
       (message-goto-body)
       (insert content)
       (message-send)
       (message-kill-buffer))))
 #+END_SRC

 #+RESULTS:
 : z/org-email-heading-me
*** export meeting file to ics
#+BEGIN_SRC emacs-lisp  :results none
(defun z/export-meetings-to-ics ()
(interactive)
(with-current-buffer (find-file-noselect "/home/zeltak/org/files/agenda/meetings.org")
(rename-file (org-icalendar-export-to-ics) "/ssh:karif:/home/zeltak/public_html" t)
(message "exported to ics")))
#+END_SRC

rename-file is an interactive built-in function in `C source code'.

(rename-file FILE NEWNAME &optional OK-IF-ALREADY-EXISTS)

For more information check the manuals.

Rename FILE as NEWNAME.  Both args must be strings.
If file has names other than FILE, it continues to have those names.
Signals a `file-already-exists' error if a file NEWNAME already exists
unless optional third argument OK-IF-ALREADY-EXISTS is non-nil.
A number as third arg means request confirmation if NEWNAME already exists.
This is what happens in interactive use with M-x.


*** cycle through predefind orgmode files
    :PROPERTIES:
    :ID:       902ed1eb-b58f-4b88-8298-8c71fdf3d1ba
    :END:

https://mail.google.com/mail/u/0/#starred/1507e982da01a9eb

#+BEGIN_SRC emacs-lisp  :results none
(setq z/food-files '("/home/zeltak/org/files/agenda/food.org" "/home/zeltak/org/files/agenda/travel.org" ))

(defun z/org-next-food-file ()
 (interactive)
 (let ((f (pop z/food-files)))
   (add-to-list 'z/food-files f t)
   (find-file f)))

(defun z/org-previous-food-file ()
  (interactive)
  (let* ((r-z/food-files (reverse z/food-files))
         (f (pop r-z/food-files)))
    (add-to-list 'r-z/food-files f t)
    (setq z/food-files (reverse r-z/food-files))
    (find-file f)))

;(global-set-key (kbd "s-<right>") 'my-next-file)
;(global-set-key (kbd "s-<left>") 'my-previous-file)

#+END_SRC
*** exporting
    :PROPERTIES:
    :ID:       7cc2dd25-83ed-445d-9f92-5757b4e5db19
    :END:
**** Publish to reveal 
 #+BEGIN_SRC emacs-lisp  :results none
 (defun z/org-reveal-publish-to-html (plist filename pub-dir)
   "Publish an org file to reveal.js HTML Presentation.
 FILENAME is the filename of the Org file to be published.  PLIST
 is the property list for the given project.  PUB-DIR is the
 publishing directory. Returns output file name."
 (org-publish-org-to 'reveal filename ".html" plist pub-dir)
   )
 #+END_SRC
    
**** export to reveal and browse
     :PROPERTIES:
     :ID:       f0ad0ff0-34aa-4df6-9d40-a5398a9fc5f6
     :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/org-export-revel-browse ()
"export to org reveal"
(interactive)                                
(org-reveal-export-to-html-and-browse)
)
#+END_SRC
**** export to reveal html  file
     :PROPERTIES:
     :ID:       f647cbb7-1e15-4d6b-8454-b4daf468ffae
     :END:
 #+BEGIN_SRC emacs-lisp :results none
 (defun z/org-export-revel-html ()
 "export to org reveal"
 (interactive)                                
 (org-reveal-export-to-html)
 )
 #+END_SRC
**** export subtree to file
     :PROPERTIES:
     :ID:       03de5a93-43a0-466e-8cf6-d5fe21679f84
     :END:
 #+BEGIN_SRC emacs-lisp :results none
 (defun z/org-export-revel-subtree ()
 "export to org reveal"
 (interactive)                                
 (org-reveal-export-current-subtree)
 )
 #+END_SRC
**** export current org buffer to html bookmark file
     :PROPERTIES:
     :ID:       02c69f31-7a2c-44af-bfc0-8b30c83d5a21
     :END:
 http://lists.gnu.org/archive/html/emacs-orgmode/2009-09/msg00834.html
 #+BEGIN_SRC emacs-lisp
 (defun z/org-export-html-bookmarks ()
   "Extract bookmarks from the current org file and create an html file that
 can be imported into a web browser."
   (interactive)
   (unless (eq major-mode 'org-mode) 
     (error "Not in an org buffer"))
   (let ((file (file-name-nondirectory (buffer-file-name)))
         bookmarks)
   (save-excursion
     (goto-char (point-min))
     (while (re-search-forward org-bracket-link-analytic-regexp nil t)
       (when (equal (match-string 2) "http")
         (let ((url (concat (match-string 1)
                            (match-string 3)))
               (desc (match-string 5)))
           (push (concat "<DT><A HREF=\"" url "\">" desc "</A>\n") bookmarks))))
     (with-temp-buffer 
       (insert
	"<!DOCTYPE NETSCAPE-Bookmark-file-1>\n"
	"<HTML>\n"
	"<META HTTP-EQUIV=\"Content-Type\" CONTENT=\"text/html; 
 charset=UTF-8\">\n"
	"<Title>Bookmarks</Title>\n"
	"<H1>Bookmarks</H1>\n"
	"<DT><H3 FOLDED>" file " (" (format-time-string "%Y-%m-%d") ")</H3>\n"
	"<DL><p>\n")
       (apply 'insert (nreverse bookmarks))
       (insert
	"</DL><p>\n"
	"</HTML>")
       (write-file (concat (file-name-sans-extension file) 
 "-bookmarks.html"))))))
 #+END_SRC

 #+RESULTS:
 : z/org-export-html-bookmarks

**** org export to pdf manual macro
     :PROPERTIES:
     :ID:       bc19d025-076e-4189-86aa-75f19b03f1d5
     :END:
#+BEGIN_SRC emacs-lisp :results none
(fset 'expdf
      [?\C-c ?\C-e ?\l ?\o ])
#+END_SRC


*** org-teleport
    :PROPERTIES:
    :ID:       6cd88dda-aaf8-4d8f-98c9-d0cedc935828
    :END:
http://kitchingroup.cheme.cmu.edu/blog/2016/03/18/Org-teleport-headlines/

#+BEGIN_SRC emacs-lisp  :results none
(defun org-teleport (&optional arg)
  "Teleport the current heading to after a headline selected with avy.
With a prefix ARG move the headline to before the selected
headline. With a numeric prefix, set the headline level. If ARG
is positive, move after, and if negative, move before."
  (interactive "P")
  ;; Kill current headline
  (org-mark-subtree)
  (kill-region (region-beginning) (region-end))
  ;; Jump to a visible headline
  (avy-with avy-goto-line (avy--generic-jump "^\\*+" nil avy-style))
  (cond
   ;; Move before  and change headline level
   ((and (numberp arg) (> 0 arg))
    (save-excursion
      (yank))
    ;; arg is what we want, second is what we have
    ;; if n is positive, we need to demote (increase level)
    (let ((n (- (abs arg) (car (org-heading-components)))))
      (cl-loop for i from 1 to (abs n)
               do
               (if (> 0 n)
                   (org-promote-subtree)
                 (org-demote-subtree)))))
   ;; Move after and change level
   ((and (numberp arg) (< 0 arg))
    (org-mark-subtree)
    (goto-char (region-end))
    (when (eobp) (insert "\n"))
    (save-excursion
      (yank))
    ;; n is what we want and second is what we have
    ;; if n is positive, we need to demote
    (let ((n (- (abs arg) (car (org-heading-components)))))
      (cl-loop for i from 1 to (abs n)
               do
               (if (> 0 n) (org-promote-subtree)
                 (org-demote-subtree)))))

   ;; move to before selection
   ((equal arg '(4))
    (save-excursion
      (yank)))
   ;; move to after selection
   (t
    (org-mark-subtree)
    (goto-char (region-end))
    (when (eobp) (insert "\n"))
    (save-excursion
      (yank))))
  (outline-hide-leaves))

#+END_SRC
*** clone subtree with new org-id 
#+BEGIN_SRC emacs-lisp  :results none
(defun z/org-clone-subtree ()
  "Clone the current subtree and change the id."
  (interactive)

  (when (not (looking-at "^\\*"))
    (re-search-backward "^\\*"))

  (org-copy-subtree)
  (goto-char (org-element-property :end (org-element-context)))

  (org-paste-subtree)
  (org-id-get-create t))
#+END_SRC


*** movements 
    :PROPERTIES:
    :ID:       8631c03b-097b-41ad-879b-d9ba28669258
    :END:
**** move to top and collapse
     :PROPERTIES:
     :ID:       14d0aa60-975b-4fb1-9065-45650b64afc1
     :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/org-move-top-collapse  ()
     (interactive)            
     (beginning-of-buffer)                    
     (hide-sublevels 1)
)
#+END_SRC
**** go to top header
     :PROPERTIES:
     :ID:       c1925b92-b4e4-4de9-85e0-f1d9df9142bf
     :END:

#+BEGIN_SRC emacs-lisp :results none
; Speed commands are really useful, but I often want to make use of
; them when I'm not at the beginning of a header. Ths command brings
; you back to the beginning of an item's header, so that you can do
; speed commands.
 
(defun org-go-speed ()
"Goes to the beginning of an element's header, so that you can
execute speed commands."
(interactive)
(when (equal major-mode 'org-mode)
(if (org-at-heading-p)
(org-beginning-of-line)
(org-up-element))))
 
#+END_SRC
*** move capture to current at point
    :PROPERTIES:
    :ID:       b5661879-5770-4026-b101-5ba6fd5ed4d0
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/org-move-point-to-capture ()
  (cond ((org-at-heading-p) (org-beginning-of-line))
        (t (org-previous-visible-heading 1))))
#+END_SRC
*** helm tagging
    :PROPERTIES:
    :ID:       c10727cc-d9d5-44c1-8f25-e3ecfd74e700
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/org-helm-tagger ()
  (interactive)
  (helm
   :sources
   `((name . "HELM tag setter")
     (candidates . ,(mapcar 'car org-tag-persistent-alist ))
     (action . (lambda (candidate)
                 (org-set-tags-to (helm-marked-candidates)))))))
#+END_SRC
*** custom org header
    :PROPERTIES:
    :ID:       1426d0e5-fc3f-499f-a470-ef6468fe6c1b
    :END:
this is an example of creating a custom function that inserts an org mode headers with added stuff like a property drawer and places point after the org asterix. based on this email: https://mail.google.com/mail/u/0/#starred/1524a92ac4cffaed

#+BEGIN_SRC emacs-lisp  :results none
(defun my-heading ()
  (interactive)
  (org-insert-heading)
  (org-id-get-create)
  (save-excursion			;-> add time stamp
    (org-end-of-meta-data-and-drawers)
    (newline)
    (org-time-stamp-inactive '(16))))
#+END_SRC
*** org-ids to all headers in file
    :PROPERTIES:
    :ID:       61feac90-6c4c-4981-8279-0d3506033510
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/org-add-ids-to-headlines-in-file ()
  (interactive)
  (org-map-entries 'org-id-get-create))
#+END_SRC
*** link to a header using refile and completion 
    :PROPERTIES:
    :ID:       3be2afef-3de0-43d2-8f26-33e2517914b9
    :END:
#+BEGIN_SRC emacs-lisp  :results none
;; Prompt for path completion when an id type link when org-insert-link is called
;; Use with C-c C-l id: RET
(defun org-id-complete-link (&optional arg)
  "Create an id: link using completion"
  (concat "id:"
          (org-id-get-with-outline-path-completion org-refile-targets)))
#+END_SRC
*** insert key combo
http://endlessparentheses.com/inserting-the-kbd-tag-in-org-mode.html
#+BEGIN_SRC emacs-lisp  :results none
(eval-after-load 'ox-html
  ;; If you prefer to use ~ for <code> tags. Replace "code" with
  ;; "verbatim" here, and replace "~" with "=" below.
  '(push '(code . "<kbd>%s</kbd>") org-html-text-markup-alist))

(define-key org-mode-map "\C-ck" #'endless/insert-key)
(defun endless/insert-key (key)
  "Ask for a key then insert its description.
Will work on both org-mode and any mode that accepts plain html."
  (interactive "kType key sequence: ")
  (let* ((orgp (derived-mode-p 'org-mode))
         (tag (if orgp "【%s】" "<kbd>%s</kbd>")))
    (if (null (equal key "\C-m"))
        (insert 
         (format tag (help-key-description key nil)))
      ;; If you just hit RET.
      (insert (format tag ""))
      (forward-char (if orgp -1 -6)))))
#+END_SRC
*** refile to predefined org files
    :PROPERTIES:
    :ID:       dc8a1a4b-3ad2-4ad0-b253-5724ac8f3976
    :END:
http://emacs.stackexchange.com/questions/8045/org-refile-to-a-known-fixed-location

refine function to include helm.ivy for sub targets in a file?
**** base function 
     :PROPERTIES:
     :ID:       b0fdd9c3-9147-45f5-9f3f-f2630191f1c4
     :END:
this is the function used in bottom fonction that helps refile to a specific location header 

#+BEGIN_SRC emacs-lisp  :results none
(defun z/org-refile-to (file headline)
    "Move current headline to specified location"
    (let ((pos (save-excursion
                 (find-file file)
                 (org-find-exact-headline-in-buffer headline))))
      (org-refile nil nil (list headline file nil pos))))

#+END_SRC

**** refile to TODO 
     :PROPERTIES:
     :ID:       bfe1d104-c5ca-49ce-aa84-49f17aa25dbb
     :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun  z/org-refile-to-todo ()
    "Move current headline to bookmarks"
    (interactive)
    (org-mark-ring-push)
    (z/org-refile-to "/home/zeltak/org/files/agenda/TODO.org" "`TODO`")
    (org-mark-ring-goto))


#+END_SRC
**** refile to research 
     :PROPERTIES:
     :ID:       6cf6299e-c6a3-4e2d-b9b5-4c083f86db08
     :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun  z/org-refile-to-research ()
    "Move current headline to research"
    (interactive)
    (org-mark-ring-push)
    (z/org-refile-to "/home/zeltak/org/files/agenda/research.org" "INBOX")
    (org-mark-ring-goto))


#+END_SRC
**** refile to bgu 
     :PROPERTIES:
     :ID:       3a57f65d-dc26-4565-a8aa-dc6ec0b73b6c
     :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun  z/org-refile-to-bgu ()
    "Move current headline to bgu"
    (interactive)
    (org-mark-ring-push)
    (z/org-refile-to "/home/zeltak/org/files/agenda/bgu.org" "TDEN")
    (org-mark-ring-goto))


#+END_SRC
**** refile to bookmarks
     :PROPERTIES:
     :ID:       ea8f0fe8-5959-4cb9-b675-30355b002c7b
     :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun  z/org-refile-to-bookmarks  ()
    "Move current headline to bookmarks "
    (interactive)
    (org-mark-ring-push)
    (z/org-refile-to "/home/zeltak/org/files/web/wbookmarks.org" "bookmarks")
    (org-mark-ring-goto))
#+END_SRC
*** TODO org save file structure as folders

https://gist.github.com/marcowahl/c12ed4b2df9748ad7185338394b92445

saves current org mode headers as folders and sub folder 

#+BEGIN_SRC emacs-lisp  :results none
(defun org-interpret-org-as-dir-file-skeleton ()
  "Return the outline paths as lists.
Separated in those headlines not tagged 'file' and those tagged with 'file'."
  (let (output-files output-dirs)
    (org-map-entries
     (lambda ()
       (let* ((headline (car (cddddr (org-heading-components))))
              (headline-path
               (reverse
                (cons
                 headline (reverse (org-get-outline-path))))))
         (cond
          ((member "file" (org-get-local-tags))
           (setf output-files (cons headline-path output-files)))
          (t
           (setf output-dirs (cons headline-path output-dirs)))))))
    (list output-dirs output-files)))


(defun z/org-save-org-structure-as-dir-file-skeleton ()
  "Write a directory/file structure to disk according to the Org structure.
Every headline gets interpreted as directory except when it's
tagged with 'file'.

This function expects an org structure which can logically be
mapped to a filesystem.  E.g. no dirs within files may occur."
  (interactive)
  (let ((dirs-and-files (org-interpret-org-as-dir-file-skeleton)))
    (mapc
     #'make-directory
     (mapcar
      (lambda (x) (reduce (lambda (x y) (concat x "/" y)) x))
      (sort (car dirs-and-files) (lambda (x y) (< (length x) (length y))))))
    (mapc
     (lambda (x) (save-excursion
              (save-buffer (set-buffer (find-file-noselect x t)))))
     (mapcar
      (lambda (x) (reduce (lambda (x y) (concat x "/" y)) x))
      (cadr dirs-and-files)))))
#+END_SRC

** org macros
   :PROPERTIES:
   :ID:       f48948d8-cf23-4101-9fda-932da886a751
   :END:
* Functions
  :PROPERTIES:
  :ID:       9e66873a-9deb-4ada-90f8-30b65bded9fc
  :END:


$Note-all my (zeltak) functions should follow the following base syntax$
#+BEGIN_EXAMPLE
Z/MODENAME-HEADER-SUBHEADER-NAME
#+END_EXAMPLE
** Encoding
   :PROPERTIES:
   :ID:       56329d90-8ac9-4bd2-9ee8-6599ba54510e
   :END:
*** fix unicode characters
    :PROPERTIES:
    :ID:       451176ba-d1ea-49ba-8739-e001eb5d2bfb
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z-fix-characters 
(start end) 
(interactive "r") 
(let ((buffer-invisibility-spec)) (query-replace-regexp "[^\t\n\r\f -~]" ""))
)

(defun z-fix2-characters ()
  (interactive)
  (let ()
    (query-replace-regexp "[^\t\n\r\f -~]" "")
    ))
#+END_SRC
** Editing
   :PROPERTIES:
   :ID:       aba420d5-4351-496f-beb6-c8efb0677710
   :END:
*** Increment years
    :PROPERTIES:
    :ID:       303c569e-78f9-417e-8bef-4694abac15c4
    :END:

#+BEGIN_SRC emacs-lisp
(defun z-year-increment  (buffer max-year)
  (interactive "b\nsMax year (yy): ")
  (setq max-year (string-to-number max-year))
  (let ((year 2003)
        (newbuf (get-buffer-create "increment-year")))
    (let ((s (with-current-buffer buffer
               (buffer-substring (point-min) (point-max)))))
      (dotimes (n (1+ max-year))
        (with-current-buffer newbuf
          (goto-char (point-max))
          (insert "\n")
          (insert (replace-regexp-in-string (int-to-string year)
                                            (int-to-string (+ year n))
                                            s)))))
    (switch-to-buffer newbuf)))
#+END_SRC

#+RESULTS:
: z-year-increment

*** Get rid of blank lines
    :PROPERTIES:
    :ID:       97f57dc6-e27c-46bc-af98-f9b57b8a4031
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun flush-blank-lines ()
    "Removes all blank lines from buffer or region"
     (interactive)
     (save-excursion
       (let (min max)
         (if (equal (region-active-p) nil)
             (mark-whole-buffer))
         (setq min (region-beginning) max (region-end))
         (flush-lines "^ *$" min max t))))
#+END_SRC 
*** Join lines
    :PROPERTIES:
    :ID:       b88526b1-b277-4dfe-abdf-e2025c7cc2ba
    :END:

#+BEGIN_SRC emacs-lisp :results none
(global-set-key (kbd "M-j")
            (lambda ()
                  (interactive)
                  (join-line -1)))
#+END_SRC
*** fill/unfill one command
    :PROPERTIES:
    :ID:       8c49e63d-db11-4e16-9d82-f92240a07742
    :END:
http://endlessparentheses.com/fill-and-unfill-paragraphs-with-a-single-key.html
#+BEGIN_SRC emacs-lisp  :results none
(defun endless/fill-or-unfill ()
  "Like `fill-paragraph', but unfill if used twice."
  (interactive)
  (let ((fill-column
         (if (eq last-command 'endless/fill-or-unfill)
             (progn (setq this-command nil)
                    (point-max))
           fill-column)))
    (call-interactively #'fill-paragraph)))

(global-set-key [remap fill-paragraph]
                #'endless/fill-or-unfill)
#+END_SRC
*** Fill/unfill paragraph
    :PROPERTIES:
    :ID:       e247a96e-2b58-46c9-b3f0-b004c44a086f
    :END:

#+BEGIN_SRC emacs-lisp :results none
(defun unfill-paragraph ()
  "Replace newline chars in current paragraph by single spaces.
This command does the inverse of `fill-paragraph'."
  (interactive)
  (let ((fill-column 90002000)) ; 90002000 is just random. you can use `most-positive-fixnum'
    (fill-paragraph nil)))

(defun unfill-region (start end)
  "Replace newline chars in region by single spaces.
This command does the inverse of `fill-region'."
  (interactive "r")
  (let ((fill-column 90002000))
    (fill-region start end)))

#+END_SRC
*** count sentences
    :PROPERTIES:
    :ID:       47c6ed4d-4cb0-427b-a8cf-f9d8729bb122
    :END:
#+BEGIN_SRC emacs-lisp
(defun count-sentences (begin end &optional print-message)
  "Count the number of sentences from BEGIN to END."
  (interactive (if (use-region-p)
		   (list (region-beginning)
			 (region-end)
			 t)
		 (list nil nil t)))
  (save-excursion
    (save-restriction
      (narrow-to-region (or begin (point-min))
			(progn
			  (goto-char (or end (point-max)))
			  (skip-chars-backward " \t\n")
			  (point)))
      (goto-char (point-min))
      (let ((sentences 0))
	(while (not (looking-at-p "[ \t\n]*\\'"))
	  (forward-sentence 1)
	  (setq sentences (1+ sentences)))
	(if print-message
	    (message
	     "%s sentences in %s."
	     sentences
	     (if (use-region-p)
		 "region"
	       "buffer"))
	  sentences)))))
#+END_SRC

*** Count words in region
    :PROPERTIES:
    :ID:       0241ff2f-62f3-4956-b407-e01d2a4ffc36
    :END:
#+BEGIN_SRC emacs-lisp :results none

(defun z-count-words-region (posBegin posEnd)
  "Print number of words and chars in region."
  (interactive "r")
  (message "Counting …")
  (save-excursion
    (let (wordCount charCount)
      (setq wordCount 0)
      (setq charCount (- posEnd posBegin))
      (goto-char posBegin)
      (while (and (< (point) posEnd)
                  (re-search-forward "\\w+\\W*" posEnd t))
        (setq wordCount (1+ wordCount)))

      (message "Words: %d. Chars: %d." wordCount charCount)
      )))

#+END_SRC
*** Copy and comment
    :PROPERTIES:
    :ID:       ba3f0e76-b554-492e-a4e8-05ef292771ff
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/copy-comment-paste ()
  "copy active region/current line, comment, and then paste"
  (interactive)
  (unless (use-region-p)
    (progn
      (beginning-of-line 2)
      (push-mark (line-beginning-position 0))))
  (kill-ring-save (region-beginning) (region-end))
  (comment-region (region-beginning) (region-end))
  (yank)
  (exchange-point-and-mark)
  (indent-according-to-mode))
#+END_SRC
*** move line up/down
    :PROPERTIES:
    :ID:       f6557c1f-4ad8-4ecc-bcb0-cf88c2cb2ef3
    :END:
    #+BEGIN_SRC emacs-lisp :results none
(defun move-line-up ()
  "Move up the current line."
  (interactive)
  (transpose-lines 1)
  (forward-line -2)
  (indent-according-to-mode))

(defun move-line-down ()
  "Move down the current line."
  (interactive)
  (forward-line 1)
  (transpose-lines 1)
  (forward-line -1)
  (indent-according-to-mode))

#+END_SRC
*** insert date
    :PROPERTIES:
    :ID:       dffdefae-e1e1-4bed-a970-f1f6dc945812
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z-insert-date (&optional addTimeStamp-p)
  "Insert current date and or time. In this format yyyy-mm-dd.
 When called with `universal-argument', insert date and time, e.g. 2012-05-28T07:06:23-07:00
 Replaces text selection.See also `current-date-time-string'."
  (interactive "P")
  (when (region-active-p) (delete-region (region-beginning) (region-end) ) )
  (cond
   ((equal addTimeStamp-p nil ) (insert (format-time-string "%Y-%m-%d")))
   (t (insert (current-date-time-string))) ) )
#+END_SRC
*** insert date and time
    :PROPERTIES:
    :ID:       52148936-a9d5-4556-b688-e580676b05a7
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z-insert-date-time (&optional addTimeStamp-p)
  "Insert current date and or time. In this format yyyy-mm-dd.
 When called with `universal-argument', insert date and time, e.g. 2012-05-28T07:06:23-07:00
 Replaces text selection.See also `current-date-time-string'."
  (interactive "P")
  (when (region-active-p) (delete-region (region-beginning) (region-end) ) )
  (cond
   ((equal addTimeStamp-p nil ) (insert (format-time-string "%Y-%m-%d-%H:%M:%S")))
   (t (insert (current-date-time-string))) ) )
#+END_SRC

*** copy/paste to/from x clip
    :PROPERTIES:
    :ID:       dd69b722-fccf-4e8b-85b6-ba2ee60da7ec
    :END:

#+BEGIN_SRC emacs-lisp :results none
(defun copy-to-x-clipboard ()
  (interactive)
  (if (region-active-p)
      (progn
        (cond
         ((and (display-graphic-p) x-select-enable-clipboard)
          (x-set-selection 'CLIPBOARD (buffer-substring (region-beginning) (region-end))))
         (t (shell-command-on-region (region-beginning) (region-end)
                                     (cond
                                      (*cygwin* "putclip")
                                      (*is-a-mac* "pbcopy")
                                      (*linux* "xsel -ib")))
            ))
        (message "Yanked region to clipboard!")
        (deactivate-mark))
        (message "No region active; can't yank to clipboard!")))

(defun paste-from-x-clipboard()
  (interactive)
  (cond
   ((and (display-graphic-p) x-select-enable-clipboard)
    (insert (x-selection 'CLIPBOARD)))
   (t (shell-command
       (cond
        (*cygwin* "getclip")
        (*is-a-mac* "pbpaste")
        (t "xsel -ob"))
       1))
   ))
#+END_SRC

*** copy and indent lines
    :PROPERTIES:
    :ID:       22dd7da6-d6ae-4ede-acef-f62b4afc7887
    :END:

#+BEGIN_SRC emacs-lisp :results none
(defun prelude-indent-rigidly-and-copy-to-clipboard (begin end indent)
  "Copy the selected code region to the clipboard, indented according
to Markdown blockquote rules."
  (let ((buffer (current-buffer)))
    (with-temp-buffer
      (insert-buffer-substring-no-properties buffer begin end)
      (indent-rigidly (point-min) (point-max) indent)
      (clipboard-kill-ring-save (point-min) (point-max)))))

(defun prelude-indent-blockquote-and-copy-to-clipboard (begin end)
  "Copy the selected code region to the clipboard, indented according
to markdown blockquote rules (useful to copy snippets to StackOverflow, Assembla, Github."
  (interactive "r")
  (prelude-indent-rigidly-and-copy-to-clipboard begin end 4))

(defun prelude-indent-nested-blockquote-and-copy-to-clipboard (begin end)
  "Copy the selected code region to the clipboard, indented according
to markdown blockquote rules. Useful to add snippets under bullet points."
  (interactive "r")
  (prelude-indent-rigidly-and-copy-to-clipboard begin end 6))

#+END_SRC
*** search replace all document
    :PROPERTIES:
    :ID:       9f21148e-f39f-427c-94ce-a768e2db65df
    :END:
@currently below code broken@

#+BEGIN_SRC emacs-lisp :results none
;(defun  z/search-replace-file ()
;(interactive)
;(goto-char (point-min))
;(query-replace-regexp ))

#+END_SRC
*** duplicate line/region 
    :PROPERTIES:
    :ID:       3fab1a86-7551-419d-a42e-cecbd1db06b4
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun duplicate-current-line-or-region (arg)
  "Duplicates the current line or region ARG times.
If there's no region, the current line will be duplicated. However, if
there's a region, all lines that region covers will be duplicated."
  (interactive "p")
  (let (beg end (origin (point)))
    (if (and mark-active (> (point) (mark)))
        (exchange-point-and-mark))
    (setq beg (line-beginning-position))
    (if mark-active
        (exchange-point-and-mark))
    (setq end (line-end-position))
    (let ((region (buffer-substring-no-properties beg end)))
      (dotimes (i arg)
        (goto-char end)
        (newline)
        (insert region)
        (setq end (point)))
      (goto-char (+ origin (* (length region) arg) arg)))))
#+END_SRC

**** old method for line only 
#+BEGIN_SRC emacs-lisp :results none
(defun duplicate-line()
  (interactive)
  (move-beginning-of-line 1)
  (kill-line)
  (yank)
  (open-line 1)
  (next-line 1)
  (yank)
)
#+END_SRC

*** duplicate line/region red hydra 
    :PROPERTIES:
    :ID:       d9ae6188-e7a3-4e8a-889f-fd64d7c87a91
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun duplicate-current-line-or-region-red (arg)
  "Duplicates the current line or region ARG times.
If there's no region, the current line will be duplicated. However, if
there's a region, all lines that region covers will be duplicated."
  (interactive "p")
  (let (beg end (origin (point)))
    (if (and mark-active (> (point) (mark)))
        (exchange-point-and-mark))
    (setq beg (line-beginning-position))
    (if mark-active
        (exchange-point-and-mark))
    (setq end (line-end-position))
    (let ((region (buffer-substring-no-properties beg end)))
      (dotimes (i arg)
        (goto-char end)
        (newline)
        (insert region)
        (setq end (point)))
      (goto-char (+ origin (* (length region) arg) arg)))))
#+END_SRC

**** old method for line only 
     :PROPERTIES:
     :ID:       412d7b66-66f5-4255-aa63-fc08070daffd
     :END:
#+BEGIN_SRC emacs-lisp :results none
(defun duplicate-line()
  (interactive)
  (move-beginning-of-line 1)
  (kill-line)
  (yank)
  (open-line 1)
  (next-line 1)
  (yank)
)
#+END_SRC

*** copy current line
    :PROPERTIES:
    :ID:       95077944-151a-4f2e-800a-e5904a442a2b
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/copy-line (arg)
    "Copy lines (as many as prefix argument) in the kill ring.
      Ease of use features:
      - Move to start of next line.
      - Appends the copy on sequential calls.
      - Use newline as last char even on the last line of the buffer.
      - If region is active, copy its lines."
    (interactive "p")
    (let ((beg (line-beginning-position))
          (end (line-end-position arg)))
      (when mark-active
        (if (> (point) (mark))
            (setq beg (save-excursion (goto-char (mark)) (line-beginning-position)))
          (setq end (save-excursion (goto-char (mark)) (line-end-position)))))
      (if (eq last-command 'copy-line)
          (kill-append (buffer-substring beg end) (< end beg))
        (kill-ring-save beg end)))
    (kill-append "\n" nil)
    (beginning-of-line (or (and arg (1+ arg)) 2))
    (if (and arg (not (= 1 arg))) (message "%d lines copied" arg)))
#+END_SRC
*** auto spell correction function
    :PROPERTIES:
    :ID:       eb3f2559-d077-466b-9368-15394ad6ffbe
    :END:
http://endlessparentheses.com/ispell-and-abbrev-the-perfect-auto-correct.html

this will store the abbrevs here: 
file:/home/zeltak/.emacs.d/abbrv/personal_abbrv.txt


#+BEGIN_SRC emacs-lisp  :results none
(define-key ctl-x-map "\C-i"
  #'endless/ispell-word-then-abbrev)

(defun endless/simple-get-word ()
  (car-safe (save-excursion (ispell-get-word nil))))

(defun endless/ispell-word-then-abbrev (p)
  "Call `ispell-word', then create an abbrev for it.
With prefix P, create local abbrev. Otherwise it will
be global.
If there's nothing wrong with the word at point, keep
looking for a typo until the beginning of buffer. You can
skip typos you don't want to fix with `SPC', and you can
abort completely with `C-g'."
  (interactive "P")
  (let (bef aft)
    (save-excursion
      (while (if (setq bef (endless/simple-get-word))
                 ;; Word was corrected or used quit.
                 (if (ispell-word nil 'quiet)
                     nil ; End the loop.
                   ;; Also end if we reach `bob'.
                   (not (bobp)))
               ;; If there's no word at point, keep looking
               ;; until `bob'.
               (not (bobp)))
        (backward-word)
        (backward-char))
      (setq aft (endless/simple-get-word)))
    (if (and aft bef (not (equal aft bef)))
        (let ((aft (downcase aft))
              (bef (downcase bef)))
          (define-abbrev
            (if p local-abbrev-table global-abbrev-table)
            bef aft)
          (message "\"%s\" now expands to \"%s\" %sally"
                   bef aft (if p "loc" "glob")))
      (user-error "No typo at or before point"))))

#+END_SRC



#+BEGIN_SRC emacs-lisp  :results none
  ;; (defun endless/ispell-word-then-abbrev (p)
  ;;   "Call `ispell-word', then create an abbrev for it.
  ;; With prefix P, create local abbrev. Otherwise it will
  ;; be global."
  ;;   (interactive "P")
  ;;   (let (bef aft)
  ;;     (save-excursion
  ;;       (while (progn
  ;;                (backward-word)
  ;;                (and (setq bef (thing-at-point 'word))
  ;;                     (not (ispell-word nil 'quiet)))))
  ;;       (setq aft (thing-at-point 'word)))
  ;;     (when (and aft bef (not (equal aft bef)))
  ;;       (setq aft (downcase aft))
  ;;       (setq bef (downcase bef))
  ;;       (define-abbrev
  ;;         (if p local-abbrev-table global-abbrev-table)
  ;;         bef aft)
  ;;       (message "\"%s\" now expands to \"%s\" %sally"
  ;;                bef aft (if p "loc" "glob")))))

#+END_SRC

*** common used regex
    :PROPERTIES:
    :ID:       941f24e3-b695-4c4a-9e90-29f3946521d2
    :END:
**** delete all numeric characters
     :PROPERTIES:
     :ID:       a87a3894-2c35-42cd-8c1f-9ff9b7a85a20
     :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/regex-delete-numeric  ()
  "delete all numeric characters"
  (interactive)
  (goto-char (point-min))
  (replace-regexp "[0-9]" "")
)
#+END_SRC

*** Code box
    :PROPERTIES:
    :ID:       651b81d5-a623-427c-ad08-09026df6cc0f
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/comment-box (b e)
  "Draw a box comment around the region but arrange for the region
to extend to at least the fill column. Place the point after the
comment box."
  (interactive "r")
  (let ((e (copy-marker e t)))
    (goto-char b)
    (end-of-line)
    (insert-char ?  (- fill-column (current-column)))
    (comment-box b e 1)
    (goto-char e)
    (set-marker e nil)))

#+END_SRC
*** insert quick snippets/Unicode texts
    :PROPERTIES:
    :ID:       e534f1d7-9eab-4306-8c59-a99f89a52e83
    :END:

#+BEGIN_SRC emacs-lisp :results none
(defun z/insert-keyleft ()
  " insert 【   "
  (interactive)
  (insert "【")
  )

(defun z/insert-keyright ()
  " insert 】   "
  (interactive)
  (insert "】")
  )


(defun z/insert-EOL ()
  " insert EOL"
  (interactive)
  (insert "\\\\")
(backward-char 2)  
)

(defun z/insert-bashscript ()
  " insert #!/bin/sh  "
  (interactive)
  (insert "#!/bin/sh")

(defun z/insert-play ()
  " insert   ‣  "
  (interactive)
  (insert "‣")
)


(defun z/insert-white-arrow ()
  " insert   ▻  "
  (interactive)
  (insert "▻")
)



(defun z/insert-reveal-split ()
  "insert REVEAL split  "
  (interactive)
  (insert "#+REVEAL: split")
)

)


#+END_SRC

*** kill line backwars 
    :PROPERTIES:
    :ID:       5ee34cd6-aae1-47c8-81a0-aad22bcca2cc
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun backward-kill-line (arg)
  "Kill ARG lines backward."
  (interactive "p")
  (kill-line (- 1 arg)))
#+END_SRC
*** copy whole buffer
    :PROPERTIES:
    :ID:       79daaed0-6ce9-42a5-99b6-a98d504ad877
    :END:
http://ergoemacs.org/emacs/emacs_copy_cut_all_or_region.html

#+BEGIN_SRC emacs-lisp :results none
(defun z/edit-copy-all-or-region ()
  "Put the whole buffer content to `kill-ring', or text selection if there's one.
Respects `narrow-to-region'.
URL `http://ergoemacs.org/emacs/emacs_copy_cut_all_or_region.html'
Version 2015-08-22"
  (interactive)
  (if (use-region-p)
      (progn
        (kill-new (buffer-substring (region-beginning) (region-end)))
        (message "Text selection copied."))
    (progn
      (kill-new (buffer-string))
      (message "Buffer content copied."))))
#+END_SRC
*** replace underscore
    :PROPERTIES:
    :ID:       d1a1e6c3-b7db-4737-b429-367534edf80f
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun xah-cycle-hyphen-underscore-space ()
  "Cycle {underscore, space, hypen} chars of current word or text selection.
When called repeatedly, this command cycles the {“_”, “-”, “ ”} characters, in that order.

URL `http://ergoemacs.org/emacs/elisp_change_space-hyphen_underscore.html'
Version 2015-08-17"
  (interactive)
  ;; this function sets a property 「'state」. Possible values are 0 to length of ξcharArray.
  (let (ξp1 ξp2)
    (if (use-region-p)
        (progn
          (setq ξp1 (region-beginning))
          (setq ξp2 (region-end)))
      (let ((ξbounds (bounds-of-thing-at-point 'symbol)))
        (progn
          (setq ξp1 (car ξbounds))
          (setq ξp2 (cdr ξbounds)))))

    (let* ((ξinputText (buffer-substring-no-properties ξp1 ξp2))
           (ξcharArray ["_" "-" " "])
           (ξlength (length ξcharArray))
           (ξregionWasActive-p (region-active-p))
           (ξnowState
            (if (equal last-command this-command )
                (get 'xah-cycle-hyphen-underscore-space 'state)
              0 ))
           (ξchangeTo (elt ξcharArray ξnowState)))
      (save-excursion
        (save-restriction
          (narrow-to-region ξp1 ξp2)
          (goto-char (point-min))
          (while
              (search-forward-regexp
               (concat
                (elt ξcharArray (% (+ ξnowState 1) ξlength))
                "\\|"
                (elt ξcharArray (% (+ ξnowState 2) ξlength)))
               (point-max)
               'NOERROR)
            (replace-match ξchangeTo 'FIXEDCASE 'LITERAL))))
      (when (or (string= ξchangeTo " ") ξregionWasActive-p)
        (goto-char ξp2)
        (set-mark ξp1)
        (setq deactivate-mark nil))
      (put 'xah-cycle-hyphen-underscore-space 'state (% (+ ξnowState 1) ξlength)))))
#+END_SRC
*** Bracket Pair Insertion Commands
    :PROPERTIES:
    :ID:       b42eadd9-8710-437a-81db-e25f87ddd0f5
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun xah-insert-bracket-pair (φleft-bracket φright-bracket)
  "Wrap or Insert a matching bracket and place cursor in between.

If there's a text selection, wrap brackets around it. Else, smartly decide wrap or insert. (basically, if there's no char after cursor, just insert bracket pair.)

φleft-bracket ＆ φright-bracket are strings.

URL `http://ergoemacs.org/emacs/elisp_insert_brackets_by_pair.html'
Version 2015-04-19"
  (if (use-region-p)
      (progn
        (let (
              (ξp1 (region-beginning))
              (ξp2 (region-end)))
          (goto-char ξp2)
          (insert φright-bracket)
          (goto-char ξp1)
          (insert φleft-bracket)
          (goto-char (+ ξp2 2))))
    (progn ; no text selection
      (if
          (or
           (looking-at "[^-_[:alnum:]]")
           (eq (point) (point-max)))
          (progn
            (insert φleft-bracket φright-bracket)
            (search-backward φright-bracket ))
        (progn
          (let (ξp1 ξp2)
            ;; basically, want all alphanumeric, plus hyphen and underscore, but don't want space or punctuations. Also want chinese.
            ;; 我有一帘幽梦，不知与谁能共。多少秘密在其中，欲诉无人能懂。
            (skip-chars-backward "-_[:alnum:]")
            (setq ξp1 (point))
            (skip-chars-forward "-_[:alnum:]")
            (setq ξp2 (point))
            (goto-char ξp2)
            (insert φright-bracket)
            (goto-char ξp1)
            (insert φleft-bracket)
            (goto-char (+ ξp2 (length φleft-bracket)))))))))

#+END_SRC
*** specific paren types enter
    :PROPERTIES:
    :ID:       6a0701d5-db13-4593-bde0-4b39147ddf3e
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/insert-black-lenticular-bracket () (interactive) (xah-insert-bracket-pair "【" "】") )
(defun z/insert-black-lenticular-bracket-white () (interactive) (xah-insert-bracket-pair "〖" "〗") )
(defun z/insert-black-lenticular-angle   () (interactive) (xah-insert-bracket-pair "«" "»") )
(defun z/insert-black-lenticular-angle-bold   () (interactive) (xah-insert-bracket-pair "❰" "❱") )
(defun z/insert-black-arrows   () (interactive) (xah-insert-bracket-pair "◀" "▶") )
(defun z/insert-black-hands   () (interactive) (xah-insert-bracket-pair "☚" "☛") )
#+END_SRC
(defun xah-insert-corner-bracket「」 () (interactive) (xah-insert-bracket-pair "「" "」") )
(defun xah-insert-white-corner-bracket『』 () (interactive) (xah-insert-bracket-pair "『" "』") )
(defun xah-insert-angle-bracket〈〉 () (interactive) (xah-insert-bracket-pair "《" "》") )
(defun xah-insert-double-angle-bracket《》 () (interactive) (xah-insert-bracket-pair "《" "》") )


*** open line above and below
    :PROPERTIES:
    :ID:       6b033da2-cad3-46a0-9f10-4b905d7dc8d0
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/insert-line-below ()
  "Insert and auto-indent line below cursor, like in vim."
  (interactive)
  (move-end-of-line 1)
  (open-line 1)
  (next-line)
  (indent-for-tab-command))

(defun z/insert-line-above ()
  "Insert and auto-indent line above cursor, like in vim."
  (interactive)
  (previous-line)
  (move-end-of-line 1)
  (stag-insert-line-below))

(global-set-key (kbd "C-o")       ' z/insert-line-below)
(global-set-key (kbd "C-S-o")     ' z/insert-line-above)
#+END_SRC


*** flyspell jump to last correction
    :PROPERTIES:
    :ID:       77bc9eaa-6b9e-496d-9664-2221f9799ecf
    :END:
#+BEGIN_SRC emacs-lisp :results none
;; move point to previous error
;; based on code by hatschipuh at
;; http://emacs.stackexchange.com/a/14912/2017
(defun z/flyspell-goto-previous-error (arg)
  "Go to arg previous spelling error."
  (interactive "p")
  (while (not (= 0 arg))
    (let ((pos (point))
          (min (point-min)))
      (if (and (eq (current-buffer) flyspell-old-buffer-error)
               (eq pos flyspell-old-pos-error))
          (progn
            (if (= flyspell-old-pos-error min)
                ;; goto beginning of buffer
                (progn
                  (message "Restarting from end of buffer")
                  (goto-char (point-max)))
              (backward-word 1))
            (setq pos (point))))
      ;; seek the next error
      (while (and (> pos min)
                  (let ((ovs (overlays-at pos))
                        (r '()))
                    (while (and (not r) (consp ovs))
                      (if (flyspell-overlay-p (car ovs))
                          (setq r t)
                        (setq ovs (cdr ovs))))
                    (not r)))
        (backward-word 1)
        (setq pos (point)))
      ;; save the current location for next invocation
      (setq arg (1- arg))
      (setq flyspell-old-pos-error pos)
      (setq flyspell-old-buffer-error (current-buffer))
      (goto-char pos)
      (if (= pos min)
          (progn
            (message "No more miss-spelled word!")
            (setq arg 0))
        (forward-word)))))
#+END_SRC

*** insert file name
    :PROPERTIES:
    :ID:       8cdfd6e1-e897-463d-94ca-bb5ef52d41b0
    :END:
http://pragmaticemacs.com/emacs/insert-file-name/
#+BEGIN_SRC emacs-lisp  :results none
;; https://www.emacswiki.org/emacs/InsertFileName
(defun z/insert-file-name (filename &optional args)
  "Insert name of file FILENAME into buffer after point.

  Prefixed with \\[universal-argument], expand the file name to
  its fully canocalized path.  See `expand-file-name'.

  Prefixed with \\[negative-argument], use relative path to file
  name from current directory, `default-directory'.  See
  `file-relative-name'.

  The default with no prefix is to insert the file name exactly as
  it appears in the minibuffer prompt."
  ;; Based on insert-file in Emacs -- ashawley 20080926
  (interactive "*fInsert file name: \nP")
  (cond ((eq '- args)
         (insert (expand-file-name filename)))
        ((not (null args))
         (insert (filename)))
        (t
         (insert (file-relative-name filename)))))


#+END_SRC
*** paste formatted html from web and clip 
https://emacs.stackexchange.com/questions/12121/org-mode-parsing-rich-html-directly-when-pasting

#+BEGIN_SRC emacs-lisp  :results none
(defun z/html2org-clipboard ()
  "Convert clipboard contents from HTML to Org and then paste (yank)."
  (interactive)
  (kill-new (shell-command-to-string "xclip -o -t TARGETS | grep -q text/html && (xclip -o -t text/html | pandoc -f html -t json | pandoc -f json -t org) || xclip -o"))
  (yank))

#+END_SRC
*** find and replace on specific lines 
#+BEGIN_SRC emacs-lisp  :results none
(defun z/replace-on-matching-lines (&optional arg)
  "Replace text on lines that match a regexp.
With prefix arg, replace on non-matching lines."
  (interactive "P")
  (let* ((regexp (concat ".*"
                         (read-from-minibuffer
                          (concat "Replace on lines "
                                  (if arg "not " "")
                                  "matching regexp: "))))
         (replace (read-from-minibuffer "Replace: "))
         (with (read-from-minibuffer (concat "Replace " replace " with: ")))
         match)
    (save-excursion
      (goto-char (point-min))
      (while (not (eobp))
        (setq match (looking-at regexp))
        (when (if arg (not match) match)
          (while (search-forward replace (point-at-eol) t)
            (replace-match with nil t)))
        (forward-line)))))
#+END_SRC
** hydra related
   :PROPERTIES:
   :ID:       fc6ec75a-3e80-40ea-810f-82b30a4e4f07
   :END:
*** insert hydra colors
    :PROPERTIES:
    :ID:       4c2b47a5-d2a3-4242-8680-46516d0288f1
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/insert-hydra-color-red ()
  " "
  (interactive)
  (insert ":face 'hydra-face-red")
  )


(defun z/insert-hydra-color-orange ()
  " "
  (interactive)
  (insert ":face 'hydra-face-orange")
  )


(defun z/insert-hydra-color-brown ()
  " "
  (interactive)
  (insert ":face 'hydra-face-brown")
  )


(defun z/insert-hydra-color-cyan ()
  " "
  (interactive)
  (insert ":face 'hydra-face-cyan")
  )


(defun z/insert-hydra-color-green ()
  " "
  (interactive)
  (insert ":face 'hydra-face-green")
  )


(defun z/insert-hydra-color-purple ()
  " "
  (interactive)
  (insert ":face 'hydra-face-purple")
  )



(defun z/insert-hydra-color-grey ()
  " "
  (interactive)
  (insert ":face 'hydra-face-grey")
  )


(defun z/insert-hydra-color-sky ()
  " "
  (interactive)
  (insert ":face 'hydra-face-sky")
  )


(defun z/insert-hydra-color-salmon ()
  " "
  (interactive)
  (insert ":face 'hydra-face-salmon")
  )


(defun z/insert-hydra-color-torq ()
  " "
  (interactive)
  (insert ":face 'hydra-face-torq")
  )


(defun z/insert-hydra-color-darkred ()
  " "
  (interactive)
  (insert ":face 'hydra-face-darkred")
  )


(defun z/insert-hydra-color-yellow ()
  " "
  (interactive)
  (insert ":face 'hydra-face-yellow")
  )


(defun z/insert-hydra-color-forestgreen ()
  " "
  (interactive)
  (insert ":face 'hydra-face-forestgreen")
  )




#+END_SRC
*** counsel search hydra
    :PROPERTIES:
    :ID:       78fc78f9-ce30-4b3f-a8fb-23753b00536e
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/counsel-hydra-heads ()
  (interactive)
  (let* ((base (substring
                (prin1-to-string hydra-curr-body-fn)
                0 -4))
         (heads (eval (intern (concat base "heads"))))
         (keymap (eval (intern (concat base "keymap"))))
         (head-names
          (mapcar (lambda (x)
                    (cons
                     (if (nth 2 x)
                         (format "[%s] %S (%s)" (nth 0 x) (nth 1 x) (nth 2 x))
                       (format "[%s] %S" (nth 0 x) (nth 1 x)))
                     (lookup-key keymap (kbd (nth 0 x)))))
                  heads)))
    (ivy-read "head: " head-names
              :action #'call-interactively)
    (hydra-keyboard-quit)))
#+END_SRC
*** slash \
    :PROPERTIES:
    :ID:       75be01fd-f4be-4994-afa8-20c530ce173a
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/insert-slsh ()
  " insert     "
  (interactive)
  (insert "\\")
)
#+END_SRC
*** jump to org-bookmarks via hydra functions 
    :PROPERTIES:
    :ID:       edae3ee6-0eb7-4d79-beef-cffddc5223ab
    :END:

#+BEGIN_SRC emacs-lisp  :results none
(defun z/org-bookmark-jump-by-string (s)
  "Jump to bookmark named S."
  (interactive)
  (org-bookmark-jump (assoc s bookmark-alist)))
#+END_SRC

** Root actions
   :PROPERTIES:
   :ID:       3b963b74-ea6e-4081-8b14-8afbc841c9f6
   :END:
*** edit file as root
    :PROPERTIES:
    :ID:       c680cecb-f50b-42fb-8f1d-986a6433b40f
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z-edit-file-as-root ()
  "Edit the file that is associated with the current buffer as root"
  (interactive)
  (if (buffer-file-name)
      (progn
        (setq file (concat "/sudo:root@localhost:" (buffer-file-name)))
        (find-file file))
    (message "Current buffer does not have an associated file.")))


#+END_SRC
** bookmarks 
*** bm+ function bookmarks
**** fb.travel.nyc
#+BEGIN_SRC emacs-lisp  :results none
(defun fb.travel.nyc ()
  "function bookmark"
  (interactive)
  (bmkp-dired-jump "fb.0001" )
  (org-narrow-to-subtree)
  )
#+END_SRC
** Buffers
   :PROPERTIES:
   :ID:       9134ade5-38ec-4db5-9819-de8fee911b82
   :END:
*** kill other buffers
    :PROPERTIES:
    :ID:       f8ef961e-7dcd-4a46-bae3-3b532cc18b20
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z-kill-other-buffers ()
      "Kill all other buffers."
      (interactive)
      (mapc 'kill-buffer (delq (current-buffer) (buffer-list))))

#+END_SRC

*** movment in buffer
    :PROPERTIES:
    :ID:       e6eb67f6-cdcb-4a37-9482-1183e26ed7d8
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun next-user-buffer ()
  "Switch to the next user buffer.
User buffers are those whose name does not start with *."
  (interactive)
  (next-buffer)
  (let ((i 0))
    (while (and (string-match "^*" (buffer-name)) (< i 50))
      (setq i (1+ i)) (next-buffer) )))

(defun previous-user-buffer ()
  "Switch to the previous user buffer.
User buffers are those whose name does not start with *."
  (interactive)
  (previous-buffer)
  (let ((i 0))
    (while (and (string-match "^*" (buffer-name)) (< i 50))
      (setq i (1+ i)) (previous-buffer) )))

(defun next-emacs-buffer ()
  "Switch to the next emacs buffer.
Emacs buffers are those whose name starts with *."
  (interactive)
  (next-buffer)
  (let ((i 0))
    (while (and (not (string-match "^*" (buffer-name))) (< i 50))
      (setq i (1+ i)) (next-buffer) )))

(defun previous-emacs-buffer ()
  "Switch to the previous emacs buffer.
Emacs buffers are those whose name starts with *."
  (interactive)
  (previous-buffer)
  (let ((i 0))
    (while (and (not (string-match "^*" (buffer-name))) (< i 50))
      (setq i (1+ i)) (previous-buffer) )))


(defun switch-to-previous-buffer ()
  "Switch to previously open buffer.
Repeated invocations toggle between the two most recently open buffers."
  (interactive)
  (switch-to-buffer (other-buffer (current-buffer) 1)))


#+END_SRC
*** save current file and close window
    :PROPERTIES:
    :ID:       88fb1240-0cfd-4b70-a8d3-ded6c538cade
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z-save-buffer-close-window ()
  "DOCSTRING"
  (interactive)
    (save-buffer)
    (kill-this-buffer)
  )
#+END_SRC
*** move to other window and close current
    :PROPERTIES:
    :ID:       64579783-854a-4e91-b29e-f117b5b8e07a
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/buffer-close-andmove-other   ()
     (interactive)    
     (save-buffer)        
      (delete-window)
)
#+END_SRC
*** pre defined buffers (workspaces)
    :PROPERTIES:
    :ID:       e927cf08-1d65-4521-8166-ecffab77b770
    :END:
**** references
     :PROPERTIES:
     :ID:       f92e83de-ee60-402f-a1db-9dedd29303d0
     :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/buffers-restore-refwork   ()
     (interactive)    
     (find-file "/home/zeltak/org/files/Uni/papers/paper.meta.org")
     (split-window-right)
     (find-file "/home/zeltak/org/files/Uni/papers/zeltak.papers.bib")
     (split-window-below)
     (find-file "/home/zeltak/org/files/help/workflows.org")
     )
#+END_SRC
**** TODO Agenda split
     :PROPERTIES:
     :ID:       b8969b3e-17d5-4913-95d1-1e68ec8550a8
     :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/buffers-restore-agenda-split   ()
  (interactive)
  (let ((org-agenda-sticky t))
    (org-agenda nil "ba")
    (split-window-right)
    (org-agenda nil "a")
    ))
#+END_SRC

*** toggle window splits
    :PROPERTIES:
    :ID:       c50b98fa-54ea-4c92-ae22-8f8fff47407e
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/toggle-window-split ()
  (interactive)
  (if (= (count-windows) 2)
      (let* ((this-win-buffer (window-buffer))
             (next-win-buffer (window-buffer (next-window)))
             (this-win-edges (window-edges (selected-window)))
             (next-win-edges (window-edges (next-window)))
             (this-win-2nd (not (and (<= (car this-win-edges)
                                         (car next-win-edges))
                                     (<= (cadr this-win-edges)
                                         (cadr next-win-edges)))))
             (splitter
              (if (= (car this-win-edges)
                     (car (window-edges (next-window))))
                  'split-window-horizontally
                'split-window-vertically)))
        (delete-other-windows)
        (let ((first-win (selected-window)))
          (funcall splitter)
          (if this-win-2nd (other-window 1))
          (set-window-buffer (selected-window) this-win-buffer)
          (set-window-buffer (next-window) next-win-buffer)
          (select-window first-win)
          (if this-win-2nd (other-window 1))))))
#+END_SRC
*** Delete current file
    :PROPERTIES:
    :ID:       520464c4-41a5-47d0-b9f3-83808246aaa0
    :END:
mainly used when viewing images in dired image
#+BEGIN_SRC emacs-lisp  :results none
(defun z/delete-current-file ()
  "Delete the file associated with the current buffer and close the buffer.
Also push file content to `kill-ring'.
If buffer is not file, just close it, and push file content to `kill-ring'.

URL `http://ergoemacs.org/emacs/elisp_delete-current-file.html'
Version 2015-08-12"
  (interactive)
  (progn
    (kill-new (buffer-string))
    (when (buffer-file-name)
      (when (file-exists-p (buffer-file-name))
        (progn
          (delete-file (buffer-file-name))
          (message "Deleted: 「%s」." (buffer-file-name)))))
    (let ((buffer-offer-save nil))
      (set-buffer-modified-p nil)
      (kill-buffer (current-buffer)))))
#+END_SRC
*** transpose-buffers
    :PROPERTIES:
    :ID:       c8d8ecae-a49a-4f8f-b0cc-e1d0f18de8c2
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/transpose-buffers (arg)
  "Transpose the buffers shown in two windows."
  (interactive "p")
  (let ((selector (if (>= arg 0) 'next-window 'previous-window)))
    (while (/= arg 0)
      (let ((this-win (window-buffer))
            (next-win (window-buffer (funcall selector))))
        (set-window-buffer (selected-window) next-win)
        (set-window-buffer (funcall selector) this-win)
        (select-window (funcall selector)))
      (setq arg (if (plusp arg) (1- arg) (1+ arg))))))
#+END_SRC
** open a specific dir
   :PROPERTIES:
   :ID:       aef2baea-ba6e-460a-a4e6-1c4f0a457551
   :END:
#+BEGIN_SRC emacs-lisp :results none
(defun ood () (interactive) (dired "/home/zeltak/org"))
#+END_SRC
** General emacs
   :PROPERTIES:
   :ID:       4dd9ac32-e5e9-48a6-9f90-f83409b16316
   :END:
*** create scratch buffer
    :PROPERTIES:
    :ID:       6b8e888d-f416-453c-a8c3-9ea1008ebebd
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun create-scratch-buffer nil
   "create a scratch buffer"
   (interactive)
   (switch-to-buffer (get-buffer-create "*scratch*"))
   (lisp-interaction-mode))  
#+END_SRC
*** describe last comman
    :PROPERTIES:
    :ID:       7351fc1b-9edc-4685-9c8d-633cac94777b
    :END:
http://stackoverflow.com/questions/275842/is-there-a-repeat-last-command-in-emacsd
#+BEGIN_SRC emacs-lisp :results none
(defun describe-last-function() 
  (interactive) 
  (describe-function last-command))
#+END_SRC
*** Launch ansi-term
    :PROPERTIES:
    :ID:       383f9aa9-b7e5-4d2b-b29d-92d79a2b4bbf
    :END:
#+BEGIN_SRC emacs-lisp :results none
;; taken from here: http://www.enigmacurry.com/2008/12/26/emacs-ansi-term-tricks/
(defun z/launch--ansi-term ()
  "If the current buffer is:
     1) a running ansi-term named *ansi-term*, rename it.
     2) a stopped ansi-term, kill it and create a new one.
     3) a non ansi-term, go to an already running ansi-term
        or start a new one while killing a defunt one"
  (interactive)
  (let ((is-term (string= "term-mode" major-mode))
        (is-running (term-check-proc (buffer-name)))
        (term-cmd "/bin/zsh")
        (anon-term (get-buffer "*ansi-term*")))
    (if is-term
        (if is-running
            (if (string= "*ansi-term*" (buffer-name))
                ;; (call-interactively 'rename-buffer)
                (ansi-term term-cmd)
              (if anon-term
                  (switch-to-buffer "*ansi-term*")
                (ansi-term term-cmd)))
          (kill-buffer (buffer-name))
          (ansi-term term-cmd))
      (if anon-term
          (if (term-check-proc "*ansi-term*")
              (switch-to-buffer "*ansi-term*")
            (kill-buffer "*ansi-term*")
            (ansi-term term-cmd))
        (ansi-term term-cmd)))))
#+END_SRC
** saving 
*** increment file num when saving
http://emacs.stackexchange.com/questions/27853/increment-file-name-and-create-a-new-version-of-the-file/27855?noredirect=1#comment42642_27855
#+BEGIN_SRC emacs-lisp  :results none
(defun z/increment-number-in-file-name (name)
  (with-temp-buffer
    (insert name)
    (search-backward "." nil t)
    (re-search-backward "[0-9]+" nil t)
    ;(skip-chars-forward "0") ;; Would preserve 0s
    (if (looking-at "[0123456789]+")
        (replace-match (number-to-string (1+ (string-to-number (match-string 0)))))
      (insert "-1"))
    (buffer-string)))

(defun z/write-file-increment ()
  (interactive)
  (write-file (z/increment-number-in-file-name (buffer-file-name))))
#+END_SRC
** toggles 
   :PROPERTIES:
   :ID:       f3576a7d-ab65-46f1-85e8-a6bc4c43da17
   :END:
*** auto narrow/widen
    :PROPERTIES:
    :ID:       77cbaab2-dd7f-445d-be9f-4e4d3975f141
    :END:

#+BEGIN_SRC emacs-lisp :results none
(defun z/narrow-or-widen-dwim ()
"If the buffer is narrowed, it widens. Otherwise, it narrows to region, or Org subtree."
(interactive)
(cond ((buffer-narrowed-p) (widen))
((region-active-p) (narrow-to-region (region-beginning) (region-end)))
((equal major-mode 'org-mode) (org-narrow-to-subtree))
(t (error "Please select a region to narrow to"))))
#+END_SRC

** outside Emacs
   :PROPERTIES:
   :ID:       ef956f1c-602e-4bb8-9286-95d1fd72e3b6
   :END:
*** search google
    :PROPERTIES:
    :ID:       30eff775-6e57-4808-b092-6e9144ff1f16
    :END:
#+BEGIN_SRC emacs-lisp :results none
(require 'thingatpt)

(defun google-search ()
 "If selected region, or thing at point, is a url, go there. Otherwise,
use region/thing as a keyword for a google search."
  (interactive)
  (let ((target
         (if (use-region-p)
             (buffer-substring (region-beginning) (region-end))
           (thing-at-point 'symbol))))
    (if (ffap-url-p target)
        (browse-url target)
      (browse-url (concat "http://www.google.com/search?q="
                          (url-hexify-string target))))))
#+END_SRC
** hooks
   :PROPERTIES:
   :ID:       7cf7419d-c7b1-47a0-bb80-5b0f2d7bcf20
   :END:
*** hooks per file
    :PROPERTIES:
    :ID:       9bad9dc2-b903-423e-9d4d-9a64947e2cad
    :END:
**** tangle a specific file when saved (dotfiles.org)
     :PROPERTIES:
     :ID:       cfcb8382-42b4-42f6-9d14-0c842b43946b
     :END:
http://emacs.stackexchange.com/questions/20707/automatically-tangle-org-files-in-a-specific-directory
#+BEGIN_SRC emacs-lisp  :results none
;(defun my/tangle-dotfiles ()
;  "If the current file is in '~/.dotfiles', the code blocks are tangled"
;  (when (equal (buffer-file-name)
;               (expand-file-name "/home/zeltak/org/files/dotfiles/dotfiles.org"))
;    (org-babel-tangle)
;    (message "Dotfile tangled")))

;(add-hook 'after-save-hook #'my/tangle-dotfiles)
#+END_SRC
***** tangle a whole folder when saved example
      :PROPERTIES:
      :ID:       956c33cf-e34f-45bb-9331-e2548a245967
      :END:
 #+BEGIN_EXAMPLE
 (defun my/tangle-dotfiles ()
   "If the current file is in '~/.dotfiles', the code blocks are tangled"
   (when (equal (file-name-directory (directory-file-name buffer-file-name))
		(concat (getenv "HOME") "/.dotfiles/"))
     (org-babel-tangle)
     (message "%s tangled" buffer-file-name)))

 (add-hook 'after-save-hook #'my/tangle-dotfiles)
 #+END_EXAMPLE
**** auto export to ics when the meeting fie is saved (meetings.org)
     :PROPERTIES:
     :ID:       a52779b8-ddd2-436b-aaa8-539831cfd36f
     :END:
https://mail.google.com/mail/u/0/#inbox

currently broken 
#+BEGIN_SRC emacs-lisp  :results none
  ;; (defun z/save-meeting-to-ics ()
  ;;   "save to ICS"
  ;;   (when (equal (buffer-file-name)
  ;;     "/home/zeltak/org/files/agenda/meetings.org")
  ;;     (z/export-to-ics)
  ;; )

;(defun z/export-to-ics ()
;(interactive)
;(rename-file (org-icalendar-export-to-ics)
;"/home/zeltak/org/files/export/kcal.ics")
;(message "exported to ics"))

  ;; )

  ;; (run-with-timer 0 (* 30 60) 'z/export-to-ics)

  ;; (add-hook 'after-save-hook #'z/save-meeting-to-ics)

#+END_SRC
**** tangle a whole folder when saved example
     :PROPERTIES:
     :ID:       fbf01c4d-6f6e-4153-878a-a68aea9f9d97
     :END:
#+BEGIN_EXAMPLE
(defun my/tangle-dotfiles ()
  "If the current file is in '~/.dotfiles', the code blocks are tangled"
  (when (equal (file-name-directory (directory-file-name buffer-file-name))
	       (concat (getenv "HOME") "/.dotfiles/"))
    (org-babel-tangle)
    (message "%s tangled" buffer-file-name)))

(add-hook 'after-save-hook #'my/tangle-dotfiles)
#+END_EXAMPLE
** helm functions 
   :PROPERTIES:
   :ID:       0faf6fd0-d2d3-4f80-8370-7a2330e6e7d5
   :END:
*** swish-e
    :PROPERTIES:
    :ID:       abb5e82b-e242-4f8a-9e35-31dc5d858197
    :END:

#+BEGIN_SRC emacs-lisp :results none
(defun helm-swish-e-candidates (query)
  "Generate a list of cons cells (swish-e result . path)."
  (let* ((result (shell-command-to-string
		  (format "swish-e -f ~/.swish-e/index.swish-e -x \"%%r\t%%p\n\" -w %s"
			  (shell-quote-argument query))))
	 (lines (s-split "\n" result t))
	 (candidates '()))
    (loop for line in lines
	  unless (or  (s-starts-with? "#" line)
		      (s-starts-with? "." line))
	  collect (cons line (cdr (s-split "\t" line))))))


(defun helm-swish-e (query)
  "Run a swish-e query and provide helm selection buffer of the results."
  (interactive "sQuery: ")
  (helm :sources `(((name . ,(format "swish-e: %s" query))
		    (candidates . ,(helm-swish-e-candidates query))
		    (action . (("open" . (lambda (f)
					   (find-file (car f)))))))
		   ((name . "New search")
		    (dummy)
		    (action . (("search" . (lambda (f)
					     (helm-swish-e helm-pattern)))))))))
#+END_SRC

*** helm hotspot menu
    :PROPERTIES:
    :ID:       5483e352-1184-4e25-a1b3-cea1066082d7
    :END:

#+BEGIN_SRC emacs-lisp :results none
(defun hotspots ()
  "helm interface to my hotspots, which includes my locations,
org-files and bookmarks"
  (interactive)
  (helm :sources `(((name . "Mail and News")
                    (candidates . (("Mail" . (lambda ()
                                               (if (get-buffer "*mu4e-headers*")
                                                   (progn
                                                     (switch-to-buffer "*mu4e-headers*")
                                                     (delete-other-windows))

                                                 (mu4e))))
                                   ("Calendar" . (lambda ()  (browse-url "https://www.google.com/calendar/render")))
                                   ("RSS" . elfeed)
                                   ("Agenda" . (lambda () (org-agenda "" "w")))))
                    (action . (("Open" . (lambda (x) (funcall x))))))
                   ((name . "My Locations")
                    (candidates . (("master" . "~/org/files/")
                                   (".emacs.d" . "~/.emacs.d/" )
                                   ("todo" . "~/org/files/agenda/todo.org")))
                    (action . (("Open" . (lambda (x) (find-file x))))))

                   ((name . "My org files")
                    (candidates . ,(f-entries "~/org/files/"))
                    (action . (("Open" . (lambda (x) (find-file x))))))
                   helm-source-recentf
                   helm-source-bookmarks
                   helm-source-bookmark-set)))
#+END_SRC
*** helm-ag-prefix
    :PROPERTIES:
    :ID:       3ade384f-c1e7-41b6-bdec-13ca5734b4a0
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/helm-mg-prefix  ()
                     (interactive)                                
                     (let ((current-prefix-arg '(4)))             
                       (call-interactively #'helm-ag)))
#+END_SRC
** ivy
   :PROPERTIES:
   :ID:       dba62577-fdf6-4e6d-b14c-972119e099dc
   :END:
*** ivy-sudo-edit-action
    :PROPERTIES:
    :ID:       cdd83aa9-c2cf-49c8-b26e-74a55d4bb70b
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun ivy-sudo-edit-action (file-name)
      (with-ivy-window
        (find-file (expand-file-name
                    (concat "/sudo:root@localhost:" file-name)
                    ivy--directory))))
#+END_SRC


*** counsel-ag prompt for dir
    :PROPERTIES:
    :ID:       3c49aed8-6516-4da4-957c-02c6f9e7ac19
    :END:
#+BEGIN_SRC emacs-lisp  :results none
;; custom ag command to always prompt for a dir
(defun z/counsel-ag-prompt-dir (&optional initial-input initial-directory)
  "Grep for a string in the current directory using ag.
INITIAL-INPUT can be given as the initial minibuffer input."
  (interactive
   (list nil
         (when t
           (read-directory-name (concat
                                 (car (split-string counsel-ag-base-command))
                                 " in directory: ")))))
  (setq counsel--git-grep-dir (or initial-directory default-directory))
  (ivy-read (funcall counsel-prompt-function
                     (car (split-string counsel-ag-base-command)))
            'counsel-ag-function
            :initial-input initial-input
            :dynamic-collection t
            :history 'counsel-git-grep-history
            :action #'counsel-git-grep-action
            :unwind (lambda ()
                      (counsel-delete-process)
                      (swiper--cleanup))
            :caller 'counsel-ag))
#+END_SRC
** isearch
   :PROPERTIES:
   :ID:       55696153-2a7d-4fd1-9dfa-0385d1ecebd4
   :END:
*** delete non matching 
    :PROPERTIES:
    :ID:       49ca2ae6-ada5-40be-8037-a9bfb64a734b
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun isearch-delete-something ()
  "Delete non-matching text or the last character."
  ;; Mostly copied from `isearch-del-char' and Drew's answer on the page above
  (interactive)
  (if (= 0 (length isearch-string))
      (ding)
    (setq isearch-string
          (substring isearch-string
                     0
                     (or (isearch-fail-pos) (1- (length isearch-string)))))
    (setq isearch-message
          (mapconcat #'isearch-text-char-description isearch-string "")))
  (if isearch-other-end (goto-char isearch-other-end))
  (isearch-search)
  (isearch-push-state)
  (isearch-update))

(define-key isearch-mode-map (kbd "<backspace>") 
  #'isearch-delete-something)
#+END_SRC
*** isearch occurrence at point 
    :PROPERTIES:
    :ID:       0aa0a0cb-7185-44ed-99c4-a703ae980414
    :END:

http://endlessparentheses.com/quickly-search-for-occurrences-of-the-symbol-at-point.html

#+BEGIN_SRC emacs-lisp  :results none
(defun endless/isearch-symbol-with-prefix (p)
  "Like isearch, unless prefix argument is provided.
With a prefix argument P, isearch for the symbol at point."
  (interactive "P")
  (let ((current-prefix-arg nil))
    (call-interactively
     (if p #'isearch-forward-symbol-at-point
       #'isearch-forward))))

(global-set-key [remap isearch-forward]
                #'endless/isearch-symbol-with-prefix)
#+END_SRC
** mail
   :PROPERTIES:
   :ID:       39fa395a-5d69-4636-a3ab-203966c0f37f
   :END:
*** yas mail functions
    :PROPERTIES:
    :ID:       fa783c8e-1945-42dc-93b6-4794cfd57648
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun my-yas-get-first-name-from-to-field ()
  (let ((rlt "AGENT_NAME") str)
    (save-excursion
      (goto-char (point-min))
      ;; first line in email could be some hidden line containing NO to field
      (setq str (buffer-substring-no-properties (point-min) (point-max))))
    (if (string-match "^To: \"\\([^ ,]+\\)" str)
        (setq rlt (match-string 1 str)))
    (message "rlt=%s" rlt)
    rlt))
#+END_SRC
** TRAMP functions
   :PROPERTIES:
   :ID:       c894cb5c-4db8-42a0-8285-bcbca329c882
   :END:
*** dired connect uni
    :PROPERTIES:
    :ID:       205ed76e-63b0-4ba0-9b35-9ea839e84074
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/tramp-connect-uni-dired ()
  (interactive)
  (dired "/zeltak@132.72.155.204:/"))
#+END_SRC
** projectile
   :PROPERTIES:
   :ID:       a8d31985-4c01-4ce2-8986-945af198ee4a
   :END:
#+BEGIN_SRC emacs-lisp  :results none
  ;; (defun projectile-find-file-in-project-org ()
  ;; (interactive)                                
  ;; (let ((default-directory "/home/zeltak/org/files/"))
  ;; (projectile-find-file)))

  ;; ;;(global-set-key (kbd "M-C-w") 'projectile-find-file-in-project-org)

#+END_SRC



* keys 
** 1-unbind keys
   :PROPERTIES:
   :ID:       324a5211-3dc6-44a5-a625-20242cb158cd
   :END:
#+BEGIN_SRC emacs-lisp :results none
(global-unset-key (kbd "<f1>"))
(global-unset-key (kbd "<f2>"))
(global-unset-key (kbd "<f3>"))
(global-unset-key (kbd "<f4>"))
(global-unset-key (kbd "<f5>"))
(global-unset-key (kbd "<f6>"))
(global-unset-key (kbd "<f7>"))
(global-unset-key (kbd "<f8>"))
(global-unset-key (kbd "<f9>"))
(global-unset-key (kbd "<f10>"))
(global-unset-key (kbd "<f11>"))
(global-unset-key (kbd "<f12>"))
(global-unset-key (kbd "C-v"))
(global-unset-key (kbd "C-z"))
(global-unset-key (kbd "C-M-p"))
(global-unset-key (kbd "C-M-e"))
(global-unset-key (kbd "C-M-b"))
(global-unset-key (kbd "C-M-b"))
(global-unset-key (kbd "C-M-t"))
(global-unset-key (kbd "M-2"))
(global-unset-key (kbd "M-1"))
(global-unset-key (kbd "\\"))
#+END_SRC

** general.el

 #+BEGIN_SRC emacs-lisp :results none
(use-package general
 :ensure t
 :config

;;;; in insert state use emacs bindings 
(setq evil-disable-insert-state-bindings t) 
(general-evil-setup t)

)
  #+END_SRC 
*** Most used keys 
#+BEGIN_SRC emacs-lisp  :results none
;;; normal keys 
(general-define-key

"M-x" 'counsel-M-x
"C-x C-f" 'counsel-find-file
"C-c y" 'yankpad-map
)
#+END_SRC
*** org mode 
#+BEGIN_SRC emacs-lisp  :results none
  (general-define-key
  ;;;org mode 
  "\C-ca" 'org-agenda
  "C-c c" 'org-capture
  "\C-cs" 'org-babel-execute-subtree
  "\C-cl" 'org-store-link
  "\C-cb" 'org-iswitchb
  "C-c x" 'org-babel-execute-subtree
  )
#+END_SRC
*** movment 
#+BEGIN_SRC emacs-lisp  :results none
(general-define-key
"C-<up>" 'windmove-up     
"C-<down>" 'windmove-down
"C-<right>" 'windmove-right
"C-<left>" 'windmove-left
"C-TAB" 'switch-to-previous-buffer
"M-1" 'ace-window
)
#+END_SRC
*** prefix keys 
#+BEGIN_SRC emacs-lisp  :results none
;; set lead keys 
(setq leadCc "C-c")
(setq leadCx "C-x")

;;with C-x prefix 
(general-define-key :prefix leadCx
"s" 'save-buffer
"c" 'z-save-buffer-close-window
"a" 'write-file
)

#+END_SRC

*** space key 
I can access those functions with SPC in normal and visual state, and M-SPC in emacs and insert state. The :which-key keyword allow me to describe the role of prefixes like SPC f, attached to file related functions.

 #+BEGIN_SRC emacs-lisp  :results none
 (general-define-key
  :states '(normal visual insert emacs)
  :prefix "SPC"
  :non-normal-prefix "M-SPC"
  "/" '(counsel-ag :wich-key "ag")
   "TAB" '(switch-to-previous-buffer :which-key "prev buffer")
   "." '(avy-goto-word-or-subword-1  :which-key "go to word")
   "SPC" '(counsel-M-x :which-key "M-x")
   "c" '(:ignore t :which-key "Comment menu")
   "cl" '(comment-or-uncomment-region-or-line :which-key "comment line")
   )
 #+END_SRC
*** omap 
I press d in normal mode (evil-delete), then SPC and l to delete from here to the line selected with avy, then t to select the target line. This is awesome. It’s a great wrapper around evil-define-motion-like definitions. Plus I don’t have to use a prefix, I can just bind l to evil-avy-goto-line in operator state.

 #+BEGIN_SRC emacs-lisp  :results none
 (general-omap
  :prefix "SPC"
   "." 'avy-goto-word-or-subword-1
   "l" 'evil-avy-goto-line
   "e" 'evil-avy-goto-subword-0 )

 #+END_SRC

*** general-nvmap

I remap the M- map functions in normal state, since I usually need them only in insert mode. They does not conflict with Evil keybindings, since Vim has no Meta key. The general-nvmap defines keybindings for the normal and visual state only. The general-simulate-keys allows me to press ' instead of C-c. So commonly defined prefixes are accessible using two key strokes.

 #+BEGIN_SRC emacs-lisp  :results none
   ;; (general-nvmap
   ;;  "'" (general-simulate-keys "C-c")
   ;;  "M-'" 'evil-goto-mark
   ;;  "M-b" 'ivy-switch-buffer
   ;;  ;; ...
   ;;  )
 #+END_SRC
** key-seq
   :PROPERTIES:
   :ID:       4ba922af-59b4-4b16-9341-0c7cf7c4265b
   :END:

 #+BEGIN_SRC emacs-lisp :results none
 (use-package key-seq
 :ensure t
 :config
;;; EVIL insert mode

(key-seq-define evil-insert-state-map "jj" #'avy-goto-char-timer)
;(key-seq-define evil-insert-state-map "jj" #'avy-goto-word-or-subword-1)
(key-seq-define evil-insert-state-map "jl" #'avy-goto-line)
(key-seq-define evil-insert-state-map "qq" #'switch-to-previous-buffer)
(key-seq-define evil-insert-state-map "cc" #'org-capture)
(key-seq-define evil-insert-state-map "0o" #'hydra-org/body)

;;;; EVIL normal mode
(key-seq-define evil-normal-state-map "jj" #'avy-goto-char-timer)
(key-seq-define evil-normal-state-map "jl" #'avy-goto-line)
(key-seq-define evil-normal-state-map "qq" #'switch-to-previous-buffer)
(key-seq-define evil-normal-state-map "cc" #'org-capture)
(key-seq-define evil-normal-state-map "0o" #'hydra-org/body)

 )
 #+END_SRC 
** key-chord
   :PROPERTIES:
   :ID:       e6089f89-c3dc-4a07-8190-a6731c28681e
   :END:
 http://blog.jenkster.com/2013/02/mapping-jk-in-emacs-evil-mode.html
   #+BEGIN_SRC emacs-lisp :results none
(use-package key-chord 
   :ensure t
   :config
(key-chord-mode 1)
(setq key-chord-two-keys-delay 0.09)
(setq key-chord-one-key-delay 0.20)
 
;;;;keys
(key-chord-define evil-insert-state-map  "jk" 'evil-normal-state)

 )
 #+END_SRC
 


* hydras
  :PROPERTIES:
  :ID:       e240cc34-4260-4f99-9dce-e34a77c7fa8a
  :END:
*** hydra evil leader-space (SPC)
    :PROPERTIES:
    :ID:       5e8fc9eb-e993-469f-806d-61091ad2421e
    :END:
may consider in the future to bind the leader to c-z which is free 
 #+BEGIN_SRC emacs-lisp :results none
   ;; (global-set-key
   ;;     (kbd "")
   ;;  (defhydra hydra-leader-space  (:color blue :hint nil :columns 4)
   ;;  "
   ;;  "


   ;; ("?" z/counsel-hydra-heads "ivy switch buffer")
   ;; ("SPC"  avy-goto-char-timer  "avy jump")


   ;; ))
 #+END_SRC
*** hydra faces
    :PROPERTIES:
    :ID:       68f43c48-8310-4587-a0e5-2b2b2a667a5e
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defface hydra-face-red
    '((t (:foreground "red" :bold t))) "red")


(defface hydra-face-orange
    '((t (:foreground "orange" :bold t)))"Orange")


(defface hydra-face-brown
    '((t (:foreground "#C15F0D" :bold t))) "brown")


(defface hydra-face-cyan
    '((t (:foreground "#42B7DE" :bold t :underline t))) "cyan")

(defface hydra-face-green
    '((t (:foreground "green" :bold t))) "green")


(defface hydra-face-purple
    '((t (:foreground "#D52BFF" :bold t))) "")


(defface hydra-face-grey
    '((t (:foreground "#Bebebe" :bold t)))"")


(defface hydra-face-sky
    '((t (:foreground "#00bfff" :bold t)))"")


(defface hydra-face-salmon
    '((t (:foreground "#Fa8072" :bold t)))"")


(defface hydra-face-torq
    '((t (:foreground "#40e0d0" :bold t)))"")


(defface hydra-face-darkred
    '((t (:foreground "#8b0000" :bold t)))"")

(defface hydra-face-yellow
    '((t (:foreground "yellow" :bold t)))"")

(defface hydra-face-forestgreen
    '((t (:foreground "#228b22" :bold t)))"")

(defface hydra-face-fade
    '((t (:foreground "#FFECEC" :bold t)))"")

#+END_SRC

*** hydra leader (\)
    :PROPERTIES:
    :ID:       b1bd78ae-83b5-4cb4-a4b5-6db5287f3956
    :END:
may consider in the future to bind the leader to c-z which is free 
 #+BEGIN_SRC emacs-lisp :results none
   (global-set-key
       (kbd "\\")
    (defhydra hydra-leader  (:color blue :hint nil :columns 4)
"
LEADER:【C-A-W】-append to killring helm-projectile-recentf 【C-c p e】

【C-SPACE C-SPACE】 add to markring
"
("\\" helm-mini "helm-mini")
;("\\" ivy-switch-buffer "ivy switch buffer")
("<backspace>" counsel-bookmark "counsel-bookmark")
("]"  hydra-chd-dired/body  "Jump:dired" :face 'hydra-face-purple )
;("\]" avy-goto-char-timer  "avy jump")


("[" z/insert-slsh "insert \\")
("|"   hydra-goto/body "goto" )
("<f3>"  repeat "repeat last command" )
("<down>" drag-stuff-down  "marked down" :color red)
("<up>" drag-stuff-up  "marked up" :color red)
("RET" avy-goto-line "goto line" )
("-"  hydra-org-capture-go/body "org-capture-hydra" )
("="  (org-capture nil "m")  "org-capture-meeting" )
("?" z/counsel-hydra-heads "ivy switch buffer")
("/"  (dired "~/") "dired" )
("?"  dired-jump  "dired current dir" )
("1"   hydra-org-tags/body "tags")
("2"   org-todo "todo dialog")
("4"   duplicate-current-line-or-region-red  "duplicate" :color red )
("5"   duplicate-current-line-or-region  "duplicate" )
("6"   z/copy-comment-paste  "duplicate-comment")
(";"   comment-or-uncomment-region )


("a" (org-agenda nil "a")   "org agenda" )
("b"  hydra-chd-work/body   "Jump:work"  :face 'hydra-face-cyan )
("c"  z/org-move-top-collapse "collapse headers" )
("d" hydra-chd-dired/body "Jump:dired"  :face 'hydra-face-cyan )

("e"  hydra-chd-tech/body   "Jump:Tech"  :face 'hydra-face-cyan )
("f"  helm-org-rifle "org-search (rifle)")
("gt"   helm-top "top")

("h"  hydra-chd-home/body   "Jump:work"  :face 'hydra-face-cyan )

("i"  hydra-editing-insert/body "insert symbol" )
("j"  hydra-copy-paste/body "copy/paste menu" :face 'hydra-face-cyan )
;("k"  helm-show-kill-ring "kill ring")
("k"  counsel-yank-pop "kill ring")
("l"  hydra-org-links/body  "org links")
("m"   multi-term-dedicated-toggle "multiterm toggle")
("M"   z/visit-ansi-term "ansi term")
("n"  clone-indirect-buffer-other-window  "indirect buffer" )
("o"   hydra-leader-extra-org/body  "org menu" :face 'hydra-face-cyan)
("p"   helm-mark-ring "HELM mark ")
("P"   helm-all-mark-rings "HELM mark ALL ")
("r"  iedit-mode  "iedit" )
("s"  hydra-search/body "search hydra" )
("t"   counsel-org-tag "tag dialog")
("u"  hydra-terminal/body  "terminal hydra" )
("v" hydra-org-tangle/body  "tangle"  )
("w" nil )
("x"  z/buffer-close-andmove-other  "close window")
("yu"  hydra-yas/body "yas menu" )
("yy"  yas-insert-snippet "yas insert" )
("z"  org-agenda "agenda-viwes" )
("q" nil "cancel")
   ))
 #+END_SRC

*** Hydra leader extra menus
**** hydra-chd-tech 
the [[id:edae3ee6-0eb7-4d79-beef-cffddc5223ab][jump to org-bookmarks via hydra functions]] function is needed to run the jumps to orgmode bookmarks 
 #+BEGIN_SRC emacs-lisp :results none


(defhydra hydra-chd-tech  (:color blue :hint nil :columns 4)
"Jump to tech bookmark"

("b"  (find-file "/home/zeltak/org/files/dotfiles/bins.org") "o.bin" )
("d"  (find-file "/home/zeltak/org/files/dotfiles/dotfiles.org") "o.dotfiles" )
("s"  (find-file "/home/zeltak/.emacs.d/settings.org")  "e.settings" )
("m"  (bmkp-dired-jump "*Messages*" ) "messages" )
("l"  (find-file "/home/zeltak/org/files/Tech/linux.org") "o.linux" )
("y"  (find-file "/home/zeltak/org/files/help/yankpad.org") "o.yankpad" )
("e"  (lambda ()(interactive) (z/org-bookmark-jump-by-string "o.emacs")) "emacs"  ) 
("o"  (lambda ()(interactive) (z/org-bookmark-jump-by-string "o.org")) "emacs"  ) 
)
 #+END_SRC
**** hydra-chd-work

 #+BEGIN_SRC emacs-lisp :results none
(defhydra hydra-chd-work  (:color blue :hint nil :columns 4)
"Jump to work  bookmark"

("b"  (find-file "/home/zeltak/org/files/agenda/bgu.org") "o.bgu" )
("g"   (find-file  "/home/zeltak/org/files/agenda/bgu.org" ) "o.grants" )
("m"   (find-file "/home/zeltak/org/files/agenda/meetings.org" ) "o.meetings" )
("p"   (find-file "/home/zeltak/org/files/Uni/papers/paper.meta.org" ) "o.paper.meta" )
("r"   (find-file "/home/zeltak/org/files/agenda/research.org" ) "o.research" )
("s"  z/buffers-restore-refwork  "refwork" :face 'hydra-face-cyan)
("w"   (find-file "/home/zeltak/org/files/help/workflows.org" ) "o.workflows" )
)
 #+END_SRC
**** hydra-chd-home 
 #+BEGIN_SRC emacs-lisp :results none
(defhydra hydra-chd-home  (:color blue :hint nil :columns 4)
"Jump to home  bookmark"
("b"   (find-file "/home/zeltak/org/files/web/wbookmarks.org" ) "o.wbookmarks" )
("d"   (find-file "/home/zeltak/org/files/agenda/dl.org" ) "o.download" )
("f"   (find-file "/home/zeltak/org/files/agenda/food.org" ) "o.food" )
("g"   (find-file "/home/zeltak/org/files/agenda/garden.org" ) "o.garden" )
("h"   (find-file "/home/zeltak/org/files/agenda/home.org" ) "o.home" )
("t"   (find-file "/home/zeltak/org/files/agenda/TODO.org" ) "o.todo" )
("u"   (find-file "/home/zeltak/org/files/agenda/travel.org" ) "o.travel" )
)
 #+END_SRC
 
**** dired-chd-dired
     :PROPERTIES:
     :ID:       55cabe92-92c9-4e02-98ea-49aaf6fdfb34
     :END:

 #+BEGIN_SRC emacs-lisp :results none
(defhydra hydra-chd-dired  (:color blue :hint nil :columns 4)

"A Capital letter means open in other window"

("\\" helm-mini "helm-mini")
;("\\" ivy-switch-buffer "ivy switch buffer")
("<backspace>" counsel-bookmark "counsel-bookmark")
("]"  hydra-leader/body  "Jump:dired" :face 'hydra-face-purple )

("<delete>" z/dired-recent-dirs-ivy "recent dirs" )

("a"   (find-file "/home/zeltak/AUR" ) "aur" )
("A"  (find-file-other-window "/home/zeltak/AUR") "aur →" :face 'hydra-face-fade )

("2"   hydra-dired-chd-raid/body  "P2P" )

("3"   (find-file "/home/zeltak/mounts/lraid/raid" ) "raid" )
("#"  (find-file-other-window "/home/zeltak/mounts/lraid/raid") "raid →" )

("b"   (find-file "/home/zeltak/bin" ) "bin" )
("B"  (find-file-other-window "/home/zeltak/bin") "bin →" )

("c"   (find-file "/home/zeltak/.config" ) "config" )
("C"  (find-file-other-window "/home/zeltak/.config") "config →" )

("d"   (find-file "/home/zeltak/Downloads" ) "downloads" )
("D"  (find-file-other-window "/home/zeltak/Downloads") "downloads →" )

("e"   (find-file "/home/zeltak/.emacs.d" ) "emacs.d" )
("E"  (find-file-other-window "/home/zeltak/.emacs.d") "emacs.d →" )

("f"   (find-file "/home/zeltak/hmedia" ) "hmedia" )
("F"  (find-file-other-window "/home/zeltak/hmedia") "hmedia →" )


("g"  nil )

("h"  (find-file "/home/zeltak" ) "home" )
("H"  (find-file-other-window "/home/zeltak") "home →" )



("ic"  (find-file "/home/zeltak/org/files/Uni/Courses") "Org-courses" )
("ia"  (find-file "/home/zeltak/org/attach/") "Org-attach" )


("I"  (find-file "/home/zeltak/Sync/Uni/") "uni-sync" )

("j"  nil )
("J"  nil )

("k"  (find-file "~/BK/") "BK" )
("l"  (find-file "~/MLT/") "MLT")
("m"  (find-file "~/music/") "music" )

("o"   (find-file "/home/zeltak/org" ) "org" )
("O"  (find-file-other-window "/home/zeltak/org") "org →" )

("p"  (find-file "/home/zeltak/Sync/Uni/pdf_lib") "pdf lib" )

("r"  (find-file "~/mreview/") "mreview" )
("R"  (find-file "/home/zeltak/Soulseek Downloads/complete") "soulseekDL" )

("ss"  (find-file "~/Sync/") "Sync" )
("sc"  (find-file "/home/zeltak/Sync/scans/") "scans" )

("S"  (find-file "~/scripts/" "scripts") )
("t"  (find-file "~/mounts/" "mounts") )
("u"  (find-file "~/Uni/") "Uni" )
("v"  (find-file "/home/zeltak/.password-store") "password-store" )
("w"  (find-file "~/dotfiles/") "dotfiles" )

("x"  z/buffer-close-andmove-other  "close window" :face 'hydra-face-red  )

("y"  (find-file "/home/zeltak/org/files/Uni/Projects/code") "code" )

("z"   (find-file "~/ZH_tmp/" ) "ZH_tmp" )
("Z"  (find-file-other-window "~/ZH_tmp/") "ZH_tmp" )

("/"  (find-file "/") "Root")

("q" nil  )

)
#+END_SRC 

***** dired chd raid
      :PROPERTIES:
      :ID:       c8dfbabb-7928-40c3-9bd1-582f3fdae1df
      :END:
 change dir only in dir mode hook?
 #+BEGIN_SRC emacs-lisp :results none
 (global-set-key
    (kbd "")
 (defhydra hydra-dired-chd-raid  (:color blue :hint nil :columns 4)

 "
 "
("2"   (find-file "/home/zeltak/mounts/lraid/Download/transmission/completed" ) "P2P" )
("@"  (find-file-other-window "/home/zeltak/mounts/lraid/Download/transmission/completed") "P2P →" )
("c"  (find-file "/home/zeltak/mounts/lraid/raid/Videos/1_Video/michal") "michal" )
("k"  (find-file "/home/zeltak/mounts/lraid/raid/Videos/1_Video/Kids") "kids" )
("m"  (find-file "/home/zeltak/mounts/lraid/raid/Videos/Movies") "Movies" )
("f"  (find-file "/home/zeltak/mounts/lraid/raid/Music/Freezed Collection") "Freezed music" )
("o"  (dired "/home/zeltak/mounts/lraid/raid/Comics") "comics" )
;;(""  (find-file "") "" )
("t"  (find-file "/home/zeltak/mounts/lraid/raid/Videos/TV") "TV" )
("u"  (find-file "/home/zeltak/mounts/lraid/raid/Videos/Q") "Query" )
("q" nil  )

 ))

 #+END_SRC

***** dired chd NAS
      :PROPERTIES:
      :ID:       c8c50d22-3ea1-45e8-b8a7-68e288e804fc
      :END:
 change dir only in dir mode hook?
 #+BEGIN_SRC emacs-lisp :results none
 (global-set-key
    (kbd "")
 (defhydra hydra-dired-chd-remote  (:color blue :hint nil :columns 4)

 "
 "
 ("n " (find-file "/media/NAS/Uni/") "NAS home" )
 ("p" (find-file "/media/NAS/Uni/Projects/") "NAS home" )
 ("d " (find-file "/media/NAS/Uni/data/") "NAS home" )
 ("u" z/tramp-connect-uni-dired "zuni-ssh" )

 ("q" nil  )

 ))

 #+END_SRC




**** hydra-leader-extra-org
  #+BEGIN_SRC emacs-lisp :results none
 (defhydra hydra-leader-extra-org  (:color blue :hint nil :columns 4)
 "Extra org commands"
("5" z/org-clone-subtree  "clone header with new org-id " )
(";" z/org-cblock-comment  "line to checkbox" )
("c" org-set-line-checkbox  "line to checkbox" )
("d" org-cut-subtree  "org cut" )
("e" z/org-email-heading  "email header" )
("f" fill-paragraph  "fill paragraph" )
("F" fill-region  "fill region" )
("h" org-set-line-headline "line to headline" )
("i" iedit-mode "edit current@point" )
("m" org-teleport  "teleport header " )
("o" worf-goto  "search headers " )
("p" org-paste-subtree  "org paste" )
("r" org-copy  "copy via refile" )
("s" org-clone-subtree-with-time-shift  "add a time series for headers" )
("t" org-insert-todo-heading-respect-content "insert TODO" )
("v" org-copy-visible "copy visible/headers " )
("w" worf-mode "Worf mode" )
("y" org-copy-subtree "org copy" )
("z" z/org-email-heading-me  "email header X" )
("<up>" org-move-subtree-up "header up" :color red )
("<down>" org-move-subtree-down "header down" :color red)
("."  org-do-demote "<" :color red)
(","  org-do-promote ">" :color red)

 )
  #+END_SRC
**** hydra-insert 
     :PROPERTIES:
     :ID:       0cf53572-68a6-4409-8318-092e512b64c1
     :END:
add the org faces macros here (%Tip%, $Note$ etc)

#+BEGIN_SRC emacs-lisp :results none
(defhydra hydra-editing-insert  (:color blue  :columns 4 :hints nil)
  "unicode"
  ("a"     helm-awesome  "helm-awesome") 
  ("b"     z/insert-bashscript  "insert basg #!") 
  ("c"     z/insert-black-lenticular-angle  "»") 
  ("C"     helm-unicode  "insert Unicode menu") 
  ("d"     z/insert-black-lenticular-angle-bold  "❱") 
  ("e"     z/insert-black-arrows  "◀ ▶") 
  ("f"     z/insert-black-hands  "☚ ☛") 
  ("g"     z/insert-black-lenticular-bracket-white  "〖") 
  ("h"     hydra-insert-colors/body  "hydra color ") 
  ("i"     yankpad-insert  "yankpad insert") 
  ("o"     yankpad-expand  "yankpad expapnd") 
  ("j"     z/insert-black-lenticular-angle  "«»") 
  ("k"     z/insert-black-lenticular-bracket  "【】") 
  ("m"    char-menu "insert symbol" )
  ("u"     yankpad-set-category  "yankpad change") 
  ("U"     yankpad-edit  "edit yankpad") 
  ("p"     z/insert-play  " ‣") 
  ("w"     z/insert-white-arrow  "▻") 
  ("r"    z/insert-reveal-split  "reveal-split") 
  ("z"     z/insert-EOL  " \\") 
  ("q" nil "cancel" nil)
)
#+END_SRC
***** hydra-insert-colors
      :PROPERTIES:
      :ID:       37250ea8-3653-40ba-a356-5bae8a960f14
      :END:
 #+BEGIN_SRC emacs-lisp  :results none
 (defhydra  hydra-insert-colors  (:color blue  :columns 4 :hints nil)
   "unicode"
   ("r"    z/insert-hydra-color-red  "red" :face 'hydra-face-red ) 
   ("o"    z/insert-hydra-color-orange  "orange" :face 'hydra-face-orange ) 
   ("b"    z/insert-hydra-color-brown  "brown" :face 'hydra-face-brown ) 
   ("c"    z/insert-hydra-color-cyan  "cyan" :face 'hydra-face-cyan ) 
   ("g"    z/insert-hydra-color-green  "green" :face 'hydra-face-green ) 
   ("p"    z/insert-hydra-color-purple  "purple" :face 'hydra-face-purple ) 
   ("e"    z/insert-hydra-color-grey  "grey" :face 'hydra-face-grey ) 
   ("s"    z/insert-hydra-color-sky  "sky" :face 'hydra-face-sky ) 
   ("m"    z/insert-hydra-color-salmon  "salmon" :face 'hydra-face-salmon ) 
   ("t"    z/insert-hydra-color-torq  "torq" :face 'hydra-face-torq ) 
   ("d"    z/insert-hydra-color-darkred  "darkred" :face 'hydra-face-darkred ) 
   ("f"    z/insert-hydra-color-forestgreen  "forestgreen" :face 'hydra-face-forestgreen ) 
   ("y"    z/insert-hydra-color-yellow  "yellow" :face 'hydra-face-yellow ) 
   ("q" nil "cancel" nil)
 )
 #+END_SRC




**** hydra-copy-paste/body 
     :PROPERTIES:
     :ID:       bdc905aa-2af6-4a34-b97c-7c9f0f9df313
     :END:
#+BEGIN_SRC emacs-lisp :results none
(defhydra hydra-copy-paste  (:color blue  :columns 4 :hints nil)
  "copy paste operations"
  ("c" copy-to-register  "copy to register") 
  ("p" insert-register  "paste from register") 
  ("v" view-register  "view register") 
  ("q" nil "cancel" nil)
)
#+END_SRC
**** hydra-terminal/body 
     :PROPERTIES:
     :ID:       f8df8c93-e4db-4d00-85f8-e374747dffc2
     :END:
#+BEGIN_SRC emacs-lisp :results none
(defhydra hydra-terminal  (:color blue  :columns 4 :hints nil)
  "term  operations"
  ("u" better-shell-remote-open  "open remote shell") 
  ("q" nil "cancel" nil)
)
#+END_SRC
**** hydra-org-tangle (hydra-org-tangle)
     :PROPERTIES:
     :ID:       4c281eef-07d2-47e9-bb1a-be2953201c01
     :END:

#+BEGIN_SRC emacs-lisp :results none
(global-set-key
   (kbd "")
(defhydra hydra-org-tangle  (:color blue :hint nil)

"
"

("a" nil )
("b"  org-babel-tangle "tangle ENTIRE file")
("c"  org-babel-execute-subtree "exe block")
("d"  org-babel-demarcate-block  "demarcate-block (paste as code block)" )
("e"  nil )
("f" z/org-tangle-at-block "tangle under header and sub headers" )
("g"  nil )
("h"  nil )
("i"  nil )
("j"  nil )
("k"  nil )
("l"  nil )
("m"  nil )
("n"  z/org-babel-edit-next "next code block" :color red)
("p"  z/org-babel-edit-previous "prev code block" :color red)
("o"  z/org-tangle-atpoint )
("r"  nil )
("s"  nil )
("t"  nil)
("u"  nil )
("v"  z/org-tangle-atpoint "tangle current")
("w"  nil )
("x"  nil )
("y"  nil )
("z"  nil )
("q"  nil )

))


#+END_SRC




*** Emacs//toggles (f1)
    :PROPERTIES:
    :ID:       6cd7ad86-0abe-426d-83dd-7ca86628f0d3
    :END:
**** main toggles 
     :PROPERTIES:
     :ID:       9cbe2715-36c1-46c2-91ea-328a44b889f2
     :END:
#+BEGIN_SRC emacs-lisp :results none
(global-set-key
   (kbd "<f1>")
(defhydra hydra-toggles (:color blue  :columns 6)
"Toggles:   【M-g M-g】 goto line 【C-x SPACE】 start mark rectangle 
easy-kill: 【M-w w】 select word // w, +- , 1..9 to increment (0 to reset)//【C-space】 turn selection to region// 【M-3】easy-mark
Term: 【C-c C-j】-activate Emacs mode 【C-c C-k】 back to normal term mode 
*calc* use 【C-enter】to copy results to clip and 【=】to print answer
【C-x (】  start defining a keyboard macro
【C-x )】  stop defining the keyboard macro
【C-x e】  execute the keyboard macro

"
("8" calculator "calc"  )
("a" pandoc-mode "pandoc"  )
("b" bug-hunter-file "bug hunter" :face 'hydra-face-orange )
("c" cua-mode "cua" :face 'hydra-face-red )
("d" tool-bar-mode "toggle toolbar"   )
("e" evil-mode "evil")
("f" fci-mode "fci" )
("g" google-search "google")
("h" hydra-toggles-help/body "help" )
("i" nil )
("j" helm-colors "color pallete" )
("k" key-chord-mode "key-chord"  )
("l" nlinum-mode  "line num")
("L" linum-mode  "linium")
("m" hydra-toggles-macro/body "Extra macro menu")
("O" org-mode "org-mode" )
("p" list-packages "elpa"  )
("r" read-only-mode "read-only")
("R" helm-regexp "regex builder")
("s" create-scratch-buffer "New scratch" )
("S" scratch "scratch")
("u" electric-pair-mode "electric-pair")
("v" view-mode "view-mode")
("w" whitespace-mode "whitespace")
("x" eval-buffer "eval buffer")
("X" eval-region "eval-region")
("y" nil )
("z" nil )
("=" text-scale-increase :color red )
("-" text-scale-decrease :color red)
("G"  indent-guide-mode "guide-mode")
("q" nil "cancel")
))
#+END_SRC

**** extra macro commands
     :PROPERTIES:
     :ID:       db004fab-d55e-451c-9ad0-64b6609b88fb
     :END:
 #+BEGIN_SRC emacs-lisp :results none
 (defhydra hydra-toggles-macro  (:color blue :hint nil )
      "macro commands
      "
      ("s" start-kbd-macro  "start macro" ) 
      ("e"   "end macro" ) 
      ("l" elmacro-show-last-commands  "elmacro" ) 
      ("e" kmacro-end-and-call-macro  "use C-x e" ) 
      ("n" name-last-kbd-macro  "name macro" ) 
      ("i" insert-kbd-macro  "insert macro" ) 
      ("q" nil "cancel" nil)
 )
 #+END_SRC

**** help menu commands
     :PROPERTIES:
     :ID:       e97abd48-cde5-46d6-9b18-aa54ef9731b4
     :END:
#+BEGIN_SRC emacs-lisp :results none

(global-set-key
   (kbd "")
(defhydra hydra-toggles-help (:color blue :hint nil)

"
_k_ :describe key  _v_ describe variable _f_ describe functiom  
M-1- change windows
M-2 expand region (select gradualy regions)
~movment~ >> 【C-e//C-a】  (end/start of line)
~editing~ >>  【C-BKSP//A-BKSP】 (kill word start/end of line)



_q_: 
"

("a" nil )
("b"  nil  )
("c"  nil )
("d"  describe-last-function "describe last command used" )
("e"  nil )
("f"  describe-function )
("g"  nil )
("h"  nil )
("i"  nil )
("j"  nil )
("k"  describe-key )
("l"  nil )
("m"  nil )
("n"  nil )
("o"  nil )
("p"  nil )
("r"  nil )
("s"  nil )
("t"  nil )
("u"  nil )
("v"  describe-variable)
("w"  nil )
("x"  nil )
("y"  nil )
("z"  nil )
("q"  nil )

))
#+END_SRC
*** ivy hydra (in dired)
    :PROPERTIES:
    :ID:       f8758074-00a3-488e-b499-0418707a15ab
    :END:
http://oremacs.com/2015/03/26/hydra-ivy-swiper/
#+BEGIN_SRC emacs-lisp  :results none
(defhydra hydra-ivy (:hint nil
                     :color pink)
  "
^^^^^^          ^Actions^    ^Dired^     ^Quit^
^^^^^^--------------------------------------------
^ ^ _k_ ^ ^     _._ repeat   _m_ark      _c_: cancel
_h_ ^✜^ _l_     _r_eplace    _U_ unmark  _q_: quit
^ ^ _j_ ^ ^     _u_ndo  
"
  ;; arrows
  ("h" ivy-beginning-of-buffer)
  ("j" ivy-next-line)
  ("k" ivy-previous-line)
  ("l" ivy-end-of-buffer)
  ;; actions
  ("." hydra-repeat)
  ("r" ivy-replace)
  ("u" ivy-undo)
  ;; dired
  ("m" ivy-dired-mark)
  ("U" ivy-dired-unmark)
  ;; exit
  ("q" keyboard-escape-quit :exit t)
  ("c" nil))


(define-key ivy-minibuffer-map (kbd "C-o") 'hydra-ivy/body)


(defun ivy-dired-mark (arg)
  (interactive "p")
  (dotimes (_i arg)
    (with-ivy-window
      (dired-mark 1))
    (ivy-next-line 1)
    (ivy--exhibit)))

(defun ivy-dired-unmark (arg)
  (interactive "p")
  (dotimes (_i arg)
    (with-ivy-window
      (dired-unmark 1))
    (ivy-next-line 1)
    (ivy--exhibit)))

(defun ivy-replace ()
  (interactive)
  (let ((from (with-ivy-window
                (move-beginning-of-line nil)
                (when (re-search-forward
                       (ivy--regex ivy-text) (line-end-position) t)
                  (match-string 0)))))
    (if (null from)
        (user-error "No match")
      (let ((rep (read-string (format "Replace [%s] with: " from))))
        (with-selected-window swiper--window
          (undo-boundary)
          (replace-match rep t t))))))

(defun ivy-undo ()
  (interactive)
  (with-ivy-window
    (undo)))


#+END_SRC
*** spelling/editing  (F3)
    :PROPERTIES:
    :ID:       4d934948-9257-4fdb-8973-c73d1835d781
    :END:

#+BEGIN_SRC emacs-lisp :results none
  (global-set-key
  (kbd "<f3>")
  (defhydra hydra-spell  (:color blue :hint nil :columns 4)
  "
【C-SPACE】 recntangle select // 【C-;】 ispell cycle // 【C-x z】 repeat last command- keep press 【z】to repeat
 "
  ("<f3>" endless/ispell-word-then-abbrev "check and add" )
  ("<f2>" flyspell-auto-correct-previous-word "correct last word" )
  ("<f4>" z/flyspell-goto-previous-error "goto prev error" )
  ("c"  cycle-spacing "cycle spacing")
  ("e"  hydra-editing/body "editing menu" 'hydra-face-green)
  ("g"  rgrep "Rgrep")
  ("h"  highlight-symbol "HS symbol")
  ("H"  highlight-symbol-remove-all "HS remove")
  ("f"  helm-flyspell-correct "helm-flyspell")
  ("i"  ispell "ispell")
  ("j"  highlight-symbol-next  :color red  "HS Next")
  ("k"  highlight-symbol-prev  :color red  "HS Prev")
  ("m"  flyspell-check-next-highlighted-word "check next error")
  ("n"  flyspell-goto-next-error "check next error" )
  ("p"  forward-whitespace "next whitespace"  )
  ("r"  hydra-rectangle/body "rectangle menu (part of hydra)")
  ("t"  z/activate-word-column-region "mark current char" )
  ("u"  imenu "imenu")
  ("v"  z/helm-insert-org-entity "insert Unicode")
  ("w"  ispell-word "ispeel word" )
  ("x"  xah-cycle-hyphen-underscore-space "cycle-underscore" )
  ("y"  nil )
  ("q"  nil )

  ))
#+END_SRC

*** code blocks (f4)
    :PROPERTIES:
    :ID:       db2fdf1e-2296-46e7-9c85-c276bcd1b5f5
    :END:
 #+BEGIN_SRC emacs-lisp :results none
   (global-set-key
    (kbd "<f4>")
    (defhydra hydra-org-blocks (:color blue :hint nil :columns 4)
"to wrap by symbol mark region and then issue symbol, like: 【*】"
    ("<f4>" z/org-cblock-iwrap-emacs-lisp "WRAP-Elisp" )
    ("<f3>" z/org-cblock-iwrap-sh  "Bash" )
    ("c"  z/org-cblock-paste-conf  "insert conf block" )
    ("d"  z/org-insert-drawer  "insert drawer" )
    ("e" z/org-cblock-nowrap-example "insert Example block" )
    ("r" z/org-cblock-iwrap-emacs-R "WRAP-R" )
    ("r" z/org-cblock-paste-R-full "WRAP-R" )
    ("a" z/org-cblock-iwrap-ASK  "Ask" )
    ("l" z/org-cblock-iwrap-ASK-LINE "Ask line" )
    ("m" z/org-cblock-iwrap-menu "Ask line" )
    ("pl" z/org-cblock-paste-lisp "paste lisp" )
    ("pb" z/org-cblock-paste-sh "paste bash" )
    ("pr" z/org-cblock-paste-R "paste R" )
    ("ps" z/org-cblock-paste-SAS  "paste SAS" )
    ("pe" z/org-cblock-paste-example  "paste Example" )
    ("pt" z/org-cblock-paste-tangle-base "paste tangle" )
    ("pq" z/org-cblock-paste-QUOTE "paste QUOTE" )
    ("s" org-babel-demarcate-block "split block" )
    ("x" z/replace-EXAMPLE-2-R "r" )
    ("x" z/replace-EXAMPLE-2-R "" )
    ("q" nil "cancel")))

 #+END_SRC
   
*** email hydras (F5)
    :PROPERTIES:
    :ID:       3fb8a049-4e2e-4b7a-a2cf-f0676e31175d
    :END:

#+BEGIN_SRC emacs-lisp :results none
(global-set-key
   (kbd "<f5>")
(defhydra hydra-mu4e (:color blue  :columns 2 :hints nil)
  "
【M-Enter】 open link 【R】 Reply to sender 
【+】flag (star)
"
;  ("<f5>"     z/gnus-toggle            "toggle gnus ")
;("<f5>"     mu4e            "mu4e inbox")
("<f5>"     z/mu4e-inbox            "mu4e inbox")
  ("7"     z/mu4e-flagged            "mu4e flagged")
  ("5"     z/helm-mu-flagged            "mu4e flagged (helm)")
;;  ("<f5>"     mu4e            "start mu4e")
  ("<f6>"     helm-mu            "helm mu4e")
  ("<f4>"    helm-mu-contacts            "helm-mu-contacts")
  ("l"    elfeed            "elfeed")
  ("ez" z/org-email-heading-me "email myslef the tree")
  ("ex" z/org-email-heading "email other the tree")
  ("d"    (execute-kbd-macro (symbol-function 'z/del_exe_mu4e))            "delete")
  ("f"    (execute-kbd-macro (symbol-function 'mu4e-flag-exe))         "flag")
  ("F"    (execute-kbd-macro (symbol-function 'mu4e-unflag-exe))          "unflag")
  ("o"     mu4e-headers-change-sorting            "sort")
    ("q"     nil                          "cancel" )
))
#+END_SRC

link-hint-open-link-at-point - Open the link at point.
link-hint-copy-link-at-point - Copy link at point to kill ring (and optionally to the clipboard/primary).
link-hint-open-link - Use avy to select and open a single visible link. If only one link is currently visible, it will be automatically opened without the need for selection.
link-hint-open-multiple-links - Use avy to select multiple visible links and open them as soon as a key that does not correspond to a link (a key not in the avy overlay) is pressed (like pentadactyl’s g;).
link-hint-open-all-links - Opens all links visible in the buffer.
link-hint-copy-link - Use avy to select and copy a single visible link to the kill ring. select-enable-clipboard and select-enable-clipboard can each be set to a non-nil value to also use the clipboard and/or primary.




*** latex/bib (F6)
    :PROPERTIES:
    :ID:       a0ef1354-3c83-43ec-a5df-a22f91d849f9
    :END:

#+BEGIN_SRC emacs-lisp :results none

(global-set-key
   (kbd "<f6>")
(defhydra hydra-bib  (:color blue :hint nil :columns 4)

"
【C-c C-s】 search by key in bib buffer 
"
("<f6>" helm-bibtex "helm-bibtex")

("<up>" org-ref-bibtex-previous-entry "prev ref" :color red )
("<down>" org-ref-bibtex-next-entry "next ref" :color red)

("2" z/dired-shell-cb2bib "launch cb2bib" )
("a" org-ref-bibtex-hydra/body "bibtex menu" )
("b" (find-file "/home/zeltak/org/files/Uni/papers/x.papers.bib") "izeltak-bitex file"   :face 'hydra-face-purple )
("c"  org-ref-clean-bibtex-entry "clean bib"  :face 'hydra-face-red )
("d"  doi-utils-add-bibtex-entry-from-doi "add by doi"  :face 'hydra-face-brown)
("D"  doi-utils-add-entry-from-crossref-query "add by doi by searching"  :face 'hydra-face-brown)
("e"  ebib )
("f"  nil )
("g"  gscholar-bibtex "gscholar-search" )
("h"  nil )
("i"  nil )
("j"  nil )
("k"  helm-bibtex-izeltak-publications "zeltak papers"  :face 'hydra-face-green )
("K"  helm-bibtex-izeltak-publications-all "zeltak ALL"  :face 'hydra-face-green )
("l"  nil )
("m" (find-file "/home/zeltak/org/files/Uni/papers/paper.meta.org") "izeltak-meta file"  :face 'hydra-face-purple )
("n"  org-bibtex-create "new bib entry")
("o"  org-ref "check current paper" )
("p"  helm-bibtex-izeltak-prep "zeltak prep"  :face 'hydra-face-green )
("r"  helm-resume "helm resume")
("s"  bibtex-sort-buffer "sort buffer"  :face 'hydra-face-red)
("t"  helm-bibtex-papers-rtodo  "toread papers"  :face 'hydra-face-green )
("u"  org-ref-bibtex-file/body "validation menu" )
("v"  bibtex-validate "validtae"  :face 'hydra-face-red )
("V"  bibtex-validate-globally "validate-check for dups"  :face 'hydra-face-red)
("w"  add org-ref-ivy-set-keywords "add keywords" )
("W"  helm-tag-bibtex-entry "add keywords via helm" )
("x"  crossref-add-bibtex-entry "search crossref" )
("y"  org-bibtex-yank "yank bibtex")
("z"  nil )
("q"  nil )

))


#+END_SRC

*** N/A (F7)
    :PROPERTIES:
    :ID:       8d4d75c4-b7d2-4cfd-8509-c45eb6cf8b5e
    :END:

#+BEGIN_SRC emacs-lisp :results none
(global-set-key
   (kbd "<f7>")
(defhydra hydra-f7 (:color blue  :columns 2 :hints nil)
  "
"
  ("<f7>"     company-complete            "complete")
  ("<f6>"     company-dabbrev            "dabbrev comp")
  ("y"   company-yasnippet  "yasnippet comp")
  ("m"   company-manual-begin  "manual comp")
  ("c"   company-complete-common  "commom comp")
  ("n"   company-select-next  "next comp")
    ("q"     nil                          "cancel" )
))
#+END_SRC



*** bookmark hydra (F8)
    :PROPERTIES:
    :ID:       90c482d3-d89d-4604-82aa-4476aa6bf904
    :END:

#+BEGIN_SRC emacs-lisp :results none
(global-set-key
   (kbd "<f8>")
(defhydra  hydra-open  (:color blue :hint nil :columns 4)
"
【C-c h】helm-prefix 【*】to select mode 【@】to select regex 【,】to select multiple (modes,regex) 【!】exclude 
【C-z】persistant select 【C-l】up dir 【C-r】back dir 
【~/】add to go back to home 【./】 default-directory  【C-c h】history (C-u before to auto go to history)
【C-s】grep Helm  【C-u】recursively grep Helm 【C-c h b】 helm res
【C-f/b】 helm frwd/back 1 char
"
("<f8>" helm-bookmarks "BKMK's")
("<f7>" helm-mini "helm-mini")
("<f9>" projectile-find-file  "projectile ff")
("7" org-iswitchb "org buffers")
("a" nil )
("b"  bmkp-bookmark-set-confirm-overwrite "add BKMK" )
("B"  bmkp-make-function-bookmark "add function BKMK" )
("c"  helm-chrome-bookmarks "Chorme BKMK")
("d"  z/helm-buffers-dired "dired buffers" )
("e"  nil )
("f"  bmkp-bmenu-filter-tags-incrementally "BKMK menu filter")
("g"  nil )
("h"  nil )
("i"  helm-projectile "Helm Projectile")
("j"  helm-projectile-switch-to-buffer "Helm projectile switch" )
("k"  nil )
("l"  nil )
("m"  bookmark-bmenu-list "BKMK menu")
("n"  nil )
("o"  z/helm-buffers-org "org buffers")
("p"  projectile-find-file "projectile find file")
("r"  helm-recentf "Helm Recents" )
("s"  bookmark-save "BKMK Save" )
("t"  z/launch--ansi-term "ansi-term" )
("u"  nil )
("v"  nil)
("w"  nil )
("x"  nil )
("y"  nil )
("z"  nil )
("q"  nil )

))

#+END_SRC

*** org 
    :PROPERTIES:
    :ID:       32adf87c-7c4e-4408-91b5-3a6710f40939
    :END:
**** org main (F9)
     :PROPERTIES:
     :ID:       18799fd6-27a5-4130-aad7-20c07daf5133
     :END:

#+BEGIN_SRC emacs-lisp :results none
(global-set-key
   (kbd "<f9>")
(defhydra hydra-org (:color blue :hint nil :columns 4)

"ORG editing
【C-c -】 convert to dashed lines  【C-M-l  org table menu
【C-u C-u C-c c】 go to where capture was filled
"

("<f9>" worf-goto "worf org headers")
("<f10 w>" helm-org-headlines "helm org headers")
("<f10> v" org-velocity-read  "org valocity")
("<f8>" z/org-insert-heading-link "link/refile")
("RET"  org-insert-todo-heading "org todo header//check list")
("<f10> RET"  org-insert-subheading "org sub header")
("<f10> t"  org-insert-todo-subheading "org sub header")
("."  org-do-demote "<" :color red)
(","  org-do-promote ">" :color red)
("<"  org-promote-subtree "T<" :color red)
(">"  org-demote-subtree "T>" :color red)

("a"  org-sort "sort")
("b"  worf-mode "worf"  )
("c"  org-columns "Columns" )
("C"  org-columns-quit "quit Columns" )
("d"  org-download-screenshot "screenshot")
("D"  org-download-delete "del screenshot")
("ee"  org-export-dispatch "export")
("ep" org-latex-export-to-pdf "export latex")
("er" z/org-export-revel-browse "export reveal browse")
("et" z/org-export-revel-subtree "export reveal subtree")
("ex" org-pandoc-export-to-docx  "ox-pandoc 2 docx")
("eR" org-pandoc-export-to-rtf  "ox-pandoc 2 rtf")
("ey" z/org-export-revel-html  "export reveal html ")
("f"  hydra-org-food/body "food menu"  :face 'hydra-face-orange )
("g"  org-set-tags "tags dialog")
("h"  org-search-view "org search")
("i"  org-display-inline-images "display images")
("I"  org-toggle-inline-images "toggle images")
("j"  nil )
("k"  nil )
("l"  hydra-org-links/body "link menu" :face 'hydra-face-green)
("m"  org-mark-subtree "mark subtree" )
("p"  org-insert-drawer "insert drawer" )
("rr"  org-refile "refile")
("rt"  hydra-org-refile/body "refile menu")
("R"  z/prefix-org-refile "jump to header using refile")
("s"  hydra-org-time/body "time menu" :face 'hydra-face-orange )
("t"  org-todo "todo dialog")
("u"  nil )
("vv"  org-babel-execute-subtree "exe block")
("vb"  org-babel-tangle "tangle")
("w"  z/narrow-or-widen-dwim "Toggle narrow//widen" )
("x"  org-archive-subtree "Archive" )
("-"  org-toggle-heading "Header lower" )
("="  z/org-convert-header-samelevel "Header same")
("0"  org-ctrl-c-star "convert lines to headers")
("\\"  hydra-org-table/body "table menu"  :face 'hydra-face-orange )
(";"  z/comment-org-in-src-block "comment block" )
("y"  nil )
("z"  nil )
("<home>" outline-up-heading  "up main header" :color red)
("<down>" org-forward-heading-same-level  "up header" :color red)
("<up>" org-backward-heading-same-level  "down header" :color red)
("q"  nil )

))
#+END_SRC
   
**** agenda (F10)
     :PROPERTIES:
     :ID:       6899c9bd-1c41-4166-b332-c480ed168960
     :END:
***** org agenda main
      :PROPERTIES:
      :ID:       5d5567f8-9f16-4b76-adb6-8600ce16e2ec
      :END:
 #+BEGIN_SRC emacs-lisp :results none
     (global-set-key
	(kbd "<f10>")
     (defhydra hydra-org-agenda (:color blue :hint nil :columns 4)
   "AGENDA:
   【g】- Refresh agenda 
   【SPACE//TAB】open//open-go item in side view 【F】will toggle follow mode for space/tab view
   【A】Append another view 【/】 filter tag 【=】 filter regex 【|】 clean all filters
   【v】Choose view 【f】forward in time 【b】back in time 【.】goto today 【j】 jump to date
   【S-left//right】 change deadline 【k】 launch capture with date/task
   【:】 set tags 【,】set priority (then choose) 【S-U/D/L/R】 change todo/pri 
   【m,u,U...】 dired marking 【M-m】toggle marking 【B】 execute on marks via dispatcher 【v】 view mode                             
   mark items +【B s】-Reschedule multiple items

   "
         ("<f10>" z/org-agenda-calendar  "org agenda"  )
         ("<f9>" cfw:open-org-calendarz  "month calendar"  )
         ("c"  org-agenda-columns  "agenda columns" )
         ("t"    org-agenda-todo      "change todo")
         ("k"    org-agenda-kill      "delete C-k")
         ("m"    org-agenda-bulk-toggle  "bulk mark"  :color red ) 
         ("x"    org-agenda-bulk-action  "bulk exe")
         ("x"   org-agenda-archive      "archive ")
         ("w"   org-agenda-refile      "refile ")
         (":"   org-agenda-set-tags      "set tags ")
         (","   org-agenda-priority      "priority (S-UP/S-Dn to change as well ")
         ("s"   org-agenda-schedule      "schedule task ")
         ("t"   org-agenda-refile      "schedule task ")
         ("d"   org-agenda-deadline      "deadline task ")
         ("p"   org-agenda-date-prompt      "prompt date ")
         ("M"   cfw:org-open-agenda-day      "month view ")
         ("z"  cfw:open-org-calendar "month calander" )
          ("q"     nil                          "cancel" )
     ))
 #+END_SRC


**** agenda-views-todos  (F11)
     :PROPERTIES:
     :ID:       4ad139ed-4fb5-4eb9-b883-13af0583f952
     :END:
 #+BEGIN_SRC emacs-lisp :results none
 (global-set-key
    (kbd "<f11>")
    (defhydra hydra-buffer  (:color blue :hint nil :columns 4)
      "TODO commands
 【C-c C-d】 imsert deadline 
 "
      ("<f11>" org-agenda "org-agenda" )
      ("s"   z/org-agenda-search     "regex search")
      ("t"   z/org-agenda-search-todo     "regex search TODO")
      ("fa" (org-tags-view nil "Cuisine=\"American\"") "food-american" )
      ("h" (org-agenda nil "2h")  "home")
      ("i" "" )
      ("c" ""  )
      ("k"  "" )
      ("n" "" )
      ("q" nil "cancel")))

 #+END_SRC

**** links org commands
     :PROPERTIES:
     :ID:       8693bfd9-cfe0-4d81-bb6d-291210654aea
     :END:
 #+BEGIN_SRC emacs-lisp :results none
(defhydra hydra-org-links (:color blue  :hint nil :columns 3)
      "
【C-c C-l id: RET】 complete all headers in agenda files  
      "
     ("a" org-mark-ring-goto  "go back to prev position-pre linqk" :face 'hydra-face-blue) 
     ("c" org-id-copy  "create ID" :face 'hydra-face-cyan) 
     ("d" org-id-create "just create Id")
     ("D" z/org-add-ids-to-headlines-in-file  "add id's to all headers" ) 
     ("e" helm-org-agenda-files-headings  "link/refile with helm" :face 'hydra-face-cyan  ) 
     ("f" z/org-link-file  "link to file" :face 'hydra-face-cyan  ) 
     ("h" worf-copy-heading-id  "worf copy id of killring"  :face 'hydra-face-grey ) 
     ("l" org-insert-link   "insert//edit link" :face 'hydra-face-green  ) 
     ("k" org-store-link   "store (copy) header link" :face 'hydra-face-green  ) 
     ("J" org-link-edit-forward-barf  "forward edit"  :face 'hydra-face-grey) 
     ("K" org-link-edit-backward-barf  "backward edit"  :face 'hydra-face-grey)
     ("o" link-hint-open-link "open link" )
     ("p" org-cliplink "org-cliplink")
     ("s" org-id-store-link  "store org-id" ) 
     ("u" org-link-edit-forward-slurp  "forward slurp"  :face 'hydra-face-grey)
     ("y" org-link-edit-backward-slurp  "back  slurp"  :face 'hydra-face-grey)
     ("w" z/org-link-paste-file-path "paste file link")
     ("q" nil "cancel" nil)
)
 #+END_SRC
**** org refile commands
     :PROPERTIES:
     :ID:       b0e5fed7-b3c2-4c48-9029-be0a56b02b0f
     :END:
 #+BEGIN_SRC emacs-lisp :results none
(defhydra hydra-org-refile (:color blue  :hint nil :columns 3)
      "
      "
     ("b" z/org-refile-to-bgu  "refile bgu" :face 'hydra-face-cyan) 
     ("r" z/org-refile-to-research  "refile research" :face 'hydra-face-cyan) 
     ("t" z/org-refile-to-todo  "refile research") 
     ("k" z/org-refile-to-bookmarks  "refile bookmarks") 
     ("q" nil "cancel" nil)
)
 #+END_SRC
**** org cooking 
     :PROPERTIES:
     :ID:       f9ee03e0-397a-43b7-a6dd-2e0514fc748b
     :END:
#+BEGIN_SRC emacs-lisp :results none
 (defhydra hydra-org-food ()
   "org-food "
   ("b" cooking-sparse-tree-breakfeast "breakfeast_view" :color blue)
   ("m" cooking-sparse-tree-main "main_view" :color blue)
   ("r" recipe-template "recipe-template" :color blue)
   ("t" travel-template  "travel-template" :color blue)
   ("q" nil "cancel")
)
#+END_SRC

**** orgmode time functions 
     :PROPERTIES:
     :ID:       7b2d1103-5ce7-4168-a510-0521d031cd17
     :END:

 #+BEGIN_SRC emacs-lisp :results none
     (defhydra hydra-org-time  (:color blue :hint nil :columns 4)
   "
   ☚+1w☛ implies that this event will repeat every week at the same time & date  ☚--☛ multi day
   【.】 Go to today 【r】rebuild agenda 
   【Ctrl+c .】 fri 【Return】// If you want an inactive date use 【Ctrl+c !】 fri 【Return】
   "
       ("s"  org-time-stamp "agenda date")
       ("x" org-time-stamp-inactive  "stamp date" )
       ("y" z-insert-date "insert current data")  
       ("t" z-insert-date-time "insert current data")  
       ("d" org-deadline  "set deadline")  
       ("f" org-schedule  "set schedule")  
       ("w" org-clone-subtree-with-time-shift   "clone and time shift")  
       ("q" nil "cancel")
    )
 #+END_SRC



**** org editing (C-M-o)						     
     :PROPERTIES:
     :ID:       3ae10732-f1d1-4a24-bf2c-5f77f9692c18
     :END:

 #+BEGIN_SRC emacs-lisp :results none
   (global-set-key
    (kbd "C-M-o")
    (defhydra hydra-org-edit (:color blue :hint nil :columns 4)
      "orgmode editing "
      ("5" z/org-clone-subtree  "clone header with new org-id " )
      (";" z/org-cblock-comment  "line to checkbox" )
      ("c" org-set-line-checkbox  "line to checkbox" )
      ("d" org-cut-subtree  "org cut" )
      ("e" z/org-email-heading  "email header" )
      ("f" fill-paragraph  "fill paragraph" )
      ("F" fill-region  "fill region" )
      ("h" org-set-line-headline "line to headline" )
      ("i" z/org-paste-image-link "paste as link" )
      ("I" iedit-mode "edit current@point" )
      ("m" org-teleport  "teleport header " )
      ("p" org-paste-subtree  "org paste" )
      ("r" org-copy  "copy via refile" )
      ("s" org-clone-subtree-with-time-shift  "add a time series for headers" )
      ("t" org-insert-todo-heading-respect-content "insert TODO" )
      ("v" org-copy-visible "copy visible text only (headers) " )
      ("w" worf-mode "Worf mode" )
      ("y" org-copy-subtree "org copy" )
      ("z" z/org-email-heading-me  "email header izeltak" )
      ("<up>" org-move-subtree-up "header up" :color red )
      ("<down>" org-move-subtree-down "header down" :color red)
      ("q" nil "cancel")))

 ;; additional bind
 (global-set-key (kbd "C-c 0") 'hydra-org-edit/body)

 #+END_SRC


**** org tags
     :PROPERTIES:
     :ID:       b4bbec18-8c51-4847-ab22-caba5c1716a1
     :END:

  #+BEGIN_SRC emacs-lisp :results none
    (global-set-key
	(kbd "")
     (defhydra hydra-org-tags  (:color blue :hint nil :columns 4)
     "
     "

    ("1" (org-set-tags-command) "set tags"  :face 'hydra-face-green)
    ("a" (org-set-tags-to "allan") "Allan" )
    ("b" (org-set-tags-to "boris") "Boris" )
    ;("c" (org-set-tags-to "") "tags" )
    ("d" (org-set-tags-to "david") "David" )
    ;("e" (org-set-tags-to "allan") "tags" )
    ;("f" (org-set-tags-to "allan") "tags" )
    ;("g" (org-set-tags-to "allan") "tags" )
    ("h" (org-set-tags-to "hila") "Hila" )
    ;("i" (org-set-tags-to "allan") "tags" )
    ("j" (org-set-tags-to "joel") "Joel" )
    ;("k" (org-set-tags-to "allan") "tags" )
    ("l" (org-set-tags-to "lara") "Lara" )
    ("m" (org-set-tags-to "meytar") "Meytar" )
    ;("n" (org-set-tags-to "allan") "tags" )
    ("o" (org-set-tags-to "omer") "Omer" )
    ;("p" (org-set-tags-to "allan") "tags" )
    ;("q" (org-set-tags-to "allan") "tags" )
    ("r" (org-set-tags-to "adar") "Adar" )
    ("s" (org-set-tags-to "massimo") "Massimo" )
    ("S" (org-set-tags-to "francesca") "Francesca" )
    ;("t" (org-set-tags-to "allan") "tags" )
    ;("u" (org-set-tags-to "allan") "tags" )
    ("v" (org-set-tags-to "adi") "Adi" )
    ;("w" (org-set-tags-to "allan") "tags" )
    ("x" (org-set-tags-to "alex") "Alex" )
    ("y" (org-set-tags-to "maayan") "Maayan" )
    ("z" (org-set-tags-to "bob") "Bob" )
    ("q" nil "cancel")

    ))
  #+END_SRC
**** org tables (C-M-t)
     :PROPERTIES:
     :ID:       38f237a0-dc51-426e-8914-269b5c7ee6d5
     :END:

 #+BEGIN_SRC emacs-lisp :results none
 (global-set-key
  (kbd "C-M-l")

 (defhydra hydra-org-table (:color blue  :columns 6)
 "【C-c +】 will sum a column and move to clip  【C-space】 blank field 【M-left/right】move column left/right  【M-S-left/right】kill/add column 
 【M-up/down】 move row up/down 【M-S-down】 insert row  【M-S-up】 kill row
 【|-】 will start a dashed line 【C-c +】 org sum 【C-c ?/}】 find/show out field info 
 【@row$column】>>  @2$3 will mean 2nd row, 3rd column 
  $1..$3f  firtst three fields in the current row // @2$1..@4$3  6 fields between these two fields
 FORUMLAS: 【C-c =】 insert formula 【C-c *】 recalculate formula  vmean/vsum 
 【:=】insert formula directly >> :=vsum(@2$3..@32$3)
 "
      ("i" org-table-insert-row  "insert row" :color blue) 
      ("y" org-table-copy-region  "copy" :color blue) 
      ("d" org-table-cut-region  "cut" :color blue) 
      ("p" org-table-paste-rectangle  "paste" :color blue) 
      ("s" org-table-sort-lines  "sort" :color blue) 
      ("c" org-table-create-or-convert-from-region  "convert" ) 
      ("w" quick-calc  "quick calc" ) 
    ("q" nil "cancel")))
 #+END_SRC
**** org-capture
     :PROPERTIES:
     :ID:       f888785c-6e05-4165-8326-9393a1573f69
     :END:
 #+BEGIN_SRC emacs-lisp  :results none
 (defhydra hydra-org-capture-go  (:color blue :hint nil :columns 5)
   "org capture:"
   ("e" (org-capture nil "e") "email TD")
   ("E" (org-capture nil "E") "email TD (alt)")
   ("m"  (org-capture nil "m")  "ADD meeting" :face 'hydra-face-purple)
   ("M"   (org-capture nil "M") "ADD rec meeting" :face 'hydra-face-purple)
   ("x"   (org-capture nil "x") "nix TD")
   ("h"   (org-capture nil "h") "Home TD")
   ("v"   (org-capture nil "v") "Research TD")
   ("b"   (org-capture nil "b") "BGU TD")
   ("r"   (org-capture nil "r") "respond TD ")
   ("pp"  (org-capture nil "pp")  "add paper ")
   ("pa"  (org-capture nil "pa") "add abstract")
   ("j"  (org-capture nil "j") "jounral work")
   ("dm"  (org-capture nil "dm") "DL-movies" :face 'hydra-face-green)
   ("dp" (org-capture nil "dp") "DL-movies-PRE" :face 'hydra-face-green)
   ("dt" (org-capture nil "dt") "DL-TV"  :face 'hydra-face-green)
   ("ds" (org-capture nil "ds") "DL-Music"  :face 'hydra-face-green)
   ("dc"  (org-capture nil "dc") "DL-comics" :face 'hydra-face-green)
   ("c" (org-capture nil "c") "contacts")
   ("k" (org-capture nil "k")   "add bookmark ")
   ("K"  (org-capture nil "K") "add bookmark(alt)")
   ("w"  (org-capture nil "w") "add tmp bookmark")
   ("ff"  (org-capture nil "ff") "add recipe")
   ("fs" (org-capture nil "fs") "add shop item")
   ("u"  (org-capture nil "u")  "add restaurant")
   ("U" (org-capture nil "U")   "add travel site")
   ("q" nil "quit"))
 #+END_SRC


*** yas (C-M-h)
    :PROPERTIES:
    :ID:       0af07a5d-2725-4e40-a00f-e51c391e66a0
    :END:

#+BEGIN_SRC emacs-lisp :results none
(global-set-key
 (kbd "C-M-y")
 (defhydra hydra-yas ()
   "yas command "
   ("a" yas-activate-extra-mode "enable Emacs mode for yas" :color blue)
   ("n" yas-new-snippet "add new snippet" :color blue)
   ("v" yas-visit-snippet-file "visit" :color blue)
   ("i" yas-insert-snippet "insert_point" :color blue)
   ("r" yas-reload-all  "reload" :color blue)
   ("t" yas-tryout-snippet  "try snipet" :color blue)
   ("q" nil "cancel")))
#+END_SRC
*** Editing (C-M-e)
    :PROPERTIES:
    :ID:       b90aa877-c683-460e-9f55-0f5fc2fe5b41
    :END:
**** main editing command 
     :PROPERTIES:
     :ID:       ce4bf3a9-354e-4e62-91ca-427475ea739f
     :END:
 #+BEGIN_SRC emacs-lisp :results none
   (global-set-key                         
    (kbd "C-M-e")
    (defhydra hydra-editing (:color blue :hint nil :columns 4)
      "editing command"
      ("o" crux-smart-open-line  "open line" )
      (";"  hydra-commenting/body  "comment!" )
      ("<down>" drag-stuff-down  "marked down" :color red)
      ("<up>" drag-stuff-up  "marked up" :color red)
      ("c" ox-clip-formatted-copy "copy formated " )
      ("d" downcase-region  "downcase " )
      ("e" hydra-edit-extra/body  "Extra editing commands" :face 'hydra-face-purple)
      ("f" flush-blank-line  "flush blank" )
      ("g" google-search "google searh selected" )
      ("h" z/edit-copy-all-or-region  "copy buffer" )
      ("i"  hydra-editing-insert/body  "insert" )   
      ("l"  endless/fill-or-unfill  "fill/unfill" )   
      ("n" z/insert-file-name "insert file name" )
      ("p" duplicate-current-line-or-region  "duplicate" :color red)
      ("s" write-abbrev-file  "save abbrv file") 
      ("t" z/html2org-clipboard  "paste formatted html" )
      ("u" upcase-region  "upcase " )
      ("U" z-fix-characters "fix unicode" )
      ("w" shrink-whitespace  "shrink-whitespace" )
      ("x" z/comment-box "comment box" )
      ;("<left>" drag-stuff-left  "marked left" :color red)
      ;("<right>" drag-stuff-right "marked right" :color red)
      ("R" revert-buffer  "revert buffer before changes" ) 
      ("q" nil "cancel")))

;;adittional bind 
(global-set-key (kbd "C-c 1") 'hydra-editing/body)
 #+END_SRC

**** extra editing commands
     :PROPERTIES:
     :ID:       a5fcc964-35ce-4c23-9e99-62449ed70f8a
     :END:

 #+BEGIN_SRC emacs-lisp :results none
 (defhydra hydra-edit-extra (:color blue :hint nil )
      "
 fix _u_nicode issue  // u_p_case region // _d_owncase region 
      "
      ("c" z/cleanup-refs  "cleanup references" ) 
      ("u" z-fix-characters  "fix unicode" ) 
      ("p" upcase-region  "upcase region" ) 
      ("d" downcase-region  "downcase region" ) 
      ("f" toggle-fill-unfill  "fill/unfill")
      ("r" z-edit-file-as-root  "edit as root")
      ("q" nil "cancel" nil)
      ("1" z/regex-delete-numeric "delete numbers")
 )

 #+END_SRC

**** commenting hydra 
     :PROPERTIES:
     :ID:       f8ed8acd-10b3-4fcd-bd73-0c4d6424e882
     :END:

#+BEGIN_SRC emacs-lisp :results none
  (defhydra hydra-commenting (:color blue  )
       "
  comment  _;_ // comment _t_o line // comment para_g_raph // co_p_y-paste-comment 
  comment _e_macs function  // copy-paste-comment-function _r_  
       "
       (";" evilnc-comment-or-uncomment-lines  "comment" ) 
       ("t" evilnc-quick-comment-or-uncomment-to-the-line   "c 2 line"  nil ) 
       ("g" evilnc-comment-or-uncomment-paragraphs  "c paragraph"  nil ) 
       ("p" evilnc-copy-and-comment-lines  "c,c,p"  nil ) 
       ("e" comment-line  "comment-line-emacsfun" :color blue)
       ("r" z/copy-comment-paste  "c,c,p-fun " :color blue)
       ("q" nil "cancel" nil)             ;
  )

#+END_SRC


*** password-store (C-M-p)
    :PROPERTIES:
    :ID:       923411b2-5605-4024-bbc3-bc58708964ec
    :END:
**** main editing command 
     :PROPERTIES:
     :ID:       221f95af-dc5a-4709-914d-1506daf0d19f
     :END:
 #+BEGIN_SRC emacs-lisp :results none
   (global-set-key                         
    (kbd "C-M-p")
    (defhydra hydra-password-store (:color blue :columns 4 :hint nil)
      "password store command"
      ("p" password-store-edit   "edit pass" )
      ("t" pass   "pass tree" )
      ("d" password-store-remove   "delete pass" )
      ("h" helm-pass   "delete pass" )
      ("q" nil "cancel")))

 #+END_SRC
*** avy (C-M;)
    :PROPERTIES:
    :ID:       688fd92b-6354-407e-9ab3-ebe93f9e9832
    :END:
#+BEGIN_SRC emacs-lisp :results none
(global-set-key
 (kbd "C-M-;")
 (defhydra hydra-avy ()
   "yas command "
   ("g" avi-goto-char-2 "avi-goto-char-2" :color blue)
   ("c" avi-goto-char "avi-goto-char" :color blue)
   ("l" avi-goto-line "avi-goto-line" :color blue)
   ("4" avi-copy-line  "avi-copy-line" :color blue)
   ("3" avi-move-line  "avi-move-line" :color blue)
   ("r" avi-copy-region  "avi-copy-region" :color blue)
   ("a" avi-goto-word-1  "avi-goto-word-1" :color blue)
   ("v" avi-goto-word-0  "avi-goto-word-0" :color blue)
   ("z" ace-jump-zap  "zap text" :color blue)
   ("q" nil "cancel")))
#+END_SRC

*** windows (F12)
    :PROPERTIES:
    :ID:       14f80f4e-b678-40ad-8a6e-924ac02e87db
    :END:

#+BEGIN_SRC emacs-lisp :results none
(global-set-key
 (kbd "<f12>")
 (defhydra hydra-window (:color blue :hint nil :columns 5)
 "Window and buffer Operations"
   ("<f12>" switch-to-previous-buffer  "last buffer"  )
   ("<f11>" ace-delete-window "delete window")
   ("<home>" ace-window "ace-window//also M-1" :exit t)   
   ("0" z/toggle-window-split "toggle splits")   
   ("=" (lambda ()
          (interactive)
          (split-window-right)
          (windmove-right))
        "Split Vertical (|)")
   ("-" (lambda ()
          (interactive)
          (split-window-below)
          (windmove-down))
        "Split horzizontal (-)")
   ("<left>" hydra-move-splitter-left "resize left"  :color red)
   ("<right>" hydra-move-splitter-right "resize right"  :color red)
   ("<up>" hydra-move-splitter-up "resize up"  :color red)
   ("<down>" hydra-move-splitter-down "resize down"  :color red)
   ("t" ace-swap-window  "transpose (ace-swap)")
   ("i" ace-maximize-window "ace-one" )
   ("r" resize-window "resize menu" )
   ;;Note winer mode must be enabled
   ("u" winner-undo "winner undo")
   ("s" save-buffer "save buffer"  )
   ("a" write-file  "save as.."  )
   ("x" kill-this-buffer "kill buffer"  )
   ("c" z-save-buffer-close-window "save and close"  )
   ("v" z/write-file-increment "increment version"  )
   ("n" next-user-buffer  "next buffer" )
   ("p" previous-user-buffer "prev buffer"  )
   ("N" next-emacs-buffer "next Emacs  buffer"  )
   ("P" previous-emacs-buffer "prev emacs buffer"  )
   ("da" ace-delete-window)
   ("db" kill-this-buffer)
   ("df" delete-frame "delete frame")
   ("kw" delete-window "delete window")
   ("ka" delete-other-windows "delete all other  windows")
   ("kh" kill-buffer "helm kill buffer" )
   ("kb" z-kill-other-buffers "kill all but current" )
   ("w" next-multiframe-window "next-multiframe-window" )
   ("q" nil "cancel")))

#+END_SRC
*** hydra mark
    :PROPERTIES:
    :ID:       c7b942ae-b3ad-4936-934f-1bf321628fee
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(global-set-key
 (kbd "M-2")
(defhydra hydra-mark-er (:body-pre (call-interactively 'set-mark-command) :hint nil :columns 4
                               :exit t )
  "hydra for mark commands"
  ("2" er/expand-region "expand region")
  ("l" er/mark-text-sentence "sentence")
  ("p" er/mark-text-paragraph "paragraph")
  ("w" er/mark-word "word")
  ("r" er/mark-outside-pairs"expand outside paris")
  ("R" er/mark-inside-pairs "expand inside paris")
  ("u" er/mark-outside-quotes)
  ("U" er/mark-inside-quotes "quotes")
  ("d" er/mark-defun "function")
  ("c" er/mark-comment "comment")
  ("k" er/mark-url "url")
  ("m" er/mark-email "email")
  ("s" er/mark-symbol "symbol")
  ("q" (funcall 'set-mark-command t) :exit nil)))

#+END_SRC
*** TODO search (C-S-s)
    :PROPERTIES:
    :ID:       a22c2f17-f8d5-40e5-9b4a-9265517df9f9
    :END:
organize better and up que in list often used searches 

#+BEGIN_SRC emacs-lisp :results none
(global-set-key
 (kbd "C-S-s")
 (defhydra hydra-search  (:color blue :hint nil :columns 4) 
   " 
〖rgrep〗 search string>> extension >> location 
〖swoop〗 will show a search word in helm buffer
〖occur〗 will show a search word inline
〖rifle〗 commands that use helm and present results in org format 
"

;iserach

("s" counsel-grep-or-swiper "'counsel-grep-or-swiper" :face 'hydra-face-brown )
;("s" isearch-forward "isearch" :face 'hydra-face-brown )
("S" isearch-forward-symbol-at-point "isearch@point" :face 'hydra-face-brown )


;;advanced searches 
("d" z/helm-mg-prefix "helm-ag-recursive" :face 'hydra-face-green )
("f" helm-ag "Helm-ag")
("F" helm-do-ag-project-root "helm-ag in porject" )
("r"  rgrep "use emacs recursive grep") 
("1"  swiper-all "swiper all open buffers" )

;;;rifle commands 

("ww"  helm-org-rifle "rifle open org" :face 'hydra-face-cyan )
("wd"  helm-org-rifle-directories "rifle selected directories" :face 'hydra-face-cyan )
("wo"  helm-org-rifle-org-directory "rifle a org dir" :face 'hydra-face-cyan )
("wf"  helm-org-rifle-files "rifle a specific file" :face 'hydra-face-cyan )

;;; helm swoops and occurs  
("2" helm-swoop "find word@point in document" :face 'hydra-face-grey )
("3" helm-multi-swoop  "find word@point in selected documents" :face 'hydra-face-grey)
("4" helm-multi-swoop-org "find word@point in org agenda"  :face 'hydra-face-grey )
("5" helm-occur "helm Occur"  :face 'hydra-face-grey)
("6"  org-occur "org-occur"  :face 'hydra-face-grey )

;file system searches 
("h" helm-for-files "Helm search all file system " )

; emacs docu searches 
("P" helm-apropos "Helm-Apropos")

;replace 
("R" anzu-query-replace-at-cursor "Replace@cursor")


("z" z/counsel-yank-zsh-history "zsh history" )

("Z" z/replace-on-matching-lines "replace only in specific lines" )

; buffer movement 
("9" goto-last-change "goto last change"  :face 'hydra-face-darkred )
("0" goto-last-change-revrese "goto prev change"  :face 'hydra-face-darkred )  

;;("" counsel-ag "counsel search org" :face 'hydra-face-purple)
;;("c" z/counsel-ag-prompt-dir "counsel search promprt dir" :face 'hydra-face-purple)

   ("q" nil "cancel")))
#+END_SRC


* Macros
  :PROPERTIES:
  :ID:       23dbe45f-888d-4dda-b92b-b847ecd1311c
  :END:
** Editing
   :PROPERTIES:
   :ID:       7053ced4-39b0-46f5-a264-b0934d0ca464
   :END:
*** link2picheader 
#+BEGIN_SRC emacs-lisp  :results none
(fset 'link2picheader
   [f12 ?= f1 ?s ?i return return return up up up f1 ?m])
#+END_SRC
*** add lines
#+BEGIN_SRC emacs-lisp  :results none
(fset 'z/mac.insert.line 
   [?\C-s ?. return ?\C-j])
#+END_SRC
** prefix macro
   :PROPERTIES:
   :ID:       7507b3cd-03e0-4c49-bbc0-24df87242be9
   :END:
#+BEGIN_SRC emacs-lisp :results none
(defmacro C-u (&rest args)
  (let ((prefix (list 4)))
    (while (cdr args)
      (cond
       ((eq (car args) 'C-u)
        (setf (car prefix) (* 4 (car prefix))))
       ((eq (car args) 'M-x)
        ;; ignore
        t)
       (t
        (error "Unknown arg %S" (car args))))
      (setq args (cdr args)))
    (unless (functionp (car args))
      (error "%S is not a function" (car args)))
    `(lambda ()
       (interactive)
       (let ((current-prefix-arg ',prefix))
         (call-interactively ',(car args))))))
#+END_SRC




* Settings
  :PROPERTIES:
  :ID:       0991546e-92b4-42d3-9b99-d3c639d2d5f8
  :END:
** XDG/open with 
   :PROPERTIES:
   :ID:       8c589e05-82a2-4f31-87ce-e3d2a858ac08
   :END:
*** set emacs browser
    :PROPERTIES:
    :ID:       162c6201-3e81-441e-a729-698e387c731d
    :END:
#+BEGIN_SRC emacs-lisp :results none
(setq browse-url-browser-function (quote browse-url-generic))
;(setq browse-url-generic-program "qutebrowser")
;(setq browse-url-generic-program "firefox")
(setq browse-url-generic-program "chromium")
#+END_SRC
** Backup
   :PROPERTIES:
   :ID:       594d400e-5afd-4935-a7dd-f878359a7214
   :END:
Auto-backup is triggered when you save a file - it will keep the old version of the file around, adding a ~ to its name. 
auto-save-mode auto-saves a file every few seconds 
here we put these files in the /tmp dir

#+BEGIN_SRC emacs-lisp :results none
(setq backup-directory-alist
      `((".*" . ,temporary-file-directory)))
(setq auto-save-file-name-transforms
      `((".*" ,temporary-file-directory t)))
#+END_SRC

** Save and sessions
   :PROPERTIES:
   :ID:       aac5fbbd-e1f5-4384-8284-e92a6938e2d3
   :END:

#+BEGIN_SRC emacs-lisp :results none
  ;If I reopen a file, I want to start at the line at which I was when I closed it.
  ; save the place in files
  ;(require 'saveplace)
  ;(setq-default save-place t)

  ; save minibuffer history
  (require 'savehist)

  (setq savehist-save-minibuffer-history 1)
  (savehist-mode 1)
  (setq history-length t)
  (setq history-delete-duplicates t)

  (setq savehist-additional-variables '(search-ring
                                        regexp-search-ring
                                        file-name-history
                                        extended-command-history
                                        search-ring
                                        sr-history-registry
                                          ))

  (setq savehist-save-minibuffer-history 1)

  ;;autosave
  ;(setq auto-save-visited-file-name t)
  ;(setq auto-save-interval 20) ; twenty keystrokes
  (setq auto-save-timeout 60) ; ten idle seconds

#+END_SRC
** save kill ring 
#+BEGIN_SRC emacs-lisp  :results none
;; Also save minibuffer/variable histories.
;; n.b. savehist-mode defaults to saving the vars listed in
;; savehist-minibuffer-history-variables, which gets added to
;; as individual features are utilised.
(setq savehist-additional-variables
'(kill-ring
;; You don't need to add minibuffer history variables to this
;; list, all minibuffer histories will be saved automatically
;; as long as `savehist-save-minibuffer-history' is non-nil.
))
;; n.b. Code elsewhere should use:
;; (eval-after-load "savehist"
;; '(add-to-list 'savehist-additional-variables 'some-var))

;; Remove text properties from kill-ring before it is saved to the
;; history file, as these bloat the file dramatically.
;; See http://emacs.stackexchange.com/a/4191 for why this doesn't
;; use `savehist-save-hook'.
(add-hook 'kill-emacs-hook 'my-unpropertize-kill-ring)
(defun my-unpropertize-kill-ring ()
(setq kill-ring (mapcar 'substring-no-properties kill-ring)))
#+END_SRC

** recentf
   :PROPERTIES:
   :ID:       35ef45c2-97dd-4fef-8117-e035dff0e2bd
   :END:

$note its built into emacs no intsall needed$

#+BEGIN_SRC emacs-lisp :results none
 (setq recentf-save-file "/home/zeltak/.emacs.t/recentf")  ;; (setq recentf-auto-cleanup 'never) ;; disable before we start recentf!
(require 'recentf)
(recentf-mode 1)
(setq recentf-max-menu-items 50)
;(setq recentf-auto-cleanup 'never) ;; disable before we start recentf!
#+END_SRC

** performance improvement
   :PROPERTIES:
   :ID:       1f7c46b4-98b2-4ef4-968c-75c1967f3a48
   :END:
#+BEGIN_SRC emacs-lisp :results none
(setq cache-long-scans nil)
#+END_SRC
** TODO file completion
   :PROPERTIES:
   :ID:       57a19e9f-d85d-4100-adf4-a593c7a5bcca
   :END:

#+BEGIN_SRC emacs-lisp
(setq read-file-name-completion-ignore-case t)
(setq read-buffer-completion-ignore-case t)
(mapc (lambda (x)
        (add-to-list 'completion-ignored-extensions x))
      '(".aux" ".bbl" ".blg" ".exe"
        ".log" ".meta" ".out" ".synctex.gz" ".tdo" ".toc"
        "-pkg.el" "-autoloads.el"
        "Notes.bib" "auto/"))
#+END_SRC
** TODO TRAMP settings
   :PROPERTIES:
   :ID:       1f9ee78d-bcc1-44c8-b661-7869712119d9
   :END:
*** tramp ssh
    :PROPERTIES:
    :ID:       f7feae99-5399-4118-8769-12d857ea32d5
    :END:
#+BEGIN_SRC emacs-lisp :results none
(require 'tramp) ; Remote file editing via ssh
(setq tramp-default-method "ssh")
#+END_SRC
*** set temp directory
    :PROPERTIES:
    :ID:       5890dbe8-c130-41b6-bec7-5082e9dd011a
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(setq temporary-file-directory "/tmp")
#+END_SRC
*** cache password
    :PROPERTIES:
    :ID:       68938f9a-ac66-4579-8ca7-3d39b4669e7b
    :END:
don't let passwords expire
#+BEGIN_SRC emacs-lisp  :results none
  ;; (setq password-cache-expiry nil)
#+END_SRC
*** tramp defaults and use .ssh settings 
    :PROPERTIES:
    :ID:       97ef5a9b-2599-4228-bdce-47ccd1ce7233
    :END:
#+BEGIN_SRC emacs-lisp  :results none
  ;; (setq tramp-default-method "ssh"
  ;;         tramp-default-user-alist '(("\\`su\\(do\\)?\\'" nil "root"))
  ;;         tramp-adb-program "adb"
  ;;         ;; use the settings in ~/.ssh/config instead of Tramp's
  ;;         tramp-use-ssh-controlmaster-options nil
  ;;         backup-enable-predicate
  ;;         (lambda (name)
  ;;           (and (normal-backup-enable-predicate name)
  ;;                (not (let ((method (file-remote-p name 'method)))
  ;;                       (when (stringp method)
  ;;                         (member method '("su" "sudo"))))))))
#+END_SRC
*** use sudo with ssh
    :PROPERTIES:
    :ID:       6d27bebc-a267-4e01-b8f1-ec5f7478a145
    :END:
http://mollermara.com/tags/productivity/

It’s even possible to remotely edit files as root using /sudo:server:/path/to/file, although this doesn’t work out of the box. You’ll need to add this to your .emacs

#+BEGIN_SRC emacs-lisp  :results none
  ;; (add-to-list 'tramp-default-proxies-alist 
  ;;      '((and (string-match system-name 
  ;;                   (tramp-file-name-host (car target-alist)))
  ;;             "THISSHOULDNEVERMATCH")
  ;;        "\\`root\\'" "/ssh:%h:"))
#+END_SRC

This allows you to sudo into remote servers, but also prevents it from interfering with sudoing locally.

** Editing
   :PROPERTIES:
   :ID:       2d6d2a96-fbba-41a0-95ba-70f0228fb6b4
   :END:
*** spelling
    :PROPERTIES:
    :ID:       8c058785-de36-420f-909a-83c69e4847bf
    :END:
#+begin_src emacs-lisp results none
;Spelling
(autoload 'flyspell-mode "flyspell" "On-the-fly spelling checker." t)
(autoload 'flyspell-delay-command "flyspell" "Delay on command." t)
(autoload 'tex-mode-flyspell-verify "flyspell" "" t) 


(defun flyspell-check-next-highlighted-word ()
  "custom function to spell check next highlighted word"
  (interactive)
  (flyspell-goto-next-error)
  (ispell-word)
  )

;; skip org mode blocks 
;;;http://emacs.stackexchange.com/questions/450/intelligent-spell-checking-in-org-mode
(add-to-list 'ispell-skip-region-alist '(":\\(PROPERTIES\\|LOGBOOK\\):" . ":END:"))
(add-to-list 'ispell-skip-region-alist '("#\\+BEGIN_SRC" . "#\\+END_SRC"))

#+end_src

#+RESULTS:
: ((#\+BEGIN_SRC . #\+END_SRC) (:\(PROPERTIES\|LOGBOOK\): . :END:) (#\+begin_src . #\+end_src) (ispell-words-keyword forward-line) (ispell-dictionary-keyword forward-line) (ispell-pdict-keyword forward-line) (ispell-parsing-keyword forward-line) (^---*BEGIN PGP [A-Z ]*--* . ^---*END PGP [A-Z ]*--*) (^begin [0-9][0-9][0-9] [^ 	]+$ . 
: end
: ) (^%!PS-Adobe-[123].0 . 
: %%EOF
: ) (^---* \(Start of \)?[Ff]orwarded [Mm]essage . ^---* End of [Ff]orwarded [Mm]essage) (\(--+\|_+\|\(/\w\|\(\(\w\|[-_]\)+[.:@]\)\)\(\w\|[-_]\)*\([.:/@]+\(\w\|[-_~=?&]\)+\)+\)))
*** Overwrite selected text (word like)
    :PROPERTIES:
    :ID:       58a50612-1e22-47ff-9407-da599addc422
    :END:
http://pragmaticemacs.com/emacs/overwrite-selected-text/

By default, if you highlight text in Emacs and then start typing, the highlighted text is not overwritten as in many other editors.
#+BEGIN_SRC emacs-lisp  :results none
;; overwrite selected text
(delete-selection-mode t)
#+END_SRC

*** warn on large files
    :PROPERTIES:
    :ID:       1c49fee9-2249-4b90-83d5-9d0b2c3909e2
    :END:
set currently to 100mb
#+BEGIN_SRC emacs-lisp :results none
;; warn when opening files bigger than 100MB
(setq large-file-warning-threshold 100000000)
#+END_SRC
** system clip 
*** Save whatever’s in the current (system) clipboard before
#+BEGIN_SRC emacs-lisp  :results none
;; Save whatever’s in the current (system) clipboard before
;; replacing it with the Emacs’ text.
;; https://github.com/dakrone/eos/blob/master/eos.org
(setq save-interprogram-paste-before-kill t)
#+END_SRC
* look and feel
  :PROPERTIES:
  :ID:       91d18530-3be7-4b34-9837-82a88213834c
  :END:
** windows popup and position (display-buffer-alist)
   :PROPERTIES:
   :ID:       1ed2f2fa-9f33-46ba-b21a-d5ebbce1520b
   :END:
example from: http://www.lunaryorn.com/posts/the-power-of-display-buffer-alist.html
#+BEGIN_EXAMPLE
(add-to-list 'display-buffer-alist
             '("\\*shell\\*"
               (
                display-buffer-in-previous-window
                display-buffer-below-selected
                )
               (reusable-frames)
               (window-height . 15)
               (window-width . 60)))
#+END_EXAMPLE


*** make help buffer open in current window
    :PROPERTIES:
    :ID:       d03dbd3a-a25e-4786-adae-689ba02b2e7e
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'display-buffer-alist
             '("*Help*" display-buffer-same-window))
#+END_SRC
*** hide specific dired pop windows 
 #+BEGIN_SRC emacs-lisp  :results none
(add-to-list 'display-buffer-alist (cons "\\*Async Shell Command\\*.*" (cons #'display-buffer-no-window nil)))

(add-to-list 'display-buffer-alist (cons "\\*Runner Output\\*.*" (cons #'display-buffer-no-window nil)))

 #+END_SRC
*** suppress specific windows from popping up (hide specific buffers)
    :PROPERTIES:
    :ID:       0c9920bd-1c61-433c-8a51-89f4590896e0
    :END:

 http://mbork.pl/2016-04-12_Showing_some_of_those_Async_Shell_Command_buffers

 #+BEGIN_SRC emacs-lisp  :results none
   ;; (add-to-list 'display-buffer-alist '("^*Async Shell Command*" . (display-buffer-no-window)))

   ;; (defun async-shell-dispatch (orig-fun command &optional output-buffer error-buffer)
   ;;   "If OUTPUT-BUFFER is '(4) (i.e., C-u), temporarily turn off
   ;; blocking of displaying the output-buffer."
   ;;   (if (equal output-buffer '(4))
   ;;       (let ((display-buffer-alist
   ;;              (remove '("^*Async Shell Command*" . (display-buffer-no-window)) display-buffer-alist)))
   ;;         (funcall orig-fun command nil error-buffer))
   ;;     (funcall orig-fun command output-buffer error-buffer)))

   ;; (advice-add 'async-shell-command :around 'async-shell-dispatch)
 #+END_SRC


 #+BEGIN_SRC emacs-lisp  :results none
   ;; (add-to-list 'display-buffer-alist '("^Shell Command Output*" . (display-buffer-no-window)))

   ;; (defun async-shell-dispatch-out (orig-fun command &optional output-buffer error-buffer)
   ;;   "If OUTPUT-BUFFER is '(4) (i.e., C-u), temporarily turn off
   ;; blocking of displaying the output-buffer."
   ;;   (if (equal output-buffer '(4))
   ;;       (let ((display-buffer-alist
   ;;              (remove '("^*Shell Command Output*" . (display-buffer-no-window)) display-buffer-alist)))
   ;;         (funcall orig-fun command nil error-buffer))
   ;;     (funcall orig-fun command output-buffer error-buffer)))

   ;; (advice-add 'async-shell-command :around 'async-shell-dispatch-out)
 #+END_SRC





** Base
   :PROPERTIES:
   :ID:       799b472b-a4d9-49b9-8eab-ab836c060ffc
   :END:

#+begin_src emacs-lisp results none
;; Remove splash screen
(setq inhibit-splash-screen t)

;; transient mode-importnat!
(transient-mark-mode 1)

;;winner mode by def-alut

;m use C-c <left> to restore the previous window configuration
(winner-mode 1)

; syntax highlighting everywhere
(global-font-lock-mode 1)

;; after copy Ctrl+c in Linux X11, you can paste by `yank' in emacs
(setq x-select-enable-clipboard t)

;; after mouse selection in X11, you can paste by `yank' in emacs
(setq x-select-enable-primary t)

;;paren mode- show visually matching parens
(show-paren-mode 1)
;show line numbers
(global-linum-mode 0) ; display line numbers in margin. Emacs 23 only

;visual line
(global-visual-line-mode 1) ; 1 for on, 0 for off.

;; don't show text in scratch buffer
(setq initial-scratch-message nil)

; Add word wrapping/wrap, may cause lines to be to short if enabled
;(global-visual-line-mode t)
(setq line-move-visual nil)


;;disable tooltips
(tooltip-mode -1)

#+end_src

#+RESULTS:

** start maximized
   :PROPERTIES:
   :ID:       5636025d-3ca9-44cd-95f1-5f4817604ed3
   :END:
#+BEGIN_SRC emacs-lisp :results none
;Start maximized, please
(custom-set-variables
 '(initial-frame-alist (quote ((fullscreen . maximized))))) ;; start maximized

#+END_SRC
** scroll
   :PROPERTIES:
   :ID:       115a8d8f-e26c-4aae-8d7a-98fe6d82ee85
   :END:
#+BEGIN_SRC emacs-lisp :results none
(setq scroll-margin 3
      scroll-conservatively 101
      scroll-up-aggressively 0.01
      scroll-down-aggressively 0.01
      scroll-preserve-screen-position t
      auto-window-vscroll nil
      hscroll-margin 5
      hscroll-step 5)
#+END_SRC
** toolbars
   :PROPERTIES:
   :ID:       7a2d034c-c9ca-4ab2-854a-865bd40ec707
   :END:
turn on off toolbars with icons
1 to switch on and -1 to switch off
#+BEGIN_SRC emacs-lisp :results none
(tool-bar-mode -1)
#+END_SRC
** mouse and cursor
   :PROPERTIES:
   :ID:       74e64c4a-89e7-4381-a4cb-1e7159a51bc0
   :END:

#+BEGIN_SRC emacs-lisp :results none
(setq mouse-wheel-scroll-amount '(1 ((shift) . 1))) ;; one line at a time

(setq mouse-wheel-progressive-speed nil) ;; don't accelerate scrolling

(setq mouse-wheel-follow-mouse 't) ;; scroll window under mouse

;make cursor blink (use -1 to disable):
(blink-cursor-mode -1)

;;Keep the cursor steady when scrolling
(setq scroll-preserve-screen-position t)
;Focus Follows Mouse
(setq mouse-autoselect-window t)


#+END_SRC
** Menus
   :PROPERTIES:
   :ID:       c96836d8-6c31-4ce2-84b1-eff3905547e6
   :END:
*** Add language switching menu
    :PROPERTIES:
    :ID:       ea4b5ac4-67ce-42db-abfa-a2efc91b9923
    :END:
 
#+begin_src emacs-lisp results none
(define-key-after global-map [menu-bar file lang-modes] 
  (cons "Language Modes" (make-sparse-keymap "major modes")) 'kill-buffer )

(define-key global-map [menu-bar file lang-modes bash] '("Bash" . sh-mode))
(define-key global-map [menu-bar file lang-modes org] '("Org" . org-mode))
(define-key global-map [menu-bar file lang-modes tcl] '("TCL" . tcl-mode))
(define-key global-map [menu-bar file lang-modes ruby] '("Ruby" . ruby-mode))
(define-key global-map [menu-bar file lang-modes python] '("Python" . python-mode))
(define-key global-map [menu-bar file lang-modes php] '("PHP" . php-mode))
(define-key global-map [menu-bar file lang-modes perl] '("Perl" . cperl-mode))
(define-key global-map [menu-bar file lang-modes separator1] '("--"))
(define-key global-map [menu-bar file lang-modes haskell] '("Haskell" . haskell-mode))
(define-key global-map [menu-bar file lang-modes ocaml] '("OCaml" . tuareg-mode))
(define-key global-map [menu-bar file lang-modes elisp] '("Emacs Lisp" . emacs-lisp-mode))
(define-key global-map [menu-bar file lang-modes separator2] '("--"))
(define-key global-map [menu-bar file lang-modes latex] '("LaTeX" . latex-mode))
(define-key global-map [menu-bar file lang-modes js] '("Javascript" . js2-mode))
(define-key global-map [menu-bar file lang-modes xml] '("XML (xml-mode)" . xml-mode))
(define-key global-map [menu-bar file lang-modes nxml] '("XML (nxml-mode)" . nxml-mode))
(define-key global-map [menu-bar file lang-modes html] '("HTML" . html-mode))
(define-key global-map [menu-bar file lang-modes htmlhelper] '("HTML (html-helper-mode)" . html-helper-mode))
(define-key global-map [menu-bar file lang-modes css] '("CSS" . css-mode))
(define-key global-map [menu-bar file lang-modes separator3] '("--"))
(define-key global-map [menu-bar file lang-modes java] '("Java" . java-mode))
(define-key global-map [menu-bar file lang-modes c++] '("C++" . c++-mode))
(define-key global-map [menu-bar file lang-modes c] '("C" . c-mode))
#+end_src

*** Add zeltak menu
    :PROPERTIES:
    :ID:       976fb60b-817c-4c11-9af0-953f4e706f20
    :END:
 
#+begin_src emacs-lisp results none
  ;; (easy-menu-define zmenu global-map "zglobal-menu"
  ;;   '("zglobal"
       
  ;; ("Programs" ;; submenu
  ;;        [""  (djcb-term-start-or-switch "mutt" t)]
  ;;        ["mc"    (djcb-term-start-or-switch "mc" t)]
  ;;        ["htop"  (djcb-term-start-or-switch "htop" t)]
  ;;        ["iotop" (djcb-term-start-or-switch "iotop" t)])
    
  ;;      ;; http://emacs-fu.blogspot.com/2009/03/math-formulae-in-webpages.html
  ;;      ;; this submenu is only visible when in org--mode
  ;;      ("Org"  :visible (or (string= major-mode "org-mode") (string= major-mode "org-mode"))
  ;;        ["Insert formula"   texdrive-insert-formula :help "Insert some formula"]
  ;;        ["Generate images"  texdrive-generate-images :help "(Re)generate the images for the formulae"])
       
  ;;      ;; http://emacs-fu.blogspot.com/2009/03/twitter.html
  ;;      ("Twitter" ;; submenu
  ;;        ["View friends" twitter-get-friends-timeline]
  ;;        ["What are you doing?" twitter-status-edit])
  
  ;;      ("Misc"  ;; submenu
  ;;        ;; http://emacs-fu.blogspot.com/2009/01/counting-words.html
  ;;        ["Count words" djcb-count-words]
  
  ;;        ;;http://emacs-fu.blogspot.com/2008/12/showing-line-numbers.html
  ;;        ["Show/hide line numbers" linum]
  
  ;;        ;; http://emacs-fu.blogspot.com/2008/12/running-emacs-in-full-screen-mode.html
  ;;        ["Toggle full-screen" djcb-fullscreen-toggle])))
  
  (easy-menu-define zorg org-mode-map "zorg-menu"
    '("zorg"
       ;; http://emacs-fu.blogspot.com/2008/12/running-console-programs-inside-emacs.html
       ("images" ;; submenu
         ["org toggle inline"  (org-toggle-inline-images t)]
         ["mc"    (fun1  t)]
         ["htop"  (fun2  t)]
         ["iotop" (fun3  t)])
       
       ;; http://emacs-fu.blogspot.com/2009/03/twitter.html
       ("Twitter" ;; submenu
         ["View friends" twitter-get-friends-timeline]
         ["What are you doing?" twitter-status-edit])
  
       ("Misc"  ;; submenu
         ;; http://emacs-fu.blogspot.com/2009/01/counting-words.html
         ["Count words" djcb-count-words]
  
         ;;http://emacs-fu.blogspot.com/2008/12/showing-line-numbers.html
         ["Show/hide line numbers" linum]
  
         ;; http://emacs-fu.blogspot.com/2008/12/running-emacs-in-full-screen-mode.html
         ["Toggle full-screen" djcb-fullscreen-toggle])))
  
  
#+end_src

** Theme and colors
   :PROPERTIES:
   :ID:       812e2340-20ff-4cc0-b1e4-a70328f5f668
   :END:
*** disable answering yes to "unsafe" themes 
    :PROPERTIES:
    :ID:       dec0eb0d-c10a-4130-a8f2-8b79562b5d2f
    :END:
#+begin_src emacs-lisp
(setq custom-safe-themes t)    
#+end_src
*** change background based on file type
    :PROPERTIES:
    :ID:       e68d7553-ea55-4e17-b0e6-8250b14b0cb8
    :END:
#+begin_src emacs-lisp results none

;; sample code for setting a background color depending on file name extension

; (defun my-set-theme-on-mode ()
;   "set background color depending on file suffix"
;   (interactive)
;   (let ((fileNameSuffix (file-name-extension (buffer-file-name) ) ))
;     (cond
;      ((string= fileNameSuffix "py" ) (set-background-color "honeydew"))
;      ((string= fileNameSuffix "txt" ) (set-background-color "cornsilk"))
;      (t (message "%s" "no match found"))
;      )
;     ))
;
; (add-hook 'find-file-hook 'my-set-theme-on-mode)
#+end_src

** Evil mode look and feel
   :PROPERTIES:
   :ID:       2394ac8c-e76f-42d5-b143-71c0e904f679
   :END:
*** Cursor colors by state
    :PROPERTIES:
    :ID:       0f039d27-95d1-431f-b827-ac5d254034c1
    :END:
#+BEGIN_SRC emacs-lisp :results none
;color in emacs mode
(setq evil-emacs-state-cursor '("cyan" box))
;nomral state mode
(setq evil-normal-state-cursor '("red" box))
;visual state mode
(setq evil-visual-state-cursor '("orange" box))
;inset state mode
(setq evil-insert-state-cursor '("green" box))
(setq evil-replace-state-cursor '("green" box))
(setq evil-operator-state-cursor '("green" hollow))

#+END_SRC
** whitespace 
#+BEGIN_SRC emacs-lisp  :results none
(setq-default show-trailing-whitespace nil)
#+END_SRC
** syntax highlighting
*** add offlineimaprc syntax
 #+BEGIN_SRC emacs-lisp  :results none
 ;; .offlineimaprc is a unix conf file
 (add-to-list 'auto-mode-alist '("\\.offlineimaprc" . conf-mode))
 #+END_SRC

* Dired
  :PROPERTIES:
  :ID:       63862a3e-5b05-424d-9a39-2ceb785d28fc
  :END:
** main options 
   :PROPERTIES:
   :ID:       b926aa40-2c39-4bd6-821f-5bb5106e0f9a
   :END:
*** Sort Directories First
    :PROPERTIES:
    :ID:       22195e14-54df-4811-b116-1240bcb55178
    :END:
#+BEGIN_SRC emacs-lisp :results none
;; Make sizes human-readable by default, sort version numbers
;; correctly, and put dotfiles and capital-letters first.
(setq-default dired-listing-switches "-alhv --group-directories-first ")

#+END_SRC
*** Auto guess target
    :PROPERTIES:
    :ID:       4ead60f8-4d3e-41e6-bd2c-d97cb42a8c36
    :END:
Set this variable to non-nil, Dired will try to guess a default target directory. This means: if there is a dired buffer displayed in the next window, use its current subdir, instead of the current subdir of this dired buffer. The target is used in the prompt for file copy, rename etc.
#+BEGIN_SRC emacs-lisp :results none
(setq dired-dwim-target t)
#+END_SRC
*** Always Recursion
    :PROPERTIES:
    :ID:       8fe76f67-121e-43f3-b774-e15505e5f649
    :END:
Always recursively delete directory
#+BEGIN_SRC emacs-lisp :results none
(setq dired-recursive-deletes 'always); “always” means no asking
;Always recursively copy directory
;(setq dired-recursive-copies 'top) ; “top” means ask once
(setq dired-recursive-copies 'always) ; never ask

#+END_SRC

*** dired find
    :PROPERTIES:
    :ID:       4abfe98a-2437-4212-984e-ca0d58d5c602
    :END:
#+BEGIN_SRC emacs-lisp :results none
(require 'find-dired)
(setq find-ls-option '("-print0 | xargs -0 ls -ld" . "-ld"))
#+END_SRC
*** Auto-refresh dired on file change
    :PROPERTIES:
    :ID:       1f219ddb-bb20-459a-b4e1-9dc5e7361149
    :END:
#+BEGIN_SRC emacs-lisp  :results none
;; Auto-refresh dired on file change
(add-hook 'dired-mode-hook 'auto-revert-mode)
;; Auto refresh dired, but be quiet about it
(setq global-auto-revert-non-file-buffers t)
(setq auto-revert-verbose nil)
#+END_SRC
*** dired sync for external commands
    :PROPERTIES:
    :ID:       88f4cf47-edab-4bc4-8501-f30767382c88
    :END:
#+BEGIN_SRC emacs-lisp  :results none
;; Allow running multiple async commands simultaneously
(defadvice shell-command (after shell-in-new-buffer (command &optional output-buffer error-buffer))
  (when (get-buffer "*Async Shell Command*")
    (with-current-buffer "*Async Shell Command*"
      (rename-uniquely))))
(ad-activate 'shell-command)
#+END_SRC
** dired omit 
   :PROPERTIES:
   :ID:       afd7987e-0eb7-4f66-88f5-c78b57342a67
   :END:
Omitting a file means removing it from the directory listing. Omitting is useful for keeping Dired buffers free of “uninteresting” files (for instance, auto-save, auxiliary, backup, and revision control files) so that the user can concentrate on the interesting files.
To activate it, add this to your .emacs

#+BEGIN_SRC emacs-lisp :results none
(setq-default dired-omit-mode t)
(setq-default dired-omit-verbose nil)
#+END_SRC

To toggle the mode, bind it to a keystroke that you like

(define-key dired-mode-map (kbd "C-o") 'dired-omit-mode)

dired-omit-files contains the regex of the files to hide in Dired Mode. For example, if you want to hide the files that begin with . and #, set that variable like this

(setq-default dired-omit-files "^\\.?#\\|^\\.$\\|^\\.\\.$\\|^\\.")

The variable dired-omit-extensions holds the list of all file extensions to hide in Dired Omit Mode. You can modify the list to add more file extensions to hide or remove the ones that you would like to show.

(add-to-list 'dired-omit-extension ".example")
(delete 'dired-omit-extension ".example")

*** start and toggle
    :PROPERTIES:
    :ID:       b13447a2-1e32-48e4-87a4-05a50c1a7be2
    :END:
@Note: If you are using Dired Omit Mode with dired+, remember to put the config of Dired Omit Mode before loading (require) dired+ since some feature of dired+ use the config from Dired Omit Mode (for example for displaying the file names).@
#+BEGIN_SRC emacs-lisp :results none
;To activate it, add this to your .emacs
(setq-default dired-omit-mode t)
;To toggle the mode, bind it to a keystroke that you like
(define-key dired-mode-map (kbd "C-o") 'dired-omit-mode)
#+END_SRC

** wdired mode
   :PROPERTIES:
   :ID:       fae48697-b0fc-4a1a-a1f8-2daf933026a5
   :END:
!check why mapping tab doesn't work and kills Emacs startup!
functions to get tab etc to work 

#+BEGIN_SRC emacs-lisp :results none
(defun my-mark-file-name-for-rename ()
    "Mark file name on current line except its extension"
    (interactive)

    ;; get the file file name first
    ;; full-name: full file name
    ;; extension: extension of the file
    ;; base-name: file name without extension
    (let ((full-name (file-name-nondirectory (dired-get-filename)))
          extension base-name)
      
      ;; check if it's a dir or a file
      ;; TODO not use if, use switch case check for symlink
      (if (file-directory-p full-name)
          (progn
            ;; if file name is directory, mark file name should mark the whole
            ;; file name
            (call-interactively 'end-of-line) ;move the end of line
            (backward-char (length full-name)) ;back to the beginning
            (set-mark (point))
            (forward-char (length full-name)))
        (progn
          ;; if current file is a file, mark file name mark only the base name,
          ;; exclude the extension
          (setq extension (file-name-extension full-name))
          (setq base-name (file-name-sans-extension full-name))
          (call-interactively 'end-of-line)
          (backward-char (length full-name))
          (set-mark (point))
          (forward-char (length base-name))))))

  (defun my-mark-file-name-forward ()
    "Mark file name on the next line"
    (interactive)
    (deactivate-mark)
    (next-line)
    (my-mark-file-name-for-rename))

  (defun my-mark-file-name-backward ()
    "Mark file name on the next line"
    (interactive)
    (deactivate-mark)
    (previous-line)
    (my-mark-file-name-for-rename))

#+END_SRC

$Note-if you see starnge behivour this maybe a culprit$  
#+BEGIN_SRC emacs-lisp :results none
  ;; (eval-after-load 'wdired
  ;;   (progn
  ;;     (define-key wdired-mode-map (kbd "d") 'my-mark-file-name-forward))
#+END_SRC
** archive files
   :PROPERTIES:
   :ID:       7360aa43-633d-4e04-b66f-70dc7dcd5a27
   :END:
#+BEGIN_SRC emacs-lisp :results none
;; Handle zip compression
(eval-after-load "dired-aux"
  '(add-to-list 'dired-compress-file-suffixes
                '("\\.zip\\'" ".zip" "unzip")))
#+END_SRC
** navigate
   :PROPERTIES:
   :ID:       9c5bb354-76f1-4b74-8b0a-abe9612b9cb9
   :END:
*** auto open/enter file/dir in isearch
    :PROPERTIES:
    :ID:       dbb9911a-45f0-467a-9b48-4202b289ac5b
    :END:
#+BEGIN_SRC emacs-lisp :results none
  ;; (add-hook 'isearch-mode-end-hook 
  ;;   (lambda ()
  ;;     (when (and (eq major-mode 'dired-mode)
  ;;            (not isearch-mode-end-hook-quit))
  ;;       (dired-find-file))))
#+END_SRC

** keybinds
   :PROPERTIES:
   :ID:       49d4796b-0734-457b-a3a9-063732e1a9bd
   :END:
 #+BEGIN_SRC emacs-lisp :results none
 (define-key dired-mode-map (kbd "<left>") 'diredp-up-directory-reuse-dir-buffer )
; (define-key dired-mode-map (kbd "<right>") 'diredp-find-file-reuse-dir-buffer )
 (define-key dired-mode-map (kbd "<right>") 'dired-find-directory )
 (define-key dired-mode-map (kbd "TAB") 'ace-window )
 (define-key dired-mode-map (kbd "S-RET") 'dired-open-in-external-app )
;; (define-key dired-mode-map (kbd "/") 'isearch-repeat-forward )
;; (define-key dired-mode-map (kbd "/") 'counsel-grep-or-swiper)
 (define-key dired-mode-map (kbd "/") 'counsel-find-file)
 (define-key dired-mode-map (kbd "S-.") 'helm-dired-recent-dirs-view )
 (define-key dired-mode-map (kbd  "\\") 'hydra-leader/body   )
; (define-key dired-mode-map (kbd  "\\") 'hydra-chd-dired/body )
 (define-key dired-mode-map (kbd  "`") 'hydra-dired-leader/body )
 (define-key dired-mode-map (kbd  "<f1>") 'dired-do-async-shell-command   )
 (define-key dired-mode-map (kbd  "<f2>") 'dired-efap   )
 (define-key dired-mode-map (kbd  "<f3>") 'dired-view-file   )
 (define-key dired-mode-map (kbd  "<f5>") 'dired-do-copy  )
 (define-key dired-mode-map (kbd  "<f6>") 'dired-do-rename  )
 (define-key dired-mode-map (kbd  "<f7>") 'dired-create-directory  )
 (define-key dired-mode-map (kbd  "<f9>") 'z/dired-shell-other-window  )
 (define-key dired-mode-map (kbd  "y") 'tda/rsync-multiple-mark-file )
 (define-key dired-mode-map (kbd  "p") 'tda/rsync-multiple )
 (define-key dired-mode-map (kbd  "s") 'hydra-dired-sort/body )
 (define-key dired-mode-map (kbd  "<C-return>") 'z/dired-xdg-open )
 (define-key dired-mode-map (kbd  "<C-a>") 'dired-mark-subdir-files )
 (define-key dired-mode-map (kbd  "S-<f1>") 'hydra-toggles/body  )
 (define-key dired-mode-map (kbd  "S-<f3>") 'hydra-spell/body  )
 (define-key dired-mode-map (kbd  "S-<f4>") 'hydra-org-blocks/body  )
 (define-key dired-mode-map (kbd  "S-<f5>") 'hydra-mu4e/body  )
 (define-key dired-mode-map (kbd  "S-<f6>") 'hydra-bib/body  )
 (define-key dired-mode-map (kbd  "S-<f9>") 'hydra-org/body  )
;;; for image dired to delete photos using 'd'
 (define-key image-mode-map (kbd  "d") 'z/delete-current-file  )
 #+END_SRC

** hydra 
   :PROPERTIES:
   :ID:       a6abe140-5b01-4a85-ba79-b61f215c5662
   :END:
*** dired leader
    :PROPERTIES:
    :ID:       64ee4731-88fb-47ab-bbb6-93ec053f249f
    :END:

 #+BEGIN_SRC emacs-lisp :results none
    (global-set-key
       (kbd "")
    (defhydra hydra-dired-leader  (:color blue  :columns 4 :hints nil)
"

"
    ("1" hydra-dired-copy/body "copy operatios" :face 'hydra-face-red  )
    ("2"  z/dired-shell-sshfs-qnap "ssh qnap" )
    ("3" hydra-dired-operations/body "dired operations" )
    ("4" hydra-dired-searches/body "dired searches" )  ("/" dired-toggle-sudo  "dired toggle sudo" :face 'hydra-face-red ) 
 
    ("<f1>" hydra-cheatsheet-dired/body  "toggle dired cheatsheet" ) 
    ("<f4>" diredp-toggle-find-file-reuse-dir  "toggle resue dired" ) 
    ("<f9>" z/dired-open-in-term    "open terminator" ) 
    ("=" z/transpose-buffers  "transpose-buffers" ) 
   
    ("a" dired-mark-subdir-files "mark all" )
    ("b" z/dired-shell-other-window-beets  "beet import" ) 
    ("B" z/dired-shell-other-window-beets-single  "beet import" ) 
  ;  ("B" (execute-kbd-macro (symbol-function 'z/dired-macro-beetimp))  "beet import BACKGROUND" ) 
    ("d"  z/dired-shell-ncdu  "ncdu" ) 
    ("c" z/dired-copy-setdirs "copy to dirs"  :face 'hydra-face-red )
    ("C" z/dired-copy-setdirs-recurs "copy to dirs-RECURSE"   :face 'hydra-face-red  )
    ("e"  z/dired-media-filebot "filebot"   :face 'hydra-face-red  )
    ("f" z/dired-shell-fb "fb" )
    ("i" peep-dired "peek (show) images etc in other panel" )
    ("l" diredp-list-marked "list marked in buffer" )
    ("L" diredp-list-marked-recursive "list marked in buffer RECURSIVLY" )
    ("m" z/dired-move-setdirs  "move to dirs"   :face 'hydra-face-red  )            
    ("M" z/dired-move-setdirs-recurs   "move to dirs-RECURSE"   :face 'hydra-face-red  )            
    ("v" z/dired-copy-rsync   "rsync copy"   :face 'hydra-face-red  )            
    ("z" dired-filter-load-saved-filters "load filter")
    ("Z" hydra-dired-filter/body "filter menu")
    ("h"  nil )
    ("o" z/dired-open-in-desktop "open with FM" )
    ("s" dired-do-symlink   "sort menu" )
    ("n"  z/dired-get-size "get size" )
    ("r" wdired-change-to-wdired-mode "wdired (bath rename)" )
    ("R" z/open-this-file-as-other-user "open as ROOT or USER" )
    ("u"  diredfd-do-unpack "unpack"   :face 'hydra-face-brown  )
  ; ("U"  z/dired-archive-unrar "unrar" :face 'hydra-face-brown )
    ("U"  z/dired-shell-pea-extract "pz unpack"   :face 'hydra-face-brown  )
    ("p"  diredfd-do-pack  "pack" :face 'hydra-face-brown )
    ("P"  z/dired-shell-pea-zip  "pea zip pack" :face 'hydra-face-brown )
    ("Y"  dired-ranger-copy "copy2clip" )
    ("P"  dired-ranger-paste "paste_F_clip")
    ("D" dired-ranger-move "move2clip")
    ("x"  z/dired-shell-chmodx "+x" )
    ("r"  wdired-change-to-wdired-mode "wdired (bath rename)" )
    (";"  nil )
    ("q"  nil )

    ))
 #+END_SRC



*** dired filter and find 
    :PROPERTIES:
    :ID:       8ae27df4-bdad-467d-90c3-90b404f0edc4
    :END:

 #+BEGIN_SRC emacs-lisp :results none
 (defhydra hydra-dired-filter  (:color blue :hint nil :columns 5)
      "
Filter by:
      "
     ("e" dired-filter-by-extension  "extension"  :face 'hydra-face-brown ) 
     ("r" dired-filter-by-regexp  "regex" :face 'hydra-face-brown ) 
     ("f" dired-filter-by-file  "file"  :face 'hydra-face-brown ) 
     ("n" dired-filter-by-name  "name"  :face 'hydra-face-brown ) 
     ("S" dired-filter-save-filters  "save filter" ) 
     ("l" dired-filter-load-saved-filters  "load filter"  :face 'hydra-face-brown ) 
     ("L" dired-filter-add-saved-filters "add ontop filter"  :face 'hydra-face-brown ) 
     ("z" dired-filter-mode "toggle (clear) filter"  :face 'hydra-face-brown ) 
     ("d" find-name-dired  "find file dired" ) 
     ("g" find-grep-dired  "find grep dired" ) 
      ("q" nil "cancel" nil)
 )
 #+END_SRC

*** dired-omit-mode
    :PROPERTIES:
    :ID:       d9816643-2fb5-4ac9-b9e2-1035eb9d9d46
    :END:

 #+BEGIN_SRC emacs-lisp :results none
 (defhydra hydra-dired-configs (:color blue )
      "
      "
     ("o" dired-omit-mode  "dired omit" ) 
     ("t" dired-details-toggle  "dired details" ) 
     ("w" wdired-change-to-wdired-mode  "wdired" ) 
      ("q" nil "cancel" nil)
 )
 #+END_SRC

dired-omit-mode


*** dired operations
    :PROPERTIES:
    :ID:       24438a7b-321b-4e49-b72d-f98be1f35d3a
    :END:
 #+BEGIN_SRC emacs-lisp :results none
 (defhydra hydra-dired-operations  (:color blue :hint nil :columns 5)
      "
Filter by:
      "
     ("nm" z/dired-shell-nmap-hlan  "nmap" ) 
     ("ns" z/dired-shell-netstat  "netstat") 
     ("o" z/del-nonorg-files  "delete non org" ) 
     ("m" z/dired-media-info  "media-info" ) 
     ("cd" z/dired-shell-doc2docx  "doc2docx" ) 
     ("cp" z/dired-shell-pdf2text  "pdf2text" ) 
     ("is" xah-dired-scale-image  "scale" ) 
     ("ic" xah-dired-image-autocrop  "autocrop" ) 
     ("ij" xah-dired-2jpg  "to-jpg" ) 
     ("ip" xah-dired-2png "to-png" ) 
     ("v"  dired-do-version  "version (copy) file" ) 
      ("q" nil "cancel" nil)
 )
 #+END_SRC


*** dired copy-move 
    :PROPERTIES:
    :ID:       a58a191b-3325-4f8a-bd60-af8993acadb0
    :END:
 #+BEGIN_SRC emacs-lisp :results none
 (defhydra hydra-dired-copy  (:color blue :hint nil :columns 5)
      "
move (red) or copy (green) to:
      "
     ("B" z/dired-copy-to-BK  "BK" :face 'hydra-face-green ) 
     ("c" z/dired-move-to-comics  "comics"  :face 'hydra-face-red ) 
     ("h" z/dired-move-to-hmedia  "hmedia"  :face 'hydra-face-red ) 
     ("t" z/dired-move-to-tv   "tv"  :face 'hydra-face-red )  
     ("k" z/dired-move-to-tv-kids   "tv-kids"  :face 'hydra-face-red )  
     ("l" z/dired-move-to-movies-kids  "movies-kids"  :face 'hydra-face-red ) 
     ("r" z/dired-move-to-mreview  "mreview"  :face 'hydra-face-red ) 
     ("m" z/dired-move-to-music  "music"  :face 'hydra-face-red ) 
     ("v" z/dired-move-to-movies  "movies"  :face 'hydra-face-red ) 
      ("q" nil "cancel" nil)
 )
 #+END_SRC
*** hydra-dired-sort
    :PROPERTIES:
    :ID:       38cb48e9-e3f9-499f-ad0b-70eef76dba9c
    :END:
#+BEGIN_SRC emacs-lisp  :results none
 (defhydra hydra-dired-sort (:color blue :hint nil :columns 5)
      "
sortby:
      "
     ("t" z/dired-sort-time-toggle  "time"   ) 
     ("r" z/dired-sort-time-toggle-reverse "time-REVERSE"   ) 
     ("n" z/dired-sort-name-toggle  "name"   ) 
     ("e" z/dired-sort-extension-toggle  "extension"   ) 
     ("s" z/dired-sort-size-toggle  "size"   ) 
     ("h" hydra-dired-quick-sort/body  "quic-sort-menu"   ) 
     ("x" z/dired-sort-menu  "xha sort menu"   ) 
      ("q" nil "cancel" nil)
 )
#+END_SRC

*** z/hydra-cheatsheet-dired-body
#+BEGIN_SRC emacs-lisp :results none
 (defhydra hydra-cheatsheet-dired (:color blue  :columns 5)
"
Marking and Unmarking Files
--------------------------------------------------------------------------
mark files with a given extension 【* .】
mark all directories 【* /】
invert marking 【t】
mark all  files in the current subdir 【* s】
mark files names matching a regular expression 【* S-5】 > mark by string // ^test(start with) txtDOLLAR (end with) 
--------------------------------------------------------------------------
【M-n】 cycle diredx guesses 【V】open file read only 【i】open dir-view below 【b】preview file 
--------------------------------------------------------------------------
【O/G】change owner/group 【M】Change mode 【%u/%l】 convert to upper/lower case
【P】 peep-dir (image view) >> image mode:  【p/n】next/prev images 【d】del image 
"
("q" nil "")
 )
#+END_SRC
*** dired searches
    :PROPERTIES:
    :ID:       23331d9b-258f-4424-bbca-bc29df66e9ce
    :END:
 #+BEGIN_SRC emacs-lisp :results none
 (defhydra hydra-dired-searches  (:color blue :hint nil :columns 5)
      "
Filter by:
      "
     ("i" z/dired-search-imdb "imdb" ) 
     ("g" z/dired-search-google "google" ) 
     ("m" z/dired-search-allmusic "allmusic" ) 
      ("q" nil "cancel" nil)
 )
 #+END_SRC


** dired functions
   :PROPERTIES:
   :ID:       5743ce57-0e6e-4200-98a1-041dd5342db8
   :END:
*** Making directories on the fly
http://mbork.pl/2016-07-25_Making_directories_on_the_fly

#+BEGIN_SRC emacs-lisp  :results none
(defun make-parent-directory ()
  "Make sure the directory of `buffer-file-name' exists."
  (make-directory (file-name-directory buffer-file-name) t))

(add-hook 'find-file-not-found-functions #'make-parent-directory)
#+END_SRC
*** marks
    :PROPERTIES:
    :ID:       ac4fbc74-254e-4ed6-bca7-33e093a3f626
    :END:
**** mark and delete non org
     :PROPERTIES:
     :ID:       9debc364-e203-449c-88b8-f4257c59d1bc
     :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/del-nonorg-files ()
(interactive)
(dired-mark-files-regexp "\\.org$") 
(dired-toggle-marks)
(dired-do-delete)
)
#+END_SRC
*** recent dirs
    :PROPERTIES:
    :ID:       1dbe8359-3be1-40e4-bf51-7fb47dfb39a3
    :END:
#+BEGIN_SRC emacs-lisp  :results none
;; open recent directory, requires ivy (part of swiper)
;; borrows from http://stackoverflow.com/questions/23328037/in-emacs-how-to-maintain-a-list-of-recent-directories
(defun z/dired-recent-dirs-ivy ()
  "Present a list of recently used directories and open the selected one in dired"
  (interactive)
  (let ((recent-dirs
         (delete-dups
          (mapcar (lambda (file)
                    (if (file-directory-p file) file (file-name-directory file)))
                  recentf-list))))

    (let ((dir (ivy-read "Directory: "
                         recent-dirs
                         :re-builder #'ivy--regex
                         :sort nil
                         :initial-input nil)))
      (dired dir))))

(global-set-key (kbd "C-x C-d") 'z/ivy-dired-recent-dirs)
#+END_SRC
*** open in external (XDG default) app
    :PROPERTIES:
    :ID:       203faad7-929d-4533-b94b-70c439155055
    :END:
http://ergoemacs.org/emacs/emacs_dired_open_file_in_ext_apps.html

#+BEGIN_SRC emacs-lisp :results none
(defun z/dired-open-in-external-app ()
  "Open the current file or dired marked files in external app.
The app is chosen from your OS's preference."
  (interactive)
  (let* (
         (ξfile-list
          (if (string-equal major-mode "dired-mode")
              (dired-get-marked-files)
            (list (buffer-file-name))))
         (ξdo-it-p (if (<= (length ξfile-list) 5)
		       t
                     (y-or-n-p "Open more than 5 files? "))))

    (when ξdo-it-p
      (cond
       ((string-equal system-type "windows-nt")
        (mapc
         (lambda (fPath)
           (w32-shell-execute "open" (replace-regexp-in-string "/" "\\" fPath t t))) ξfile-list))
       ((string-equal system-type "darwin")
        (mapc
         (lambda (fPath) (shell-command (format "open \"%s\"" fPath)))  ξfile-list))
       ((string-equal system-type "gnu/linux")
        (mapc
         (lambda (fPath) (let ((process-connection-type nil)) (start-process "" nil "xdg-open" fPath))) ξfile-list))))))
#+END_SRC
*** open in WM/DE file manager
    :PROPERTIES:
    :ID:       9183773b-e710-4139-b201-acac5fa7371e
    :END:

#+BEGIN_SRC emacs-lisp :results none
(defun z/dired-open-in-desktop ()
  "Show current file in desktop (OS's file manager)."
  (interactive)
  (cond
   ((string-equal system-type "windows-nt")
    (w32-shell-execute "explore" (replace-regexp-in-string "/" "\\" default-directory t t)))
   ((string-equal system-type "darwin") (shell-command "open ."))
   ((string-equal system-type "gnu/linux")
    (let ((process-connection-type nil)) (start-process "" nil "xdg-open" "."))
    ;; (shell-command "xdg-open .") ;; 2013-02-10 this sometimes froze emacs till the folder is closed. ⁖ with nautilus
    ) ))
#+END_SRC

*** open in term
    :PROPERTIES:
    :ID:       dd6a7d7f-c43c-4059-98e0-bb90bd183e76
    :END:
 #+BEGIN_SRC emacs-lisp :results none
(defun z/dired-open-in-term ()
  (interactive)
  (async-shell-command "termite ."))
 #+END_SRC
*** dired-find directoy
to use the right key to only enter directories not files 
#+BEGIN_SRC emacs-lisp  :results none
(defun dired-find-directory ()
  "A `dired-find-file' which only works on directories."
  (interactive)
  (let ((find-file-run-dired t)
        (file (dired-get-file-for-visit)))
    (when (file-directory-p file)
      (find-file file))))
#+END_SRC
*** Shell functions
    :PROPERTIES:
    :ID:       8a202561-4b59-4c1d-9a2a-514e96872c54
    :END:
**** convert doc to docx
     :PROPERTIES:
     :ID:       61dea651-ec3d-4908-a2c4-bfb805ecea94
     :END:
#+BEGIN_SRC emacs-lisp
(defun  z/dired-shell-doc2docx ()
    "doc to docx"
    (interactive)
    (shell-command (concat "libreoffice --headless --convert-to docx " (dired-file-name-at-point))))

 ;; (add-hook 'dired-mode-hook '(lambda () 
 ;;                               (local-set-key (kbd "O") 'cygstart-in-dired)))
#+END_SRC
**** convert doc to docx
     :PROPERTIES:
     :ID:       8ea4e485-e078-474e-8739-16a62072b02a
     :END:
#+BEGIN_SRC emacs-lisp
(defun  z/dired-shell-pdf2text ()
    "pdf to text"
    (interactive)
    (shell-command (concat "pdftotext " (dired-file-name-at-point))))

 ;; (add-hook 'dired-mode-hook '(lambda () 
 ;;                               (local-set-key (kbd "O") 'cygstart-in-dired)))
#+END_SRC
**** TODO convert md to org
     :PROPERTIES:
     :ID:       2701bc34-ac81-45a7-b43f-7017bfcbd8e5
     :END:
 #+BEGIN_SRC emacs-lisp
(defun  z/dired-shell-md2org ()
 "..."
 (interactive)
 (let ((base  (file-name-base (dired-get-file-name))))
   (shell-command (format "pandoc -o %s.org %.md" base base))))
#+END_SRC


**** ncdu
     :PROPERTIES:
     :ID:       8ccb3e48-2342-457c-a155-3ac3ffec0a55
     :END:
 #+BEGIN_SRC emacs-lisp
(defun  z/dired-shell-ncdu ()
 "ncdu"
(interactive)
(z/visit-ansi-term)
(term-send-input)
(insert "ncdu" )
(term-send-input)
)
 #+END_SRC

**** sshfs qnap
     :PROPERTIES:
     :ID:       13cc65a3-c748-4793-8b64-29a5ce7033e5
     :END:
#+BEGIN_SRC emacs-lisp :results none
 (defun  z/dired-shell-sshfs-qnap ()
     "ssh qnap"
     (interactive)
   (z/visit-ansi-term)
(term-send-input)
    (insert "sshfs -p 12121 admin@10.0.0.2:/share/MD0_DATA/ /home/zeltak/mounts/lraid  " )
(term-send-input)
)
 #+END_SRC
**** shell other window
     :PROPERTIES:
     :ID:       46d6cc95-dc1e-4c7d-a990-ad999d54816c
     :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-shell-other-window ()
  "Open a `shell' in a new window."
  (interactive)
  (let ((buf (shell)))
    (switch-to-buffer (other-buffer buf))
    (switch-to-buffer-other-window buf)))

#+END_SRC
**** cb2bib
#+BEGIN_SRC emacs-lisp  :results none
 (defun  z/dired-shell-cb2bib ()
     "Uses fb to upload file at point."
     (interactive)
     (shell-command "cb2bib")
		    )
#+END_SRC

**** shell beet 
     :PROPERTIES:
     :ID:       fe0a5d99-1853-423e-836b-3a59eccd643e
     :END:
http://emacs.stackexchange.com/questions/23961/help-with-dired-function-i-wrote-how-to-insert-current-file-at-point-into-buffe/23963#23963

 #+BEGIN_SRC emacs-lisp  :results none
 (defun z/dired-shell-other-window-beets ()
   (interactive)
   (let ((command (concat "beet import " (format "%S" (dired-get-filename)))))
     (switch-to-buffer (shell)
       (insert command)
       (comint-send-input))))
#+END_SRC
**** shell beet 
     :PROPERTIES:
     :ID:       482d8349-c76a-40cf-867e-7f2aa2b3d849
     :END:
http://emacs.stackexchange.com/questions/23961/help-with-dired-function-i-wrote-how-to-insert-current-file-at-point-into-buffe/23963#23963

 #+BEGIN_SRC emacs-lisp  :results none
 (defun z/dired-shell-other-window-beets-single ()
   (interactive)
   (let ((command (concat "beet import -s " (format "%S" (dired-get-filename)))))
     (switch-to-buffer (shell)
       (insert command)
       (comint-send-input))))
#+END_SRC
*** get marked files size
    :PROPERTIES:
    :ID:       f8061f4b-addb-47be-8f0d-dc1f4917e303
    :END:
#+BEGIN_SRC emacs-lisp :results none
 (defun z/dired-get-size ()
  (interactive)
  (let ((files (dired-get-marked-files)))
    (with-temp-buffer
      (apply 'call-process "/usr/bin/du" nil t nil "-sch" files)
      (message "Size of all marked files: %s"
	       (progn 
                 (re-search-backward "\\(^[0-9.,]+[A-Za-z]+\\).*total$")
                  (match-string 1))))))
#+END_SRC

*** media
    :PROPERTIES:
    :ID:       cf0f099e-bad3-419c-8b6b-665831860997
    :END:
**** mediainfo
     :PROPERTIES:
     :ID:       8412a912-79f9-4b1f-8c1c-f2a7329ce20b
     :END:
#+BEGIN_SRC emacs-lisp :results none
  (defun  z/dired-media-info ()
      "media info "
      (interactive)
      (shell-command (concat "mediainfo "  (dired-file-name-at-point)
 )))
#+END_SRC
**** file bot
     :PROPERTIES:
     :ID:       4a16569e-d111-484e-80fc-24d08c35fd81
     :END:
#+BEGIN_SRC emacs-lisp  :results none
  (defun  z/dired-media-filebot ()
      "media info"
      (interactive)
      (shell-command (concat "filebot "  (dired-file-name-at-point)
 )))
#+END_SRC
*** networking
    :PROPERTIES:
    :ID:       b00a814e-8b5e-46cf-85e7-08454c980e1b
    :END:
**** netstat
     :PROPERTIES:
     :ID:       0cd2813c-fcef-4086-b386-d332df21bca6
     :END:
#+BEGIN_SRC emacs-lisp :results none
(defun  z/dired-shell-netstat ()
 "netstat"
(interactive)
(z/visit-ansi-term)
(term-send-input)
(insert "netstat -tlnp" )
(term-send-input)
)
 #+END_SRC
**** nmap home lan
     :PROPERTIES:
     :ID:       859c2ea7-6e76-4620-91c1-e3432b58eec1
     :END:
#+BEGIN_SRC emacs-lisp :results none
(defun  z/dired-shell-nmap-hlan ()
 "nmap-hlan"
(interactive)
(z/visit-ansi-term)
(term-send-input)
(insert "nmap -sP 192.168.0.1/24" )
(term-send-input)
)
 #+END_SRC
*** fb
    :PROPERTIES:
    :ID:       64b066df-9047-4a06-902e-8afef29d1525
    :END:
 #+BEGIN_SRC emacs-lisp
 (defun  z/dired-shell-fb ()
     "Uses fb to upload file at point."
     (interactive)
     (shell-command (concat "fb " (dired-file-name-at-point)))
     (message (propertize "Uploaded to FB" 'face 'font-lock-warning-face))
     (alert "Upload to FB" :title "FB" :category 'debug)

)
 #+END_SRC

 #+RESULTS:
 : z/dired-shell-fb

 
*** sshfs qnap
    :PROPERTIES:
    :ID:       15305964-6cb6-4239-9e25-8b1cf8292713
    :END:
#+BEGIN_SRC emacs-lisp
(defun z/dired-ssh-qnap ()
    "chmod"
    (interactive)
    (shell-command (concat "sshfs -p 12121 admin@10.0.0.2:/share/MD0_DATA/ /home/zeltak/mounts/lraid " (dired-file-name-at-point)))
    (message (propertize "connected to ssh" 'face 'font-lock-warning-face))
)
#+END_SRC

*** chmodx
    :PROPERTIES:
    :ID:       07168f17-ff83-4666-8928-ca38d21cd96a
    :END:

 #+BEGIN_SRC emacs-lisp
 (defun z/dired-shell-chmodx ()
     "chmod"
     (interactive)
     (shell-command (concat "chmod +x " (dired-file-name-at-point)))
;;; to refresh view use revert buffer  
    (revert-buffer)
    (message (propertize "changed mode to executable" 'face 'font-lock-warning-face))
 )

 #+END_SRC

**** sshfs qnap
     :PROPERTIES:
     :ID:       4a85428b-33e6-4f16-9d30-fda66aa42059
     :END:
 #+BEGIN_SRC emacs-lisp
 (defun z/dired-ssh-qnap ()
     "chmod"
     (interactive)
     (shell-command (concat "sshfs -p 12121 admin@10.0.0.2:/share/MD0_DATA/ /home/zeltak/mounts/lraid " (dired-file-name-at-point)))
     (message (propertize "connected to ssh" 'face 'font-lock-warning-face))
 )
 #+END_SRC
*** nmap network
    :PROPERTIES:
    :ID:       933b98d8-aef4-4da1-8548-dc76d1a92a3f
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/dired-nmap-network ()
"map all available IP on my netwrok"
(interactive)
(sr-term )
(insert " nmap -sP 10.0.0.1/24" )
(eshell-send-input)
)
#+END_SRC
*** Sorting 
    :PROPERTIES:
    :ID:       8e4f8883-00c8-4837-8b1e-277b10093730
    :END:
**** xha dired sort
     :PROPERTIES:
     :ID:       0f5386fb-985f-4f38-8b98-ca72a24a1dfa
     :END:
 #+BEGIN_SRC emacs-lisp :results none
 (defun z/dired-sort-menu ()
   "Sort dired dir listing in different ways.
 Prompt for a choice.
 URL `http://ergoemacs.org/emacs/dired_sort.html'
 Version 2015-07-30"
   (interactive)
   (let (ξsort-by ξarg)
     (setq ξsort-by (ido-completing-read "Sort by:" '( "date" "size" "name" "dir")))
     (cond
      ((equal ξsort-by "name") (setq ξarg "-Al --si --time-style long-iso "))
      ((equal ξsort-by "date") (setq ξarg "-Al --si --time-style long-iso -t"))
      ((equal ξsort-by "size") (setq ξarg "-Al --si --time-style long-iso -S"))
      ((equal ξsort-by "dir") (setq ξarg "-Al --si --time-style long-iso --group-directories-first"))
      (t (error "logic error 09535" )))
     (dired-sort-other ξarg )))
 #+END_SRC
**** dired-quick-sort-time
     :PROPERTIES:
     :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-sort-time-toggle ()
    (interactive)
    (dired-quick-sort "time" (if (char-equal dired-quick-sort-reverse-last ?y)
                                 ?n ?y))
                  (beginning-of-buffer )
)
#+END_SRC

**** dired-quick-sort-time-reverse
     :PROPERTIES:
     :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-sort-time-toggle-reverse ()
    (interactive)
(z/dired-sort-time-toggle)
(z/dired-sort-time-toggle)
)
#+END_SRC


**** dired-quick-sort-name
     :PROPERTIES:
     :ID:       c93c148e-7d8f-4b07-8c15-c22c133b841a
     :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-sort-name-toggle ()
    (interactive)
    (dired-quick-sort "version" (if (char-equal dired-quick-sort-reverse-last ?y)
                                 ?n ?y))
                  (beginning-of-buffer )
)
#+END_SRC
**** dired-quick-sort-size
     :PROPERTIES:
     :ID:       ffe897cc-8697-40b1-836a-f32eb8ef1145
     :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-sort-size-toggle ()
    (interactive)
    (dired-quick-sort "size" (if (char-equal dired-quick-sort-reverse-last ?y)
                                 ?n ?y))
                  (beginning-of-buffer )
)
#+END_SRC
**** dired-quick-sort-extension
     :PROPERTIES:
     :ID:       08b4757e-35a7-42b5-9e56-69b7f73a9dc4
     :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-sort-extension-toggle ()
    (interactive)
    (dired-quick-sort "extension" (if (char-equal dired-quick-sort-reverse-last ?y)
                                 ?n ?y))
                  (beginning-of-buffer )
)
#+END_SRC


*** dired-image
    :PROPERTIES:
    :ID:       8d2c1aeb-8083-4080-9b9a-4e7bbfa70ceb
    :END:
**** extra binds
     :PROPERTIES:
     :ID:       c4e47d0a-de7c-4352-ae0e-2cc4769a224b
     :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-next-image ()
  (interactive)
  (save-excursion 
    (with-current-buffer "*image-dired*"
      (image-dired-forward-image)
      (image-dired-display-thumbnail-original-image))))

(defun z/dired-prev-image ()
  (interactive)
  (save-excursion 
    (with-current-buffer "*image-dired*"
      (image-dired-backward-image)
      (image-dired-display-thumbnail-original-image))))

(defun x/dired-insert-current-image-path ()
  (interactive)
  (insert
   (concat
    "[["
    (save-excursion
      (with-current-buffer "*image-dired*"
        (image-dired-original-file-name)))
    "]]")))
#+END_SRC
**** xah image manipulations
     :PROPERTIES:
     :ID:       dcbd3634-e7f6-48c5-9b2e-f5e89b309974
     :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun xah-process-image (φfile-list φargs-str φnew-name-suffix φnew-name-file-suffix )
  "Wrapper to ImageMagick's “convert” shell command.
φfile-list is a list of image file paths.
φargs-str is argument string passed to ImageMagick's “convert” command.
φnew-name-suffix is the string appended to file. e.g. “_new” gets you “…_new.jpg”
φnew-name-file-suffix is the new file's file extension. e.g. “.png”

URL `http://ergoemacs.org/emacs/emacs_dired_convert_images.html'
Version 2015-10-19"
  (require 'dired)
  (mapc
   (lambda (ξf)
     (let ( newName cmdStr )
       (setq newName
             (concat
              (file-name-sans-extension ξf)
              φnew-name-suffix
              φnew-name-file-suffix))
       (while (file-exists-p newName)
         (setq newName
               (concat
                (file-name-sans-extension newName)
                φnew-name-suffix
                (file-name-extension newName t))))
       ;; relative paths used to get around Windows/Cygwin path remapping problem
       (setq cmdStr
             (format
              "convert %s '%s' '%s'" 
              φargs-str 
              (file-relative-name ξf) 
              (file-relative-name newName)))
       (shell-command cmdStr)))
   φfile-list )
  (revert-buffer))

(defun xah-dired-scale-image (φfile-list φscale-percentage φsharpen?)
  "Create a scaled version of images of marked files in dired.
The new names have “-s” appended before the file name extension.

If `universal-argument' is given, output is PNG format. Else, JPG.

When called in lisp code,
 φfile-list is a list.
 φscale-percentage is a integer.
 φsharpen? is true or false.

Requires ImageMagick unix shell command.
URL `http://ergoemacs.org/emacs/emacs_dired_convert_images.html'
Version 2015-03-10"
  (interactive
   (let (
         (myFileList
          (cond
           ((string-equal major-mode "dired-mode") (dired-get-marked-files))
           ((string-equal major-mode "image-mode") (list (buffer-file-name)))
           (t (list (read-from-minibuffer "file name:"))))))
     (list myFileList
           (read-from-minibuffer "Scale %:")
           (y-or-n-p "Sharpen"))))
  (let ((sharpenOrNo (if φsharpen? "-sharpen 1" "" ))
        (outputSuffix (if current-prefix-arg ".png" ".jpg" )))
    (xah-process-image φfile-list
                       (format "-scale %s%% -quality 85%% %s " φscale-percentage sharpenOrNo)
                       "-s" outputSuffix )))

(defun xah-dired-image-autocrop (φfile-list φoutput-image-type-suffix)
  "Create a new auto-cropped version of images of marked files in dired.
Requires ImageMagick shell command.

If `universal-argument' is given, output is PNG format. Else, JPG.
URL `http://ergoemacs.org/emacs/emacs_dired_convert_images.html'
Version 2015-03-10"
  (interactive
   (let (
         (myFileList
          (cond
           ((string-equal major-mode "dired-mode") (dired-get-marked-files))
           ((string-equal major-mode "image-mode") (list (buffer-file-name)))
           (t (list (read-from-minibuffer "file name:")))))
         (φoutput-image-type-suffix (if current-prefix-arg ".png" ".jpg" )))
     (list myFileList φoutput-image-type-suffix)))
  (xah-process-image φfile-list "-trim" "-cropped" φoutput-image-type-suffix ))

(defun xah-dired-2png (φfile-list)
  "Create a png version of images of marked files in dired.
Requires ImageMagick shell command.
URL `http://ergoemacs.org/emacs/emacs_dired_convert_images.html'
Version 2015-03-10"
  (interactive
   (let (
         (myFileList
          (cond
           ((string-equal major-mode "dired-mode") (dired-get-marked-files))
           ((string-equal major-mode "image-mode") (list (buffer-file-name)))
           (t (list (read-from-minibuffer "file name:"))))))
     (list myFileList)))
  (xah-process-image φfile-list "" "-2" ".png" ))

(defun xah-dired-2jpg (φfile-list)
  "Create a JPG version of images of marked files in dired.
Requires ImageMagick shell command.
URL `http://ergoemacs.org/emacs/emacs_dired_convert_images.html'
Version 2015-03-10"
  (interactive
   (let (
         (myFileList
          (cond
           ((string-equal major-mode "dired-mode") (dired-get-marked-files))
           ((string-equal major-mode "image-mode") (list (buffer-file-name)))
           (t (list (read-from-minibuffer "file name:") )) ) ) )
     (list myFileList) )
   )
  (xah-process-image φfile-list "" "-2" ".jpg" ))
#+END_SRC
*** Archives 
    :PROPERTIES:
    :ID:       f8b6477f-10b7-4b00-9c4b-b63d6baba79c
    :END:
**** unrar 
     :PROPERTIES:
     :ID:       57aa2756-b822-459d-8a4e-a4dffc65fe95
     :END:
 #+BEGIN_SRC emacs-lisp :results none
 (defun  z/dired-archive-unrar ()
     "unrar"
     (interactive)
     (shell-command (concat "unrar x" (dired-file-name-at-point))))
 #+END_SRC
**** peazip extract
     :PROPERTIES:
     :ID:       f47ce447-4995-4250-b392-179110b1214a
     :END:
 #+BEGIN_SRC emacs-lisp
 (defun z/dired-shell-pea-extract ()
     "chmod"
     (interactive)
     (shell-command (concat "peazip -ext2folder " (dired-file-name-at-point)))
;;; to refresh view use revert buffer  
    (revert-buffer)
    (message (propertize "extracted" 'face 'font-lock-warning-face))
 )

 #+END_SRC


**** peazip zip
     :PROPERTIES:
     :ID:       2f340b18-695e-46e9-ba25-c448d316c3d4
     :END:
 #+BEGIN_SRC emacs-lisp
 (defun z/dired-shell-pea-zip ()
     "chmod"
     (interactive)
     (shell-command (concat "peazip -add2zip " (dired-file-name-at-point)))
;;; to refresh view use revert buffer  
    (revert-buffer)
    (message (propertize "peazip zipped" 'face 'font-lock-warning-face))
 )

 #+END_SRC

 #+RESULTS:
 : z/dired-shell-pea-zip


*** Copy/move operations
    :PROPERTIES:
    :ID:       a1233e86-1ca9-4601-b65d-1ee9e8b86711
    :END:
**** copy to list of specific folders
     :PROPERTIES:
     :ID:       0e09e869-92c6-4631-b8ea-6a499d54a6ec
     :END:
http://stackoverflow.com/questions/29809698/emacs-dired-using-predefined-variable

#+BEGIN_SRC emacs-lisp  :results none
;; Use ido
(require 'ido)

;; Make a hash table to hold the paths
(setq my-target-dirs (make-hash-table :test 'equal))

;; A function to return all the keys from a hash.
(defun get-keys-from-hash (hash)
  (let ((keys ()))
    (maphash (lambda (k v) (push k keys)) hash)
    keys))

;; And the function to prompt for a directory by keyword that is looked
;; up in the hash-table and used to build the target path from the
;; value of the lookup.
(defun z/dired-copy-setdirs ()
  (interactive)
  (let* ((my-hash my-target-dirs)
         (files (dired-get-marked-files))
         (keys (get-keys-from-hash my-hash)))
    (mapc (lambda (file)
            (copy-file file
		       (concat
                        (gethash
                         (ido-completing-read
                          (concat "copy " file " to: ") keys) my-hash)
                        (file-name-nondirectory file))))
          files)))


(defun z/dired-move-setdirs ()
  (interactive)
  (let* ((my-hash my-target-dirs)
         (files (dired-get-marked-files))
         (keys (get-keys-from-hash my-hash)))
    (mapc (lambda (file)
            (rename-file file
		       (concat
                        (gethash
                         (ido-completing-read
                          (concat "move" file " to: ") keys) my-hash)
                        (file-name-nondirectory file))))
          files)))
#+END_SRC


#+BEGIN_SRC emacs-lisp  :results none
;; Put some paths in the hash (sorry for Unix pathnames)
(puthash "home" "/home/zeltak/" my-target-dirs)
(puthash "AUR" "/home/zeltak/AUR/" my-target-dirs)
(puthash "downloads" "/home/zeltak/Downloads/ " my-target-dirs)
(puthash "ZH_tmp" "/home/zeltak/ZH_tmp/" my-target-dirs)
(puthash "music" "/home/zeltak/music/" my-target-dirs)
(puthash "bin" "/home/zeltak/bin/" my-target-dirs)
(puthash "BK" "/home/zeltak/BK/" my-target-dirs)
(puthash "org" "/home/zeltak/org/" my-target-dirs)
(puthash "mreview" "/home/zeltak/mreview/" my-target-dirs)
(puthash "Sync" "/home/zeltak/Sync/" my-target-dirs)
(puthash "Uni" "/home/zeltak/Uni/" my-target-dirs)
(puthash "scripts" "/home/zeltak/scripts/" my-target-dirs)
(puthash "p2p" "/home/zeltak/mounts/lraid/Download/transmission/completed/" my-target-dirs)
(puthash "dotfiles" "/home/zeltak/dotfiles/" my-target-dirs)
(puthash "config" "/home/zeltak/.config/" my-target-dirs)
(puthash "conv" "/home/zeltak/ZH_tmp/$CONV" my-target-dirs)
(puthash "mvid" "/home/zeltak/mounts/lraid/raid/Videos/1_Video/michal/" my-target-dirs)
(puthash "kidstv" "/home/zeltak/mounts/lraid/raid/Videos/1_Video/Kids/TV/" my-target-dirs)
(puthash "kidstv" "/home/zeltak/mounts/lraid/raid/Videos/1_Video/Kids/Animated Movies/" my-target-dirs)
#+END_SRC


 #+BEGIN_SRC emacs-lisp
   (defun z/dired-copy-setdirs-recurs ()
     (interactive)
     (let* ((my-hash my-target-dirs)
            (files (dired-get-marked-files))
            (keys (get-keys-from-hash my-hash)))
       (mapc (lambda (file)
	       (let ((target (gethash
                              (ido-completing-read
			       (concat "copy " file " to: ") keys) my-hash)))
                 (if (y-or-n-p "Descend?")
                     ;; Descend into subdirectories relative to target dir
                     (let ((new-target (ido-read-directory-name "new dir: " target))) 
		       (copy-file file (concat new-target
					       (file-name-nondirectory file)))
		       (message (concat "File: " file " was copied to " new-target)))
                   ;; Else copy to root of originally selected directory
                   (copy-file file (concat target (file-name-nondirectory file)))
                   (message (concat "File: " file " was copied to " target)))))
             files)))

   (defun z/dired-move-setdirs-recurs ()
     (interactive)
     (let* ((my-hash my-target-dirs)
            (files (dired-get-marked-files))
            (keys (get-keys-from-hash my-hash)))
       (mapc (lambda (file)
	       (let ((target (gethash
                              (ido-completing-read
			       (concat "move " file " to: ") keys) my-hash)))
                 (if (y-or-n-p "Descend?")
                     ;; Descend into subdirectories relative to target dir
                     (let ((new-target (ido-read-directory-name "new dir: " target))) 
		       (rename-file file (concat new-target
					       (file-name-nondirectory file)))
		       (message (concat "File: " file " was moved to " new-target)))
                   ;; Else copy to root of originally selected directory
                   (rename-file file (concat target (file-name-nondirectory file)))
                   (message (concat "File: " file " was moved to " target)))))
             files)))
 #+END_SRC
**** copy file (version it)
     :PROPERTIES:
     :ID:       c6544088-5abf-444d-b03b-d6182386385e
     :END:
#+BEGIN_SRC emacs-lisp  :results none
(defcustom dired-keep-marker-version ?V
  "Controls marking of versioned files.
If t, versioned files are marked if and as the corresponding original files were.
If a character, copied files are unconditionally marked with that character."
  :type '(choice (const :tag "Keep" t)
         (character :tag "Mark"))
  :group 'dired-mark)

(defun dired-version-file (from to ok-flag)
  (dired-handle-overwrite to)
  (dired-copy-file-recursive from to ok-flag dired-copy-preserve-time t
                 dired-recursive-copies))

(defun dired-do-version (&optional arg)
  "Search for numeric pattern in file name and create a version of that file
with that number incremented by one, or, in case such file already exists,
will search for a file with the similar name, incrementing the counter each
time by one.
Additionally, if called with prefix argument, will prompt for number format.
The formatting is the same as is used with `format' function."
  (interactive "P")
  (let ((fn-list (dired-get-marked-files nil nil)))
    (dired-create-files
     (function dired-version-file) "Version" fn-list
     (function
      (lambda (from)
        (let (new-name (i 0) (fmt (if arg (read-string "Version format: " "%d") "%d")))
          (while (or (null new-name) (file-exists-p new-name))
            (setq new-name
                  (if (string-match  "^\\([^0-9]*\\)\\([0-9]+\\)\\(.*\\)$" from)
                      (concat (match-string 1 from)
                              (format fmt
                                      (+ (string-to-number (match-string 2 from)) (1+ i)))
                              (match-string 3 from))
                    (concat from (format (concat "." fmt) i)))
                  i (1+ i))) new-name)))
     dired-keep-marker-version)))

;;(define-key dired-mode-map (kbd "c") 'dired-do-version)
#+END_SRC
**** quick move/copy to predefined folders
     :PROPERTIES:
     :ID:       a64e9482-d03d-4654-9bcb-3692b4973737
     :END:
***** move to Movies
      :PROPERTIES:
      :ID:       23059f45-f8c8-4e58-a372-ddc7737e4f17
      :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-move-to-movies (&optional arg)
  (interactive "P")
  (cl-letf* ((default-dest-dir "/home/zeltak/mounts/lraid/raid/Videos/Movies")
             ((symbol-function 'dired-dwim-target-directory)
              (lambda ()
                default-dest-dir)))
    (call-interactively #'dired-do-rename)))
;;(define-key dired-mode-map (kbd ";") #'my/dired-do-rename)
#+END_SRC
***** move to Movies kids
      :PROPERTIES:
      :ID:       fadb8b92-ab08-41d0-85ac-e07c06ea3b91
      :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-move-to-movies-kids (&optional arg)
  (interactive "P")
  (cl-letf* ((default-dest-dir "/home/zeltak/mounts/lraid/raid/Videos/1_Video/Kids/Animated Movies/")
             ((symbol-function 'dired-dwim-target-directory)
              (lambda ()
                default-dest-dir)))
    (call-interactively #'dired-do-rename)))
;;(define-key dired-mode-map (kbd ";") #'my/dired-do-rename)
#+END_SRC
***** move to tv
      :PROPERTIES:
      :ID:       81fe2c42-0c17-403f-b7e9-3469d2cdf89b
      :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-move-to-tv (&optional arg)
  (interactive "P")
  (cl-letf* ((default-dest-dir "/home/zeltak/mounts/lraid/raid/Videos/TV")
             ((symbol-function 'dired-dwim-target-directory)
              (lambda ()
                default-dest-dir)))
    (call-interactively #'dired-do-rename)))
#+END_SRC

***** move to tv kids
      :PROPERTIES:
      :ID:       7f8efe10-f997-4edf-ad09-f86c1fc31488
      :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-move-to-tv-kids (&optional arg)
  (interactive "P")
  (cl-letf* ((default-dest-dir "/home/zeltak/mounts/lraid/raid/Videos/1_Video/Kids/TV/")
             ((symbol-function 'dired-dwim-target-directory)
              (lambda ()
                default-dest-dir)))
    (call-interactively #'dired-do-rename)))
#+END_SRC

***** move to hmedia
      :PROPERTIES:
      :ID:       2cc0746e-ed16-4457-9e4c-fbef7f9b5009
      :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-move-to-hmedia (&optional arg)
  (interactive "P")
  (cl-letf* ((default-dest-dir "/home/zeltak/media/")
             ((symbol-function 'dired-dwim-target-directory)
              (lambda ()
                default-dest-dir)))
    (call-interactively #'dired-do-rename)))
#+END_SRC

***** move to mreview
      :PROPERTIES:
      :ID:       e0d71412-6a3e-4888-b22e-8e078442e54d
      :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-move-to-mreview (&optional arg)
  (interactive "P")
  (cl-letf* ((default-dest-dir "/home/zeltak/mreview")
             ((symbol-function 'dired-dwim-target-directory)
              (lambda ()
                default-dest-dir)))
    (call-interactively #'dired-do-rename)))
#+END_SRC
***** move to comics
      :PROPERTIES:
      :ID:       a5418a9f-3ce1-4b4a-875d-375aa3cb2fa2
      :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-move-to-comics (&optional arg)
  (interactive "P")
  (cl-letf* ((default-dest-dir "/home/zeltak/mounts/lraid/raid/Comics")
             ((symbol-function 'dired-dwim-target-directory)
              (lambda ()
                default-dest-dir)))
    (call-interactively #'dired-do-rename)))
#+END_SRC
***** move to music
      :PROPERTIES:
      :ID:       41083158-5d8c-4e12-a991-90a7fea47185
      :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-move-to-music (&optional arg)
  (interactive "P")
  (cl-letf* ((default-dest-dir "/home/zeltak/music/")
             ((symbol-function 'dired-dwim-target-directory)
              (lambda ()
                default-dest-dir)))
    (call-interactively #'dired-do-rename)))
#+END_SRC

***** move to BK
      :PROPERTIES:
      :ID:       d14447af-215c-46fe-9c7a-aa086404bf9b
      :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-copy-to-BK (&optional arg)
  (interactive "P")
  (cl-letf* ((default-dest-dir "/home/zeltak/BK/")
             ((symbol-function 'dired-dwim-target-directory)
              (lambda ()
                default-dest-dir)))
    (call-interactively #'dired-do-copy)))
#+END_SRC



*** searching
    :PROPERTIES:
    :ID:       73d2c56c-9132-4bac-8a34-aa4f0cffdf8c
    :END:
**** imdb search
     :PROPERTIES:
     :ID:       78602910-c016-4328-869a-f18c837ef195
     :END:
 #+BEGIN_SRC emacs-lisp :results none
 (defun  z/dired-search-imdb ()
     "imdb point "
     (interactive)
     (shell-command (concat "surfraw imdb " (directory-file-name (file-relative-name (dired-file-name-at-point))) 
)))
 #+END_SRC
**** google search
     :PROPERTIES:
     :ID:       bdb80cd4-30e7-4a35-b395-72d38c0ace43
     :END:
 #+BEGIN_SRC emacs-lisp :results none
 (defun  z/dired-search-google ()
     "google point "
     (interactive)
     (shell-command (concat "surfraw google " (directory-file-name (file-relative-name (dired-file-name-at-point))) 
)))
 #+END_SRC

**** allmusic search
     :PROPERTIES:
     :ID:       93d545db-4d61-4db2-aa7f-ad294c78359d
     :END:
 #+BEGIN_SRC emacs-lisp :results none
 (defun  z/dired-search-allmusic ()
     "allmusic point "
     (interactive)
     (shell-command (concat "surfraw yubnub allmusic  " (directory-file-name (file-relative-name (dired-file-name-at-point))) 
)))
 #+END_SRC
*** Rsync copy 
    :PROPERTIES:
    :ID:       f4daf3ff-154e-46c9-86a9-8e1bc93c74c3
    :END:
#+BEGIN_SRC emacs-lisp  :results none
;;;###autoload
(defun z/dired-copy-rsync (dest)
  (interactive
   (list
    (expand-file-name
     (read-file-name
      "Rsync to:"
      (dired-dwim-target-directory)))))
  ;; store all selected files into "files" list
  (let ((files (dired-get-marked-files
                nil current-prefix-arg))
        ;; the rsync command
        (tmtxt/rsync-command
         "rsync -arvz --progress "))
    ;; add all selected file names as arguments
    ;; to the rsync command
    (dolist (file files)
      (setq tmtxt/rsync-command
            (concat tmtxt/rsync-command
                    (shell-quote-argument file)
                    " ")))
    ;; append the destination
    (setq tmtxt/rsync-command
          (concat tmtxt/rsync-command
                  (shell-quote-argument dest)))
    ;; run the async shell command
    (async-shell-command tmtxt/rsync-command "*rsync*")
    ;; finally, switch to that window
    (other-window 1)))

(define-key dired-mode-map "Y" 'ora-dired-rsync)

#+END_SRC
*** dired XDG open
    :PROPERTIES:
    :ID:       d03609d8-ac1a-4b97-abd2-129a0bf88122
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-xdg-open ()
  "Open the current file or dired marked files in external app.
The app is chosen from your OS's preference.

URL `http://ergoemacs.org/emacs/emacs_dired_open_file_in_ext_apps.html'
Version 2015-01-26"
  (interactive)
  (let* (
         (ξfile-list
          (if (string-equal major-mode "dired-mode")
              (dired-get-marked-files)
            (list (buffer-file-name))))
         (ξdo-it-p (if (<= (length ξfile-list) 5)
                       t
                     (y-or-n-p "Open more than 5 files? "))))

    (when ξdo-it-p
      (cond
       ((string-equal system-type "windows-nt")
        (mapc
         (lambda (fPath)
           (w32-shell-execute "open" (replace-regexp-in-string "/" "\\" fPath t t))) ξfile-list))
       ((string-equal system-type "darwin")
        (mapc
         (lambda (fPath) (shell-command (format "open \"%s\"" fPath)))  ξfile-list))
       ((string-equal system-type "gnu/linux")
        (mapc
         (lambda (fPath) (let ((process-connection-type nil)) (start-process "" nil "xdg-open" fPath))) ξfile-list))))))
#+END_SRC
*** copy current open buffer path to killring
    :PROPERTIES:
    :ID:       47ea9ff3-43a6-4ddc-96bf-f531ad799509
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-copy-buffer-file-path (&optional φdir-path-only-p)
  "Copy the current buffer's file path or dired path to `kill-ring'.
Result is full path.
If `universal-argument' is called first, copy only the dir path.
URL `http://ergoemacs.org/emacs/emacs_copy_file_path.html'
Version 2015-12-02"
  (interactive "P")
  (let ((ξfpath
         (if (equal major-mode 'dired-mode)
             (expand-file-name default-directory)
           (if (null (buffer-file-name))
               (user-error "Current buffer is not associated with a file.")
             (buffer-file-name)))))
    (kill-new
     (if (null φdir-path-only-p)
         (progn
           (message "File path copied: 「%s」" ξfpath)
           ξfpath
           )
       (progn
         (message "Directory path copied: 「%s」" (file-name-directory ξfpath))
         (file-name-directory ξfpath))))))
#+END_SRC\N
*** get-other-dired-directory
    :PROPERTIES:
    :ID:       308fa4d8-e377-4487-91b1-7e115b5f2c6e
    :END:
http://emacs.stackexchange.com/questions/20935/synchronize-current-dired-path-to-next-dired-dir-shown-in-a-split-window

#+BEGIN_SRC emacs-lisp  :results none
(defun z/dired-get-other-dired-directory ()
  "find name and directory of another dired buffer"
  (let ((bs (buffer-list))
        (here (current-buffer))
        this)
    (mapc (lambda (b) (unless (equal b here)
            (with-current-buffer b
              (if dired-directory
                  (setq this (cons (buffer-name) dired-directory)))))) bs)
    this))

(defun my/set-dired-dir-to-other ()
  "Change the dired directory to the one of another existing dired buffer"
  (interactive)
  (let ((d (my/get-other-dired-directory)))
    (if d
        (progn
          (setq dired-directory (cdr d)
                default-directory (cdr d))
          (revert-buffer)
          (rename-buffer (generate-new-buffer-name (car d))))
      (message "No other dired buffer"))))
#+END_SRC
*** Quickly move a file to the current directory
    :PROPERTIES:
    :ID:       8d06ee86-b0fd-4f38-9523-9c24291472db
    :END:

http://pragmaticemacs.com/emacs/quickly-move-a-file-to-the-current-directory/

Often I’ll download a file in my browser, and then want to move that file to the directory in which I am working in emacs. I wrote a little helper function to streamline this, called bjm/move-file-here, given below or at this github gist. Call the function and it will prompt you with a list of files in your starting directory (defaulting to ~/downloads, but configurable with bjm/move-file-here-start-dir) sorted to have the most recent first. The chosen file will then be moved to the current directory if you are in dired, or else the directory of the current buffer. 

#+BEGIN_SRC emacs-lisp  :results none
(require 'dash)

;; start directory
(defvar bjm/move-file-here-start-dir (expand-file-name "~/downloads"))

(defun bjm/move-file-here ()
  "Move file from somewhere else to here.
The file is taken from a start directory set by `bjm/move-file-here-start-dir' and moved to the current directory if invoked in dired, or else the directory containing current buffer. The user is presented with a list of files in the start directory, from which to select the file to move, sorted by most recent first."
  (interactive)
  (let (file-list target-dir file-list-sorted start-file start-file-full)
    ;; clean directories from list but keep times
    (setq file-list
          (-remove (lambda (x) (nth 1 x))
                   (directory-files-and-attributes bjm/move-file-here-start-dir)))

    ;; get target directory
    ;; http://ergoemacs.org/emacs/emacs_copy_file_path.html
    (setq target-dir
          (if (equal major-mode 'dired-mode)
              (expand-file-name default-directory)
            (if (null (buffer-file-name))
                (user-error "ERROR: current buffer is not associated with a file.")
              (file-name-directory (buffer-file-name)))))

  ;; sort list by most recent
  ;;http://stackoverflow.com/questions/26514437/emacs-sort-list-of-directories-files-by-modification-date
  (setq file-list-sorted
        (mapcar #'car
                (sort file-list
                      #'(lambda (x y) (time-less-p (nth 6 y) (nth 6 x))))))

  ;; use ivy to select start-file
  (setq start-file (ivy-read
                    (concat "Move selected file to " target-dir ":")
                    file-list-sorted
                    :re-builder #'ivy--regex
                    :sort nil
                    :initial-input nil))

  ;; add full path to start file and end-file
  (setq start-file-full
        (expand-file-name start-file bjm/move-file-here-start-dir))
  (setq end-file
        (expand-file-name (file-name-nondirectory start-file) target-dir))
  (rename-file start-file-full end-file)
  (message "moved %s to %s" start-file-full end-file)))

#+END_SRC
*** bookmark+ functions
    :PROPERTIES:
    :ID:       c1912531-586e-47b5-b23e-72802310e684
    :END:
#+BEGIN_SRC emacs-lisp  :results none
  ;;  (defun  z/dired-bk-chgd-zh_tmp ()
  ;;      "chgd "
  ;;      (interactive)
  ;;     (bmkp-dired-jump "dired//zh_tmp" )
  ;;      (message (propertize "chgd" 'face 'font-lock-warning-face))
  ;; )
#+END_SRC
*** open as root

http://gergely.polonkai.eu/2016/11/10/edit-file-as-other-user-in-emacs/
#+BEGIN_SRC emacs-lisp  :results none
(defun z/open-this-file-as-other-user (user)
  "Edit current file as USER, using `tramp' and `sudo'.  If the current
buffer is not visiting a file, prompt for a file name."
  (interactive "sEdit as user (default: root): ")
  (when (string= "" user)
    (setq user "root"))
  (let* ((filename (or buffer-file-name
                       (read-file-name (format "Find file (as %s): "
                                               user))))
         (tramp-path (concat (format "/sudo:%s@localhost:" user) filename)))
    (if buffer-file-name
        (find-alternate-file tramp-path)
      (find-file tramp-path))))
#+END_SRC
** dired macro
   :PROPERTIES:
   :ID:       64ea062f-8a94-4bfb-8151-271aec80daa5
   :END:
*** beet import 
    :PROPERTIES:
    :ID:       c406eac7-c6e3-499a-a2c2-af2f8fb60757
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(fset 'z/dired-macro-beetimp
   [?& ?b ?e ?e ?t ?  ?i ?m ?p ?o ?r ?t ])
#+END_SRC
*** beet import single
    :PROPERTIES:
    :ID:       7cea5ea1-4309-4b85-8e05-16b9f0d3bb63
    :END:
#+BEGIN_SRC emacs-lisp  :results none
(fset 'z/dired-macro-beetimp-single
   [?& ?b ?e ?e ?t ?  ?i ?m ?p ?o ?r ?t ?- ?s ])
#+END_SRC

** look and feel
   :PROPERTIES:
   :ID:       0c4a03d8-8e4c-42ab-8f86-054a0335fb42
   :END:
*** breadcrumbs topbar
    :PROPERTIES:
    :ID:       ee93ebdf-5557-468c-8550-52c18cc5a0e4
    :END:
this will add it permanently for each dired buffer. I currently disable it

#+BEGIN_SRC emacs-lisp  :results none
;(add-hook 'dired-before-readin-hook 'diredp-breadcrumbs-in-header-line-mode)
#+END_SRC 
*** add highlight line
    :PROPERTIES:
    :ID:       06d0cded-5353-476a-9507-850cafdc5c6f
    :END:
#+BEGIN_SRC emacs-lisp  :results none
;; Always hilight the current agenda line
(add-hook 'dired-mode-hook
          '(lambda () (hl-line-mode 1))
          'append)

#+END_SRC
* Shell
** settings  
   :PROPERTIES:
   :ID:       3e0f1aa5-6197-4567-bb31-e7d3b1e3e472
   :END:
*** TODO no confirmation for shell exit
http://emacs.stackexchange.com/questions/14509/kill-process-buffer-without-confirmation
or 
http://emacs.stackexchange.com/questions/17005/killing-ansi-term-says-has-a-running-process

#+BEGIN_SRC emacs-lisp  :results none
   (defun set-no-process-query-on-exit ()
     (let ((proc (get-buffer-process (current-buffer))))
       (when (processp proc)
         (set-process-query-on-exit-flag proc nil))))
   (add-hook 'term-exec-hook 'set-no-process-query-on-exit)
;; for Emacs *shell* this is also needed
(add-hook 'shell-mode-hook 'set-no-process-query-on-exit)
#+END_SRC

*** set default term zshrc
    :PROPERTIES:
    :ID:       74820d0a-b37d-420a-ba39-05d6b157f80d
    :END:
#+BEGIN_SRC emacs-lisp :results none
(setq explicit-shell-file-name "/bin/zsh")
#+END_SRC

** shell functions 
  :PROPERTIES:
  :ID:       b82dbd22-2a46-4430-b12a-6681c109a801
  :END:
*** search bash history
    :PROPERTIES:
    :ID:       e7ab7dee-28ba-4b1b-9ed3-68ccc2d40754
    :END:
 can be edited and converted to zsh
 #+BEGIN_SRC emacs-lisp  :results none
 (defun z/counsel-yank-bash-history ()
   "Yank the bash history"
   (interactive)
   (let (hist-cmd collection val)
     (shell-command "history -r") ; reload history
     (setq collection
           (nreverse
            (split-string (with-temp-buffer (insert-file-contents (file-truename "~/.bash_history"))
                                            (buffer-string))
                          "\n"
                          t)))
     (when (and collection (> (length collection) 0)
		(setq val (if (= 1 (length collection)) (car collection)
                            (ivy-read (format "Bash history:") collection))))
         (kill-new val)
         (message "%s => kill-ring" val))))
 #+END_SRC
*** visit ansi term 
    :PROPERTIES:
    :ID:       9e62d4b6-f401-428e-8074-4425267aad72
    :END:
#+BEGIN_SRC emacs-lisp  :results none
;; taken from here: http://www.enigmacurry.com/2008/12/26/emacs-ansi-term-tricks/
(defun z/visit-ansi-term ()
  "If the current buffer is:
     1) a running ansi-term named *ansi-term*, rename it.
     2) a stopped ansi-term, kill it and create a new one.
     3) a non ansi-term, go to an already running ansi-term
        or start a new one while killing a defunt one"
  (interactive)
  (let ((is-term (string= "term-mode" major-mode))
        (is-running (term-check-proc (buffer-name)))
        (term-cmd "/bin/zsh")
        (anon-term (get-buffer "*ansi-term*")))
    (if is-term
        (if is-running
            (if (string= "*ansi-term*" (buffer-name))
                ;; (call-interactively 'rename-buffer)
                (ansi-term term-cmd)
              (if anon-term
                  (switch-to-buffer "*ansi-term*")
                (ansi-term term-cmd)))
          (kill-buffer (buffer-name))
          (ansi-term term-cmd))
      (if anon-term
          (if (term-check-proc "*ansi-term*")
              (switch-to-buffer "*ansi-term*")
            (kill-buffer "*ansi-term*")
            (ansi-term term-cmd))
        (ansi-term term-cmd)))))
#+END_SRC
*** search zsh history

 http://blog.binchen.org/posts/use-ivy-mode-to-search-bash-history.html

 #+BEGIN_SRC emacs-lisp  :results none
(defun z/counsel-yank-zsh-history ()
  "Yank the zsh history"
  (interactive)
  (let (hist-cmd collection val)
    (shell-command "history -r") ; reload history
    (setq collection
          (nreverse
           (split-string (with-temp-buffer (insert-file-contents (file-truename "~/.zsh_history"))
                                           (buffer-string))
                         "\n"
                         t)))

    (setq collection (mapcar (lambda (it) (replace-regexp-in-string ".*;" "" it)) collection))
                      
    (when (and collection (> (length collection) 0)
               (setq val (if (= 1 (length collection)) (car collection)
                           (ivy-read (format "Zsh history:") collection))))
      ;; (setq val (replace-regexp-in-string "^:[^;]*;" "" val))
      ;; (setq val (replace-regexp-in-string ".*;" "" val))
      (kill-new val)
      (message "%s => kill-ring" val))))

#+END_SRC


* Aliases
  :PROPERTIES:
  :ID:       d2aec1b8-66dc-44ba-b882-789918e35809
  :END:
** settings
   :PROPERTIES:
   :ID:       aadae8b6-2bc5-47ae-bf47-01d47fc7cfbf
   :END:
#+BEGIN_SRC emacs-lisp :results none
(defalias 'yes-or-no-p 'y-or-n-p) ; y or n is enough
(defalias 'list-buffers 'ibuffer) ; always use ibuffer
(defalias '~ 'make-backup)
(defalias 'lp 'list-packages)
(defalias 'lm 'lini)
(defalias 'rr 'regex-replace)
(defalias 'em 'evil-mode)
(defalias 'iss 'ispell) ;check spelling on buffer or region if marked
(defalias 'bks 'bmkp-save-menu-list-state) ;check spelling on buffer or region if marked

#+END_SRC

** Editing
   :PROPERTIES:
   :ID:       1a60c490-7eaa-49a0-b052-2d537dc11b48
   :END:
#+BEGIN_SRC emacs-lisp :results none

(defalias 'sl 'sort-lines)
(defalias 'rr 'reverse-region)
(defalias 'rs 'replace-string)
(defalias 'g 'grep)
(defalias 'gf 'grep-find)
(defalias 'fd 'find-dired)
(defalias 'rb 'revert-buffer)
(defalias 'sh 'shell)
(defalias 'ps 'powershell)
(defalias 'fb 'flyspell-buffer)
(defalias 'sbc 'set-background-color)
(defalias 'rof 'recentf-open-files)
(defalias 'lcd 'list-colors-display)

#+END_SRC

** major/minor modes
   :PROPERTIES:
   :ID:       87c575d9-374a-4ab6-95b9-b20c724d7751
   :END:
#+BEGIN_SRC emacs-lisp :results none
; major modes
(defalias 'hm 'html-mode)
(defalias 'tm 'text-mode)
(defalias 'elm 'emacs-lisp-mode)
(defalias 'om 'org-mode)
(defalias 'ssm 'shell-script-mode)
(defalias 'html6-mode 'xah-html6-mode)

; minor modes
(defalias 'wsm 'whitespace-mode)
(defalias 'gwsm 'global-whitespace-mode)
(defalias 'dsm 'desktop-save-mode)
(defalias 'acm 'auto-complete-mode)
(defalias 'vlm 'visual-line-mode)
(defalias 'glm 'global-linum-mode)
#+END_SRC
** Code
   :PROPERTIES:
   :ID:       f6100d88-81ee-42ad-a580-014f3b20878b
   :END:
#+BEGIN_SRC emacs-lisp :results none
; elisp
(defalias 'eb 'eval-buffer)
(defalias 'er 'eval-region)
(defalias 'ed 'eval-defun)
(defalias 'eis 'elisp-index-search)
(defalias 'lf 'load-file)


;escapes
(defalias '\\ 'escape-quotes-region)
(defalias '\[ 'remove-square-brackets)
(defalias '\" 'replace-straight-quotes)
#+END_SRC
+
** mail
   :PROPERTIES:
   :ID:       67c4aaab-df46-493a-948f-621fb38dc657
   :END:
#+BEGIN_SRC emacs-lisp :results none
; elisp
(defalias 'ik 'izeltak@gmail.com)
#+END_SRC

* Abbreviations
  :PROPERTIES:
  :ID:       5d708030-5926-4c4d-ae80-8485ae001047
  :END:
** global abbrv defenitions 
   :PROPERTIES:
   :ID:       f4f6cee3-4cd2-4d73-99ea-97fc408a2087
   :END:
#+BEGIN_SRC emacs-lisp :results none
;(setq save-abbrevs t)
;; stop asking whether to save newly added abbrev when quitting emacs
(setq save-abbrevs 'silently)
;; turn on abbrev mode globally
(setq-default abbrev-mode t)
#+END_SRC

** personal abbriviations
   :PROPERTIES:
   :ID:       e09fad19-96c8-4670-8769-29618e50f0d1
   :END:
*** new collected abbrv
    :PROPERTIES:
    :ID:       8b86b856-59b2-402e-ac9d-7cb7c030a145
    :END:
to quickly peak at the personal file look here:

file:/home/zeltak/.emacs.d/abbrv/personal_abbrv.txt

to set 
#+BEGIN_SRC emacs-lisp :results none
(setq abbrev-file-name "/home/zeltak/.emacs.d/abbrv/personal_abbrv.txt")
#+END_SRC
to autoload it 
#+BEGIN_SRC emacs-lisp :results none
(load "/home/zeltak/.emacs.d/abbrv/personal_abbrv.txt")
#+END_SRC

*** loads a huge common abbreviations file
    :PROPERTIES:
    :ID:       a7f03b5c-7e74-4a66-8f56-20bb3bf2b1d3
    :END:

file:/home/zeltak/.emacs.d/abbrv/common_abbrv.txt

#+BEGIN_SRC emacs-lisp :results none
  (load "/home/zeltak/.emacs.d/abbrv/common_abbrv.txt")
#+END_SRC

*** misc abbrv file (general stuff to quick add)
    :PROPERTIES:
    :ID:       018d14e4-b169-4c31-8eb2-2588d2b31661
    :END:

file:/home/zeltak/.emacs.d/abbrv/misc_abbrv.txt

#+BEGIN_SRC emacs-lisp :results none
  (load "/home/zeltak/.emacs.d/abbrv/misc_abbrv.txt")
#+END_SRC


* minor modes
  :PROPERTIES:
  :ID:       221572e4-c8f3-4fe3-86c2-af3c805df652
  :END:
** vimrc mode
   :PROPERTIES:
   :ID:       0244a602-49bc-448c-92d2-719cafdc90eb
   :END:
#+BEGIN_SRC emacs-lisp :results none
(define-generic-mode 'vimrc-generic-mode
    '()
    '()
    '(("^[\t ]*:?\\(!\\|ab\\|map\\|unmap\\)[^\r\n\"]*\"[^\r\n\"]*\\(\"[^\r\n\"]*\"[^\r\n\"]*\\)*$"
       (0 font-lock-warning-face))
      ("\\(^\\|[\t ]\\)\\(\".*\\)$"
      (2 font-lock-comment-face))
      ("\"\\([^\n\r\"\\]\\|\\.\\)*\""
       (0 font-lock-string-face)))
    '("/vimrc\\'" "\\.vim\\(rc\\)?\\'")
    '((lambda ()
        (modify-syntax-entry ?\" ".")))
    "Generic mode for Vim configuration files.")
#+END_SRC
* Extensions
  :PROPERTIES:
  :ID:       4aad25db-56dc-4a69-a9a4-0e2e2fd29cb8
  :END:
** Xha menu dirs
   :PROPERTIES:
   :ID:       e187220b-733c-47a1-b66b-852bbf68a55b
   :END:
#+BEGIN_SRC emacs-lisp :results none
(if (string= system-name "zbeast") 
(progn

(defvar xah-filelist nil "alist for files i need to open frequently. Key is a short abbrev, Value is file path.")
(setq xah-filelist
      '(
        ("z" . "~/ZH_tmp/" )
        ("k " . "~/BK/" )
        ("l" . "~/org/files/Tech/linux.org" )
        ("f" . "~/org/files/agenda/food.org" )
        ("v" . "~/org/files/Home/travel.org" )
        ("h" . "~/org/files/Home/home.org" )
        ("m" . "~/org/files/from-mobile.org" )
        ("v" . "~/org/files/files/agenda/travel.org" )
        ("h" . "~/org/files/files/Home/home.org" )
        ("p" . "~/org/files/files/uni/papers/papers.org" )
        ("E" . "~/.emacs.d/init.el" )
        ("B" . "/home/zeltak/.config/beets/config.yaml" )
        ("S" . "~/.config/sxhkd/sxhkdrc" )
        ("I" . "~/.i3/config" )
        ("X" . "~/.xinitrc" )
        ("B" . "~/.interrobangrc" )
        ("Z" . "~/.zshrc" )
        ("o" . "~/org/attach/" )
        ) )
)

(progn

(defvar xah-filelist nil "alist for files i need to open frequently. Key is a short abbrev, Value is file path.")
(setq xah-filelist
      '(
       ("z" . "~/ZH_tmp/" )
        ("k " . "~/BK/" )
        ("l" . "~/org/files/Tech/linux.org" )
        ("f" . "~/org/files/agenda/food.org" )
        ("v" . "~/org/files/Home/travel.org" )
        ("h" . "~/org/files/Home/home.org" )
        ("m" . "~/org/files/from-mobile.org" )
        ("v" . "~/org/files/files/agenda/travel.org" )
        ("h" . "~/org/files/files/Home/home.org" )
        ("p" . "~/org/files/files/uni/papers/papers.org" )
        ("E" . "~/.emacs.d/init.el" )
        ("B" . "/home/zeltak/.config/beets/config.yaml" )
        ("S" . "~/.config/sxhkd/sxhkdrc" )
        ("I" . "~/.i3/config" )
        ("X" . "~/.xinitrc" )
        ("B" . "~/.interrobangrc" )
        ("Z" . "~/.zshrc" )
        ("o" . "~/org/attach/" )
        ) )
)
)

#+END_SRC

** z/dired-jump-folders
   :PROPERTIES:
   :ID:       e96b4714-3dce-4676-9a4c-3b4972ef8d36
   :END:
#+BEGIN_SRC emacs-lisp :results none
(defun z/dired-jump-folders  (openCode)
  "Prompt to open a file from a pre-defined set."
  (interactive
   (list (ido-completing-read "Open:" (mapcar (lambda (x) (car x)) xah-filelist)))
   )
  (find-file (cdr (assoc openCode xah-filelist)) ) )
#+END_SRC

** menu per machine
   :PROPERTIES:
   :ID:       26071164-114e-459e-959a-48c495a4fc68
   :END:
(if (string= system-name "voices") 
(progn
COMMAND1
COMMAND2
)

(progn
COMMAND1
COMMAND2
)
)


#+END_EXAMPLE
** edit webpages with emacs
   :PROPERTIES:
   :ID:       2b6ce67e-32fa-4acf-b34f-9cb8c5f2d70b
   :END:
#+BEGIN_SRC emacs-lisp :results none
;(add-to-list 'load-path "/home/zeltak/.emacs.g/extra/edit-server/")
;(require 'edit-server)
;(edit-server-start)
#+END_SRC
* R/ESS
  :PROPERTIES:
  :ID:       90435f6c-a42b-4d65-a18c-84bdabc97942
  :END:
** output
   :PROPERTIES:
   :ID:       a446c601-7502-4a8c-b784-2764c2af26f2
   :END:
*** make scrolling always hit bottom
    :PROPERTIES:
    :ID:       449f014e-0bb2-4435-917b-c585c4c1ba27
    :END:
#+BEGIN_SRC emacs-lisp :results none
  (setq comint-scroll-to-bottom-on-input t)
  (setq comint-scroll-to-bottom-on-output t)
  (setq comint-move-point-for-output t)
#+END_SRC
** default dirs
   :PROPERTIES:
   :ID:       bc400326-5b6d-41de-8335-17c0fcd68944
   :END:
*** transfile file
    :PROPERTIES:
    :ID:       9b8cbec2-82c9-4c7d-b1cf-01a63b3241c1
    :END:
#+BEGIN_SRC emacs-lisp :results none
;don't ask to save file
;(setq ess-ask-about-transfile nil)
(setq ess-ask-about-transfile nil)
#+END_SRC

*** default directory 
    :PROPERTIES:
    :ID:       6ed5f10a-c31d-4d14-9f9e-13e4eee042eb
    :END:
#+BEGIN_SRC emacs-lisp :results none
(setq ess-ask-for-ess-directory nil)
;define deault ess dir
(setq ess-directory "/home/zeltak/ZH_tmp/")
#+END_SRC
*** local process name 
    :PROPERTIES:
    :ID:       1529c204-002c-461e-a4cc-05c261c6414b
    :END:
#+BEGIN_SRC emacs-lisp :results none
(setq ess-local-process-name "Runi")
#+END_SRC

*** history file
    :PROPERTIES:
    :ID:       e38dcf7c-4409-4aa6-b3b6-a7acbd660063
    :END:
global command history file and have:
#+BEGIN_SRC emacs-lisp :results none
 (setq ess-history-directory "~/.essrhist/")
#+END_SRC
** functions
   :PROPERTIES:
   :ID:       9e220e98-c9c9-42fc-8632-d2ad6fd849c8
   :END:
*** clear shell function
    :PROPERTIES:
    :ID:       2dc65a5d-a617-4483-8ad6-450935bd63f7
    :END:
#+BEGIN_SRC emacs-lisp :results none
(defun clear-shell ()
   (interactive)
   (let ((old-max comint-buffer-maximum-size))
     (setq comint-buffer-maximum-size 0)
     (comint-truncate-buffer)
     (setq comint-buffer-maximum-size old-max))) 
#+END_SRC 
*** This recalls the R statement from your R statement history, but it tries to match it with the one which is already on your line.
    :PROPERTIES:
    :ID:       b62a84e0-321c-46c0-8f4b-facee48237bf
    :END:

#+BEGIN_SRC emacs-lisp :results none
(add-hook 'inferior-ess-mode-hook
    '(lambda nil
          (define-key inferior-ess-mode-map [\C-up]
              'comint-previous-matching-input-from-input)
          (define-key inferior-ess-mode-map [\C-down]
              'comint-next-matching-input-from-input)
          (define-key inferior-ess-mode-map [\C-x \t]
              'comint-dynamic-complete-filename)
     )
 )
#+END_SRC
This recalls the R statement from your R statement history, but it tries to match it with the one which is already on your line. So, for example, typing pl in R process and pressing \C-up (that’s control and the up arrow) will cycle through all the statements which start with pl, so it will recall for example all the plot(... commands.

*** allow ess to run procceses in background
    :PROPERTIES:
    :ID:       4b493193-d3e1-4061-90e0-cf201648112c
    :END:

#+BEGIN_SRC emacs-lisp :results none
(setq ess-eval-visibly 'nowait)
#+END_SRC

* Ediff
  :PROPERTIES:
  :ID:       500bdb52-fc46-47d1-8435-86245fe5ff86
  :END:

#+BEGIN_SRC emacs-lisp :results none
(defmacro csetq (variable value)
  `(funcall (or (get ',variable 'custom-set)
                'set-default)
            ',variable ,value))

(csetq ediff-window-setup-function 'ediff-setup-windows-plain)

(csetq ediff-split-window-function 'split-window-horizontally)

(csetq ediff-diff-options "-w")

(defun ora-ediff-hook ()
  (ediff-setup-keymap)
  (define-key ediff-mode-map "j" 'ediff-next-difference)
  (define-key ediff-mode-map "k" 'ediff-previous-difference))

(add-hook 'ediff-mode-hook 'ora-ediff-hook)

(winner-mode)
(add-hook 'ediff-after-quit-hook-internal 'winner-undo)
#+END_SRC




* mail 
** ALL mail
*** user info
#+BEGIN_SRC emacs-lisp  :results none
(setq user-mail-address "izeltak@gmail")
(setq user-full-name "zeltak")
#+END_SRC
*** kill message buffer after exit 
 #+BEGIN_SRC emacs-lisp  :results none
 (setq message-kill-buffer-on-exit t) ; kill buffer after sending mail)
 #+END_SRC
*** Sending mail
    :PROPERTIES:
    :ID:       32d71f9d-b05b-449f-824b-439af66de8c8
    :END:
 #+BEGIN_SRC emacs-lisp :results none
(require 'smtpmail)
;; [smtpmail-async] Experimental, use `smtpmail-send-it' otherwise. 
;(setq message-send-mail-function 'async-smtpmail-send-it)
(setq message-send-mail-function 'smtpmail-send-it)

 (setq starttls-use-gnutls t
    smtpmail-starttls-credentials '(("smtp.gmail.com" 587 nil nil))
    smtpmail-auth-credentials
      '(("smtp.gmail.com" 587 "izeltak@gmail.com" nil))
    smtpmail-default-smtp-server "smtp.gmail.com"
    smtpmail-smtp-server "smtp.gmail.com"
    smtpmail-smtp-service 587)


 #+END_SRC

*** functions 
**** yas auto mail to sender name 
 http://pragmaticemacs.com/emacs/email-templates-in-mu4e-with-yasnippet/

 #+BEGIN_SRC emacs-lisp  :results none
 ;; function to return first name of email recipients
 ;; used by yasnippet
 ;; inspired by
 ;;http://blog.binchen.org/posts/how-to-use-yasnippets-to-produce-email-templates-in-emacs.html
 (defun bjm/mu4e-get-names-for-yasnippet ()
   "Return comma separated string of names for an email"
   (interactive)
   (let ((email-name "") str email-string email-list email-name2 tmpname)
     (save-excursion
       (goto-char (point-min))
       ;; first line in email could be some hidden line containing NO to field
       (setq str (buffer-substring-no-properties (point-min) (point-max))))
     ;; take name from TO field - match series of names
     (when (string-match "^To: \"?\\(.+\\)" str)
       (setq email-string (match-string 1 str)))
     ;;split to list by comma
     (setq email-list (split-string email-string " *, *"))
     ;;loop over emails
     (dolist (tmpstr email-list)
       ;;get first word of email string
       (setq tmpname (car (split-string tmpstr " ")))
       ;;remove whitespace or ""
       (setq tmpname (replace-regexp-in-string "[ \"]" "" tmpname))
       ;;join to string
       (setq email-name
             (concat email-name ", " tmpname)))
     ;;remove initial comma
     (setq email-name (replace-regexp-in-string "^, " "" email-name))

     ;;see if we want to use the name in the FROM field
     ;;get name in FROM field if available, but only if there is only
     ;;one name in TO field
     (if (< (length email-list) 2)
         (when (string-match "^\\([^ ,\n]+\\).+writes:$" str)
           (progn (setq email-name2 (match-string 1 str))
                  ;;prefer name in FROM field if TO field has "@"
                  (when (string-match "@" email-name)
                    (setq email-name email-name2))
                  )))
     email-name))

 #+END_SRC
** Mu4e
   :PROPERTIES:
   :ID:       8a00e5c0-28f4-4e9a-8e73-83ca174237e6
   :END:
to see how to initially setup mu4e see this link [[id:5de95b73-bb3a-4da8-81d2-23e78a6dc5cf][setting up MU4E]]   
*** Config
**** Basic configuration
     :PROPERTIES:
     :ID:       cce879f8-f6b9-4cc8-9b96-823a29c3dabb
     :END:
#+BEGIN_SRC emacs-lisp :results none
(require 'mu4e)
(require 'mu4e-contrib) 
#+END_SRC
***** for ubuntu work machine 
#+BEGIN_SRC emacs-lisp :results none
(when (string= system-name "zuni")
(add-to-list 'load-path "~/mu/mu4e/")
 )
#+END_SRC


**** Folders 
     :PROPERTIES:
     :ID:       a7479aee-16e6-4cfa-ad56-1b98240ac02f
     :END:

 #+BEGIN_SRC emacs-lisp :results none
;; set your default maildir (if not ~/Maildir 
(setq mu4e-maildir "~/mbsync/")

 ;;location of my maildir
(setq mu4e-sent-folder "/[Gmail].All Mail"
      mu4e-drafts-folder "/[Gmail].Drafts"
      mu4e-trash-folder "/[Gmail].Bin"
      mu4e-refile-folder "/[Gmail].All Mail")
#+END_SRC
**** Retrieval and indexing
     :PROPERTIES:
     :ID:       62b88209-90ac-4fa4-8904-fced58fb083f
     :END:
 #+BEGIN_SRC emacs-lisp :results none
; get mail automatically
(setq mu4e-get-mail-command "/usr/bin/mbsync -a") ;

;;how often to launch it 
(setq mu4e-update-interval 100)

;; run in the background 
(setq mu4e-index-update-in-background t)

;;If the mail-retrieval process returns with a non-zero exit code, mu4e shows a warning
;(setq mu4e-index-update-error-warning  t)

;; update when new mail arrives the headers 
(setq mu4e-headers-auto-update t)

;;show the indexing process (to disable use nil 
;(setq mu4e-hide-index-messages nil)


;(setq mu4e-index-update-error-continue   t)

#+END_SRC
**** Sending
***** don't save message to Sent Messages, Gmail/IMAP takes care of this
#+BEGIN_SRC emacs-lisp  :results none
;; don't save message to Sent Messages, Gmail/IMAP takes care of this
(setq mu4e-sent-messages-behavior 'delete)
#+END_SRC
**** Headers view
***** TODO headers-fields
 #+BEGIN_SRC emacs-lisp  :results none
;; the headers to show in the headers list -- a pair of a field
;; and its width, with `nil' meaning 'unlimited'
;; (better only use that for the last field.
 ;; These are the defaults:
(setq mu4e-headers-fields
'( 
(:flags         .   6)
(:date          .  25)
(:from          .  22)
(:subject       .  nil)

))
 #+END_SRC


alternatove 
(:flags         .   6)
(:from          .  22)
(:subject       .  50)
(:human-date          . nil )

original order

(:date          .  25)
(:flags         .   6)
(:from          .  22)
(:subject       .  nil)


**** Keybinds
     :PROPERTIES:
     :ID:       b1c01af4-0655-44b4-a738-dbd3b8e56d79
     :END:
***** extra keybinds
      :PROPERTIES:
      :ID:       f690dba5-3d2c-40de-94d7-4e311ea1b56c
      :END:
  #+BEGIN_SRC emacs-lisp :results none
(define-key mu4e-headers-mode-map (kbd "w") 'z/mu4e-del-exe-func )
(define-key mu4e-headers-mode-map (kbd "\\") 'hydra-leader/body )
(define-key mu4e-view-mode-map (kbd "\\") 'hydra-leader/body )

(define-key mu4e-headers-mode-map (kbd "c") 'org-capture)
(define-key mu4e-headers-mode-map (kbd "F") 'z/mu4e-unflag-exe-func )

(define-key mu4e-headers-mode-map (kbd "C-c c") 'org-mu4e-store-and-capture)
(define-key mu4e-view-mode-map    (kbd "C-c c") 'org-mu4e-store-and-capture)


(define-key mu4e-view-mode-map    (kbd "C-c d") 'gnus-dired-attach)
  #+END_SRC

**** Message view  
***** scroll with space 
You can scroll down the message using SPC; if you do this at the end of a message,it automatically takes you to the next one. If you want to prevent this behavior, set mu4e-view-scroll-to-next to nil
#+BEGIN_SRC emacs-lisp  :results none
(setq mu4e-view-scroll-to-next nil)
#+END_SRC
***** Attachments
      :PROPERTIES:
      :ID:       ea031ce7-9490-4aaf-a3f0-f1188a257c8c
      :END:
****** define attachment dirs
       :PROPERTIES:
       :ID:       ec9f465a-0bfe-44fb-a685-a32a982cf400
       :END:
   #+BEGIN_SRC emacs-lisp :results none
   (setq mu4e-attachment-dir
     (lambda (fname mtype)
       (cond
	 ;; docfiles go to ~/Desktop
	 ((and fname (string-match "\\.pdf$" fname))  "~/Downloads/")
	 ((and fname (string-match "\\.doc$" fname))  "~/Uni/")
	 ;; ... other cases  ...
	 (t "~/Downloads")))) ;; everything else
   #+END_SRC
****** attach files during send at end of email
       :PROPERTIES:
       :ID:       97b54fb6-ce30-49f8-9d32-177e380e0d2d
       :END:
  http://mbork.pl/2015-11-28_Fixing_mml-attach-file_using_advice

  $Note-if you see starnge behivour this maybe a culprit$  
  #+BEGIN_SRC emacs-lisp  :results none
    ;; (defun mml-attach-file--go-to-eob (orig-fun &rest args)
    ;;   "Go to the end of buffer before attaching files."
    ;;   (save-excursion
    ;;     (save-restriction
    ;;       (widen)
    ;;       (goto-char (point-max))
    ;;       (apply orig-fun args))))

    ;; (advice-add 'mml-attach-file :around #'mml-attach-file--go-to-eob)
  #+END_SRC
****** Attachment Reminder in Emacs message-mode
https://www.topbug.net/blog/2016/12/09/attachment-reminder-in-emacs-message-mode/

#+BEGIN_SRC emacs-lisp  :results none
(defun my-message-current-line-cited-p ()
  "Indicate whether the line at point is a cited line."
  (save-match-data
    (string-match (concat "^" message-cite-prefix-regexp)
                  (buffer-substring (line-beginning-position) (line-end-position)))))

(defun my-message-says-attachment-p ()
  "Return t if the message suggests there can be an attachment."
  (save-excursion
    (goto-char (point-min))
    (save-match-data
      (let (search-result)
        (while
            (and (setq search-result (re-search-forward "\\(attach\\|pdf\\|file\\)" nil t))
                 (my-message-current-line-cited-p)))
        search-result))))

(defun my-message-has-attachment-p ()
  "Return t if the message has an attachment."
  (save-excursion
    (goto-char (point-min))
    (save-match-data
      (re-search-forward "<#part" nil t))))

(defun my-message-pre-send-check-attachment ()
  (when (and (my-message-says-attachment-p)
             (not (my-message-has-attachment-p)))
    (unless
        (y-or-n-p "The message suggests that you may want to attach something, but no attachment is found. Send anyway?")
      (error "It seems that an attachment is needed, but none was found. Aborting sending."))))
(add-hook 'message-send-hook 'my-message-pre-send-check-attachment)
#+END_SRC
****** add attachment using dired
 mark the file(s) in dired you would like to attach and press C-c RET C-a, and you’ll be asked whether to attach them to an existing message, or create a new one.

 #+BEGIN_SRC emacs-lisp  :results none
 (require 'gnus-dired)
 ;; make the `gnus-dired-mail-buffers' function also work on
 ;; message-mode derived modes, such as mu4e-compose-mode
 (defun gnus-dired-mail-buffers ()
   "Return a list of active message buffers."
   (let (buffers)
     (save-current-buffer
       (dolist (buffer (buffer-list t))
         (set-buffer buffer)
         (when (and (derived-mode-p 'message-mode)
                 (null message-sent-message-via))
           (push (buffer-name buffer) buffers))))
     (nreverse buffers)))

 (setq gnus-dired-mail-mode 'mu4e-user-agent)
 (add-hook 'dired-mode-hook 'turn-on-gnus-dired-mode)
 #+END_SRC
***** Viewing images inline
#+BEGIN_SRC emacs-lisp  :results none
;; enable inline images
(setq mu4e-view-show-images t)
;; use imagemagick, if available
(when (fboundp 'imagemagick-register-types)
  (imagemagick-register-types))
#+END_SRC
***** Displaying rich-text messages
#+BEGIN_SRC emacs-lisp  :results none
;preffer html  
(setq mu4e-view-prefer-html t)
;; use new shr command 
(setq mu4e-html2text-command 'mu4e-shr2text) 
#+END_SRC
**** Composing/Editing
***** don't send myself when reply to all
#+BEGIN_SRC emacs-lisp  :results none
(setq mu4e-compose-dont-reply-to-self  t)
#+END_SRC
***** make mu4e default mail program
emacs allows you to select an e-mail program as the default program it uses when you press C-x m (compose-mail), call report-emacs-bug and so on. If you want to use mu4e for this, you can do so by adding the following to your configuration:
 #+BEGIN_SRC emacs-lisp  :results none
(setq mail-user-agent 'mu4e-user-agent)
 #+END_SRC
**** Searching (bookmarks, queries etc)
***** TODO Bookmarks
      :PROPERTIES:
      :ID:       e417b58a-5b81-4842-aba9-26dfa3ad10e5
      :END:
 add more bookmarks after studying the query mechanism

  #+BEGIN_SRC emacs-lisp :results none
 (add-to-list 'mu4e-bookmarks
   (make-mu4e-bookmark
     :name  "flagged"
     :query "flag:flagged"
     :key ?f))

#+END_SRC

There is also M-x mu4e-headers-search-bookmark-edit (key B), which lets you edit the bookmarked query before invoking it
***** maildir-shortcuts 

 #+BEGIN_SRC emacs-lisp  :results none
 (setq mu4e-maildir-shortcuts
     '(("/INBOX"              . ?i)
       ("/[Gmail].Sent Mail"  . ?s)
       ("/[Gmail].Bin"        . ?b)
       ("/[Gmail].All Mail"   . ?a)))
 #+END_SRC

**** mbsync (isync) specific
     :PROPERTIES:
     :ID:       89f3f975-6e3d-4e68-b98e-83b244878726
     :END:
 #+BEGIN_SRC emacs-lisp  :results none
   ;; ;;rename files when moving
   ;; ;;NEEDED FOR MBSYNC
   ;; (setq mu4e-change-filenames-when-moving t)
#+END_SRC
**** helm mu
     :PROPERTIES:
     :ID:       6795319d-942f-4c8c-8dd0-677ecaae5ed6
     :END:
***** TODO search flagged
      :PROPERTIES:
      :ID:       049bb572-d8b1-4f3e-8e59-0330201d57c7
      :END:

 #+BEGIN_SRC emacs-lisp  :results none
  (defun z/helm-mu-flagged  ()
    "Search flagged mail"
    (interactive)
    (helm :sources '(helm-source-mu)
    :full-frame t
          :input "maildir:"/INBOX" flag:flagged "
          :candidate-number-limit 500))

 #+END_SRC
**** orgmode integration
     :PROPERTIES:
     :ID:       273929bd-ee11-49d9-a93f-4d6e62580795
     :END:
 http://www.djcbsoftware.nl/code/mu/mu4e/Creating-org_002dmode-links.html
 #+BEGIN_SRC emacs-lisp :results none
;;store org-mode links to messages
(require 'org-mu4e)
;;store link to message if in header view, not to header query
(setq org-mu4e-link-query-in-headers-mode nil)

;; when mail is sent, automatically convert org body to HTML
(setq org-mu4e-convert-to-html t)

 #+END_SRC
**** view settings
     :PROPERTIES:
     :ID:       a3106e39-ee40-4b67-9f78-b45bd0274627
     :END:
 #+BEGIN_SRC emacs-lisp :results none
 (setq mu4e-date-format-long "%d/%m/%Y (%H:%M:%S)")
 (setq mu4e-headers-date-format "%d/%m/%Y (%H:%M:%S)")

 ;can define a horizontal or vertical split 
 (setq mu4e-split-view 'horizontal)

 ;; use 'fancy' non-ascii characters in various places in mu4e
 (setq mu4e-use-fancy-chars t)

;; Silly mu4e only shows names in From: by default. Of course we also  want the addresses.
(setq mu4e-view-show-addresses t)

 ;; mu4e-action-view-in-browser is built into mu4e
 ;; by adding it to these lists of custom actions
 ;; it can be invoked by first pressing a, then selecting
 (add-to-list 'mu4e-headers-actions
              '("in browser" . mu4e-action-view-in-browser) t)
 (add-to-list 'mu4e-view-actions
              '("in browser" . mu4e-action-view-in-browser) t)
 #+END_SRC
**** mu4e functions
     :PROPERTIES:
     :ID:       8b045647-824d-4fb0-a687-d15d247b6ea3
     :END:
***** open mu4e inbox
      :PROPERTIES:
      :ID:       5839a5ee-c885-47e1-8305-a3f92e2bd84a
      :END:
  #+BEGIN_SRC emacs-lisp :results none
(defun z/mu4e-inbox ()
"Display the inbox."
(interactive)
;(mu4e)
(mu4e-headers-search "maildir:/INBOX"))
  #+END_SRC

***** open mu4e flagged
      :PROPERTIES:
      :ID:       e06fb69e-4420-49e1-ae90-ac8c7e12e036
      :END:
  #+BEGIN_SRC emacs-lisp :results none
  (defun z/mu4e-flagged ()
  "Display the inbox."
  (interactive)
  (mu4e)
  (mu4e-headers-search "maildir:/INBOX AND flag:flagged "))
  #+END_SRC
**** gmail integration
***** TODO star
#+BEGIN_SRC elisp
  ;; (add-hook 'mu4e-mark-execute-pre-hook 
  ;;           (lambda (mark msg) 
  ;;             (cond ((equal mark 'refile) (mu4e-action-retag-message msg "-\\Inbox")) 
  ;;                   ((equal mark 'trash) (mu4e-action-retag-message msg "-\\Inbox,-\\Starred")) 
  ;;                   ((equal mark 'flag) (mu4e-action-retag-message msg "-\\Inbox,\\Starred")) 
  ;;                   ((equal mark 'unflag) (mu4e-action-retag-message msg "-\\Starred"))))) 

#+END_SRC

#+RESULTS:



**** TODO Accounts
curent commented below code kills compose..need to investiagete 
***** Setting accounts
https://github.com/xgarrido/emacs-starter-kit/blob/master/starter-kit.org

  #+BEGIN_SRC emacs-lisp
    ;; (defvar sk-mu4e-account-alist
    ;;   '(("BGU"
    ;;      (user-mail-address  "izeltak@bgu.ac.il")
    ;;      (user-full-name     "Zeltak zeltak")
    ;;      (mu4e-compose-signature (concat
    ;;                               "                                                                     \n"
    ;;                               " Prof. Zeltak zeltak                                                    \n"
    ;;                               )))
    ;;     ("Gmail"
    ;;      (user-mail-address  "izeltak@gmail.com")
    ;;      (user-full-name     "Zeltak")
    ;;      (mu4e-compose-signature (concat
    ;;                               "zeltak\n"
    ;;                               "\n")))))

    ;; (setq mu4e-user-mail-address-list
    ;;       (mapcar (lambda (account) (cadr (assq 'user-mail-address account)))
    ;;               sk-mu4e-account-alist))
  #+END_SRC

  #+RESULTS:

***** Set account when composing mail
  #+BEGIN_SRC emacs-lisp
    ;; (defun sk-mu4e-set-account ()
    ;;   "Set the account for composing a message."
    ;;   (let* ((account
    ;;           (if mu4e-compose-parent-message
    ;;               (let ((maildir (mu4e-message-field mu4e-compose-parent-message :maildir)))
    ;;                 (string-match "/\\(.*?\\)/" maildir)
    ;;                 (match-string 1 maildir))
    ;; 	    (completing-read (format "Compose with account: (%s) "
    ;; 				     (mapconcat #'(lambda (var) (car var))
    ;;                                                 sk-mu4e-account-alist "/"))
    ;; 			     (mapcar #'(lambda (var) (car var)) sk-mu4e-account-alist)
    ;; 			     nil t nil nil (caar sk-mu4e-account-alist))))
    ;;          (account-vars (cdr (assoc account sk-mu4e-account-alist))))
    ;;     (if account-vars
    ;;         (mapc #'(lambda (var)
    ;;                   (set (car var) (cadr var)))
    ;;               account-vars)
    ;;       (error "No email account found"))))

    ;; ;; ask for account when composing mail
    ;; (add-hook 'mu4e-compose-pre-hook 'sk-mu4e-set-account)
  #+END_SRC

  #+RESULTS:
*** DOCU
**** Queries
***** examples
Get all messages regarding bananas from John with an attachment:
from:john flag:attach bananas

Get all messages with subject wombat in June 2009
subject:wombat date:20090601..20090630

Get all messages with PDF attachments in the /projects folder
maildir:/projects mime:application/pdf

Get all messages about Rupert in the /Sent Items folder. Note that maildirs with spaces must be quoted.
maildir:"/Sent Items" rupert

Get all messages from Jim without an attachment:
from:jim AND NOT flag:attach

Get all messages with Alice in one of the contacts-fields (to, from, cc, bcc):
contact:alice

Get all unread messages where the subject mentions Ångström: 
subject:Ångström flag:unread


Get all unread messages between Mar-2002 and Aug-2003 about some bird:
date:20020301..20030831 nightingale flag:unread

Get today’s messages:
date:today..now

Get all messages we got in the last two weeks regarding emacs:
date:2w..now emacs

Get messages from the Mu mailing list:
list:mu-discuss.googlegroups.com

Get messages with a subject soccer, Socrates, society, ...; 

note that the ’*’-wildcard can only appear as a term’s rightmost character:
subject:soc*

Get all messages not sent to a mailing-list:
NOT flag:list

Get all mails with attachments with filenames starting with pic; note that the ’*’ wildcard can only appear as the term’s rightmost character:
file:pic*

Get all messages with PDF-attachments:
mime:application/pdf

Get all messages with image attachments, and note that the ’*’ wildcard can only appear as the term’s rightmost character:

mime:image/*
***** Que mail 

toggle [m]ail sending mode (direct) toggles between sending mail directly, and queuing it first (for example, when you are offline), and [f]lush queued mail flushes any queued mail.
**** The headers view
The headers view shows the results of a query. The header-line shows the names of the fields. Below that, there is a line with those fields, for each matching message, followed by a footer line. The major-mode for the headers view is mu4e-headers-mode.
**** keybinds 
***** important binds 
y- swap between header and message 
e- attchments
C-u e- save multiple attachments
A w - open attachment with external app 
h toggle html/text view 

C-c C-k      kill the message buffer (the message remains in the draft folder)
C-c C-a      attach a file (pro-tip: drag & drop works as well)


***** header view binds 
Using the below key bindings, you can do various things with these messages; these actions are also listed in the Headers menu in the emacs menu bar.

key          description
===========================================================
n,p          view the next, previous message
],[          move to the next, previous unread message
y            select the message view (if it's visible)
RET          open the message at point in the message view

searching
---------
s            search
S            edit last query
/            narrow the search
b            search bookmark
B            edit bookmark before search
j            jump to maildir
M-left,\     previous query
M-right      next query

O            change sort order
P            toggle threading
Q            toggle full-search
V            toggle skip-duplicates
W            toggle include-related

marking
-------
d            mark for moving to the trash folder
=            mark for removing trash flag ('untrash')
DEL,D        mark for complete deletion
m            mark for moving to another maildir folder
r            mark for refiling
+,-          mark for flagging/unflagging
?,!          mark message as unread, read

u            unmark message at point
U            unmark *all* messages

%            mark based on a regular expression
T,t          mark whole thread, subthread

<insert>,*   mark for 'something' (decide later)
#            resolve deferred 'something' marks

x            execute actions for the marked messages

composition
-----------
R,F,C        reply/forward/compose
E            edit (only allowed for draft messages)


misc
----
;            switch focus
a            execute some custom action on a header
| pipe message through shell command |
C-+,C--      increase / decrease the number of headers shown
H            get help
C-S-u        update mail & reindex
q            leave the headers buffer
***** message view binds
key          description
==============================================================
n,p          view the next, previous message
],[          move to the next, previous unread message
y            select the headers view (if it's visible)

RET          scroll down
M-RET        open URL at point / attachment at point

SPC          scroll down, if at end, move to next message
S-SPC        scroll up

searching
---------
s            search
e            edit last query
/            narrow the search
b            search bookmark
B            edit bookmark before search
j            jump to maildir

M-left       previous query
M-right      next query

marking
-------
d            mark for moving to the trash folder
=            mark for removing trash flag ('untrash')
DEL,D        mark for complete deletion
m            mark for moving to another maildir folder
r            mark for refiling
+,-          mark for flagging/unflagging

u            unmark message at point
U            unmark *all* messages

%            mark based on a regular expression
T,t          mark whole thread, subthread

<insert>,*   mark for 'something' (decide later)
#            resolve deferred 'something' marks

x            execute actions for the marked messages

composition
-----------
R,F,C        reply/forward/compose
E            edit (only allowed for draft messages)

actions
-------
g            go to (visit) numbered URL (using `browse-url')
(or: <mouse-1> or M-RET with point on url)
C-u g visits multiple URLs
f            fetch (download )the numbered URL.
C-u f fetches multiple URLs
k            save the numbered URL in the kill-ring.
C-u k saves multiple URLs

e            extract (save) attachment (asks for number)
(or: <mouse-2> or S-RET with point on attachment)
C-u e extracts multiple attachments
o            open attachment (asks for number)
(or: <mouse-1> or M-RET with point on attachment)

a            execute some custom action on the message
A            execute some custom action on an attachment

misc
----
;            switch focus
c            copy address at point (with C-u copy long version)

h            toggle between html/text (if available)
w            toggle line wrapping
#            toggle show/hide cited parts

v            show details about the cryptographic signature

.            show the raw message view. 'q' takes you back.
C-+,C--      increase / decrease the number of headers shown
H            get help
C-S-u        update mail & reindex
q            leave the message view
* Latex
** Functions
*** cleanup references 
#+BEGIN_SRC emacs-lisp  :results none
  (defun z/cleanup-refs ()
"Delete portions of reference section within region."
(interactive)
(let ((start (region-beginning)))
  (while (re-search-forward " ?([0-9]+ Citations[\n -~]*?)" (region-end) t) (replace-match ""))
  (goto-char start)
  (while (re-search-forward "\\(C\\|PD\\|PI\\)\\>" (region-end) t) (replace-match ""))
  (goto-char (region-end))
))

#+END_SRC
** settings 
*** export to PDF settings
#+BEGIN_SRC emacs-lisp  :results none
(setq org-latex-pdf-process
      '("pdflatex -interaction nonstopmode -output-directory %o %f"
	"bibtex %b"
	"pdflatex -interaction nonstopmode -output-directory %o %f"
	"pdflatex -interaction nonstopmode -output-directory %o %f")
)
#+END_SRC
* Emacs 25 ready stuff
  :PROPERTIES:
  :ID:       8d850e7a-4e8c-42b0-99c0-1ba8abcf4c41
  :END:
*** save position
 You can save the cursor position for every file you opened. So, next time you open the file, the cursor will be at the position you last opened it.

 Put this code in your emacs init file:

 #+BEGIN_SRC emacs-lisp  :results none
; remember cursor position, for emacs 25.1 or later
(save-place-mode 1)
 #+END_SRC

*** compress to tar in dired
    :PROPERTIES:
    :ID:       8045ec44-fb68-496c-b083-c749daa8b947
    :END:
  this will only work on Emacs 25..keep track!
  http://oremacs.com/2015/10/23/dired-compress/

  This new command dired-do-compress-to, bound to c, will prompt me for a file name of the output archive. So now it's easier to type in that file name, if you use ido-mode / ivy-mode / helm-mode. What's more, the command will be automatically determined from the archive extension and executed. Here's the corresponding customization variable:

  #+BEGIN_SRC emacs-lisp :results none
    ;; (define-key dired-mode-map "c" 'dired-do-compress-to)

    ;; (defvar dired-compress-files-alist
    ;;   '(("\\.tar\\.gz\\'" . "tar -c %i | gzip -c9 > %o")
    ;;     ("\\.zip\\'" . "zip %o -r --filesync %i"))
    ;;   "Control the compression shell command for `dired-do-compress-to'.

    ;; Each element is (REGEXP . CMD), where REGEXP is the name of the
    ;; archive to which you want to compress, and CMD the the
    ;; corresponding command.

    ;; Within CMD, %i denotes the input file(s), and %o denotes the
    ;; output file. %i path(s) are relative, while %o is absolute.")

  #+END_SRC


* EOF 
  :PROPERTIES:
  :ID:       03bae773-afdf-48a1-94b0-fff3472b7fe7
  :END:
this has to be at the end since this is a init file it wont know if its a safe variable until it goes through the whole init 
also $Note$ that since this is at the end the emacs syntax is different
https://www.gnu.org/software/emacs/manual/html_node/emacs/Specifying-File-Variables.html



  
